import { Construct } from 'constructs';
import * as cdktf from 'cdktf';
/**
 * @stability stable
 */
export interface AccessContextManagerAccessLevelConditionConfig extends cdktf.TerraformMetaArguments {
    /**
     * The name of the Access Level to add this condition to.
     *
     * @stability stable
     */
    readonly accessLevel: string;
    /**
     * A list of CIDR block IP subnetwork specification.
     *
     * May be IPv4
     * or IPv6.
     * Note that for a CIDR IP address block, the specified IP address
     * portion must be properly truncated (i.e. all the host bits must
     * be zero) or the input is considered malformed. For example,
     * "192.0.2.0/24" is accepted but "192.0.2.1/24" is not. Similarly,
     * for IPv6, "2001:db8::/32" is accepted whereas "2001:db8::1/32"
     * is not. The originating IP of a request must be in one of the
     * listed subnets in order for this Condition to be true.
     * If empty, all IP addresses are allowed.
     *
     * @stability stable
     */
    readonly ipSubnetworks?: string[];
    /**
     * An allowed list of members (users, service accounts). Using groups is not supported yet.
     *
     * The signed-in user originating the request must be a part of one
     * of the provided members. If not specified, a request may come
     * from any user (logged in/not logged in, not present in any
     * groups, etc.).
     * Formats: 'user:{emailid}', 'serviceAccount:{emailid}'
     *
     * @stability stable
     */
    readonly members?: string[];
    /**
     * Whether to negate the Condition.
     *
     * If true, the Condition becomes
     * a NAND over its non-empty fields, each field must be false for
     * the Condition overall to be satisfied. Defaults to false.
     *
     * @stability stable
     */
    readonly negate?: boolean;
    /**
     * The request must originate from one of the provided countries/regions.
     *
     * Format: A valid ISO 3166-1 alpha-2 code.
     *
     * @stability stable
     */
    readonly regions?: string[];
    /**
     * A list of other access levels defined in the same Policy, referenced by resource name.
     *
     * Referencing an AccessLevel which
     * does not exist is an error. All access levels listed must be
     * granted for the Condition to be true.
     * Format: accessPolicies/{policy_id}/accessLevels/{short_name}
     *
     * @stability stable
     */
    readonly requiredAccessLevels?: string[];
    /**
     * device_policy block.
     *
     * @stability stable
     */
    readonly devicePolicy?: AccessContextManagerAccessLevelConditionDevicePolicy[];
    /**
     * timeouts block.
     *
     * @stability stable
     */
    readonly timeouts?: AccessContextManagerAccessLevelConditionTimeouts;
}
/**
 * @stability stable
 */
export interface AccessContextManagerAccessLevelConditionDevicePolicyOsConstraints {
    /**
     * The minimum allowed OS version.
     *
     * If not set, any version
     * of this OS satisfies the constraint.
     * Format: "major.minor.patch" such as "10.5.301", "9.2.1".
     *
     * @stability stable
     */
    readonly minimumVersion?: string;
    /**
     * The operating system type of the device.
     *
     * Possible values: ["OS_UNSPECIFIED", "DESKTOP_MAC", "DESKTOP_WINDOWS", "DESKTOP_LINUX", "DESKTOP_CHROME_OS"]
     *
     * @stability stable
     */
    readonly osType: string;
}
/**
 * @stability stable
 */
export interface AccessContextManagerAccessLevelConditionDevicePolicy {
    /**
     * A list of allowed device management levels.
     *
     * An empty list allows all management levels. Possible values: ["MANAGEMENT_UNSPECIFIED", "NONE", "BASIC", "COMPLETE"]
     *
     * @stability stable
     */
    readonly allowedDeviceManagementLevels?: string[];
    /**
     * A list of allowed encryptions statuses.
     *
     * An empty list allows all statuses. Possible values: ["ENCRYPTION_UNSPECIFIED", "ENCRYPTION_UNSUPPORTED", "UNENCRYPTED", "ENCRYPTED"]
     *
     * @stability stable
     */
    readonly allowedEncryptionStatuses?: string[];
    /**
     * Whether the device needs to be approved by the customer admin.
     *
     * @stability stable
     */
    readonly requireAdminApproval?: boolean;
    /**
     * Whether the device needs to be corp owned.
     *
     * @stability stable
     */
    readonly requireCorpOwned?: boolean;
    /**
     * Whether or not screenlock is required for the DevicePolicy to be true.
     *
     * Defaults to false.
     *
     * @stability stable
     */
    readonly requireScreenLock?: boolean;
    /**
     * os_constraints block.
     *
     * @stability stable
     */
    readonly osConstraints?: AccessContextManagerAccessLevelConditionDevicePolicyOsConstraints[];
}
/**
 * @stability stable
 */
export interface AccessContextManagerAccessLevelConditionTimeouts {
    /**
     * @stability stable
     */
    readonly create?: string;
    /**
     * @stability stable
     */
    readonly delete?: string;
}
/**
 * @stability stable
 */
export declare class AccessContextManagerAccessLevelCondition extends cdktf.TerraformResource {
    /**
     * @stability stable
     */
    constructor(scope: Construct, id: string, config: AccessContextManagerAccessLevelConditionConfig);
    private _accessLevel;
    /**
     * @stability stable
     */
    get accessLevel(): string;
    /**
     * @stability stable
     */
    set accessLevel(value: string);
    /**
     * @stability stable
     */
    get accessLevelInput(): string;
    /**
     * @stability stable
     */
    get id(): string;
    private _ipSubnetworks?;
    /**
     * @stability stable
     */
    get ipSubnetworks(): string[];
    /**
     * @stability stable
     */
    set ipSubnetworks(value: string[]);
    /**
     * @stability stable
     */
    resetIpSubnetworks(): void;
    /**
     * @stability stable
     */
    get ipSubnetworksInput(): string[] | undefined;
    private _members?;
    /**
     * @stability stable
     */
    get members(): string[];
    /**
     * @stability stable
     */
    set members(value: string[]);
    /**
     * @stability stable
     */
    resetMembers(): void;
    /**
     * @stability stable
     */
    get membersInput(): string[] | undefined;
    private _negate?;
    /**
     * @stability stable
     */
    get negate(): boolean;
    /**
     * @stability stable
     */
    set negate(value: boolean);
    /**
     * @stability stable
     */
    resetNegate(): void;
    /**
     * @stability stable
     */
    get negateInput(): boolean | undefined;
    private _regions?;
    /**
     * @stability stable
     */
    get regions(): string[];
    /**
     * @stability stable
     */
    set regions(value: string[]);
    /**
     * @stability stable
     */
    resetRegions(): void;
    /**
     * @stability stable
     */
    get regionsInput(): string[] | undefined;
    private _requiredAccessLevels?;
    /**
     * @stability stable
     */
    get requiredAccessLevels(): string[];
    /**
     * @stability stable
     */
    set requiredAccessLevels(value: string[]);
    /**
     * @stability stable
     */
    resetRequiredAccessLevels(): void;
    /**
     * @stability stable
     */
    get requiredAccessLevelsInput(): string[] | undefined;
    private _devicePolicy?;
    /**
     * @stability stable
     */
    get devicePolicy(): AccessContextManagerAccessLevelConditionDevicePolicy[];
    /**
     * @stability stable
     */
    set devicePolicy(value: AccessContextManagerAccessLevelConditionDevicePolicy[]);
    /**
     * @stability stable
     */
    resetDevicePolicy(): void;
    /**
     * @stability stable
     */
    get devicePolicyInput(): AccessContextManagerAccessLevelConditionDevicePolicy[] | undefined;
    private _timeouts?;
    /**
     * @stability stable
     */
    get timeouts(): AccessContextManagerAccessLevelConditionTimeouts;
    /**
     * @stability stable
     */
    set timeouts(value: AccessContextManagerAccessLevelConditionTimeouts);
    /**
     * @stability stable
     */
    resetTimeouts(): void;
    /**
     * @stability stable
     */
    get timeoutsInput(): AccessContextManagerAccessLevelConditionTimeouts | undefined;
    /**
     * @stability stable
     */
    protected synthesizeAttributes(): {
        [name: string]: any;
    };
}
