import { Construct } from 'constructs';
import * as cdktf from 'cdktf';
/**
 * @stability stable
 */
export interface AccessContextManagerServicePerimeterConfig extends cdktf.TerraformMetaArguments {
    /**
     * Description of the ServicePerimeter and its use.
     *
     * Does not affect
     * behavior.
     *
     * @stability stable
     */
    readonly description?: string;
    /**
     * Resource name for the ServicePerimeter.
     *
     * The short_name component must
     * begin with a letter and only include alphanumeric and '_'.
     * Format: accessPolicies/{policy_id}/servicePerimeters/{short_name}
     *
     * @stability stable
     */
    readonly name: string;
    /**
     * The AccessPolicy this ServicePerimeter lives in.
     *
     * Format: accessPolicies/{policy_id}
     *
     * @stability stable
     */
    readonly parent: string;
    /**
     * Specifies the type of the Perimeter.
     *
     * There are two types: regular and
     * bridge. Regular Service Perimeter contains resources, access levels,
     * and restricted services. Every resource can be in at most
     * ONE regular Service Perimeter.
     *
     * In addition to being in a regular service perimeter, a resource can also
     * be in zero or more perimeter bridges. A perimeter bridge only contains
     * resources. Cross project operations are permitted if all effected
     * resources share some perimeter (whether bridge or regular). Perimeter
     * Bridge does not contain access levels or services: those are governed
     * entirely by the regular perimeter that resource is in.
     *
     * Perimeter Bridges are typically useful when building more complex
     * topologies with many independent perimeters that need to share some data
     * with a common perimeter, but should not be able to share data among
     * themselves. Default value: "PERIMETER_TYPE_REGULAR" Possible values: ["PERIMETER_TYPE_REGULAR", "PERIMETER_TYPE_BRIDGE"]
     *
     * @stability stable
     */
    readonly perimeterType?: string;
    /**
     * Human readable title.
     *
     * Must be unique within the Policy.
     *
     * @stability stable
     */
    readonly title: string;
    /**
     * Use explicit dry run spec flag.
     *
     * Ordinarily, a dry-run spec implicitly exists
     * for all Service Perimeters, and that spec is identical to the status for those
     * Service Perimeters. When this flag is set, it inhibits the generation of the
     * implicit spec, thereby allowing the user to explicitly provide a
     * configuration ("spec") to use in a dry-run version of the Service Perimeter.
     * This allows the user to test changes to the enforced config ("status") without
     * actually enforcing them. This testing is done through analyzing the differences
     * between currently enforced and suggested restrictions. useExplicitDryRunSpec must
     * bet set to True if any of the fields in the spec are set to non-default values.
     *
     * @stability stable
     */
    readonly useExplicitDryRunSpec?: boolean;
    /**
     * spec block.
     *
     * @stability stable
     */
    readonly spec?: AccessContextManagerServicePerimeterSpec[];
    /**
     * status block.
     *
     * @stability stable
     */
    readonly status?: AccessContextManagerServicePerimeterStatus[];
    /**
     * timeouts block.
     *
     * @stability stable
     */
    readonly timeouts?: AccessContextManagerServicePerimeterTimeouts;
}
/**
 * @stability stable
 */
export interface AccessContextManagerServicePerimeterSpecVpcAccessibleServices {
    /**
     * The list of APIs usable within the Service Perimeter.
     *
     * Must be empty unless 'enableRestriction' is True.
     *
     * @stability stable
     */
    readonly allowedServices?: string[];
    /**
     * Whether to restrict API calls within the Service Perimeter to the list of APIs specified in 'allowedServices'.
     *
     * @stability stable
     */
    readonly enableRestriction?: boolean;
}
/**
 * @stability stable
 */
export interface AccessContextManagerServicePerimeterSpec {
    /**
     * A list of AccessLevel resource names that allow resources within the ServicePerimeter to be accessed from the internet.
     *
     * AccessLevels listed must be in the same policy as this
     * ServicePerimeter. Referencing a nonexistent AccessLevel is a
     * syntax error. If no AccessLevel names are listed, resources within
     * the perimeter can only be accessed via GCP calls with request
     * origins within the perimeter. For Service Perimeter Bridge, must
     * be empty.
     *
     * Format: accessPolicies/{policy_id}/accessLevels/{access_level_name}
     *
     * @stability stable
     */
    readonly accessLevels?: string[];
    /**
     * A list of GCP resources that are inside of the service perimeter.
     *
     * Currently only projects are allowed.
     * Format: projects/{project_number}
     *
     * @stability stable
     */
    readonly resources?: string[];
    /**
     * GCP services that are subject to the Service Perimeter restrictions.
     *
     * Must contain a list of services. For example, if
     * 'storage.googleapis.com' is specified, access to the storage
     * buckets inside the perimeter must meet the perimeter's access
     * restrictions.
     *
     * @stability stable
     */
    readonly restrictedServices?: string[];
    /**
     * vpc_accessible_services block.
     *
     * @stability stable
     */
    readonly vpcAccessibleServices?: AccessContextManagerServicePerimeterSpecVpcAccessibleServices[];
}
/**
 * @stability stable
 */
export interface AccessContextManagerServicePerimeterStatusVpcAccessibleServices {
    /**
     * The list of APIs usable within the Service Perimeter.
     *
     * Must be empty unless 'enableRestriction' is True.
     *
     * @stability stable
     */
    readonly allowedServices?: string[];
    /**
     * Whether to restrict API calls within the Service Perimeter to the list of APIs specified in 'allowedServices'.
     *
     * @stability stable
     */
    readonly enableRestriction?: boolean;
}
/**
 * @stability stable
 */
export interface AccessContextManagerServicePerimeterStatus {
    /**
     * A list of AccessLevel resource names that allow resources within the ServicePerimeter to be accessed from the internet.
     *
     * AccessLevels listed must be in the same policy as this
     * ServicePerimeter. Referencing a nonexistent AccessLevel is a
     * syntax error. If no AccessLevel names are listed, resources within
     * the perimeter can only be accessed via GCP calls with request
     * origins within the perimeter. For Service Perimeter Bridge, must
     * be empty.
     *
     * Format: accessPolicies/{policy_id}/accessLevels/{access_level_name}
     *
     * @stability stable
     */
    readonly accessLevels?: string[];
    /**
     * A list of GCP resources that are inside of the service perimeter.
     *
     * Currently only projects are allowed.
     * Format: projects/{project_number}
     *
     * @stability stable
     */
    readonly resources?: string[];
    /**
     * GCP services that are subject to the Service Perimeter restrictions.
     *
     * Must contain a list of services. For example, if
     * 'storage.googleapis.com' is specified, access to the storage
     * buckets inside the perimeter must meet the perimeter's access
     * restrictions.
     *
     * @stability stable
     */
    readonly restrictedServices?: string[];
    /**
     * vpc_accessible_services block.
     *
     * @stability stable
     */
    readonly vpcAccessibleServices?: AccessContextManagerServicePerimeterStatusVpcAccessibleServices[];
}
/**
 * @stability stable
 */
export interface AccessContextManagerServicePerimeterTimeouts {
    /**
     * @stability stable
     */
    readonly create?: string;
    /**
     * @stability stable
     */
    readonly delete?: string;
    /**
     * @stability stable
     */
    readonly update?: string;
}
/**
 * @stability stable
 */
export declare class AccessContextManagerServicePerimeter extends cdktf.TerraformResource {
    /**
     * @stability stable
     */
    constructor(scope: Construct, id: string, config: AccessContextManagerServicePerimeterConfig);
    /**
     * @stability stable
     */
    get createTime(): string;
    private _description?;
    /**
     * @stability stable
     */
    get description(): string;
    /**
     * @stability stable
     */
    set description(value: string);
    /**
     * @stability stable
     */
    resetDescription(): void;
    /**
     * @stability stable
     */
    get descriptionInput(): string | undefined;
    /**
     * @stability stable
     */
    get id(): string;
    private _name;
    /**
     * @stability stable
     */
    get name(): string;
    /**
     * @stability stable
     */
    set name(value: string);
    /**
     * @stability stable
     */
    get nameInput(): string;
    private _parent;
    /**
     * @stability stable
     */
    get parent(): string;
    /**
     * @stability stable
     */
    set parent(value: string);
    /**
     * @stability stable
     */
    get parentInput(): string;
    private _perimeterType?;
    /**
     * @stability stable
     */
    get perimeterType(): string;
    /**
     * @stability stable
     */
    set perimeterType(value: string);
    /**
     * @stability stable
     */
    resetPerimeterType(): void;
    /**
     * @stability stable
     */
    get perimeterTypeInput(): string | undefined;
    private _title;
    /**
     * @stability stable
     */
    get title(): string;
    /**
     * @stability stable
     */
    set title(value: string);
    /**
     * @stability stable
     */
    get titleInput(): string;
    /**
     * @stability stable
     */
    get updateTime(): string;
    private _useExplicitDryRunSpec?;
    /**
     * @stability stable
     */
    get useExplicitDryRunSpec(): boolean;
    /**
     * @stability stable
     */
    set useExplicitDryRunSpec(value: boolean);
    /**
     * @stability stable
     */
    resetUseExplicitDryRunSpec(): void;
    /**
     * @stability stable
     */
    get useExplicitDryRunSpecInput(): boolean | undefined;
    private _spec?;
    /**
     * @stability stable
     */
    get spec(): AccessContextManagerServicePerimeterSpec[];
    /**
     * @stability stable
     */
    set spec(value: AccessContextManagerServicePerimeterSpec[]);
    /**
     * @stability stable
     */
    resetSpec(): void;
    /**
     * @stability stable
     */
    get specInput(): AccessContextManagerServicePerimeterSpec[] | undefined;
    private _status?;
    /**
     * @stability stable
     */
    get status(): AccessContextManagerServicePerimeterStatus[];
    /**
     * @stability stable
     */
    set status(value: AccessContextManagerServicePerimeterStatus[]);
    /**
     * @stability stable
     */
    resetStatus(): void;
    /**
     * @stability stable
     */
    get statusInput(): AccessContextManagerServicePerimeterStatus[] | undefined;
    private _timeouts?;
    /**
     * @stability stable
     */
    get timeouts(): AccessContextManagerServicePerimeterTimeouts;
    /**
     * @stability stable
     */
    set timeouts(value: AccessContextManagerServicePerimeterTimeouts);
    /**
     * @stability stable
     */
    resetTimeouts(): void;
    /**
     * @stability stable
     */
    get timeoutsInput(): AccessContextManagerServicePerimeterTimeouts | undefined;
    /**
     * @stability stable
     */
    protected synthesizeAttributes(): {
        [name: string]: any;
    };
}
