import { Construct } from 'constructs';
import * as cdktf from 'cdktf';
/**
 * @stability stable
 */
export interface ActiveDirectoryDomainTrustConfig extends cdktf.TerraformMetaArguments {
    /**
     * The fully qualified domain name.
     *
     * e.g. mydomain.myorganization.com, with the restrictions,
     * https://cloud.google.com/managed-microsoft-ad/reference/rest/v1/projects.locations.global.domains.
     *
     * @stability stable
     */
    readonly domain: string;
    /**
     * @stability stable
     */
    readonly project?: string;
    /**
     * Whether the trusted side has forest/domain wide access or selective access to an approved set of resources.
     *
     * @stability stable
     */
    readonly selectiveAuthentication?: boolean;
    /**
     * The target DNS server IP addresses which can resolve the remote domain involved in the trust.
     *
     * @stability stable
     */
    readonly targetDnsIpAddresses: string[];
    /**
     * The fully qualified target domain name which will be in trust with the current domain.
     *
     * @stability stable
     */
    readonly targetDomainName: string;
    /**
     * The trust direction, which decides if the current domain is trusted, trusting, or both.
     *
     * Possible values: ["INBOUND", "OUTBOUND", "BIDIRECTIONAL"]
     *
     * @stability stable
     */
    readonly trustDirection: string;
    /**
     * The trust secret used for the handshake with the target domain.
     *
     * This will not be stored.
     *
     * @stability stable
     */
    readonly trustHandshakeSecret: string;
    /**
     * The type of trust represented by the trust resource.
     *
     * Possible values: ["FOREST", "EXTERNAL"]
     *
     * @stability stable
     */
    readonly trustType: string;
    /**
     * timeouts block.
     *
     * @stability stable
     */
    readonly timeouts?: ActiveDirectoryDomainTrustTimeouts;
}
/**
 * @stability stable
 */
export interface ActiveDirectoryDomainTrustTimeouts {
    /**
     * @stability stable
     */
    readonly create?: string;
    /**
     * @stability stable
     */
    readonly delete?: string;
    /**
     * @stability stable
     */
    readonly update?: string;
}
/**
 * @stability stable
 */
export declare class ActiveDirectoryDomainTrust extends cdktf.TerraformResource {
    /**
     * @stability stable
     */
    constructor(scope: Construct, id: string, config: ActiveDirectoryDomainTrustConfig);
    private _domain;
    /**
     * @stability stable
     */
    get domain(): string;
    /**
     * @stability stable
     */
    set domain(value: string);
    /**
     * @stability stable
     */
    get domainInput(): string;
    /**
     * @stability stable
     */
    get id(): string;
    private _project?;
    /**
     * @stability stable
     */
    get project(): string;
    /**
     * @stability stable
     */
    set project(value: string);
    /**
     * @stability stable
     */
    resetProject(): void;
    /**
     * @stability stable
     */
    get projectInput(): string | undefined;
    private _selectiveAuthentication?;
    /**
     * @stability stable
     */
    get selectiveAuthentication(): boolean;
    /**
     * @stability stable
     */
    set selectiveAuthentication(value: boolean);
    /**
     * @stability stable
     */
    resetSelectiveAuthentication(): void;
    /**
     * @stability stable
     */
    get selectiveAuthenticationInput(): boolean | undefined;
    private _targetDnsIpAddresses;
    /**
     * @stability stable
     */
    get targetDnsIpAddresses(): string[];
    /**
     * @stability stable
     */
    set targetDnsIpAddresses(value: string[]);
    /**
     * @stability stable
     */
    get targetDnsIpAddressesInput(): string[];
    private _targetDomainName;
    /**
     * @stability stable
     */
    get targetDomainName(): string;
    /**
     * @stability stable
     */
    set targetDomainName(value: string);
    /**
     * @stability stable
     */
    get targetDomainNameInput(): string;
    private _trustDirection;
    /**
     * @stability stable
     */
    get trustDirection(): string;
    /**
     * @stability stable
     */
    set trustDirection(value: string);
    /**
     * @stability stable
     */
    get trustDirectionInput(): string;
    private _trustHandshakeSecret;
    /**
     * @stability stable
     */
    get trustHandshakeSecret(): string;
    /**
     * @stability stable
     */
    set trustHandshakeSecret(value: string);
    /**
     * @stability stable
     */
    get trustHandshakeSecretInput(): string;
    private _trustType;
    /**
     * @stability stable
     */
    get trustType(): string;
    /**
     * @stability stable
     */
    set trustType(value: string);
    /**
     * @stability stable
     */
    get trustTypeInput(): string;
    private _timeouts?;
    /**
     * @stability stable
     */
    get timeouts(): ActiveDirectoryDomainTrustTimeouts;
    /**
     * @stability stable
     */
    set timeouts(value: ActiveDirectoryDomainTrustTimeouts);
    /**
     * @stability stable
     */
    resetTimeouts(): void;
    /**
     * @stability stable
     */
    get timeoutsInput(): ActiveDirectoryDomainTrustTimeouts | undefined;
    /**
     * @stability stable
     */
    protected synthesizeAttributes(): {
        [name: string]: any;
    };
}
