import { Construct } from 'constructs';
import * as cdktf from 'cdktf';
/**
 * @stability stable
 */
export interface AppEngineApplicationConfig extends cdktf.TerraformMetaArguments {
    /**
     * The domain to authenticate users with when using App Engine's User API.
     *
     * @stability stable
     */
    readonly authDomain?: string;
    /**
     * @stability stable
     */
    readonly databaseType?: string;
    /**
     * The location to serve the app from.
     *
     * @stability stable
     */
    readonly locationId: string;
    /**
     * The project ID to create the application under.
     *
     * @stability stable
     */
    readonly project?: string;
    /**
     * The serving status of the app.
     *
     * @stability stable
     */
    readonly servingStatus?: string;
    /**
     * feature_settings block.
     *
     * @stability stable
     */
    readonly featureSettings?: AppEngineApplicationFeatureSettings[];
    /**
     * iap block.
     *
     * @stability stable
     */
    readonly iap?: AppEngineApplicationIap[];
    /**
     * timeouts block.
     *
     * @stability stable
     */
    readonly timeouts?: AppEngineApplicationTimeouts;
}
/**
 * @stability stable
 */
export declare class AppEngineApplicationUrlDispatchRule extends cdktf.ComplexComputedList {
    /**
     * @stability stable
     */
    get domain(): string;
    /**
     * @stability stable
     */
    get path(): string;
    /**
     * @stability stable
     */
    get service(): string;
}
/**
 * @stability stable
 */
export interface AppEngineApplicationFeatureSettings {
    /**
     * @stability stable
     */
    readonly splitHealthChecks: boolean;
}
/**
 * @stability stable
 */
export interface AppEngineApplicationIap {
    /**
     * Adapted for use with the app.
     *
     * @stability stable
     */
    readonly enabled?: boolean;
    /**
     * OAuth2 client ID to use for the authentication flow.
     *
     * @stability stable
     */
    readonly oauth2ClientId: string;
    /**
     * OAuth2 client secret to use for the authentication flow.
     *
     * The SHA-256 hash of the value is returned in the oauth2ClientSecretSha256 field.
     *
     * @stability stable
     */
    readonly oauth2ClientSecret: string;
}
/**
 * @stability stable
 */
export interface AppEngineApplicationTimeouts {
    /**
     * @stability stable
     */
    readonly create?: string;
    /**
     * @stability stable
     */
    readonly update?: string;
}
/**
 * @stability stable
 */
export declare class AppEngineApplication extends cdktf.TerraformResource {
    /**
     * @stability stable
     */
    constructor(scope: Construct, id: string, config: AppEngineApplicationConfig);
    /**
     * @stability stable
     */
    get appId(): string;
    private _authDomain?;
    /**
     * @stability stable
     */
    get authDomain(): string;
    /**
     * @stability stable
     */
    set authDomain(value: string);
    /**
     * @stability stable
     */
    resetAuthDomain(): void;
    /**
     * @stability stable
     */
    get authDomainInput(): string | undefined;
    /**
     * @stability stable
     */
    get codeBucket(): string;
    private _databaseType?;
    /**
     * @stability stable
     */
    get databaseType(): string;
    /**
     * @stability stable
     */
    set databaseType(value: string);
    /**
     * @stability stable
     */
    resetDatabaseType(): void;
    /**
     * @stability stable
     */
    get databaseTypeInput(): string | undefined;
    /**
     * @stability stable
     */
    get defaultBucket(): string;
    /**
     * @stability stable
     */
    get defaultHostname(): string;
    /**
     * @stability stable
     */
    get gcrDomain(): string;
    /**
     * @stability stable
     */
    get id(): string;
    private _locationId;
    /**
     * @stability stable
     */
    get locationId(): string;
    /**
     * @stability stable
     */
    set locationId(value: string);
    /**
     * @stability stable
     */
    get locationIdInput(): string;
    /**
     * @stability stable
     */
    get name(): string;
    private _project?;
    /**
     * @stability stable
     */
    get project(): string;
    /**
     * @stability stable
     */
    set project(value: string);
    /**
     * @stability stable
     */
    resetProject(): void;
    /**
     * @stability stable
     */
    get projectInput(): string | undefined;
    private _servingStatus?;
    /**
     * @stability stable
     */
    get servingStatus(): string;
    /**
     * @stability stable
     */
    set servingStatus(value: string);
    /**
     * @stability stable
     */
    resetServingStatus(): void;
    /**
     * @stability stable
     */
    get servingStatusInput(): string | undefined;
    /**
     * @stability stable
     */
    urlDispatchRule(index: string): AppEngineApplicationUrlDispatchRule;
    private _featureSettings?;
    /**
     * @stability stable
     */
    get featureSettings(): AppEngineApplicationFeatureSettings[];
    /**
     * @stability stable
     */
    set featureSettings(value: AppEngineApplicationFeatureSettings[]);
    /**
     * @stability stable
     */
    resetFeatureSettings(): void;
    /**
     * @stability stable
     */
    get featureSettingsInput(): AppEngineApplicationFeatureSettings[] | undefined;
    private _iap?;
    /**
     * @stability stable
     */
    get iap(): AppEngineApplicationIap[];
    /**
     * @stability stable
     */
    set iap(value: AppEngineApplicationIap[]);
    /**
     * @stability stable
     */
    resetIap(): void;
    /**
     * @stability stable
     */
    get iapInput(): AppEngineApplicationIap[] | undefined;
    private _timeouts?;
    /**
     * @stability stable
     */
    get timeouts(): AppEngineApplicationTimeouts;
    /**
     * @stability stable
     */
    set timeouts(value: AppEngineApplicationTimeouts);
    /**
     * @stability stable
     */
    resetTimeouts(): void;
    /**
     * @stability stable
     */
    get timeoutsInput(): AppEngineApplicationTimeouts | undefined;
    /**
     * @stability stable
     */
    protected synthesizeAttributes(): {
        [name: string]: any;
    };
}
