import { Construct } from 'constructs';
import * as cdktf from 'cdktf';
/**
 * @stability stable
 */
export interface AppEngineFlexibleAppVersionConfig extends cdktf.TerraformMetaArguments {
    /**
     * Metadata settings that are supplied to this version to enable beta runtime features.
     *
     * @stability stable
     */
    readonly betaSettings?: {
        [key: string]: string;
    };
    /**
     * Duration that static files should be cached by web proxies and browsers.
     *
     * Only applicable if the corresponding StaticFilesHandler does not specify its own expiration time.
     *
     * @stability stable
     */
    readonly defaultExpiration?: string;
    /**
     * @stability stable
     */
    readonly deleteServiceOnDestroy?: boolean;
    /**
     * Environment variables available to the application.
     *
     * As these are not returned in the API request, Terraform will not detect any changes made outside of the Terraform config.
     *
     * @stability stable
     */
    readonly envVariables?: {
        [key: string]: string;
    };
    /**
     * A list of the types of messages that this application is able to receive.
     *
     * Possible values: ["INBOUND_SERVICE_MAIL", "INBOUND_SERVICE_MAIL_BOUNCE", "INBOUND_SERVICE_XMPP_ERROR", "INBOUND_SERVICE_XMPP_MESSAGE", "INBOUND_SERVICE_XMPP_SUBSCRIBE", "INBOUND_SERVICE_XMPP_PRESENCE", "INBOUND_SERVICE_CHANNEL_PRESENCE", "INBOUND_SERVICE_WARMUP"]
     *
     * @stability stable
     */
    readonly inboundServices?: string[];
    /**
     * Instance class that is used to run this version.
     *
     * Valid values are
     * AutomaticScaling: F1, F2, F4, F4_1G
     * ManualScaling: B1, B2, B4, B8, B4_1G
     * Defaults to F1 for AutomaticScaling and B1 for ManualScaling.
     *
     * @stability stable
     */
    readonly instanceClass?: string;
    /**
     * Files that match this pattern will not be built into this version.
     *
     * Only applicable for Go runtimes.
     *
     * @stability stable
     */
    readonly nobuildFilesRegex?: string;
    /**
     * @stability stable
     */
    readonly noopOnDestroy?: boolean;
    /**
     * @stability stable
     */
    readonly project?: string;
    /**
     * Desired runtime.
     *
     * Example python27.
     *
     * @stability stable
     */
    readonly runtime: string;
    /**
     * The version of the API in the given runtime environment.
     *
     * Please see the app.yaml reference for valid values at https://cloud.google.com/appengine/docs/standard//config/appref
     *
     * @stability stable
     */
    readonly runtimeApiVersion?: string;
    /**
     * The channel of the runtime to use.
     *
     * Only available for some runtimes.
     *
     * @stability stable
     */
    readonly runtimeChannel?: string;
    /**
     * The path or name of the app's main executable.
     *
     * @stability stable
     */
    readonly runtimeMainExecutablePath?: string;
    /**
     * AppEngine service resource.
     *
     * @stability stable
     */
    readonly service: string;
    /**
     * Current serving status of this version.
     *
     * Only the versions with a SERVING status create instances and can be billed. Default value: "SERVING" Possible values: ["SERVING", "STOPPED"]
     *
     * @stability stable
     */
    readonly servingStatus?: string;
    /**
     * Relative name of the version within the service.
     *
     * For example, 'v1'. Version names can contain only lowercase letters, numbers, or hyphens.
     * Reserved names,"default", "latest", and any name with the prefix "ah-".
     *
     * @stability stable
     */
    readonly versionId?: string;
    /**
     * api_config block.
     *
     * @stability stable
     */
    readonly apiConfig?: AppEngineFlexibleAppVersionApiConfig[];
    /**
     * automatic_scaling block.
     *
     * @stability stable
     */
    readonly automaticScaling?: AppEngineFlexibleAppVersionAutomaticScaling[];
    /**
     * deployment block.
     *
     * @stability stable
     */
    readonly deployment?: AppEngineFlexibleAppVersionDeployment[];
    /**
     * endpoints_api_service block.
     *
     * @stability stable
     */
    readonly endpointsApiService?: AppEngineFlexibleAppVersionEndpointsApiService[];
    /**
     * entrypoint block.
     *
     * @stability stable
     */
    readonly entrypoint?: AppEngineFlexibleAppVersionEntrypoint[];
    /**
     * handlers block.
     *
     * @stability stable
     */
    readonly handlers?: AppEngineFlexibleAppVersionHandlers[];
    /**
     * liveness_check block.
     *
     * @stability stable
     */
    readonly livenessCheck: AppEngineFlexibleAppVersionLivenessCheck[];
    /**
     * manual_scaling block.
     *
     * @stability stable
     */
    readonly manualScaling?: AppEngineFlexibleAppVersionManualScaling[];
    /**
     * network block.
     *
     * @stability stable
     */
    readonly network?: AppEngineFlexibleAppVersionNetwork[];
    /**
     * readiness_check block.
     *
     * @stability stable
     */
    readonly readinessCheck: AppEngineFlexibleAppVersionReadinessCheck[];
    /**
     * resources block.
     *
     * @stability stable
     */
    readonly resources?: AppEngineFlexibleAppVersionResources[];
    /**
     * timeouts block.
     *
     * @stability stable
     */
    readonly timeouts?: AppEngineFlexibleAppVersionTimeouts;
    /**
     * vpc_access_connector block.
     *
     * @stability stable
     */
    readonly vpcAccessConnector?: AppEngineFlexibleAppVersionVpcAccessConnector[];
}
/**
 * @stability stable
 */
export interface AppEngineFlexibleAppVersionApiConfig {
    /**
     * Action to take when users access resources that require authentication.
     *
     * Default value: "AUTH_FAIL_ACTION_REDIRECT" Possible values: ["AUTH_FAIL_ACTION_REDIRECT", "AUTH_FAIL_ACTION_UNAUTHORIZED"]
     *
     * @stability stable
     */
    readonly authFailAction?: string;
    /**
     * Level of login required to access this resource.
     *
     * Default value: "LOGIN_OPTIONAL" Possible values: ["LOGIN_OPTIONAL", "LOGIN_ADMIN", "LOGIN_REQUIRED"]
     *
     * @stability stable
     */
    readonly login?: string;
    /**
     * Path to the script from the application root directory.
     *
     * @stability stable
     */
    readonly script: string;
    /**
     * Security (HTTPS) enforcement for this URL.
     *
     * Possible values: ["SECURE_DEFAULT", "SECURE_NEVER", "SECURE_OPTIONAL", "SECURE_ALWAYS"]
     *
     * @stability stable
     */
    readonly securityLevel?: string;
    /**
     * URL to serve the endpoint at.
     *
     * @stability stable
     */
    readonly url?: string;
}
/**
 * @stability stable
 */
export interface AppEngineFlexibleAppVersionAutomaticScalingCpuUtilization {
    /**
     * Period of time over which CPU utilization is calculated.
     *
     * @stability stable
     */
    readonly aggregationWindowLength?: string;
    /**
     * Target CPU utilization ratio to maintain when scaling.
     *
     * Must be between 0 and 1.
     *
     * @stability stable
     */
    readonly targetUtilization: number;
}
/**
 * @stability stable
 */
export interface AppEngineFlexibleAppVersionAutomaticScalingDiskUtilization {
    /**
     * Target bytes read per second.
     *
     * @stability stable
     */
    readonly targetReadBytesPerSecond?: number;
    /**
     * Target ops read per seconds.
     *
     * @stability stable
     */
    readonly targetReadOpsPerSecond?: number;
    /**
     * Target bytes written per second.
     *
     * @stability stable
     */
    readonly targetWriteBytesPerSecond?: number;
    /**
     * Target ops written per second.
     *
     * @stability stable
     */
    readonly targetWriteOpsPerSecond?: number;
}
/**
 * @stability stable
 */
export interface AppEngineFlexibleAppVersionAutomaticScalingNetworkUtilization {
    /**
     * Target bytes received per second.
     *
     * @stability stable
     */
    readonly targetReceivedBytesPerSecond?: number;
    /**
     * Target packets received per second.
     *
     * @stability stable
     */
    readonly targetReceivedPacketsPerSecond?: number;
    /**
     * Target bytes sent per second.
     *
     * @stability stable
     */
    readonly targetSentBytesPerSecond?: number;
    /**
     * Target packets sent per second.
     *
     * @stability stable
     */
    readonly targetSentPacketsPerSecond?: number;
}
/**
 * @stability stable
 */
export interface AppEngineFlexibleAppVersionAutomaticScalingRequestUtilization {
    /**
     * Target number of concurrent requests.
     *
     * @stability stable
     */
    readonly targetConcurrentRequests?: number;
    /**
     * Target requests per second.
     *
     * @stability stable
     */
    readonly targetRequestCountPerSecond?: string;
}
/**
 * @stability stable
 */
export interface AppEngineFlexibleAppVersionAutomaticScaling {
    /**
     * The time period that the Autoscaler should wait before it starts collecting information from a new instance.
     *
     * This prevents the autoscaler from collecting information when the instance is initializing,
     * during which the collected usage would not be reliable. Default: 120s
     *
     * @stability stable
     */
    readonly coolDownPeriod?: string;
    /**
     * Number of concurrent requests an automatic scaling instance can accept before the scheduler spawns a new instance.
     *
     * Defaults to a runtime-specific value.
     *
     * @stability stable
     */
    readonly maxConcurrentRequests?: number;
    /**
     * Maximum number of idle instances that should be maintained for this version.
     *
     * @stability stable
     */
    readonly maxIdleInstances?: number;
    /**
     * Maximum amount of time that a request should wait in the pending queue before starting a new instance to handle it.
     *
     * @stability stable
     */
    readonly maxPendingLatency?: string;
    /**
     * Maximum number of instances that should be started to handle requests for this version.
     *
     * Default: 20
     *
     * @stability stable
     */
    readonly maxTotalInstances?: number;
    /**
     * Minimum number of idle instances that should be maintained for this version.
     *
     * Only applicable for the default version of a service.
     *
     * @stability stable
     */
    readonly minIdleInstances?: number;
    /**
     * Minimum amount of time a request should wait in the pending queue before starting a new instance to handle it.
     *
     * @stability stable
     */
    readonly minPendingLatency?: string;
    /**
     * Minimum number of running instances that should be maintained for this version.
     *
     * Default: 2
     *
     * @stability stable
     */
    readonly minTotalInstances?: number;
    /**
     * cpu_utilization block.
     *
     * @stability stable
     */
    readonly cpuUtilization: AppEngineFlexibleAppVersionAutomaticScalingCpuUtilization[];
    /**
     * disk_utilization block.
     *
     * @stability stable
     */
    readonly diskUtilization?: AppEngineFlexibleAppVersionAutomaticScalingDiskUtilization[];
    /**
     * network_utilization block.
     *
     * @stability stable
     */
    readonly networkUtilization?: AppEngineFlexibleAppVersionAutomaticScalingNetworkUtilization[];
    /**
     * request_utilization block.
     *
     * @stability stable
     */
    readonly requestUtilization?: AppEngineFlexibleAppVersionAutomaticScalingRequestUtilization[];
}
/**
 * @stability stable
 */
export interface AppEngineFlexibleAppVersionDeploymentCloudBuildOptions {
    /**
     * Path to the yaml file used in deployment, used to determine runtime configuration details.
     *
     * @stability stable
     */
    readonly appYamlPath: string;
    /**
     * The Cloud Build timeout used as part of any dependent builds performed by version creation. Defaults to 10 minutes.
     *
     * A duration in seconds with up to nine fractional digits, terminated by 's'. Example: "3.5s".
     *
     * @stability stable
     */
    readonly cloudBuildTimeout?: string;
}
/**
 * @stability stable
 */
export interface AppEngineFlexibleAppVersionDeploymentContainer {
    /**
     * URI to the hosted container image in Google Container Registry.
     *
     * The URI must be fully qualified and include a tag or digest.
     * Examples: "gcr.io/my-project/image:tag" or "gcr.io/my-project/image@digest"
     *
     * @stability stable
     */
    readonly image: string;
}
/**
 * @stability stable
 */
export interface AppEngineFlexibleAppVersionDeploymentFiles {
    /**
     * @stability stable
     */
    readonly name: string;
    /**
     * SHA1 checksum of the file.
     *
     * @stability stable
     */
    readonly sha1Sum?: string;
    /**
     * Source URL.
     *
     * @stability stable
     */
    readonly sourceUrl: string;
}
/**
 * @stability stable
 */
export interface AppEngineFlexibleAppVersionDeploymentZip {
    /**
     * files count.
     *
     * @stability stable
     */
    readonly filesCount?: number;
    /**
     * Source URL.
     *
     * @stability stable
     */
    readonly sourceUrl: string;
}
/**
 * @stability stable
 */
export interface AppEngineFlexibleAppVersionDeployment {
    /**
     * cloud_build_options block.
     *
     * @stability stable
     */
    readonly cloudBuildOptions?: AppEngineFlexibleAppVersionDeploymentCloudBuildOptions[];
    /**
     * container block.
     *
     * @stability stable
     */
    readonly container?: AppEngineFlexibleAppVersionDeploymentContainer[];
    /**
     * files block.
     *
     * @stability stable
     */
    readonly files?: AppEngineFlexibleAppVersionDeploymentFiles[];
    /**
     * zip block.
     *
     * @stability stable
     */
    readonly zip?: AppEngineFlexibleAppVersionDeploymentZip[];
}
/**
 * @stability stable
 */
export interface AppEngineFlexibleAppVersionEndpointsApiService {
    /**
     * Endpoints service configuration ID as specified by the Service Management API. For example "2016-09-19r1".
     *
     * By default, the rollout strategy for Endpoints is "FIXED". This means that Endpoints starts up with a particular configuration ID.
     * When a new configuration is rolled out, Endpoints must be given the new configuration ID. The configId field is used to give the configuration ID
     * and is required in this case.
     *
     * Endpoints also has a rollout strategy called "MANAGED". When using this, Endpoints fetches the latest configuration and does not need
     * the configuration ID. In this case, configId must be omitted.
     *
     * @stability stable
     */
    readonly configId?: string;
    /**
     * Enable or disable trace sampling.
     *
     * By default, this is set to false for enabled.
     *
     * @stability stable
     */
    readonly disableTraceSampling?: boolean;
    /**
     * Endpoints service name which is the name of the "service" resource in the Service Management API.
     *
     * For example "myapi.endpoints.myproject.cloud.goog"
     *
     * @stability stable
     */
    readonly name: string;
    /**
     * Endpoints rollout strategy.
     *
     * If FIXED, configId must be specified. If MANAGED, configId must be omitted. Default value: "FIXED" Possible values: ["FIXED", "MANAGED"]
     *
     * @stability stable
     */
    readonly rolloutStrategy?: string;
}
/**
 * @stability stable
 */
export interface AppEngineFlexibleAppVersionEntrypoint {
    /**
     * The format should be a shell command that can be fed to bash -c.
     *
     * @stability stable
     */
    readonly shell: string;
}
/**
 * @stability stable
 */
export interface AppEngineFlexibleAppVersionHandlersScript {
    /**
     * Path to the script from the application root directory.
     *
     * @stability stable
     */
    readonly scriptPath: string;
}
/**
 * @stability stable
 */
export interface AppEngineFlexibleAppVersionHandlersStaticFiles {
    /**
     * Whether files should also be uploaded as code data.
     *
     * By default, files declared in static file handlers are
     * uploaded as static data and are only served to end users; they cannot be read by the application. If enabled,
     * uploads are charged against both your code and static data storage resource quotas.
     *
     * @stability stable
     */
    readonly applicationReadable?: boolean;
    /**
     * Time a static file served by this handler should be cached by web proxies and browsers.
     *
     * A duration in seconds with up to nine fractional digits, terminated by 's'. Example "3.5s".
     * Default is '0s'
     *
     * @stability stable
     */
    readonly expiration?: string;
    /**
     * HTTP headers to use for all responses from these URLs.
     *
     * An object containing a list of "key:value" value pairs.".
     *
     * @stability stable
     */
    readonly httpHeaders?: {
        [key: string]: string;
    };
    /**
     * MIME type used to serve all files served by this handler.
     *
     * Defaults to file-specific MIME types, which are derived from each file's filename extension.
     *
     * @stability stable
     */
    readonly mimeType?: string;
    /**
     * Path to the static files matched by the URL pattern, from the application root directory.
     *
     * The path can refer to text matched in groupings in the URL pattern.
     *
     * @stability stable
     */
    readonly path?: string;
    /**
     * Whether this handler should match the request if the file referenced by the handler does not exist.
     *
     * @stability stable
     */
    readonly requireMatchingFile?: boolean;
    /**
     * Regular expression that matches the file paths for all files that should be referenced by this handler.
     *
     * @stability stable
     */
    readonly uploadPathRegex?: string;
}
/**
 * @stability stable
 */
export interface AppEngineFlexibleAppVersionHandlers {
    /**
     * Actions to take when the user is not logged in.
     *
     * Possible values: ["AUTH_FAIL_ACTION_REDIRECT", "AUTH_FAIL_ACTION_UNAUTHORIZED"]
     *
     * @stability stable
     */
    readonly authFailAction?: string;
    /**
     * Methods to restrict access to a URL based on login status.
     *
     * Possible values: ["LOGIN_OPTIONAL", "LOGIN_ADMIN", "LOGIN_REQUIRED"]
     *
     * @stability stable
     */
    readonly login?: string;
    /**
     * 30x code to use when performing redirects for the secure field.
     *
     * Possible values: ["REDIRECT_HTTP_RESPONSE_CODE_301", "REDIRECT_HTTP_RESPONSE_CODE_302", "REDIRECT_HTTP_RESPONSE_CODE_303", "REDIRECT_HTTP_RESPONSE_CODE_307"]
     *
     * @stability stable
     */
    readonly redirectHttpResponseCode?: string;
    /**
     * Security (HTTPS) enforcement for this URL.
     *
     * Possible values: ["SECURE_DEFAULT", "SECURE_NEVER", "SECURE_OPTIONAL", "SECURE_ALWAYS"]
     *
     * @stability stable
     */
    readonly securityLevel?: string;
    /**
     * URL prefix.
     *
     * Uses regular expression syntax, which means regexp special characters must be escaped, but should not contain groupings.
     * All URLs that begin with this prefix are handled by this handler, using the portion of the URL after the prefix as part of the file path.
     *
     * @stability stable
     */
    readonly urlRegex?: string;
    /**
     * script block.
     *
     * @stability stable
     */
    readonly script?: AppEngineFlexibleAppVersionHandlersScript[];
    /**
     * static_files block.
     *
     * @stability stable
     */
    readonly staticFiles?: AppEngineFlexibleAppVersionHandlersStaticFiles[];
}
/**
 * @stability stable
 */
export interface AppEngineFlexibleAppVersionLivenessCheck {
    /**
     * Interval between health checks.
     *
     * @stability stable
     */
    readonly checkInterval?: string;
    /**
     * Number of consecutive failed checks required before considering the VM unhealthy.
     *
     * Default: 4.
     *
     * @stability stable
     */
    readonly failureThreshold?: number;
    /**
     * Host header to send when performing a HTTP Readiness check.
     *
     * Example: "myapp.appspot.com"
     *
     * @stability stable
     */
    readonly host?: string;
    /**
     * The initial delay before starting to execute the checks.
     *
     * Default: "300s"
     *
     * @stability stable
     */
    readonly initialDelay?: string;
    /**
     * The request path.
     *
     * @stability stable
     */
    readonly path: string;
    /**
     * Number of consecutive successful checks required before considering the VM healthy.
     *
     * Default: 2.
     *
     * @stability stable
     */
    readonly successThreshold?: number;
    /**
     * Time before the check is considered failed.
     *
     * Default: "4s"
     *
     * @stability stable
     */
    readonly timeout?: string;
}
/**
 * @stability stable
 */
export interface AppEngineFlexibleAppVersionManualScaling {
    /**
     * Number of instances to assign to the service at the start.
     *
     * *Note:** When managing the number of instances at runtime through the App Engine Admin API or the (now deprecated) Python 2
     * Modules API set_num_instances() you must use 'lifecycle.ignore_changes = ["manual_scaling"[0].instances]' to prevent drift detection.
     *
     * @stability stable
     */
    readonly instances: number;
}
/**
 * @stability stable
 */
export interface AppEngineFlexibleAppVersionNetwork {
    /**
     * List of ports, or port pairs, to forward from the virtual machine to the application container.
     *
     * @stability stable
     */
    readonly forwardedPorts?: string[];
    /**
     * Tag to apply to the instance during creation.
     *
     * @stability stable
     */
    readonly instanceTag?: string;
    /**
     * Google Compute Engine network where the virtual machines are created.
     *
     * Specify the short name, not the resource path.
     *
     * @stability stable
     */
    readonly name: string;
    /**
     * Enable session affinity.
     *
     * @stability stable
     */
    readonly sessionAffinity?: boolean;
    /**
     * Google Cloud Platform sub-network where the virtual machines are created. Specify the short name, not the resource path.
     *
     * If the network that the instance is being created in is a Legacy network, then the IP address is allocated from the IPv4Range.
     * If the network that the instance is being created in is an auto Subnet Mode Network, then only network name should be specified (not the subnetworkName) and the IP address is created from the IPCidrRange of the subnetwork that exists in that zone for that network.
     * If the network that the instance is being created in is a custom Subnet Mode Network, then the subnetworkName must be specified and the IP address is created from the IPCidrRange of the subnetwork.
     * If specified, the subnetwork must exist in the same region as the App Engine flexible environment application.
     *
     * @stability stable
     */
    readonly subnetwork?: string;
}
/**
 * @stability stable
 */
export interface AppEngineFlexibleAppVersionReadinessCheck {
    /**
     * A maximum time limit on application initialization, measured from moment the application successfully replies to a healthcheck until it is ready to serve traffic.
     *
     * Default: "300s"
     *
     * @stability stable
     */
    readonly appStartTimeout?: string;
    /**
     * Interval between health checks.
     *
     * Default: "5s".
     *
     * @stability stable
     */
    readonly checkInterval?: string;
    /**
     * Number of consecutive failed checks required before removing traffic.
     *
     * Default: 2.
     *
     * @stability stable
     */
    readonly failureThreshold?: number;
    /**
     * Host header to send when performing a HTTP Readiness check.
     *
     * Example: "myapp.appspot.com"
     *
     * @stability stable
     */
    readonly host?: string;
    /**
     * The request path.
     *
     * @stability stable
     */
    readonly path: string;
    /**
     * Number of consecutive successful checks required before receiving traffic.
     *
     * Default: 2.
     *
     * @stability stable
     */
    readonly successThreshold?: number;
    /**
     * Time before the check is considered failed.
     *
     * Default: "4s"
     *
     * @stability stable
     */
    readonly timeout?: string;
}
/**
 * @stability stable
 */
export interface AppEngineFlexibleAppVersionResourcesVolumes {
    /**
     * Unique name for the volume.
     *
     * @stability stable
     */
    readonly name: string;
    /**
     * Volume size in gigabytes.
     *
     * @stability stable
     */
    readonly sizeGb: number;
    /**
     * Underlying volume type, e.g. 'tmpfs'.
     *
     * @stability stable
     */
    readonly volumeType: string;
}
/**
 * @stability stable
 */
export interface AppEngineFlexibleAppVersionResources {
    /**
     * Number of CPU cores needed.
     *
     * @stability stable
     */
    readonly cpu?: number;
    /**
     * Disk size (GB) needed.
     *
     * @stability stable
     */
    readonly diskGb?: number;
    /**
     * Memory (GB) needed.
     *
     * @stability stable
     */
    readonly memoryGb?: number;
    /**
     * volumes block.
     *
     * @stability stable
     */
    readonly volumes?: AppEngineFlexibleAppVersionResourcesVolumes[];
}
/**
 * @stability stable
 */
export interface AppEngineFlexibleAppVersionTimeouts {
    /**
     * @stability stable
     */
    readonly create?: string;
    /**
     * @stability stable
     */
    readonly delete?: string;
    /**
     * @stability stable
     */
    readonly update?: string;
}
/**
 * @stability stable
 */
export interface AppEngineFlexibleAppVersionVpcAccessConnector {
    /**
     * Full Serverless VPC Access Connector name e.g. /projects/my-project/locations/us-central1/connectors/c1.
     *
     * @stability stable
     */
    readonly name: string;
}
/**
 * @stability stable
 */
export declare class AppEngineFlexibleAppVersion extends cdktf.TerraformResource {
    /**
     * @stability stable
     */
    constructor(scope: Construct, id: string, config: AppEngineFlexibleAppVersionConfig);
    private _betaSettings?;
    /**
     * @stability stable
     */
    get betaSettings(): {
        [key: string]: string;
    };
    /**
     * @stability stable
     */
    set betaSettings(value: {
        [key: string]: string;
    });
    /**
     * @stability stable
     */
    resetBetaSettings(): void;
    /**
     * @stability stable
     */
    get betaSettingsInput(): {
        [key: string]: string;
    } | undefined;
    private _defaultExpiration?;
    /**
     * @stability stable
     */
    get defaultExpiration(): string;
    /**
     * @stability stable
     */
    set defaultExpiration(value: string);
    /**
     * @stability stable
     */
    resetDefaultExpiration(): void;
    /**
     * @stability stable
     */
    get defaultExpirationInput(): string | undefined;
    private _deleteServiceOnDestroy?;
    /**
     * @stability stable
     */
    get deleteServiceOnDestroy(): boolean;
    /**
     * @stability stable
     */
    set deleteServiceOnDestroy(value: boolean);
    /**
     * @stability stable
     */
    resetDeleteServiceOnDestroy(): void;
    /**
     * @stability stable
     */
    get deleteServiceOnDestroyInput(): boolean | undefined;
    private _envVariables?;
    /**
     * @stability stable
     */
    get envVariables(): {
        [key: string]: string;
    };
    /**
     * @stability stable
     */
    set envVariables(value: {
        [key: string]: string;
    });
    /**
     * @stability stable
     */
    resetEnvVariables(): void;
    /**
     * @stability stable
     */
    get envVariablesInput(): {
        [key: string]: string;
    } | undefined;
    /**
     * @stability stable
     */
    get id(): string;
    private _inboundServices?;
    /**
     * @stability stable
     */
    get inboundServices(): string[];
    /**
     * @stability stable
     */
    set inboundServices(value: string[]);
    /**
     * @stability stable
     */
    resetInboundServices(): void;
    /**
     * @stability stable
     */
    get inboundServicesInput(): string[] | undefined;
    private _instanceClass?;
    /**
     * @stability stable
     */
    get instanceClass(): string;
    /**
     * @stability stable
     */
    set instanceClass(value: string);
    /**
     * @stability stable
     */
    resetInstanceClass(): void;
    /**
     * @stability stable
     */
    get instanceClassInput(): string | undefined;
    /**
     * @stability stable
     */
    get name(): string;
    private _nobuildFilesRegex?;
    /**
     * @stability stable
     */
    get nobuildFilesRegex(): string;
    /**
     * @stability stable
     */
    set nobuildFilesRegex(value: string);
    /**
     * @stability stable
     */
    resetNobuildFilesRegex(): void;
    /**
     * @stability stable
     */
    get nobuildFilesRegexInput(): string | undefined;
    private _noopOnDestroy?;
    /**
     * @stability stable
     */
    get noopOnDestroy(): boolean;
    /**
     * @stability stable
     */
    set noopOnDestroy(value: boolean);
    /**
     * @stability stable
     */
    resetNoopOnDestroy(): void;
    /**
     * @stability stable
     */
    get noopOnDestroyInput(): boolean | undefined;
    private _project?;
    /**
     * @stability stable
     */
    get project(): string;
    /**
     * @stability stable
     */
    set project(value: string);
    /**
     * @stability stable
     */
    resetProject(): void;
    /**
     * @stability stable
     */
    get projectInput(): string | undefined;
    private _runtime;
    /**
     * @stability stable
     */
    get runtime(): string;
    /**
     * @stability stable
     */
    set runtime(value: string);
    /**
     * @stability stable
     */
    get runtimeInput(): string;
    private _runtimeApiVersion?;
    /**
     * @stability stable
     */
    get runtimeApiVersion(): string;
    /**
     * @stability stable
     */
    set runtimeApiVersion(value: string);
    /**
     * @stability stable
     */
    resetRuntimeApiVersion(): void;
    /**
     * @stability stable
     */
    get runtimeApiVersionInput(): string | undefined;
    private _runtimeChannel?;
    /**
     * @stability stable
     */
    get runtimeChannel(): string;
    /**
     * @stability stable
     */
    set runtimeChannel(value: string);
    /**
     * @stability stable
     */
    resetRuntimeChannel(): void;
    /**
     * @stability stable
     */
    get runtimeChannelInput(): string | undefined;
    private _runtimeMainExecutablePath?;
    /**
     * @stability stable
     */
    get runtimeMainExecutablePath(): string;
    /**
     * @stability stable
     */
    set runtimeMainExecutablePath(value: string);
    /**
     * @stability stable
     */
    resetRuntimeMainExecutablePath(): void;
    /**
     * @stability stable
     */
    get runtimeMainExecutablePathInput(): string | undefined;
    private _service;
    /**
     * @stability stable
     */
    get service(): string;
    /**
     * @stability stable
     */
    set service(value: string);
    /**
     * @stability stable
     */
    get serviceInput(): string;
    private _servingStatus?;
    /**
     * @stability stable
     */
    get servingStatus(): string;
    /**
     * @stability stable
     */
    set servingStatus(value: string);
    /**
     * @stability stable
     */
    resetServingStatus(): void;
    /**
     * @stability stable
     */
    get servingStatusInput(): string | undefined;
    private _versionId?;
    /**
     * @stability stable
     */
    get versionId(): string;
    /**
     * @stability stable
     */
    set versionId(value: string);
    /**
     * @stability stable
     */
    resetVersionId(): void;
    /**
     * @stability stable
     */
    get versionIdInput(): string | undefined;
    private _apiConfig?;
    /**
     * @stability stable
     */
    get apiConfig(): AppEngineFlexibleAppVersionApiConfig[];
    /**
     * @stability stable
     */
    set apiConfig(value: AppEngineFlexibleAppVersionApiConfig[]);
    /**
     * @stability stable
     */
    resetApiConfig(): void;
    /**
     * @stability stable
     */
    get apiConfigInput(): AppEngineFlexibleAppVersionApiConfig[] | undefined;
    private _automaticScaling?;
    /**
     * @stability stable
     */
    get automaticScaling(): AppEngineFlexibleAppVersionAutomaticScaling[];
    /**
     * @stability stable
     */
    set automaticScaling(value: AppEngineFlexibleAppVersionAutomaticScaling[]);
    /**
     * @stability stable
     */
    resetAutomaticScaling(): void;
    /**
     * @stability stable
     */
    get automaticScalingInput(): AppEngineFlexibleAppVersionAutomaticScaling[] | undefined;
    private _deployment?;
    /**
     * @stability stable
     */
    get deployment(): AppEngineFlexibleAppVersionDeployment[];
    /**
     * @stability stable
     */
    set deployment(value: AppEngineFlexibleAppVersionDeployment[]);
    /**
     * @stability stable
     */
    resetDeployment(): void;
    /**
     * @stability stable
     */
    get deploymentInput(): AppEngineFlexibleAppVersionDeployment[] | undefined;
    private _endpointsApiService?;
    /**
     * @stability stable
     */
    get endpointsApiService(): AppEngineFlexibleAppVersionEndpointsApiService[];
    /**
     * @stability stable
     */
    set endpointsApiService(value: AppEngineFlexibleAppVersionEndpointsApiService[]);
    /**
     * @stability stable
     */
    resetEndpointsApiService(): void;
    /**
     * @stability stable
     */
    get endpointsApiServiceInput(): AppEngineFlexibleAppVersionEndpointsApiService[] | undefined;
    private _entrypoint?;
    /**
     * @stability stable
     */
    get entrypoint(): AppEngineFlexibleAppVersionEntrypoint[];
    /**
     * @stability stable
     */
    set entrypoint(value: AppEngineFlexibleAppVersionEntrypoint[]);
    /**
     * @stability stable
     */
    resetEntrypoint(): void;
    /**
     * @stability stable
     */
    get entrypointInput(): AppEngineFlexibleAppVersionEntrypoint[] | undefined;
    private _handlers?;
    /**
     * @stability stable
     */
    get handlers(): AppEngineFlexibleAppVersionHandlers[];
    /**
     * @stability stable
     */
    set handlers(value: AppEngineFlexibleAppVersionHandlers[]);
    /**
     * @stability stable
     */
    resetHandlers(): void;
    /**
     * @stability stable
     */
    get handlersInput(): AppEngineFlexibleAppVersionHandlers[] | undefined;
    private _livenessCheck;
    /**
     * @stability stable
     */
    get livenessCheck(): AppEngineFlexibleAppVersionLivenessCheck[];
    /**
     * @stability stable
     */
    set livenessCheck(value: AppEngineFlexibleAppVersionLivenessCheck[]);
    /**
     * @stability stable
     */
    get livenessCheckInput(): AppEngineFlexibleAppVersionLivenessCheck[];
    private _manualScaling?;
    /**
     * @stability stable
     */
    get manualScaling(): AppEngineFlexibleAppVersionManualScaling[];
    /**
     * @stability stable
     */
    set manualScaling(value: AppEngineFlexibleAppVersionManualScaling[]);
    /**
     * @stability stable
     */
    resetManualScaling(): void;
    /**
     * @stability stable
     */
    get manualScalingInput(): AppEngineFlexibleAppVersionManualScaling[] | undefined;
    private _network?;
    /**
     * @stability stable
     */
    get network(): AppEngineFlexibleAppVersionNetwork[];
    /**
     * @stability stable
     */
    set network(value: AppEngineFlexibleAppVersionNetwork[]);
    /**
     * @stability stable
     */
    resetNetwork(): void;
    /**
     * @stability stable
     */
    get networkInput(): AppEngineFlexibleAppVersionNetwork[] | undefined;
    private _readinessCheck;
    /**
     * @stability stable
     */
    get readinessCheck(): AppEngineFlexibleAppVersionReadinessCheck[];
    /**
     * @stability stable
     */
    set readinessCheck(value: AppEngineFlexibleAppVersionReadinessCheck[]);
    /**
     * @stability stable
     */
    get readinessCheckInput(): AppEngineFlexibleAppVersionReadinessCheck[];
    private _resources?;
    /**
     * @stability stable
     */
    get resources(): AppEngineFlexibleAppVersionResources[];
    /**
     * @stability stable
     */
    set resources(value: AppEngineFlexibleAppVersionResources[]);
    /**
     * @stability stable
     */
    resetResources(): void;
    /**
     * @stability stable
     */
    get resourcesInput(): AppEngineFlexibleAppVersionResources[] | undefined;
    private _timeouts?;
    /**
     * @stability stable
     */
    get timeouts(): AppEngineFlexibleAppVersionTimeouts;
    /**
     * @stability stable
     */
    set timeouts(value: AppEngineFlexibleAppVersionTimeouts);
    /**
     * @stability stable
     */
    resetTimeouts(): void;
    /**
     * @stability stable
     */
    get timeoutsInput(): AppEngineFlexibleAppVersionTimeouts | undefined;
    private _vpcAccessConnector?;
    /**
     * @stability stable
     */
    get vpcAccessConnector(): AppEngineFlexibleAppVersionVpcAccessConnector[];
    /**
     * @stability stable
     */
    set vpcAccessConnector(value: AppEngineFlexibleAppVersionVpcAccessConnector[]);
    /**
     * @stability stable
     */
    resetVpcAccessConnector(): void;
    /**
     * @stability stable
     */
    get vpcAccessConnectorInput(): AppEngineFlexibleAppVersionVpcAccessConnector[] | undefined;
    /**
     * @stability stable
     */
    protected synthesizeAttributes(): {
        [name: string]: any;
    };
}
