import { Construct } from 'constructs';
import * as cdktf from 'cdktf';
/**
 * @stability stable
 */
export interface AppEngineServiceSplitTrafficConfig extends cdktf.TerraformMetaArguments {
    /**
     * If set to true traffic will be migrated to this version.
     *
     * @stability stable
     */
    readonly migrateTraffic?: boolean;
    /**
     * @stability stable
     */
    readonly project?: string;
    /**
     * The name of the service these settings apply to.
     *
     * @stability stable
     */
    readonly service: string;
    /**
     * split block.
     *
     * @stability stable
     */
    readonly split: AppEngineServiceSplitTrafficSplit[];
    /**
     * timeouts block.
     *
     * @stability stable
     */
    readonly timeouts?: AppEngineServiceSplitTrafficTimeouts;
}
/**
 * @stability stable
 */
export interface AppEngineServiceSplitTrafficSplit {
    /**
     * Mapping from version IDs within the service to fractional (0.000, 1] allocations of traffic for that version. Each version can be specified only once, but some versions in the service may not have any traffic allocation. Services that have traffic allocated cannot be deleted until either the service is deleted or their traffic allocation is removed. Allocations must sum to 1. Up to two decimal place precision is supported for IP-based splits and up to three decimal places is supported for cookie-based splits.
     *
     * @stability stable
     */
    readonly allocations: {
        [key: string]: string;
    };
    /**
     * Mechanism used to determine which version a request is sent to.
     *
     * The traffic selection algorithm will be stable for either type until allocations are changed. Possible values: ["UNSPECIFIED", "COOKIE", "IP", "RANDOM"]
     *
     * @stability stable
     */
    readonly shardBy?: string;
}
/**
 * @stability stable
 */
export interface AppEngineServiceSplitTrafficTimeouts {
    /**
     * @stability stable
     */
    readonly create?: string;
    /**
     * @stability stable
     */
    readonly delete?: string;
    /**
     * @stability stable
     */
    readonly update?: string;
}
/**
 * @stability stable
 */
export declare class AppEngineServiceSplitTraffic extends cdktf.TerraformResource {
    /**
     * @stability stable
     */
    constructor(scope: Construct, id: string, config: AppEngineServiceSplitTrafficConfig);
    /**
     * @stability stable
     */
    get id(): string;
    private _migrateTraffic?;
    /**
     * @stability stable
     */
    get migrateTraffic(): boolean;
    /**
     * @stability stable
     */
    set migrateTraffic(value: boolean);
    /**
     * @stability stable
     */
    resetMigrateTraffic(): void;
    /**
     * @stability stable
     */
    get migrateTrafficInput(): boolean | undefined;
    private _project?;
    /**
     * @stability stable
     */
    get project(): string;
    /**
     * @stability stable
     */
    set project(value: string);
    /**
     * @stability stable
     */
    resetProject(): void;
    /**
     * @stability stable
     */
    get projectInput(): string | undefined;
    private _service;
    /**
     * @stability stable
     */
    get service(): string;
    /**
     * @stability stable
     */
    set service(value: string);
    /**
     * @stability stable
     */
    get serviceInput(): string;
    private _split;
    /**
     * @stability stable
     */
    get split(): AppEngineServiceSplitTrafficSplit[];
    /**
     * @stability stable
     */
    set split(value: AppEngineServiceSplitTrafficSplit[]);
    /**
     * @stability stable
     */
    get splitInput(): AppEngineServiceSplitTrafficSplit[];
    private _timeouts?;
    /**
     * @stability stable
     */
    get timeouts(): AppEngineServiceSplitTrafficTimeouts;
    /**
     * @stability stable
     */
    set timeouts(value: AppEngineServiceSplitTrafficTimeouts);
    /**
     * @stability stable
     */
    resetTimeouts(): void;
    /**
     * @stability stable
     */
    get timeoutsInput(): AppEngineServiceSplitTrafficTimeouts | undefined;
    /**
     * @stability stable
     */
    protected synthesizeAttributes(): {
        [name: string]: any;
    };
}
