import { Construct } from 'constructs';
import * as cdktf from 'cdktf';
/**
 * @stability stable
 */
export interface BigqueryTableConfig extends cdktf.TerraformMetaArguments {
    /**
     * Specifies column names to use for data clustering.
     *
     * Up to four top-level columns are allowed, and should be specified in descending priority order.
     *
     * @stability stable
     */
    readonly clustering?: string[];
    /**
     * The dataset ID to create the table in.
     *
     * Changing this forces a new resource to be created.
     *
     * @stability stable
     */
    readonly datasetId: string;
    /**
     * The field description.
     *
     * @stability stable
     */
    readonly description?: string;
    /**
     * The time when this table expires, in milliseconds since the epoch.
     *
     * If not present, the table will persist indefinitely. Expired tables will be deleted and their storage reclaimed.
     *
     * @stability stable
     */
    readonly expirationTime?: number;
    /**
     * A descriptive name for the table.
     *
     * @stability stable
     */
    readonly friendlyName?: string;
    /**
     * A mapping of labels to assign to the resource.
     *
     * @stability stable
     */
    readonly labels?: {
        [key: string]: string;
    };
    /**
     * The ID of the project in which the resource belongs.
     *
     * @stability stable
     */
    readonly project?: string;
    /**
     * A JSON schema for the table.
     *
     * @stability stable
     */
    readonly schema?: string;
    /**
     * A unique ID for the resource.
     *
     * Changing this forces a new resource to be created.
     *
     * @stability stable
     */
    readonly tableId: string;
    /**
     * encryption_configuration block.
     *
     * @stability stable
     */
    readonly encryptionConfiguration?: BigqueryTableEncryptionConfiguration[];
    /**
     * external_data_configuration block.
     *
     * @stability stable
     */
    readonly externalDataConfiguration?: BigqueryTableExternalDataConfiguration[];
    /**
     * materialized_view block.
     *
     * @stability stable
     */
    readonly materializedView?: BigqueryTableMaterializedView[];
    /**
     * range_partitioning block.
     *
     * @stability stable
     */
    readonly rangePartitioning?: BigqueryTableRangePartitioning[];
    /**
     * time_partitioning block.
     *
     * @stability stable
     */
    readonly timePartitioning?: BigqueryTableTimePartitioning[];
    /**
     * view block.
     *
     * @stability stable
     */
    readonly view?: BigqueryTableView[];
}
/**
 * @stability stable
 */
export interface BigqueryTableEncryptionConfiguration {
    /**
     * The self link or full name of a key which should be used to encrypt this table.
     *
     * Note that the default bigquery service account will need to have encrypt/decrypt permissions on this key - you may want to see the google_bigquery_default_service_account datasource and the google_kms_crypto_key_iam_binding resource.
     *
     * @stability stable
     */
    readonly kmsKeyName: string;
}
/**
 * @stability stable
 */
export interface BigqueryTableExternalDataConfigurationCsvOptions {
    /**
     * Indicates if BigQuery should accept rows that are missing trailing optional columns.
     *
     * @stability stable
     */
    readonly allowJaggedRows?: boolean;
    /**
     * Indicates if BigQuery should allow quoted data sections that contain newline characters in a CSV file.
     *
     * The default value is false.
     *
     * @stability stable
     */
    readonly allowQuotedNewlines?: boolean;
    /**
     * The character encoding of the data.
     *
     * The supported values are UTF-8 or ISO-8859-1.
     *
     * @stability stable
     */
    readonly encoding?: string;
    /**
     * The separator for fields in a CSV file.
     *
     * @stability stable
     */
    readonly fieldDelimiter?: string;
    /**
     * The value that is used to quote data sections in a CSV file.
     *
     * If your data does not contain quoted sections, set the property value to an empty string. If your data contains quoted newline characters, you must also set the allow_quoted_newlines property to true. The API-side default is ", specified in Terraform escaped as \". Due to limitations with Terraform default values, this value is required to be explicitly set.
     *
     * @stability stable
     */
    readonly quote: string;
    /**
     * The number of rows at the top of a CSV file that BigQuery will skip when reading the data.
     *
     * @stability stable
     */
    readonly skipLeadingRows?: number;
}
/**
 * @stability stable
 */
export interface BigqueryTableExternalDataConfigurationGoogleSheetsOptions {
    /**
     * Range of a sheet to query from.
     *
     * Only used when non-empty. At least one of range or skip_leading_rows must be set. Typical format: "sheet_name!top_left_cell_id:bottom_right_cell_id" For example: "sheet1!A1:B20"
     *
     * @stability stable
     */
    readonly range?: string;
    /**
     * The number of rows at the top of the sheet that BigQuery will skip when reading the data.
     *
     * At least one of range or skip_leading_rows must be set.
     *
     * @stability stable
     */
    readonly skipLeadingRows?: number;
}
/**
 * @stability stable
 */
export interface BigqueryTableExternalDataConfigurationHivePartitioningOptions {
    /**
     * When set, what mode of hive partitioning to use when reading data.
     *
     * @stability stable
     */
    readonly mode?: string;
    /**
     * When hive partition detection is requested, a common for all source uris must be required.
     *
     * The prefix must end immediately before the partition key encoding begins.
     *
     * @stability stable
     */
    readonly sourceUriPrefix?: string;
}
/**
 * @stability stable
 */
export interface BigqueryTableExternalDataConfiguration {
    /**
     * Let BigQuery try to autodetect the schema and format of the table.
     *
     * @stability stable
     */
    readonly autodetect: boolean;
    /**
     * The compression type of the data source.
     *
     * Valid values are "NONE" or "GZIP".
     *
     * @stability stable
     */
    readonly compression?: string;
    /**
     * Indicates if BigQuery should allow extra values that are not represented in the table schema.
     *
     * If true, the extra values are ignored. If false, records with extra columns are treated as bad records, and if there are too many bad records, an invalid error is returned in the job result. The default value is false.
     *
     * @stability stable
     */
    readonly ignoreUnknownValues?: boolean;
    /**
     * The maximum number of bad records that BigQuery can ignore when reading data.
     *
     * @stability stable
     */
    readonly maxBadRecords?: number;
    /**
     * A JSON schema for the external table.
     *
     * Schema is required for CSV and JSON formats and is disallowed for Google Cloud Bigtable, Cloud Datastore backups, and Avro formats when using external tables.
     *
     * @stability stable
     */
    readonly schema?: string;
    /**
     * The data format.
     *
     * Supported values are: "CSV", "GOOGLE_SHEETS", "NEWLINE_DELIMITED_JSON", "AVRO", "PARQUET", "ORC" and "DATASTORE_BACKUP". To use "GOOGLE_SHEETS" the scopes must include "googleapis.com/auth/drive.readonly".
     *
     * @stability stable
     */
    readonly sourceFormat: string;
    /**
     * A list of the fully-qualified URIs that point to your data in Google Cloud.
     *
     * @stability stable
     */
    readonly sourceUris: string[];
    /**
     * csv_options block.
     *
     * @stability stable
     */
    readonly csvOptions?: BigqueryTableExternalDataConfigurationCsvOptions[];
    /**
     * google_sheets_options block.
     *
     * @stability stable
     */
    readonly googleSheetsOptions?: BigqueryTableExternalDataConfigurationGoogleSheetsOptions[];
    /**
     * hive_partitioning_options block.
     *
     * @stability stable
     */
    readonly hivePartitioningOptions?: BigqueryTableExternalDataConfigurationHivePartitioningOptions[];
}
/**
 * @stability stable
 */
export interface BigqueryTableMaterializedView {
    /**
     * Specifies if BigQuery should automatically refresh materialized view when the base table is updated.
     *
     * The default is true.
     *
     * @stability stable
     */
    readonly enableRefresh?: boolean;
    /**
     * A query whose result is persisted.
     *
     * @stability stable
     */
    readonly query: string;
    /**
     * Specifies maximum frequency at which this materialized view will be refreshed.
     *
     * The default is 1800000
     *
     * @stability stable
     */
    readonly refreshIntervalMs?: number;
}
/**
 * @stability stable
 */
export interface BigqueryTableRangePartitioningRange {
    /**
     * End of the range partitioning, exclusive.
     *
     * @stability stable
     */
    readonly end: number;
    /**
     * The width of each range within the partition.
     *
     * @stability stable
     */
    readonly interval: number;
    /**
     * Start of the range partitioning, inclusive.
     *
     * @stability stable
     */
    readonly start: number;
}
/**
 * @stability stable
 */
export interface BigqueryTableRangePartitioning {
    /**
     * The field used to determine how to create a range-based partition.
     *
     * @stability stable
     */
    readonly field: string;
    /**
     * range block.
     *
     * @stability stable
     */
    readonly range: BigqueryTableRangePartitioningRange[];
}
/**
 * @stability stable
 */
export interface BigqueryTableTimePartitioning {
    /**
     * Number of milliseconds for which to keep the storage for a partition.
     *
     * @stability stable
     */
    readonly expirationMs?: number;
    /**
     * The field used to determine how to create a time-based partition.
     *
     * If time-based partitioning is enabled without this value, the table is partitioned based on the load time.
     *
     * @stability stable
     */
    readonly field?: string;
    /**
     * If set to true, queries over this table require a partition filter that can be used for partition elimination to be specified.
     *
     * @stability stable
     */
    readonly requirePartitionFilter?: boolean;
    /**
     * The supported types are DAY, HOUR, MONTH, and YEAR, which will generate one partition per day, hour, month, and year, respectively.
     *
     * @stability stable
     */
    readonly type: string;
}
/**
 * @stability stable
 */
export interface BigqueryTableView {
    /**
     * A query that BigQuery executes when the view is referenced.
     *
     * @stability stable
     */
    readonly query: string;
    /**
     * Specifies whether to use BigQuery's legacy SQL for this view.
     *
     * The default value is true. If set to false, the view will use BigQuery's standard SQL
     *
     * @stability stable
     */
    readonly useLegacySql?: boolean;
}
/**
 * @stability stable
 */
export declare class BigqueryTable extends cdktf.TerraformResource {
    /**
     * @stability stable
     */
    constructor(scope: Construct, id: string, config: BigqueryTableConfig);
    private _clustering?;
    /**
     * @stability stable
     */
    get clustering(): string[];
    /**
     * @stability stable
     */
    set clustering(value: string[]);
    /**
     * @stability stable
     */
    resetClustering(): void;
    /**
     * @stability stable
     */
    get clusteringInput(): string[] | undefined;
    /**
     * @stability stable
     */
    get creationTime(): number;
    private _datasetId;
    /**
     * @stability stable
     */
    get datasetId(): string;
    /**
     * @stability stable
     */
    set datasetId(value: string);
    /**
     * @stability stable
     */
    get datasetIdInput(): string;
    private _description?;
    /**
     * @stability stable
     */
    get description(): string;
    /**
     * @stability stable
     */
    set description(value: string);
    /**
     * @stability stable
     */
    resetDescription(): void;
    /**
     * @stability stable
     */
    get descriptionInput(): string | undefined;
    /**
     * @stability stable
     */
    get etag(): string;
    private _expirationTime?;
    /**
     * @stability stable
     */
    get expirationTime(): number;
    /**
     * @stability stable
     */
    set expirationTime(value: number);
    /**
     * @stability stable
     */
    resetExpirationTime(): void;
    /**
     * @stability stable
     */
    get expirationTimeInput(): number | undefined;
    private _friendlyName?;
    /**
     * @stability stable
     */
    get friendlyName(): string;
    /**
     * @stability stable
     */
    set friendlyName(value: string);
    /**
     * @stability stable
     */
    resetFriendlyName(): void;
    /**
     * @stability stable
     */
    get friendlyNameInput(): string | undefined;
    /**
     * @stability stable
     */
    get id(): string;
    private _labels?;
    /**
     * @stability stable
     */
    get labels(): {
        [key: string]: string;
    };
    /**
     * @stability stable
     */
    set labels(value: {
        [key: string]: string;
    });
    /**
     * @stability stable
     */
    resetLabels(): void;
    /**
     * @stability stable
     */
    get labelsInput(): {
        [key: string]: string;
    } | undefined;
    /**
     * @stability stable
     */
    get lastModifiedTime(): number;
    /**
     * @stability stable
     */
    get location(): string;
    /**
     * @stability stable
     */
    get numBytes(): number;
    /**
     * @stability stable
     */
    get numLongTermBytes(): number;
    /**
     * @stability stable
     */
    get numRows(): number;
    private _project?;
    /**
     * @stability stable
     */
    get project(): string;
    /**
     * @stability stable
     */
    set project(value: string);
    /**
     * @stability stable
     */
    resetProject(): void;
    /**
     * @stability stable
     */
    get projectInput(): string | undefined;
    private _schema?;
    /**
     * @stability stable
     */
    get schema(): string;
    /**
     * @stability stable
     */
    set schema(value: string);
    /**
     * @stability stable
     */
    resetSchema(): void;
    /**
     * @stability stable
     */
    get schemaInput(): string | undefined;
    /**
     * @stability stable
     */
    get selfLink(): string;
    private _tableId;
    /**
     * @stability stable
     */
    get tableId(): string;
    /**
     * @stability stable
     */
    set tableId(value: string);
    /**
     * @stability stable
     */
    get tableIdInput(): string;
    /**
     * @stability stable
     */
    get type(): string;
    private _encryptionConfiguration?;
    /**
     * @stability stable
     */
    get encryptionConfiguration(): BigqueryTableEncryptionConfiguration[];
    /**
     * @stability stable
     */
    set encryptionConfiguration(value: BigqueryTableEncryptionConfiguration[]);
    /**
     * @stability stable
     */
    resetEncryptionConfiguration(): void;
    /**
     * @stability stable
     */
    get encryptionConfigurationInput(): BigqueryTableEncryptionConfiguration[] | undefined;
    private _externalDataConfiguration?;
    /**
     * @stability stable
     */
    get externalDataConfiguration(): BigqueryTableExternalDataConfiguration[];
    /**
     * @stability stable
     */
    set externalDataConfiguration(value: BigqueryTableExternalDataConfiguration[]);
    /**
     * @stability stable
     */
    resetExternalDataConfiguration(): void;
    /**
     * @stability stable
     */
    get externalDataConfigurationInput(): BigqueryTableExternalDataConfiguration[] | undefined;
    private _materializedView?;
    /**
     * @stability stable
     */
    get materializedView(): BigqueryTableMaterializedView[];
    /**
     * @stability stable
     */
    set materializedView(value: BigqueryTableMaterializedView[]);
    /**
     * @stability stable
     */
    resetMaterializedView(): void;
    /**
     * @stability stable
     */
    get materializedViewInput(): BigqueryTableMaterializedView[] | undefined;
    private _rangePartitioning?;
    /**
     * @stability stable
     */
    get rangePartitioning(): BigqueryTableRangePartitioning[];
    /**
     * @stability stable
     */
    set rangePartitioning(value: BigqueryTableRangePartitioning[]);
    /**
     * @stability stable
     */
    resetRangePartitioning(): void;
    /**
     * @stability stable
     */
    get rangePartitioningInput(): BigqueryTableRangePartitioning[] | undefined;
    private _timePartitioning?;
    /**
     * @stability stable
     */
    get timePartitioning(): BigqueryTableTimePartitioning[];
    /**
     * @stability stable
     */
    set timePartitioning(value: BigqueryTableTimePartitioning[]);
    /**
     * @stability stable
     */
    resetTimePartitioning(): void;
    /**
     * @stability stable
     */
    get timePartitioningInput(): BigqueryTableTimePartitioning[] | undefined;
    private _view?;
    /**
     * @stability stable
     */
    get view(): BigqueryTableView[];
    /**
     * @stability stable
     */
    set view(value: BigqueryTableView[]);
    /**
     * @stability stable
     */
    resetView(): void;
    /**
     * @stability stable
     */
    get viewInput(): BigqueryTableView[] | undefined;
    /**
     * @stability stable
     */
    protected synthesizeAttributes(): {
        [name: string]: any;
    };
}
