import { Construct } from 'constructs';
import * as cdktf from 'cdktf';
/**
 * @stability stable
 */
export interface BinaryAuthorizationAttestorConfig extends cdktf.TerraformMetaArguments {
    /**
     * A descriptive comment.
     *
     * This field may be updated. The field may be
     * displayed in chooser dialogs.
     *
     * @stability stable
     */
    readonly description?: string;
    /**
     * The resource name.
     *
     * @stability stable
     */
    readonly name: string;
    /**
     * @stability stable
     */
    readonly project?: string;
    /**
     * attestation_authority_note block.
     *
     * @stability stable
     */
    readonly attestationAuthorityNote: BinaryAuthorizationAttestorAttestationAuthorityNote[];
    /**
     * timeouts block.
     *
     * @stability stable
     */
    readonly timeouts?: BinaryAuthorizationAttestorTimeouts;
}
/**
 * @stability stable
 */
export interface BinaryAuthorizationAttestorAttestationAuthorityNotePublicKeysPkixPublicKey {
    /**
     * A PEM-encoded public key, as described in 'https://tools.ietf.org/html/rfc7468#section-13'.
     *
     * @stability stable
     */
    readonly publicKeyPem?: string;
    /**
     * The signature algorithm used to verify a message against a signature using this key.
     *
     * These signature algorithm must
     * match the structure and any object identifiers encoded in
     * publicKeyPem (i.e. this algorithm must match that of the
     * public key).
     *
     * @stability stable
     */
    readonly signatureAlgorithm?: string;
}
/**
 * @stability stable
 */
export interface BinaryAuthorizationAttestorAttestationAuthorityNotePublicKeys {
    /**
     * ASCII-armored representation of a PGP public key, as the entire output by the command 'gpg --export --armor foo@example.com' (either LF or CRLF line endings). When using this field, id should be left blank. The BinAuthz API handlers will calculate the ID and fill it in automatically. BinAuthz computes this ID as the OpenPGP RFC4880 V4 fingerprint, represented as upper-case hex. If id is provided by the caller, it will be overwritten by the API-calculated ID.
     *
     * @stability stable
     */
    readonly asciiArmoredPgpPublicKey?: string;
    /**
     * A descriptive comment.
     *
     * This field may be updated.
     *
     * @stability stable
     */
    readonly comment?: string;
    /**
     * The ID of this public key.
     *
     * Signatures verified by BinAuthz
     * must include the ID of the public key that can be used to
     * verify them, and that ID must match the contents of this
     * field exactly. Additional restrictions on this field can
     * be imposed based on which public key type is encapsulated.
     * See the documentation on publicKey cases below for details.
     *
     * @stability stable
     */
    readonly id?: string;
    /**
     * pkix_public_key block.
     *
     * @stability stable
     */
    readonly pkixPublicKey?: BinaryAuthorizationAttestorAttestationAuthorityNotePublicKeysPkixPublicKey[];
}
/**
 * @stability stable
 */
export interface BinaryAuthorizationAttestorAttestationAuthorityNote {
    /**
     * The resource name of a ATTESTATION_AUTHORITY Note, created by the user.
     *
     * If the Note is in a different project from the Attestor, it
     * should be specified in the format 'projects/*\/notes/*' (or the legacy
     * 'providers/*\/notes/*'). This field may not be updated.
     * An attestation by this attestor is stored as a Container Analysis
     * ATTESTATION_AUTHORITY Occurrence that names a container image
     * and that links to this Note.
     *
     * @stability stable
     */
    readonly noteReference: string;
    /**
     * public_keys block.
     *
     * @stability stable
     */
    readonly publicKeys?: BinaryAuthorizationAttestorAttestationAuthorityNotePublicKeys[];
}
/**
 * @stability stable
 */
export interface BinaryAuthorizationAttestorTimeouts {
    /**
     * @stability stable
     */
    readonly create?: string;
    /**
     * @stability stable
     */
    readonly delete?: string;
    /**
     * @stability stable
     */
    readonly update?: string;
}
/**
 * @stability stable
 */
export declare class BinaryAuthorizationAttestor extends cdktf.TerraformResource {
    /**
     * @stability stable
     */
    constructor(scope: Construct, id: string, config: BinaryAuthorizationAttestorConfig);
    private _description?;
    /**
     * @stability stable
     */
    get description(): string;
    /**
     * @stability stable
     */
    set description(value: string);
    /**
     * @stability stable
     */
    resetDescription(): void;
    /**
     * @stability stable
     */
    get descriptionInput(): string | undefined;
    /**
     * @stability stable
     */
    get id(): string;
    private _name;
    /**
     * @stability stable
     */
    get name(): string;
    /**
     * @stability stable
     */
    set name(value: string);
    /**
     * @stability stable
     */
    get nameInput(): string;
    private _project?;
    /**
     * @stability stable
     */
    get project(): string;
    /**
     * @stability stable
     */
    set project(value: string);
    /**
     * @stability stable
     */
    resetProject(): void;
    /**
     * @stability stable
     */
    get projectInput(): string | undefined;
    private _attestationAuthorityNote;
    /**
     * @stability stable
     */
    get attestationAuthorityNote(): BinaryAuthorizationAttestorAttestationAuthorityNote[];
    /**
     * @stability stable
     */
    set attestationAuthorityNote(value: BinaryAuthorizationAttestorAttestationAuthorityNote[]);
    /**
     * @stability stable
     */
    get attestationAuthorityNoteInput(): BinaryAuthorizationAttestorAttestationAuthorityNote[];
    private _timeouts?;
    /**
     * @stability stable
     */
    get timeouts(): BinaryAuthorizationAttestorTimeouts;
    /**
     * @stability stable
     */
    set timeouts(value: BinaryAuthorizationAttestorTimeouts);
    /**
     * @stability stable
     */
    resetTimeouts(): void;
    /**
     * @stability stable
     */
    get timeoutsInput(): BinaryAuthorizationAttestorTimeouts | undefined;
    /**
     * @stability stable
     */
    protected synthesizeAttributes(): {
        [name: string]: any;
    };
}
