import { Construct } from 'constructs';
import * as cdktf from 'cdktf';
/**
 * @stability stable
 */
export interface CloudAssetFolderFeedConfig extends cdktf.TerraformMetaArguments {
    /**
     * A list of the full names of the assets to receive updates.
     *
     * You must specify either or both of
     * assetNames and assetTypes. Only asset updates matching specified assetNames and assetTypes are
     * exported to the feed. For example: //compute.googleapis.com/projects/my_project_123/zones/zone1/instances/instance1.
     * See https://cloud.google.com/apis/design/resourceNames#fullResourceName for more info.
     *
     * @stability stable
     */
    readonly assetNames?: string[];
    /**
     * A list of types of the assets to receive updates.
     *
     * You must specify either or both of assetNames
     * and assetTypes. Only asset updates matching specified assetNames and assetTypes are exported to
     * the feed. For example: "compute.googleapis.com/Disk"
     * See https://cloud.google.com/asset-inventory/docs/supported-asset-types for a list of all
     * supported asset types.
     *
     * @stability stable
     */
    readonly assetTypes?: string[];
    /**
     * The project whose identity will be used when sending messages to the destination pubsub topic.
     *
     * It also specifies the project for API
     * enablement check, quota, and billing.
     *
     * @stability stable
     */
    readonly billingProject: string;
    /**
     * Asset content type.
     *
     * If not specified, no content but the asset name and type will be returned. Possible values: ["CONTENT_TYPE_UNSPECIFIED", "RESOURCE", "IAM_POLICY", "ORG_POLICY", "ACCESS_POLICY"]
     *
     * @stability stable
     */
    readonly contentType?: string;
    /**
     * This is the client-assigned asset feed identifier and it needs to be unique under a specific parent.
     *
     * @stability stable
     */
    readonly feedId: string;
    /**
     * The folder this feed should be created in.
     *
     * @stability stable
     */
    readonly folder: string;
    /**
     * condition block.
     *
     * @stability stable
     */
    readonly condition?: CloudAssetFolderFeedCondition[];
    /**
     * feed_output_config block.
     *
     * @stability stable
     */
    readonly feedOutputConfig: CloudAssetFolderFeedFeedOutputConfig[];
    /**
     * timeouts block.
     *
     * @stability stable
     */
    readonly timeouts?: CloudAssetFolderFeedTimeouts;
}
/**
 * @stability stable
 */
export interface CloudAssetFolderFeedCondition {
    /**
     * Description of the expression.
     *
     * This is a longer text which describes the expression,
     * e.g. when hovered over it in a UI.
     *
     * @stability stable
     */
    readonly description?: string;
    /**
     * Textual representation of an expression in Common Expression Language syntax.
     *
     * @stability stable
     */
    readonly expression: string;
    /**
     * String indicating the location of the expression for error reporting, e.g. a file  name and a position in the file.
     *
     * @stability stable
     */
    readonly location?: string;
    /**
     * Title for the expression, i.e. a short string describing its purpose. This can be used e.g. in UIs which allow to enter the expression.
     *
     * @stability stable
     */
    readonly title?: string;
}
/**
 * @stability stable
 */
export interface CloudAssetFolderFeedFeedOutputConfigPubsubDestination {
    /**
     * Destination on Cloud Pubsub topic.
     *
     * @stability stable
     */
    readonly topic: string;
}
/**
 * @stability stable
 */
export interface CloudAssetFolderFeedFeedOutputConfig {
    /**
     * pubsub_destination block.
     *
     * @stability stable
     */
    readonly pubsubDestination: CloudAssetFolderFeedFeedOutputConfigPubsubDestination[];
}
/**
 * @stability stable
 */
export interface CloudAssetFolderFeedTimeouts {
    /**
     * @stability stable
     */
    readonly create?: string;
    /**
     * @stability stable
     */
    readonly delete?: string;
    /**
     * @stability stable
     */
    readonly update?: string;
}
/**
 * @stability stable
 */
export declare class CloudAssetFolderFeed extends cdktf.TerraformResource {
    /**
     * @stability stable
     */
    constructor(scope: Construct, id: string, config: CloudAssetFolderFeedConfig);
    private _assetNames?;
    /**
     * @stability stable
     */
    get assetNames(): string[];
    /**
     * @stability stable
     */
    set assetNames(value: string[]);
    /**
     * @stability stable
     */
    resetAssetNames(): void;
    /**
     * @stability stable
     */
    get assetNamesInput(): string[] | undefined;
    private _assetTypes?;
    /**
     * @stability stable
     */
    get assetTypes(): string[];
    /**
     * @stability stable
     */
    set assetTypes(value: string[]);
    /**
     * @stability stable
     */
    resetAssetTypes(): void;
    /**
     * @stability stable
     */
    get assetTypesInput(): string[] | undefined;
    private _billingProject;
    /**
     * @stability stable
     */
    get billingProject(): string;
    /**
     * @stability stable
     */
    set billingProject(value: string);
    /**
     * @stability stable
     */
    get billingProjectInput(): string;
    private _contentType?;
    /**
     * @stability stable
     */
    get contentType(): string;
    /**
     * @stability stable
     */
    set contentType(value: string);
    /**
     * @stability stable
     */
    resetContentType(): void;
    /**
     * @stability stable
     */
    get contentTypeInput(): string | undefined;
    private _feedId;
    /**
     * @stability stable
     */
    get feedId(): string;
    /**
     * @stability stable
     */
    set feedId(value: string);
    /**
     * @stability stable
     */
    get feedIdInput(): string;
    private _folder;
    /**
     * @stability stable
     */
    get folder(): string;
    /**
     * @stability stable
     */
    set folder(value: string);
    /**
     * @stability stable
     */
    get folderInput(): string;
    /**
     * @stability stable
     */
    get folderId(): string;
    /**
     * @stability stable
     */
    get id(): string;
    /**
     * @stability stable
     */
    get name(): string;
    private _condition?;
    /**
     * @stability stable
     */
    get condition(): CloudAssetFolderFeedCondition[];
    /**
     * @stability stable
     */
    set condition(value: CloudAssetFolderFeedCondition[]);
    /**
     * @stability stable
     */
    resetCondition(): void;
    /**
     * @stability stable
     */
    get conditionInput(): CloudAssetFolderFeedCondition[] | undefined;
    private _feedOutputConfig;
    /**
     * @stability stable
     */
    get feedOutputConfig(): CloudAssetFolderFeedFeedOutputConfig[];
    /**
     * @stability stable
     */
    set feedOutputConfig(value: CloudAssetFolderFeedFeedOutputConfig[]);
    /**
     * @stability stable
     */
    get feedOutputConfigInput(): CloudAssetFolderFeedFeedOutputConfig[];
    private _timeouts?;
    /**
     * @stability stable
     */
    get timeouts(): CloudAssetFolderFeedTimeouts;
    /**
     * @stability stable
     */
    set timeouts(value: CloudAssetFolderFeedTimeouts);
    /**
     * @stability stable
     */
    resetTimeouts(): void;
    /**
     * @stability stable
     */
    get timeoutsInput(): CloudAssetFolderFeedTimeouts | undefined;
    /**
     * @stability stable
     */
    protected synthesizeAttributes(): {
        [name: string]: any;
    };
}
