import { Construct } from 'constructs';
import * as cdktf from 'cdktf';
/**
 * @stability stable
 */
export interface CloudIdentityGroupMembershipConfig extends cdktf.TerraformMetaArguments {
    /**
     * The name of the Group to create this membership in.
     *
     * @stability stable
     */
    readonly group: string;
    /**
     * preferred_member_key block.
     *
     * @stability stable
     */
    readonly preferredMemberKey?: CloudIdentityGroupMembershipPreferredMemberKey[];
    /**
     * roles block.
     *
     * @stability stable
     */
    readonly roles: CloudIdentityGroupMembershipRoles[];
    /**
     * timeouts block.
     *
     * @stability stable
     */
    readonly timeouts?: CloudIdentityGroupMembershipTimeouts;
}
/**
 * @stability stable
 */
export interface CloudIdentityGroupMembershipPreferredMemberKey {
    /**
     * The ID of the entity.
     *
     * For Google-managed entities, the id must be the email address of an existing
     * group or user.
     *
     * For external-identity-mapped entities, the id must be a string conforming
     * to the Identity Source's requirements.
     *
     * Must be unique within a namespace.
     *
     * @stability stable
     */
    readonly id: string;
    /**
     * The namespace in which the entity exists.
     *
     * If not specified, the EntityKey represents a Google-managed entity
     * such as a Google user or a Google Group.
     *
     * If specified, the EntityKey represents an external-identity-mapped group.
     * The namespace must correspond to an identity source created in Admin Console
     * and must be in the form of 'identitysources/{identity_source_id}'.
     *
     * @stability stable
     */
    readonly namespace?: string;
}
/**
 * @stability stable
 */
export interface CloudIdentityGroupMembershipRoles {
    /**
     * The name of the MembershipRole.
     *
     * Must be one of OWNER, MANAGER, MEMBER. Possible values: ["OWNER", "MANAGER", "MEMBER"]
     *
     * @stability stable
     */
    readonly name: string;
}
/**
 * @stability stable
 */
export interface CloudIdentityGroupMembershipTimeouts {
    /**
     * @stability stable
     */
    readonly create?: string;
    /**
     * @stability stable
     */
    readonly delete?: string;
    /**
     * @stability stable
     */
    readonly update?: string;
}
/**
 * @stability stable
 */
export declare class CloudIdentityGroupMembership extends cdktf.TerraformResource {
    /**
     * @stability stable
     */
    constructor(scope: Construct, id: string, config: CloudIdentityGroupMembershipConfig);
    /**
     * @stability stable
     */
    get createTime(): string;
    private _group;
    /**
     * @stability stable
     */
    get group(): string;
    /**
     * @stability stable
     */
    set group(value: string);
    /**
     * @stability stable
     */
    get groupInput(): string;
    /**
     * @stability stable
     */
    get id(): string;
    /**
     * @stability stable
     */
    get name(): string;
    /**
     * @stability stable
     */
    get type(): string;
    /**
     * @stability stable
     */
    get updateTime(): string;
    private _preferredMemberKey?;
    /**
     * @stability stable
     */
    get preferredMemberKey(): CloudIdentityGroupMembershipPreferredMemberKey[];
    /**
     * @stability stable
     */
    set preferredMemberKey(value: CloudIdentityGroupMembershipPreferredMemberKey[]);
    /**
     * @stability stable
     */
    resetPreferredMemberKey(): void;
    /**
     * @stability stable
     */
    get preferredMemberKeyInput(): CloudIdentityGroupMembershipPreferredMemberKey[] | undefined;
    private _roles;
    /**
     * @stability stable
     */
    get roles(): CloudIdentityGroupMembershipRoles[];
    /**
     * @stability stable
     */
    set roles(value: CloudIdentityGroupMembershipRoles[]);
    /**
     * @stability stable
     */
    get rolesInput(): CloudIdentityGroupMembershipRoles[];
    private _timeouts?;
    /**
     * @stability stable
     */
    get timeouts(): CloudIdentityGroupMembershipTimeouts;
    /**
     * @stability stable
     */
    set timeouts(value: CloudIdentityGroupMembershipTimeouts);
    /**
     * @stability stable
     */
    resetTimeouts(): void;
    /**
     * @stability stable
     */
    get timeoutsInput(): CloudIdentityGroupMembershipTimeouts | undefined;
    /**
     * @stability stable
     */
    protected synthesizeAttributes(): {
        [name: string]: any;
    };
}
