import { Construct } from 'constructs';
import * as cdktf from 'cdktf';
/**
 * @stability stable
 */
export interface CloudIdentityGroupConfig extends cdktf.TerraformMetaArguments {
    /**
     * An extended description to help users determine the purpose of a Group.
     *
     * Must not be longer than 4,096 characters.
     *
     * @stability stable
     */
    readonly description?: string;
    /**
     * The display name of the Group.
     *
     * @stability stable
     */
    readonly displayName?: string;
    /**
     * The labels that apply to the Group.
     *
     * Must not contain more than one entry. Must contain the entry
     * 'cloudidentity.googleapis.com/groups.discussion_forum': '' if the Group is a Google Group or
     * 'system/groups/external': '' if the Group is an external-identity-mapped group.
     *
     * @stability stable
     */
    readonly labels: {
        [key: string]: string;
    };
    /**
     * The resource name of the entity under which this Group resides in the Cloud Identity resource hierarchy.
     *
     * Must be of the form identitysources/{identity_source_id} for external-identity-mapped
     * groups or customers/{customer_id} for Google Groups.
     *
     * @stability stable
     */
    readonly parent: string;
    /**
     * group_key block.
     *
     * @stability stable
     */
    readonly groupKey: CloudIdentityGroupGroupKey[];
    /**
     * timeouts block.
     *
     * @stability stable
     */
    readonly timeouts?: CloudIdentityGroupTimeouts;
}
/**
 * @stability stable
 */
export interface CloudIdentityGroupGroupKey {
    /**
     * The ID of the entity.
     *
     * For Google-managed entities, the id must be the email address of an existing
     * group or user.
     *
     * For external-identity-mapped entities, the id must be a string conforming
     * to the Identity Source's requirements.
     *
     * Must be unique within a namespace.
     *
     * @stability stable
     */
    readonly id: string;
    /**
     * The namespace in which the entity exists.
     *
     * If not specified, the EntityKey represents a Google-managed entity
     * such as a Google user or a Google Group.
     *
     * If specified, the EntityKey represents an external-identity-mapped group.
     * The namespace must correspond to an identity source created in Admin Console
     * and must be in the form of 'identitysources/{identity_source_id}'.
     *
     * @stability stable
     */
    readonly namespace?: string;
}
/**
 * @stability stable
 */
export interface CloudIdentityGroupTimeouts {
    /**
     * @stability stable
     */
    readonly create?: string;
    /**
     * @stability stable
     */
    readonly delete?: string;
    /**
     * @stability stable
     */
    readonly update?: string;
}
/**
 * @stability stable
 */
export declare class CloudIdentityGroup extends cdktf.TerraformResource {
    /**
     * @stability stable
     */
    constructor(scope: Construct, id: string, config: CloudIdentityGroupConfig);
    /**
     * @stability stable
     */
    get createTime(): string;
    private _description?;
    /**
     * @stability stable
     */
    get description(): string;
    /**
     * @stability stable
     */
    set description(value: string);
    /**
     * @stability stable
     */
    resetDescription(): void;
    /**
     * @stability stable
     */
    get descriptionInput(): string | undefined;
    private _displayName?;
    /**
     * @stability stable
     */
    get displayName(): string;
    /**
     * @stability stable
     */
    set displayName(value: string);
    /**
     * @stability stable
     */
    resetDisplayName(): void;
    /**
     * @stability stable
     */
    get displayNameInput(): string | undefined;
    /**
     * @stability stable
     */
    get id(): string;
    private _labels;
    /**
     * @stability stable
     */
    get labels(): {
        [key: string]: string;
    };
    /**
     * @stability stable
     */
    set labels(value: {
        [key: string]: string;
    });
    /**
     * @stability stable
     */
    get labelsInput(): {
        [key: string]: string;
    };
    /**
     * @stability stable
     */
    get name(): string;
    private _parent;
    /**
     * @stability stable
     */
    get parent(): string;
    /**
     * @stability stable
     */
    set parent(value: string);
    /**
     * @stability stable
     */
    get parentInput(): string;
    /**
     * @stability stable
     */
    get updateTime(): string;
    private _groupKey;
    /**
     * @stability stable
     */
    get groupKey(): CloudIdentityGroupGroupKey[];
    /**
     * @stability stable
     */
    set groupKey(value: CloudIdentityGroupGroupKey[]);
    /**
     * @stability stable
     */
    get groupKeyInput(): CloudIdentityGroupGroupKey[];
    private _timeouts?;
    /**
     * @stability stable
     */
    get timeouts(): CloudIdentityGroupTimeouts;
    /**
     * @stability stable
     */
    set timeouts(value: CloudIdentityGroupTimeouts);
    /**
     * @stability stable
     */
    resetTimeouts(): void;
    /**
     * @stability stable
     */
    get timeoutsInput(): CloudIdentityGroupTimeouts | undefined;
    /**
     * @stability stable
     */
    protected synthesizeAttributes(): {
        [name: string]: any;
    };
}
