import { Construct } from 'constructs';
import * as cdktf from 'cdktf';
/**
 * @stability stable
 */
export interface CloudRunServiceConfig extends cdktf.TerraformMetaArguments {
    /**
     * @stability stable
     */
    readonly autogenerateRevisionName?: boolean;
    /**
     * The location of the cloud run instance.
     *
     * eg us-central1
     *
     * @stability stable
     */
    readonly location: string;
    /**
     * Name must be unique within a namespace, within a Cloud Run region.
     *
     * Is required when creating resources. Name is primarily intended
     * for creation idempotence and configuration definition. Cannot be updated.
     * More info: http://kubernetes.io/docs/user-guide/identifiers#names
     *
     * @stability stable
     */
    readonly name: string;
    /**
     * @stability stable
     */
    readonly project?: string;
    /**
     * metadata block.
     *
     * @stability stable
     */
    readonly metadata?: CloudRunServiceMetadata[];
    /**
     * template block.
     *
     * @stability stable
     */
    readonly template?: CloudRunServiceTemplate[];
    /**
     * timeouts block.
     *
     * @stability stable
     */
    readonly timeouts?: CloudRunServiceTimeouts;
    /**
     * traffic block.
     *
     * @stability stable
     */
    readonly traffic?: CloudRunServiceTraffic[];
}
/**
 * @stability stable
 */
export declare class CloudRunServiceStatusConditions extends cdktf.ComplexComputedList {
    /**
     * @stability stable
     */
    get message(): string;
    /**
     * @stability stable
     */
    get reason(): string;
    /**
     * @stability stable
     */
    get status(): string;
    /**
     * @stability stable
     */
    get type(): string;
}
/**
 * @stability stable
 */
export declare class CloudRunServiceStatus extends cdktf.ComplexComputedList {
    /**
     * @stability stable
     */
    get conditions(): any;
    /**
     * @stability stable
     */
    get latestCreatedRevisionName(): string;
    /**
     * @stability stable
     */
    get latestReadyRevisionName(): string;
    /**
     * @stability stable
     */
    get observedGeneration(): number;
    /**
     * @stability stable
     */
    get url(): string;
}
/**
 * @stability stable
 */
export interface CloudRunServiceMetadata {
    /**
     * Annotations is a key value map stored with a resource that may be set by external tools to store and retrieve arbitrary metadata.
     *
     * More
     * info: http://kubernetes.io/docs/user-guide/annotations
     *
     * @stability stable
     */
    readonly annotations?: {
        [key: string]: string;
    };
    /**
     * Map of string keys and values that can be used to organize and categorize (scope and select) objects.
     *
     * May match selectors of replication controllers
     * and routes.
     * More info: http://kubernetes.io/docs/user-guide/labels
     *
     * @stability stable
     */
    readonly labels?: {
        [key: string]: string;
    };
    /**
     * In Cloud Run the namespace must be equal to either the project ID or project number.
     *
     * @stability stable
     */
    readonly namespace?: string;
}
/**
 * @stability stable
 */
export interface CloudRunServiceTemplateMetadata {
    /**
     * Annotations is a key value map stored with a resource that may be set by external tools to store and retrieve arbitrary metadata.
     *
     * More
     * info: http://kubernetes.io/docs/user-guide/annotations
     *
     * @stability stable
     */
    readonly annotations?: {
        [key: string]: string;
    };
    /**
     * Map of string keys and values that can be used to organize and categorize (scope and select) objects.
     *
     * May match selectors of replication controllers
     * and routes.
     * More info: http://kubernetes.io/docs/user-guide/labels
     *
     * @stability stable
     */
    readonly labels?: {
        [key: string]: string;
    };
    /**
     * Name must be unique within a namespace, within a Cloud Run region.
     *
     * Is required when creating resources. Name is primarily intended
     * for creation idempotence and configuration definition. Cannot be updated.
     * More info: http://kubernetes.io/docs/user-guide/identifiers#names
     *
     * @stability stable
     */
    readonly name?: string;
    /**
     * In Cloud Run the namespace must be equal to either the project ID or project number.
     *
     * It will default to the resource's project.
     *
     * @stability stable
     */
    readonly namespace?: string;
}
/**
 * @stability stable
 */
export interface CloudRunServiceTemplateSpecContainersEnv {
    /**
     * Name of the environment variable.
     *
     * @stability stable
     */
    readonly name?: string;
    /**
     * Variable references $(VAR_NAME) are expanded using the previous defined environment variables in the container and any route environment variables.
     *
     * If a variable cannot be resolved,
     * the reference in the input string will be unchanged. The $(VAR_NAME)
     * syntax can be escaped with a double $$, ie: $$(VAR_NAME). Escaped
     * references will never be expanded, regardless of whether the variable
     * exists or not.
     * Defaults to "".
     *
     * @stability stable
     */
    readonly value?: string;
}
/**
 * @stability stable
 */
export interface CloudRunServiceTemplateSpecContainersEnvFromConfigMapRefLocalObjectReference {
    /**
     * Name of the referent.
     *
     * More info:
     * https://kubernetes.io/docs/concepts/overview/working-with-objects/names/#names
     *
     * @stability stable
     */
    readonly name: string;
}
/**
 * @stability stable
 */
export interface CloudRunServiceTemplateSpecContainersEnvFromConfigMapRef {
    /**
     * Specify whether the ConfigMap must be defined.
     *
     * @stability stable
     */
    readonly optional?: boolean;
    /**
     * local_object_reference block.
     *
     * @stability stable
     */
    readonly localObjectReference?: CloudRunServiceTemplateSpecContainersEnvFromConfigMapRefLocalObjectReference[];
}
/**
 * @stability stable
 */
export interface CloudRunServiceTemplateSpecContainersEnvFromSecretRefLocalObjectReference {
    /**
     * Name of the referent.
     *
     * More info:
     * https://kubernetes.io/docs/concepts/overview/working-with-objects/names/#names
     *
     * @stability stable
     */
    readonly name: string;
}
/**
 * @stability stable
 */
export interface CloudRunServiceTemplateSpecContainersEnvFromSecretRef {
    /**
     * Specify whether the Secret must be defined.
     *
     * @stability stable
     */
    readonly optional?: boolean;
    /**
     * local_object_reference block.
     *
     * @stability stable
     */
    readonly localObjectReference?: CloudRunServiceTemplateSpecContainersEnvFromSecretRefLocalObjectReference[];
}
/**
 * @stability stable
 */
export interface CloudRunServiceTemplateSpecContainersEnvFrom {
    /**
     * An optional identifier to prepend to each key in the ConfigMap.
     *
     * @stability stable
     */
    readonly prefix?: string;
    /**
     * config_map_ref block.
     *
     * @stability stable
     */
    readonly configMapRef?: CloudRunServiceTemplateSpecContainersEnvFromConfigMapRef[];
    /**
     * secret_ref block.
     *
     * @stability stable
     */
    readonly secretRef?: CloudRunServiceTemplateSpecContainersEnvFromSecretRef[];
}
/**
 * @stability stable
 */
export interface CloudRunServiceTemplateSpecContainersPorts {
    /**
     * Port number.
     *
     * @stability stable
     */
    readonly containerPort: number;
    /**
     * Name of the port.
     *
     * @stability stable
     */
    readonly name?: string;
    /**
     * Protocol used on port.
     *
     * Defaults to TCP.
     *
     * @stability stable
     */
    readonly protocol?: string;
}
/**
 * @stability stable
 */
export interface CloudRunServiceTemplateSpecContainersResources {
    /**
     * Limits describes the maximum amount of compute resources allowed.
     *
     * The values of the map is string form of the 'quantity' k8s type:
     * https://github.com/kubernetes/kubernetes/blob/master/staging/src/k8s.io/apimachinery/pkg/api/resource/quantity.go
     *
     * @stability stable
     */
    readonly limits?: {
        [key: string]: string;
    };
    /**
     * Requests describes the minimum amount of compute resources required.
     *
     * If Requests is omitted for a container, it defaults to Limits if that is
     * explicitly specified, otherwise to an implementation-defined value.
     * The values of the map is string form of the 'quantity' k8s type:
     * https://github.com/kubernetes/kubernetes/blob/master/staging/src/k8s.io/apimachinery/pkg/api/resource/quantity.go
     *
     * @stability stable
     */
    readonly requests?: {
        [key: string]: string;
    };
}
/**
 * @stability stable
 */
export interface CloudRunServiceTemplateSpecContainers {
    /**
     * Arguments to the entrypoint.
     *
     * The docker image's CMD is used if this is not provided.
     * Variable references $(VAR_NAME) are expanded using the container's
     * environment. If a variable cannot be resolved, the reference in the input
     * string will be unchanged. The $(VAR_NAME) syntax can be escaped with a
     * double $$, ie: $$(VAR_NAME). Escaped references will never be expanded,
     * regardless of whether the variable exists or not.
     * More info:
     * https://kubernetes.io/docs/tasks/inject-data-application/define-command-argument-container/#running-a-command-in-a-shell
     *
     * @stability stable
     */
    readonly args?: string[];
    /**
     * Entrypoint array.
     *
     * Not executed within a shell.
     * The docker image's ENTRYPOINT is used if this is not provided.
     * Variable references $(VAR_NAME) are expanded using the container's
     * environment. If a variable cannot be resolved, the reference in the input
     * string will be unchanged. The $(VAR_NAME) syntax can be escaped with a
     * double $$, ie: $$(VAR_NAME). Escaped references will never be expanded,
     * regardless of whether the variable exists or not.
     * More info:
     * https://kubernetes.io/docs/tasks/inject-data-application/define-command-argument-container/#running-a-command-in-a-shell
     *
     * @stability stable
     */
    readonly command?: string[];
    /**
     * Docker image name.
     *
     * This is most often a reference to a container located
     * in the container registry, such as gcr.io/cloudrun/hello
     * More info: https://kubernetes.io/docs/concepts/containers/images
     *
     * @stability stable
     */
    readonly image: string;
    /**
     * Container's working directory.
     *
     * If not specified, the container runtime's default will be used, which
     * might be configured in the container image.
     *
     * @stability stable
     */
    readonly workingDir?: string;
    /**
     * env block.
     *
     * @stability stable
     */
    readonly env?: CloudRunServiceTemplateSpecContainersEnv[];
    /**
     * env_from block.
     *
     * @stability stable
     */
    readonly envFrom?: CloudRunServiceTemplateSpecContainersEnvFrom[];
    /**
     * ports block.
     *
     * @stability stable
     */
    readonly ports?: CloudRunServiceTemplateSpecContainersPorts[];
    /**
     * resources block.
     *
     * @stability stable
     */
    readonly resources?: CloudRunServiceTemplateSpecContainersResources[];
}
/**
 * @stability stable
 */
export interface CloudRunServiceTemplateSpec {
    /**
     * ContainerConcurrency specifies the maximum allowed in-flight (concurrent) requests per container of the Revision.
     *
     * Values are:
     * - '0' thread-safe, the system should manage the max concurrency. This is
     * the default value.
     * - '1' not-thread-safe. Single concurrency
     * - '2-N' thread-safe, max concurrency of N
     *
     * @stability stable
     */
    readonly containerConcurrency?: number;
    /**
     * Email address of the IAM service account associated with the revision of the service.
     *
     * The service account represents the identity of the running revision,
     * and determines what permissions the revision has. If not provided, the revision
     * will use the project's default service account.
     *
     * @stability stable
     */
    readonly serviceAccountName?: string;
    /**
     * TimeoutSeconds holds the max duration the instance is allowed for responding to a request.
     *
     * @stability stable
     */
    readonly timeoutSeconds?: number;
    /**
     * containers block.
     *
     * @stability stable
     */
    readonly containers?: CloudRunServiceTemplateSpecContainers[];
}
/**
 * @stability stable
 */
export interface CloudRunServiceTemplate {
    /**
     * metadata block.
     *
     * @stability stable
     */
    readonly metadata?: CloudRunServiceTemplateMetadata[];
    /**
     * spec block.
     *
     * @stability stable
     */
    readonly spec?: CloudRunServiceTemplateSpec[];
}
/**
 * @stability stable
 */
export interface CloudRunServiceTimeouts {
    /**
     * @stability stable
     */
    readonly create?: string;
    /**
     * @stability stable
     */
    readonly delete?: string;
    /**
     * @stability stable
     */
    readonly update?: string;
}
/**
 * @stability stable
 */
export interface CloudRunServiceTraffic {
    /**
     * LatestRevision may be optionally provided to indicate that the latest ready Revision of the Configuration should be used for this traffic target.
     *
     * When
     * provided LatestRevision must be true if RevisionName is empty; it must be
     * false when RevisionName is non-empty.
     *
     * @stability stable
     */
    readonly latestRevision?: boolean;
    /**
     * Percent specifies percent of the traffic to this Revision or Configuration.
     *
     * @stability stable
     */
    readonly percent: number;
    /**
     * RevisionName of a specific revision to which to send this portion of traffic.
     *
     * @stability stable
     */
    readonly revisionName?: string;
}
/**
 * @stability stable
 */
export declare class CloudRunService extends cdktf.TerraformResource {
    /**
     * @stability stable
     */
    constructor(scope: Construct, id: string, config: CloudRunServiceConfig);
    private _autogenerateRevisionName?;
    /**
     * @stability stable
     */
    get autogenerateRevisionName(): boolean;
    /**
     * @stability stable
     */
    set autogenerateRevisionName(value: boolean);
    /**
     * @stability stable
     */
    resetAutogenerateRevisionName(): void;
    /**
     * @stability stable
     */
    get autogenerateRevisionNameInput(): boolean | undefined;
    /**
     * @stability stable
     */
    get id(): string;
    private _location;
    /**
     * @stability stable
     */
    get location(): string;
    /**
     * @stability stable
     */
    set location(value: string);
    /**
     * @stability stable
     */
    get locationInput(): string;
    private _name;
    /**
     * @stability stable
     */
    get name(): string;
    /**
     * @stability stable
     */
    set name(value: string);
    /**
     * @stability stable
     */
    get nameInput(): string;
    private _project?;
    /**
     * @stability stable
     */
    get project(): string;
    /**
     * @stability stable
     */
    set project(value: string);
    /**
     * @stability stable
     */
    resetProject(): void;
    /**
     * @stability stable
     */
    get projectInput(): string | undefined;
    /**
     * @stability stable
     */
    status(index: string): CloudRunServiceStatus;
    private _metadata?;
    /**
     * @stability stable
     */
    get metadata(): CloudRunServiceMetadata[];
    /**
     * @stability stable
     */
    set metadata(value: CloudRunServiceMetadata[]);
    /**
     * @stability stable
     */
    resetMetadata(): void;
    /**
     * @stability stable
     */
    get metadataInput(): CloudRunServiceMetadata[] | undefined;
    private _template?;
    /**
     * @stability stable
     */
    get template(): CloudRunServiceTemplate[];
    /**
     * @stability stable
     */
    set template(value: CloudRunServiceTemplate[]);
    /**
     * @stability stable
     */
    resetTemplate(): void;
    /**
     * @stability stable
     */
    get templateInput(): CloudRunServiceTemplate[] | undefined;
    private _timeouts?;
    /**
     * @stability stable
     */
    get timeouts(): CloudRunServiceTimeouts;
    /**
     * @stability stable
     */
    set timeouts(value: CloudRunServiceTimeouts);
    /**
     * @stability stable
     */
    resetTimeouts(): void;
    /**
     * @stability stable
     */
    get timeoutsInput(): CloudRunServiceTimeouts | undefined;
    private _traffic?;
    /**
     * @stability stable
     */
    get traffic(): CloudRunServiceTraffic[];
    /**
     * @stability stable
     */
    set traffic(value: CloudRunServiceTraffic[]);
    /**
     * @stability stable
     */
    resetTraffic(): void;
    /**
     * @stability stable
     */
    get trafficInput(): CloudRunServiceTraffic[] | undefined;
    /**
     * @stability stable
     */
    protected synthesizeAttributes(): {
        [name: string]: any;
    };
}
