import { Construct } from 'constructs';
import * as cdktf from 'cdktf';
/**
 * @stability stable
 */
export interface CloudiotRegistryConfig extends cdktf.TerraformMetaArguments {
    /**
     * Activate or deactivate HTTP.
     *
     * @stability stable
     */
    readonly httpConfig?: {
        [key: string]: string;
    };
    /**
     * The default logging verbosity for activity from devices in this registry.
     *
     * Specifies which events should be written to logs. For
     * example, if the LogLevel is ERROR, only events that terminate in
     * errors will be logged. LogLevel is inclusive; enabling INFO logging
     * will also enable ERROR logging. Default value: "NONE" Possible values: ["NONE", "ERROR", "INFO", "DEBUG"]
     *
     * @stability stable
     */
    readonly logLevel?: string;
    /**
     * Activate or deactivate MQTT.
     *
     * @stability stable
     */
    readonly mqttConfig?: {
        [key: string]: string;
    };
    /**
     * A unique name for the resource, required by device registry.
     *
     * @stability stable
     */
    readonly name: string;
    /**
     * @stability stable
     */
    readonly project?: string;
    /**
     * The region in which the created registry should reside.
     *
     * If it is not provided, the provider region is used.
     *
     * @stability stable
     */
    readonly region?: string;
    /**
     * A PubSub topic to publish device state updates.
     *
     * @stability stable
     */
    readonly stateNotificationConfig?: {
        [key: string]: string;
    };
    /**
     * credentials block.
     *
     * @stability stable
     */
    readonly credentials?: CloudiotRegistryCredentials[];
    /**
     * event_notification_configs block.
     *
     * @stability stable
     */
    readonly eventNotificationConfigs?: CloudiotRegistryEventNotificationConfigs[];
    /**
     * timeouts block.
     *
     * @stability stable
     */
    readonly timeouts?: CloudiotRegistryTimeouts;
}
/**
 * @stability stable
 */
export interface CloudiotRegistryCredentials {
    /**
     * A public key certificate format and data.
     *
     * @stability stable
     */
    readonly publicKeyCertificate: {
        [key: string]: string;
    };
}
/**
 * @stability stable
 */
export interface CloudiotRegistryEventNotificationConfigs {
    /**
     * PubSub topic name to publish device events.
     *
     * @stability stable
     */
    readonly pubsubTopicName: string;
    /**
     * If the subfolder name matches this string exactly, this configuration will be used.
     *
     * The string must not include the
     * leading '/' character. If empty, all strings are matched. Empty
     * value can only be used for the last 'event_notification_configs'
     * item.
     *
     * @stability stable
     */
    readonly subfolderMatches?: string;
}
/**
 * @stability stable
 */
export interface CloudiotRegistryTimeouts {
    /**
     * @stability stable
     */
    readonly create?: string;
    /**
     * @stability stable
     */
    readonly delete?: string;
    /**
     * @stability stable
     */
    readonly update?: string;
}
/**
 * @stability stable
 */
export declare class CloudiotRegistry extends cdktf.TerraformResource {
    /**
     * @stability stable
     */
    constructor(scope: Construct, id: string, config: CloudiotRegistryConfig);
    private _httpConfig?;
    /**
     * @stability stable
     */
    get httpConfig(): {
        [key: string]: string;
    };
    /**
     * @stability stable
     */
    set httpConfig(value: {
        [key: string]: string;
    });
    /**
     * @stability stable
     */
    resetHttpConfig(): void;
    /**
     * @stability stable
     */
    get httpConfigInput(): {
        [key: string]: string;
    } | undefined;
    /**
     * @stability stable
     */
    get id(): string;
    private _logLevel?;
    /**
     * @stability stable
     */
    get logLevel(): string;
    /**
     * @stability stable
     */
    set logLevel(value: string);
    /**
     * @stability stable
     */
    resetLogLevel(): void;
    /**
     * @stability stable
     */
    get logLevelInput(): string | undefined;
    private _mqttConfig?;
    /**
     * @stability stable
     */
    get mqttConfig(): {
        [key: string]: string;
    };
    /**
     * @stability stable
     */
    set mqttConfig(value: {
        [key: string]: string;
    });
    /**
     * @stability stable
     */
    resetMqttConfig(): void;
    /**
     * @stability stable
     */
    get mqttConfigInput(): {
        [key: string]: string;
    } | undefined;
    private _name;
    /**
     * @stability stable
     */
    get name(): string;
    /**
     * @stability stable
     */
    set name(value: string);
    /**
     * @stability stable
     */
    get nameInput(): string;
    private _project?;
    /**
     * @stability stable
     */
    get project(): string;
    /**
     * @stability stable
     */
    set project(value: string);
    /**
     * @stability stable
     */
    resetProject(): void;
    /**
     * @stability stable
     */
    get projectInput(): string | undefined;
    private _region?;
    /**
     * @stability stable
     */
    get region(): string;
    /**
     * @stability stable
     */
    set region(value: string);
    /**
     * @stability stable
     */
    resetRegion(): void;
    /**
     * @stability stable
     */
    get regionInput(): string | undefined;
    private _stateNotificationConfig?;
    /**
     * @stability stable
     */
    get stateNotificationConfig(): {
        [key: string]: string;
    };
    /**
     * @stability stable
     */
    set stateNotificationConfig(value: {
        [key: string]: string;
    });
    /**
     * @stability stable
     */
    resetStateNotificationConfig(): void;
    /**
     * @stability stable
     */
    get stateNotificationConfigInput(): {
        [key: string]: string;
    } | undefined;
    private _credentials?;
    /**
     * @stability stable
     */
    get credentials(): CloudiotRegistryCredentials[];
    /**
     * @stability stable
     */
    set credentials(value: CloudiotRegistryCredentials[]);
    /**
     * @stability stable
     */
    resetCredentials(): void;
    /**
     * @stability stable
     */
    get credentialsInput(): CloudiotRegistryCredentials[] | undefined;
    private _eventNotificationConfigs?;
    /**
     * @stability stable
     */
    get eventNotificationConfigs(): CloudiotRegistryEventNotificationConfigs[];
    /**
     * @stability stable
     */
    set eventNotificationConfigs(value: CloudiotRegistryEventNotificationConfigs[]);
    /**
     * @stability stable
     */
    resetEventNotificationConfigs(): void;
    /**
     * @stability stable
     */
    get eventNotificationConfigsInput(): CloudiotRegistryEventNotificationConfigs[] | undefined;
    private _timeouts?;
    /**
     * @stability stable
     */
    get timeouts(): CloudiotRegistryTimeouts;
    /**
     * @stability stable
     */
    set timeouts(value: CloudiotRegistryTimeouts);
    /**
     * @stability stable
     */
    resetTimeouts(): void;
    /**
     * @stability stable
     */
    get timeoutsInput(): CloudiotRegistryTimeouts | undefined;
    /**
     * @stability stable
     */
    protected synthesizeAttributes(): {
        [name: string]: any;
    };
}
