import { Construct } from 'constructs';
import * as cdktf from 'cdktf';
/**
 * @stability stable
 */
export interface ComposerEnvironmentConfig extends cdktf.TerraformMetaArguments {
    /**
     * User-defined labels for this environment.
     *
     * The labels map can contain no more than 64 entries. Entries of the labels map are UTF8 strings that comply with the following restrictions: Label keys must be between 1 and 63 characters long and must conform to the following regular expression: [a-z]([-a-z0-9]*[a-z0-9])?. Label values must be between 0 and 63 characters long and must conform to the regular expression ([a-z]([-a-z0-9]*[a-z0-9])?)?. No more than 64 labels can be associated with a given environment. Both keys and values must be <= 128 bytes in size.
     *
     * @stability stable
     */
    readonly labels?: {
        [key: string]: string;
    };
    /**
     * Name of the environment.
     *
     * @stability stable
     */
    readonly name: string;
    /**
     * The ID of the project in which the resource belongs.
     *
     * If it is not provided, the provider project is used.
     *
     * @stability stable
     */
    readonly project?: string;
    /**
     * The location or Compute Engine region for the environment.
     *
     * @stability stable
     */
    readonly region?: string;
    /**
     * config block.
     *
     * @stability stable
     */
    readonly config?: ComposerEnvironmentConfigA[];
    /**
     * timeouts block.
     *
     * @stability stable
     */
    readonly timeouts?: ComposerEnvironmentTimeouts;
}
/**
 * @stability stable
 */
export interface ComposerEnvironmentConfigNodeConfigIpAllocationPolicy {
    /**
     * @stability stable
     */
    readonly clusterIpv4CidrBlock?: string;
    /**
     * @stability stable
     */
    readonly clusterSecondaryRangeName?: string;
    /**
     * @stability stable
     */
    readonly servicesIpv4CidrBlock?: string;
    /**
     * @stability stable
     */
    readonly servicesSecondaryRangeName?: string;
    /**
     * @stability stable
     */
    readonly useIpAliases?: boolean;
}
/**
 * @stability stable
 */
export interface ComposerEnvironmentConfigNodeConfig {
    /**
     * The disk size in GB used for node VMs.
     *
     * Minimum size is 20GB. If unspecified, defaults to 100GB. Cannot be updated.
     *
     * @stability stable
     */
    readonly diskSizeGb?: number;
    /**
     * Configuration for controlling how IPs are allocated in the GKE cluster.
     *
     * Cannot be updated.
     *
     * @stability stable
     */
    readonly ipAllocationPolicy?: ComposerEnvironmentConfigNodeConfigIpAllocationPolicy[];
    /**
     * The Compute Engine machine type used for cluster instances, specified as a name or relative resource name.
     *
     * For example: "projects/{project}/zones/{zone}/machineTypes/{machineType}". Must belong to the enclosing environment's project and region/zone.
     *
     * @stability stable
     */
    readonly machineType?: string;
    /**
     * The Compute Engine machine type used for cluster instances, specified as a name or relative resource name.
     *
     * For example: "projects/{project}/zones/{zone}/machineTypes/{machineType}". Must belong to the enclosing environment's project and region/zone. The network must belong to the environment's project. If unspecified, the "default" network ID in the environment's project is used. If a Custom Subnet Network is provided, subnetwork must also be provided.
     *
     * @stability stable
     */
    readonly network?: string;
    /**
     * The set of Google API scopes to be made available on all node VMs.
     *
     * Cannot be updated. If empty, defaults to ["https://www.googleapis.com/auth/cloud-platform"].
     *
     * @stability stable
     */
    readonly oauthScopes?: string[];
    /**
     * The Google Cloud Platform Service Account to be used by the node VMs.
     *
     * If a service account is not specified, the "default" Compute Engine service account is used. Cannot be updated. If given, note that the service account must have roles/composer.worker for any GCP resources created under the Cloud Composer Environment.
     *
     * @stability stable
     */
    readonly serviceAccount?: string;
    /**
     * The Compute Engine subnetwork to be used for machine communications, , specified as a self-link, relative resource name (e.g. "projects/{project}/regions/{region}/subnetworks/{subnetwork}"), or by name. If subnetwork is provided, network must also be provided and the subnetwork must belong to the enclosing environment's project and region.
     *
     * @stability stable
     */
    readonly subnetwork?: string;
    /**
     * The list of instance tags applied to all node VMs.
     *
     * Tags are used to identify valid sources or targets for network firewalls. Each tag within the list must comply with RFC1035. Cannot be updated.
     *
     * @stability stable
     */
    readonly tags?: string[];
    /**
     * The Compute Engine zone in which to deploy the VMs running the Apache Airflow software, specified as the zone name or relative resource name (e.g. "projects/{project}/zones/{zone}"). Must belong to the enclosing environment's project and region.
     *
     * @stability stable
     */
    readonly zone: string;
}
/**
 * @stability stable
 */
export interface ComposerEnvironmentConfigPrivateEnvironmentConfig {
    /**
     * The CIDR block from which IP range in tenant project will be reserved for Cloud SQL.
     *
     * Needs to be disjoint from web_server_ipv4_cidr_block.
     *
     * @stability stable
     */
    readonly cloudSqlIpv4CidrBlock?: string;
    /**
     * If true, access to the public endpoint of the GKE cluster is denied.
     *
     * @stability stable
     */
    readonly enablePrivateEndpoint?: boolean;
    /**
     * The IP range in CIDR notation to use for the hosted master network.
     *
     * This range is used for assigning internal IP addresses to the cluster master or set of masters and to the internal load balancer virtual IP. This range must not overlap with any other ranges in use within the cluster's network. If left blank, the default value of '172.16.0.0/28' is used.
     *
     * @stability stable
     */
    readonly masterIpv4CidrBlock?: string;
    /**
     * The CIDR block from which IP range for web server will be reserved.
     *
     * Needs to be disjoint from master_ipv4_cidr_block and cloud_sql_ipv4_cidr_block.
     *
     * @stability stable
     */
    readonly webServerIpv4CidrBlock?: string;
}
/**
 * @stability stable
 */
export interface ComposerEnvironmentConfigSoftwareConfig {
    /**
     * Apache Airflow configuration properties to override.
     *
     * Property keys contain the section and property names, separated by a hyphen, for example "core-dags_are_paused_at_creation". Section names must not contain hyphens ("-"), opening square brackets ("["), or closing square brackets ("]"). The property name must not be empty and cannot contain "=" or ";". Section and property names cannot contain characters: "." Apache Airflow configuration property names must be written in snake_case. Property values can contain any character, and can be written in any lower/upper case format. Certain Apache Airflow configuration property values are blacklisted, and cannot be overridden.
     *
     * @stability stable
     */
    readonly airflowConfigOverrides?: {
        [key: string]: string;
    };
    /**
     * Additional environment variables to provide to the Apache Airflow scheduler, worker, and webserver processes.
     *
     * Environment variable names must match the regular expression [a-zA-Z_][a-zA-Z0-9_]*. They cannot specify Apache Airflow software configuration overrides (they cannot match the regular expression AIRFLOW__[A-Z0-9_]+__[A-Z0-9_]+), and they cannot match any of the following reserved names: AIRFLOW_HOME C_FORCE_ROOT CONTAINER_NAME DAGS_FOLDER GCP_PROJECT GCS_BUCKET GKE_CLUSTER_NAME SQL_DATABASE SQL_INSTANCE SQL_PASSWORD SQL_PROJECT SQL_REGION SQL_USER.
     *
     * @stability stable
     */
    readonly envVariables?: {
        [key: string]: string;
    };
    /**
     * The version of the software running in the environment.
     *
     * This encapsulates both the version of Cloud Composer functionality and the version of Apache Airflow. It must match the regular expression composer-[0-9]+\.[0-9]+(\.[0-9]+)?-airflow-[0-9]+\.[0-9]+(\.[0-9]+.*)?. The Cloud Composer portion of the version is a semantic version. The portion of the image version following 'airflow-' is an official Apache Airflow repository release name. See documentation for allowed release names.
     *
     * @stability stable
     */
    readonly imageVersion?: string;
    /**
     * Custom Python Package Index (PyPI) packages to be installed in the environment.
     *
     * Keys refer to the lowercase package name (e.g. "numpy"). Values are the lowercase extras and version specifier (e.g. "==1.12.0", "[devel,gcp_api]", "[devel]>=1.8.2, <1.9.2"). To specify a package without pinning it to a version specifier, use the empty string as the value.
     *
     * @stability stable
     */
    readonly pypiPackages?: {
        [key: string]: string;
    };
    /**
     * The major version of Python used to run the Apache Airflow scheduler, worker, and webserver processes.
     *
     * Can be set to '2' or '3'. If not specified, the default is '2'. Cannot be updated.
     *
     * @stability stable
     */
    readonly pythonVersion?: string;
}
/**
 * @stability stable
 */
export interface ComposerEnvironmentConfigA {
    /**
     * The number of nodes in the Kubernetes Engine cluster that will be used to run this environment.
     *
     * @stability stable
     */
    readonly nodeCount?: number;
    /**
     * node_config block.
     *
     * @stability stable
     */
    readonly nodeConfig?: ComposerEnvironmentConfigNodeConfig[];
    /**
     * private_environment_config block.
     *
     * @stability stable
     */
    readonly privateEnvironmentConfig?: ComposerEnvironmentConfigPrivateEnvironmentConfig[];
    /**
     * software_config block.
     *
     * @stability stable
     */
    readonly softwareConfig?: ComposerEnvironmentConfigSoftwareConfig[];
}
/**
 * @stability stable
 */
export interface ComposerEnvironmentTimeouts {
    /**
     * @stability stable
     */
    readonly create?: string;
    /**
     * @stability stable
     */
    readonly delete?: string;
    /**
     * @stability stable
     */
    readonly update?: string;
}
/**
 * @stability stable
 */
export declare class ComposerEnvironment extends cdktf.TerraformResource {
    /**
     * @stability stable
     */
    constructor(scope: Construct, id: string, config: ComposerEnvironmentConfig);
    /**
     * @stability stable
     */
    get id(): string;
    private _labels?;
    /**
     * @stability stable
     */
    get labels(): {
        [key: string]: string;
    };
    /**
     * @stability stable
     */
    set labels(value: {
        [key: string]: string;
    });
    /**
     * @stability stable
     */
    resetLabels(): void;
    /**
     * @stability stable
     */
    get labelsInput(): {
        [key: string]: string;
    } | undefined;
    private _name;
    /**
     * @stability stable
     */
    get name(): string;
    /**
     * @stability stable
     */
    set name(value: string);
    /**
     * @stability stable
     */
    get nameInput(): string;
    private _project?;
    /**
     * @stability stable
     */
    get project(): string;
    /**
     * @stability stable
     */
    set project(value: string);
    /**
     * @stability stable
     */
    resetProject(): void;
    /**
     * @stability stable
     */
    get projectInput(): string | undefined;
    private _region?;
    /**
     * @stability stable
     */
    get region(): string;
    /**
     * @stability stable
     */
    set region(value: string);
    /**
     * @stability stable
     */
    resetRegion(): void;
    /**
     * @stability stable
     */
    get regionInput(): string | undefined;
    private _config?;
    /**
     * @stability stable
     */
    get config(): ComposerEnvironmentConfigA[];
    /**
     * @stability stable
     */
    set config(value: ComposerEnvironmentConfigA[]);
    /**
     * @stability stable
     */
    resetConfig(): void;
    /**
     * @stability stable
     */
    get configInput(): ComposerEnvironmentConfigA[] | undefined;
    private _timeouts?;
    /**
     * @stability stable
     */
    get timeouts(): ComposerEnvironmentTimeouts;
    /**
     * @stability stable
     */
    set timeouts(value: ComposerEnvironmentTimeouts);
    /**
     * @stability stable
     */
    resetTimeouts(): void;
    /**
     * @stability stable
     */
    get timeoutsInput(): ComposerEnvironmentTimeouts | undefined;
    /**
     * @stability stable
     */
    protected synthesizeAttributes(): {
        [name: string]: any;
    };
}
