import { Construct } from 'constructs';
import * as cdktf from 'cdktf';
/**
 * @stability stable
 */
export interface ComputeAutoscalerConfig extends cdktf.TerraformMetaArguments {
    /**
     * An optional description of this resource.
     *
     * @stability stable
     */
    readonly description?: string;
    /**
     * Name of the resource.
     *
     * The name must be 1-63 characters long and match
     * the regular expression '[a-z]([-a-z0-9]*[a-z0-9])?' which means the
     * first character must be a lowercase letter, and all following
     * characters must be a dash, lowercase letter, or digit, except the last
     * character, which cannot be a dash.
     *
     * @stability stable
     */
    readonly name: string;
    /**
     * @stability stable
     */
    readonly project?: string;
    /**
     * URL of the managed instance group that this autoscaler will scale.
     *
     * @stability stable
     */
    readonly target: string;
    /**
     * URL of the zone where the instance group resides.
     *
     * @stability stable
     */
    readonly zone?: string;
    /**
     * autoscaling_policy block.
     *
     * @stability stable
     */
    readonly autoscalingPolicy: ComputeAutoscalerAutoscalingPolicy[];
    /**
     * timeouts block.
     *
     * @stability stable
     */
    readonly timeouts?: ComputeAutoscalerTimeouts;
}
/**
 * @stability stable
 */
export interface ComputeAutoscalerAutoscalingPolicyCpuUtilization {
    /**
     * The target CPU utilization that the autoscaler should maintain.
     *
     * Must be a float value in the range (0, 1]. If not specified, the
     * default is 0.6.
     *
     * If the CPU level is below the target utilization, the autoscaler
     * scales down the number of instances until it reaches the minimum
     * number of instances you specified or until the average CPU of
     * your instances reaches the target utilization.
     *
     * If the average CPU is above the target utilization, the autoscaler
     * scales up until it reaches the maximum number of instances you
     * specified or until the average utilization reaches the target
     * utilization.
     *
     * @stability stable
     */
    readonly target: number;
}
/**
 * @stability stable
 */
export interface ComputeAutoscalerAutoscalingPolicyLoadBalancingUtilization {
    /**
     * Fraction of backend capacity utilization (set in HTTP(s) load balancing configuration) that autoscaler should maintain.
     *
     * Must
     * be a positive float value. If not defined, the default is 0.8.
     *
     * @stability stable
     */
    readonly target: number;
}
/**
 * @stability stable
 */
export interface ComputeAutoscalerAutoscalingPolicyMetric {
    /**
     * The identifier (type) of the Stackdriver Monitoring metric. The metric cannot have negative values.
     *
     * The metric must have a value type of INT64 or DOUBLE.
     *
     * @stability stable
     */
    readonly name: string;
    /**
     * The target value of the metric that autoscaler should maintain.
     *
     * This must be a positive value. A utilization
     * metric scales number of virtual machines handling requests
     * to increase or decrease proportionally to the metric.
     *
     * For example, a good metric to use as a utilizationTarget is
     * www.googleapis.com/compute/instance/network/received_bytes_count.
     * The autoscaler will work to keep this value constant for each
     * of the instances.
     *
     * @stability stable
     */
    readonly target?: number;
    /**
     * Defines how target utilization value is expressed for a Stackdriver Monitoring metric.
     *
     * Possible values: ["GAUGE", "DELTA_PER_SECOND", "DELTA_PER_MINUTE"]
     *
     * @stability stable
     */
    readonly type?: string;
}
/**
 * @stability stable
 */
export interface ComputeAutoscalerAutoscalingPolicyScaleInControlMaxScaledInReplicas {
    /**
     * Specifies a fixed number of VM instances.
     *
     * This must be a positive
     * integer.
     *
     * @stability stable
     */
    readonly fixed?: number;
    /**
     * Specifies a percentage of instances between 0 to 100%, inclusive.
     *
     * For example, specify 80 for 80%.
     *
     * @stability stable
     */
    readonly percent?: number;
}
/**
 * @stability stable
 */
export interface ComputeAutoscalerAutoscalingPolicyScaleInControl {
    /**
     * How long back autoscaling should look when computing recommendations to include directives regarding slower scale down, as described above.
     *
     * @stability stable
     */
    readonly timeWindowSec?: number;
    /**
     * max_scaled_in_replicas block.
     *
     * @stability stable
     */
    readonly maxScaledInReplicas?: ComputeAutoscalerAutoscalingPolicyScaleInControlMaxScaledInReplicas[];
}
/**
 * @stability stable
 */
export interface ComputeAutoscalerAutoscalingPolicy {
    /**
     * The number of seconds that the autoscaler should wait before it starts collecting information from a new instance.
     *
     * This prevents
     * the autoscaler from collecting information when the instance is
     * initializing, during which the collected usage would not be
     * reliable. The default time autoscaler waits is 60 seconds.
     *
     * Virtual machine initialization times might vary because of
     * numerous factors. We recommend that you test how long an
     * instance may take to initialize. To do this, create an instance
     * and time the startup process.
     *
     * @stability stable
     */
    readonly cooldownPeriod?: number;
    /**
     * The maximum number of instances that the autoscaler can scale up to.
     *
     * This is required when creating or updating an autoscaler. The
     * maximum number of replicas should not be lower than minimal number
     * of replicas.
     *
     * @stability stable
     */
    readonly maxReplicas: number;
    /**
     * The minimum number of replicas that the autoscaler can scale down to.
     *
     * This cannot be less than 0. If not provided, autoscaler will
     * choose a default value depending on maximum number of instances
     * allowed.
     *
     * @stability stable
     */
    readonly minReplicas: number;
    /**
     * Defines operating mode for this policy.
     *
     * Default value: "ON" Possible values: ["OFF", "ONLY_UP", "ON"]
     *
     * @stability stable
     */
    readonly mode?: string;
    /**
     * cpu_utilization block.
     *
     * @stability stable
     */
    readonly cpuUtilization?: ComputeAutoscalerAutoscalingPolicyCpuUtilization[];
    /**
     * load_balancing_utilization block.
     *
     * @stability stable
     */
    readonly loadBalancingUtilization?: ComputeAutoscalerAutoscalingPolicyLoadBalancingUtilization[];
    /**
     * metric block.
     *
     * @stability stable
     */
    readonly metric?: ComputeAutoscalerAutoscalingPolicyMetric[];
    /**
     * scale_in_control block.
     *
     * @stability stable
     */
    readonly scaleInControl?: ComputeAutoscalerAutoscalingPolicyScaleInControl[];
}
/**
 * @stability stable
 */
export interface ComputeAutoscalerTimeouts {
    /**
     * @stability stable
     */
    readonly create?: string;
    /**
     * @stability stable
     */
    readonly delete?: string;
    /**
     * @stability stable
     */
    readonly update?: string;
}
/**
 * @stability stable
 */
export declare class ComputeAutoscaler extends cdktf.TerraformResource {
    /**
     * @stability stable
     */
    constructor(scope: Construct, id: string, config: ComputeAutoscalerConfig);
    /**
     * @stability stable
     */
    get creationTimestamp(): string;
    private _description?;
    /**
     * @stability stable
     */
    get description(): string;
    /**
     * @stability stable
     */
    set description(value: string);
    /**
     * @stability stable
     */
    resetDescription(): void;
    /**
     * @stability stable
     */
    get descriptionInput(): string | undefined;
    /**
     * @stability stable
     */
    get id(): string;
    private _name;
    /**
     * @stability stable
     */
    get name(): string;
    /**
     * @stability stable
     */
    set name(value: string);
    /**
     * @stability stable
     */
    get nameInput(): string;
    private _project?;
    /**
     * @stability stable
     */
    get project(): string;
    /**
     * @stability stable
     */
    set project(value: string);
    /**
     * @stability stable
     */
    resetProject(): void;
    /**
     * @stability stable
     */
    get projectInput(): string | undefined;
    /**
     * @stability stable
     */
    get selfLink(): string;
    private _target;
    /**
     * @stability stable
     */
    get target(): string;
    /**
     * @stability stable
     */
    set target(value: string);
    /**
     * @stability stable
     */
    get targetInput(): string;
    private _zone?;
    /**
     * @stability stable
     */
    get zone(): string;
    /**
     * @stability stable
     */
    set zone(value: string);
    /**
     * @stability stable
     */
    resetZone(): void;
    /**
     * @stability stable
     */
    get zoneInput(): string | undefined;
    private _autoscalingPolicy;
    /**
     * @stability stable
     */
    get autoscalingPolicy(): ComputeAutoscalerAutoscalingPolicy[];
    /**
     * @stability stable
     */
    set autoscalingPolicy(value: ComputeAutoscalerAutoscalingPolicy[]);
    /**
     * @stability stable
     */
    get autoscalingPolicyInput(): ComputeAutoscalerAutoscalingPolicy[];
    private _timeouts?;
    /**
     * @stability stable
     */
    get timeouts(): ComputeAutoscalerTimeouts;
    /**
     * @stability stable
     */
    set timeouts(value: ComputeAutoscalerTimeouts);
    /**
     * @stability stable
     */
    resetTimeouts(): void;
    /**
     * @stability stable
     */
    get timeoutsInput(): ComputeAutoscalerTimeouts | undefined;
    /**
     * @stability stable
     */
    protected synthesizeAttributes(): {
        [name: string]: any;
    };
}
