import { Construct } from 'constructs';
import * as cdktf from 'cdktf';
/**
 * @stability stable
 */
export interface ComputeGlobalForwardingRuleConfig extends cdktf.TerraformMetaArguments {
    /**
     * An optional description of this resource.
     *
     * Provide this property when
     * you create the resource.
     *
     * @stability stable
     */
    readonly description?: string;
    /**
     * The IP address that this forwarding rule is serving on behalf of.
     *
     * Addresses are restricted based on the forwarding rule's load balancing
     * scheme (EXTERNAL or INTERNAL) and scope (global or regional).
     *
     * When the load balancing scheme is EXTERNAL, for global forwarding
     * rules, the address must be a global IP, and for regional forwarding
     * rules, the address must live in the same region as the forwarding
     * rule. If this field is empty, an ephemeral IPv4 address from the same
     * scope (global or regional) will be assigned. A regional forwarding
     * rule supports IPv4 only. A global forwarding rule supports either IPv4
     * or IPv6.
     *
     * When the load balancing scheme is INTERNAL, this can only be an RFC
     * 1918 IP address belonging to the network/subnet configured for the
     * forwarding rule. By default, if this field is empty, an ephemeral
     * internal IP address will be automatically allocated from the IP range
     * of the subnet or network configured for this forwarding rule.
     *
     * An address must be specified by a literal IP address. ~> **NOTE**: While
     * the API allows you to specify various resource paths for an address resource
     * instead, Terraform requires this to specifically be an IP address to
     * avoid needing to fetching the IP address from resource paths on refresh
     * or unnecessary diffs.
     *
     * @stability stable
     */
    readonly ipAddress?: string;
    /**
     * The IP protocol to which this rule applies.
     *
     * When the load balancing scheme is
     * INTERNAL_SELF_MANAGED, only TCP is valid. Possible values: ["TCP", "UDP", "ESP", "AH", "SCTP", "ICMP"]
     *
     * @stability stable
     */
    readonly ipProtocol?: string;
    /**
     * The IP Version that will be used by this global forwarding rule.
     *
     * Possible values: ["IPV4", "IPV6"]
     *
     * @stability stable
     */
    readonly ipVersion?: string;
    /**
     * This signifies what the GlobalForwardingRule will be used for.
     *
     * The value of INTERNAL_SELF_MANAGED means that this will be used for
     * Internal Global HTTP(S) LB. The value of EXTERNAL means that this
     * will be used for External Global Load Balancing (HTTP(S) LB,
     * External TCP/UDP LB, SSL Proxy)
     *
     * NOTE: Currently global forwarding rules cannot be used for INTERNAL
     * load balancing. Default value: "EXTERNAL" Possible values: ["EXTERNAL", "INTERNAL_SELF_MANAGED"]
     *
     * @stability stable
     */
    readonly loadBalancingScheme?: string;
    /**
     * Name of the resource;
     *
     * provided by the client when the resource is
     * created. The name must be 1-63 characters long, and comply with
     * RFC1035. Specifically, the name must be 1-63 characters long and match
     * the regular expression '[a-z]([-a-z0-9]*[a-z0-9])?' which means the
     * first character must be a lowercase letter, and all following
     * characters must be a dash, lowercase letter, or digit, except the last
     * character, which cannot be a dash.
     *
     * @stability stable
     */
    readonly name: string;
    /**
     * This field is used along with the target field for TargetHttpProxy, TargetHttpsProxy, TargetSslProxy, TargetTcpProxy, TargetVpnGateway, TargetPool, TargetInstance.
     *
     * Applicable only when IPProtocol is TCP, UDP, or SCTP, only packets
     * addressed to ports in the specified range will be forwarded to target.
     * Forwarding rules with the same [IPAddress, IPProtocol] pair must have
     * disjoint port ranges.
     *
     * Some types of forwarding target have constraints on the acceptable
     * ports:
     *
     * TargetHttpProxy: 80, 8080
     * TargetHttpsProxy: 443
     * TargetTcpProxy: 25, 43, 110, 143, 195, 443, 465, 587, 700, 993, 995,
     *             1883, 5222
     * TargetSslProxy: 25, 43, 110, 143, 195, 443, 465, 587, 700, 993, 995,
     *             1883, 5222
     * TargetVpnGateway: 500, 4500
     *
     * @stability stable
     */
    readonly portRange?: string;
    /**
     * @stability stable
     */
    readonly project?: string;
    /**
     * The URL of the target resource to receive the matched traffic.
     *
     * The forwarded traffic must be of a type appropriate to the target object.
     * For INTERNAL_SELF_MANAGED load balancing, only HTTP and HTTPS targets
     * are valid.
     *
     * @stability stable
     */
    readonly target: string;
    /**
     * metadata_filters block.
     *
     * @stability stable
     */
    readonly metadataFilters?: ComputeGlobalForwardingRuleMetadataFilters[];
    /**
     * timeouts block.
     *
     * @stability stable
     */
    readonly timeouts?: ComputeGlobalForwardingRuleTimeouts;
}
/**
 * @stability stable
 */
export interface ComputeGlobalForwardingRuleMetadataFiltersFilterLabels {
    /**
     * Name of the metadata label.
     *
     * The length must be between
     * 1 and 1024 characters, inclusive.
     *
     * @stability stable
     */
    readonly name: string;
    /**
     * The value that the label must match.
     *
     * The value has a maximum
     * length of 1024 characters.
     *
     * @stability stable
     */
    readonly value: string;
}
/**
 * @stability stable
 */
export interface ComputeGlobalForwardingRuleMetadataFilters {
    /**
     * Specifies how individual filterLabel matches within the list of filterLabels contribute towards the overall metadataFilter match.
     *
     * MATCH_ANY - At least one of the filterLabels must have a matching
     * label in the provided metadata.
     * MATCH_ALL - All filterLabels must have matching labels in the
     * provided metadata. Possible values: ["MATCH_ANY", "MATCH_ALL"]
     *
     * @stability stable
     */
    readonly filterMatchCriteria: string;
    /**
     * filter_labels block.
     *
     * @stability stable
     */
    readonly filterLabels: ComputeGlobalForwardingRuleMetadataFiltersFilterLabels[];
}
/**
 * @stability stable
 */
export interface ComputeGlobalForwardingRuleTimeouts {
    /**
     * @stability stable
     */
    readonly create?: string;
    /**
     * @stability stable
     */
    readonly delete?: string;
    /**
     * @stability stable
     */
    readonly update?: string;
}
/**
 * @stability stable
 */
export declare class ComputeGlobalForwardingRule extends cdktf.TerraformResource {
    /**
     * @stability stable
     */
    constructor(scope: Construct, id: string, config: ComputeGlobalForwardingRuleConfig);
    private _description?;
    /**
     * @stability stable
     */
    get description(): string;
    /**
     * @stability stable
     */
    set description(value: string);
    /**
     * @stability stable
     */
    resetDescription(): void;
    /**
     * @stability stable
     */
    get descriptionInput(): string | undefined;
    /**
     * @stability stable
     */
    get id(): string;
    private _ipAddress?;
    /**
     * @stability stable
     */
    get ipAddress(): string;
    /**
     * @stability stable
     */
    set ipAddress(value: string);
    /**
     * @stability stable
     */
    resetIpAddress(): void;
    /**
     * @stability stable
     */
    get ipAddressInput(): string | undefined;
    private _ipProtocol?;
    /**
     * @stability stable
     */
    get ipProtocol(): string;
    /**
     * @stability stable
     */
    set ipProtocol(value: string);
    /**
     * @stability stable
     */
    resetIpProtocol(): void;
    /**
     * @stability stable
     */
    get ipProtocolInput(): string | undefined;
    private _ipVersion?;
    /**
     * @stability stable
     */
    get ipVersion(): string;
    /**
     * @stability stable
     */
    set ipVersion(value: string);
    /**
     * @stability stable
     */
    resetIpVersion(): void;
    /**
     * @stability stable
     */
    get ipVersionInput(): string | undefined;
    private _loadBalancingScheme?;
    /**
     * @stability stable
     */
    get loadBalancingScheme(): string;
    /**
     * @stability stable
     */
    set loadBalancingScheme(value: string);
    /**
     * @stability stable
     */
    resetLoadBalancingScheme(): void;
    /**
     * @stability stable
     */
    get loadBalancingSchemeInput(): string | undefined;
    private _name;
    /**
     * @stability stable
     */
    get name(): string;
    /**
     * @stability stable
     */
    set name(value: string);
    /**
     * @stability stable
     */
    get nameInput(): string;
    private _portRange?;
    /**
     * @stability stable
     */
    get portRange(): string;
    /**
     * @stability stable
     */
    set portRange(value: string);
    /**
     * @stability stable
     */
    resetPortRange(): void;
    /**
     * @stability stable
     */
    get portRangeInput(): string | undefined;
    private _project?;
    /**
     * @stability stable
     */
    get project(): string;
    /**
     * @stability stable
     */
    set project(value: string);
    /**
     * @stability stable
     */
    resetProject(): void;
    /**
     * @stability stable
     */
    get projectInput(): string | undefined;
    /**
     * @stability stable
     */
    get selfLink(): string;
    private _target;
    /**
     * @stability stable
     */
    get target(): string;
    /**
     * @stability stable
     */
    set target(value: string);
    /**
     * @stability stable
     */
    get targetInput(): string;
    private _metadataFilters?;
    /**
     * @stability stable
     */
    get metadataFilters(): ComputeGlobalForwardingRuleMetadataFilters[];
    /**
     * @stability stable
     */
    set metadataFilters(value: ComputeGlobalForwardingRuleMetadataFilters[]);
    /**
     * @stability stable
     */
    resetMetadataFilters(): void;
    /**
     * @stability stable
     */
    get metadataFiltersInput(): ComputeGlobalForwardingRuleMetadataFilters[] | undefined;
    private _timeouts?;
    /**
     * @stability stable
     */
    get timeouts(): ComputeGlobalForwardingRuleTimeouts;
    /**
     * @stability stable
     */
    set timeouts(value: ComputeGlobalForwardingRuleTimeouts);
    /**
     * @stability stable
     */
    resetTimeouts(): void;
    /**
     * @stability stable
     */
    get timeoutsInput(): ComputeGlobalForwardingRuleTimeouts | undefined;
    /**
     * @stability stable
     */
    protected synthesizeAttributes(): {
        [name: string]: any;
    };
}
