import { Construct } from 'constructs';
import * as cdktf from 'cdktf';
/**
 * @stability stable
 */
export interface ComputeGlobalNetworkEndpointConfig extends cdktf.TerraformMetaArguments {
    /**
     * Fully qualified domain name of network endpoint.
     *
     * This can only be specified when network_endpoint_type of the NEG is INTERNET_FQDN_PORT.
     *
     * @stability stable
     */
    readonly fqdn?: string;
    /**
     * The global network endpoint group this endpoint is part of.
     *
     * @stability stable
     */
    readonly globalNetworkEndpointGroup: string;
    /**
     * IPv4 address external endpoint.
     *
     * @stability stable
     */
    readonly ipAddress?: string;
    /**
     * Port number of the external endpoint.
     *
     * @stability stable
     */
    readonly port: number;
    /**
     * @stability stable
     */
    readonly project?: string;
    /**
     * timeouts block.
     *
     * @stability stable
     */
    readonly timeouts?: ComputeGlobalNetworkEndpointTimeouts;
}
/**
 * @stability stable
 */
export interface ComputeGlobalNetworkEndpointTimeouts {
    /**
     * @stability stable
     */
    readonly create?: string;
    /**
     * @stability stable
     */
    readonly delete?: string;
}
/**
 * @stability stable
 */
export declare class ComputeGlobalNetworkEndpoint extends cdktf.TerraformResource {
    /**
     * @stability stable
     */
    constructor(scope: Construct, id: string, config: ComputeGlobalNetworkEndpointConfig);
    private _fqdn?;
    /**
     * @stability stable
     */
    get fqdn(): string;
    /**
     * @stability stable
     */
    set fqdn(value: string);
    /**
     * @stability stable
     */
    resetFqdn(): void;
    /**
     * @stability stable
     */
    get fqdnInput(): string | undefined;
    private _globalNetworkEndpointGroup;
    /**
     * @stability stable
     */
    get globalNetworkEndpointGroup(): string;
    /**
     * @stability stable
     */
    set globalNetworkEndpointGroup(value: string);
    /**
     * @stability stable
     */
    get globalNetworkEndpointGroupInput(): string;
    /**
     * @stability stable
     */
    get id(): string;
    private _ipAddress?;
    /**
     * @stability stable
     */
    get ipAddress(): string;
    /**
     * @stability stable
     */
    set ipAddress(value: string);
    /**
     * @stability stable
     */
    resetIpAddress(): void;
    /**
     * @stability stable
     */
    get ipAddressInput(): string | undefined;
    private _port;
    /**
     * @stability stable
     */
    get port(): number;
    /**
     * @stability stable
     */
    set port(value: number);
    /**
     * @stability stable
     */
    get portInput(): number;
    private _project?;
    /**
     * @stability stable
     */
    get project(): string;
    /**
     * @stability stable
     */
    set project(value: string);
    /**
     * @stability stable
     */
    resetProject(): void;
    /**
     * @stability stable
     */
    get projectInput(): string | undefined;
    private _timeouts?;
    /**
     * @stability stable
     */
    get timeouts(): ComputeGlobalNetworkEndpointTimeouts;
    /**
     * @stability stable
     */
    set timeouts(value: ComputeGlobalNetworkEndpointTimeouts);
    /**
     * @stability stable
     */
    resetTimeouts(): void;
    /**
     * @stability stable
     */
    get timeoutsInput(): ComputeGlobalNetworkEndpointTimeouts | undefined;
    /**
     * @stability stable
     */
    protected synthesizeAttributes(): {
        [name: string]: any;
    };
}
