import { Construct } from 'constructs';
import * as cdktf from 'cdktf';
/**
 * @stability stable
 */
export interface ComputeInstanceFromTemplateConfig extends cdktf.TerraformMetaArguments {
    /**
     * If true, allows Terraform to stop the instance to update its properties.
     *
     * If you try to update a property that requires stopping the instance without setting this field, the update will fail.
     *
     * @stability stable
     */
    readonly allowStoppingForUpdate?: boolean;
    /**
     * List of disks attached to the instance.
     *
     * @stability stable
     */
    readonly attachedDisk?: ComputeInstanceFromTemplateAttachedDisk[];
    /**
     * Whether sending and receiving of packets with non-matching source or destination IPs is allowed.
     *
     * @stability stable
     */
    readonly canIpForward?: boolean;
    /**
     * Whether deletion protection is enabled on this instance.
     *
     * @stability stable
     */
    readonly deletionProtection?: boolean;
    /**
     * A brief description of the resource.
     *
     * @stability stable
     */
    readonly description?: string;
    /**
     * Desired status of the instance.
     *
     * Either "RUNNING" or "TERMINATED".
     *
     * @stability stable
     */
    readonly desiredStatus?: string;
    /**
     * Whether the instance has virtual displays enabled.
     *
     * @stability stable
     */
    readonly enableDisplay?: boolean;
    /**
     * List of the type and count of accelerator cards attached to the instance.
     *
     * @stability stable
     */
    readonly guestAccelerator?: ComputeInstanceFromTemplateGuestAccelerator[];
    /**
     * A custom hostname for the instance.
     *
     * Must be a fully qualified DNS name and RFC-1035-valid. Valid format is a series of labels 1-63 characters long matching the regular expression [a-z]([-a-z0-9]*[a-z0-9]), concatenated with periods. The entire hostname must not exceed 253 characters. Changing this forces a new resource to be created.
     *
     * @stability stable
     */
    readonly hostname?: string;
    /**
     * A set of key/value label pairs assigned to the instance.
     *
     * @stability stable
     */
    readonly labels?: {
        [key: string]: string;
    };
    /**
     * The machine type to create.
     *
     * @stability stable
     */
    readonly machineType?: string;
    /**
     * Metadata key/value pairs made available within the instance.
     *
     * @stability stable
     */
    readonly metadata?: {
        [key: string]: string;
    };
    /**
     * Metadata startup scripts made available within the instance.
     *
     * @stability stable
     */
    readonly metadataStartupScript?: string;
    /**
     * The minimum CPU platform specified for the VM instance.
     *
     * @stability stable
     */
    readonly minCpuPlatform?: string;
    /**
     * The name of the instance.
     *
     * One of name or self_link must be provided.
     *
     * @stability stable
     */
    readonly name: string;
    /**
     * The ID of the project in which the resource belongs.
     *
     * If self_link is provided, this value is ignored. If neither self_link nor project are provided, the provider project is used.
     *
     * @stability stable
     */
    readonly project?: string;
    /**
     * A list of short names or self_links of resource policies to attach to the instance.
     *
     * Modifying this list will cause the instance to recreate. Currently a max of 1 resource policy is supported.
     *
     * @stability stable
     */
    readonly resourcePolicies?: string[];
    /**
     * The scratch disks attached to the instance.
     *
     * @stability stable
     */
    readonly scratchDisk?: ComputeInstanceFromTemplateScratchDisk[];
    /**
     * The service account to attach to the instance.
     *
     * @stability stable
     */
    readonly serviceAccount?: ComputeInstanceFromTemplateServiceAccount[];
    /**
     * Name or self link of an instance template to create the instance based on.
     *
     * @stability stable
     */
    readonly sourceInstanceTemplate: string;
    /**
     * The list of tags attached to the instance.
     *
     * @stability stable
     */
    readonly tags?: string[];
    /**
     * The zone of the instance.
     *
     * If self_link is provided, this value is ignored. If neither self_link nor zone are provided, the provider zone is used.
     *
     * @stability stable
     */
    readonly zone?: string;
    /**
     * boot_disk block.
     *
     * @stability stable
     */
    readonly bootDisk?: ComputeInstanceFromTemplateBootDisk[];
    /**
     * network_interface block.
     *
     * @stability stable
     */
    readonly networkInterface?: ComputeInstanceFromTemplateNetworkInterface[];
    /**
     * scheduling block.
     *
     * @stability stable
     */
    readonly scheduling?: ComputeInstanceFromTemplateScheduling[];
    /**
     * shielded_instance_config block.
     *
     * @stability stable
     */
    readonly shieldedInstanceConfig?: ComputeInstanceFromTemplateShieldedInstanceConfig[];
    /**
     * timeouts block.
     *
     * @stability stable
     */
    readonly timeouts?: ComputeInstanceFromTemplateTimeouts;
}
/**
 * @stability stable
 */
export interface ComputeInstanceFromTemplateAttachedDisk {
    /**
     * @stability stable
     */
    readonly deviceName?: string;
    /**
     * @stability stable
     */
    readonly diskEncryptionKeyRaw?: string;
    /**
     * @stability stable
     */
    readonly diskEncryptionKeySha256?: string;
    /**
     * @stability stable
     */
    readonly kmsKeySelfLink?: string;
    /**
     * @stability stable
     */
    readonly mode?: string;
    /**
     * @stability stable
     */
    readonly source?: string;
}
/**
 * @stability stable
 */
export interface ComputeInstanceFromTemplateGuestAccelerator {
    /**
     * @stability stable
     */
    readonly count?: number;
    /**
     * @stability stable
     */
    readonly type?: string;
}
/**
 * @stability stable
 */
export interface ComputeInstanceFromTemplateScratchDisk {
    /**
     * @stability stable
     */
    readonly interface?: string;
}
/**
 * @stability stable
 */
export interface ComputeInstanceFromTemplateServiceAccount {
    /**
     * @stability stable
     */
    readonly email?: string;
    /**
     * @stability stable
     */
    readonly scopes?: string[];
}
/**
 * @stability stable
 */
export interface ComputeInstanceFromTemplateBootDiskInitializeParams {
    /**
     * The image from which this disk was initialised.
     *
     * @stability stable
     */
    readonly image?: string;
    /**
     * A set of key/value label pairs assigned to the disk.
     *
     * @stability stable
     */
    readonly labels?: {
        [key: string]: string;
    };
    /**
     * The size of the image in gigabytes.
     *
     * @stability stable
     */
    readonly size?: number;
    /**
     * The Google Compute Engine disk type.
     *
     * One of pd-standard, pd-ssd or pd-balanced.
     *
     * @stability stable
     */
    readonly type?: string;
}
/**
 * @stability stable
 */
export interface ComputeInstanceFromTemplateBootDisk {
    /**
     * Whether the disk will be auto-deleted when the instance is deleted.
     *
     * @stability stable
     */
    readonly autoDelete?: boolean;
    /**
     * Name with which attached disk will be accessible under /dev/disk/by-id/.
     *
     * @stability stable
     */
    readonly deviceName?: string;
    /**
     * A 256-bit customer-supplied encryption key, encoded in RFC 4648 base64 to encrypt this disk.
     *
     * Only one of kms_key_self_link and disk_encryption_key_raw may be set.
     *
     * @stability stable
     */
    readonly diskEncryptionKeyRaw?: string;
    /**
     * The self_link of the encryption key that is stored in Google Cloud KMS to encrypt this disk.
     *
     * Only one of kms_key_self_link and disk_encryption_key_raw may be set.
     *
     * @stability stable
     */
    readonly kmsKeySelfLink?: string;
    /**
     * Read/write mode for the disk.
     *
     * One of "READ_ONLY" or "READ_WRITE".
     *
     * @stability stable
     */
    readonly mode?: string;
    /**
     * The name or self_link of the disk attached to this instance.
     *
     * @stability stable
     */
    readonly source?: string;
    /**
     * initialize_params block.
     *
     * @stability stable
     */
    readonly initializeParams?: ComputeInstanceFromTemplateBootDiskInitializeParams[];
}
/**
 * @stability stable
 */
export interface ComputeInstanceFromTemplateNetworkInterfaceAccessConfig {
    /**
     * @stability stable
     */
    readonly natIp?: string;
    /**
     * @stability stable
     */
    readonly networkTier?: string;
    /**
     * @stability stable
     */
    readonly publicPtrDomainName?: string;
}
/**
 * @stability stable
 */
export interface ComputeInstanceFromTemplateNetworkInterfaceAliasIpRange {
    /**
     * @stability stable
     */
    readonly ipCidrRange?: string;
    /**
     * @stability stable
     */
    readonly subnetworkRangeName?: string;
}
/**
 * @stability stable
 */
export interface ComputeInstanceFromTemplateNetworkInterface {
    /**
     * Access configurations, i.e. IPs via which this instance can be accessed via the Internet.
     *
     * @stability stable
     */
    readonly accessConfig?: ComputeInstanceFromTemplateNetworkInterfaceAccessConfig[];
    /**
     * An array of alias IP ranges for this network interface.
     *
     * @stability stable
     */
    readonly aliasIpRange?: ComputeInstanceFromTemplateNetworkInterfaceAliasIpRange[];
    /**
     * The name or self_link of the network attached to this interface.
     *
     * @stability stable
     */
    readonly network?: string;
    /**
     * The private IP address assigned to the instance.
     *
     * @stability stable
     */
    readonly networkIp?: string;
    /**
     * The name or self_link of the subnetwork attached to this interface.
     *
     * @stability stable
     */
    readonly subnetwork?: string;
    /**
     * The project in which the subnetwork belongs.
     *
     * @stability stable
     */
    readonly subnetworkProject?: string;
}
/**
 * @stability stable
 */
export interface ComputeInstanceFromTemplateSchedulingNodeAffinities {
    /**
     * @stability stable
     */
    readonly key: string;
    /**
     * @stability stable
     */
    readonly operator: string;
    /**
     * @stability stable
     */
    readonly values: string[];
}
/**
 * @stability stable
 */
export interface ComputeInstanceFromTemplateScheduling {
    /**
     * Specifies if the instance should be restarted if it was terminated by Compute Engine (not a user).
     *
     * @stability stable
     */
    readonly automaticRestart?: boolean;
    /**
     * Describes maintenance behavior for the instance.
     *
     * One of MIGRATE or TERMINATE,
     *
     * @stability stable
     */
    readonly onHostMaintenance?: string;
    /**
     * Whether the instance is preemptible.
     *
     * @stability stable
     */
    readonly preemptible?: boolean;
    /**
     * node_affinities block.
     *
     * @stability stable
     */
    readonly nodeAffinities?: ComputeInstanceFromTemplateSchedulingNodeAffinities[];
}
/**
 * @stability stable
 */
export interface ComputeInstanceFromTemplateShieldedInstanceConfig {
    /**
     * Whether integrity monitoring is enabled for the instance.
     *
     * @stability stable
     */
    readonly enableIntegrityMonitoring?: boolean;
    /**
     * Whether secure boot is enabled for the instance.
     *
     * @stability stable
     */
    readonly enableSecureBoot?: boolean;
    /**
     * Whether the instance uses vTPM.
     *
     * @stability stable
     */
    readonly enableVtpm?: boolean;
}
/**
 * @stability stable
 */
export interface ComputeInstanceFromTemplateTimeouts {
    /**
     * @stability stable
     */
    readonly create?: string;
    /**
     * @stability stable
     */
    readonly delete?: string;
    /**
     * @stability stable
     */
    readonly update?: string;
}
/**
 * @stability stable
 */
export declare class ComputeInstanceFromTemplate extends cdktf.TerraformResource {
    /**
     * @stability stable
     */
    constructor(scope: Construct, id: string, config: ComputeInstanceFromTemplateConfig);
    private _allowStoppingForUpdate?;
    /**
     * @stability stable
     */
    get allowStoppingForUpdate(): boolean;
    /**
     * @stability stable
     */
    set allowStoppingForUpdate(value: boolean);
    /**
     * @stability stable
     */
    resetAllowStoppingForUpdate(): void;
    /**
     * @stability stable
     */
    get allowStoppingForUpdateInput(): boolean | undefined;
    private _attachedDisk?;
    /**
     * @stability stable
     */
    get attachedDisk(): ComputeInstanceFromTemplateAttachedDisk[];
    /**
     * @stability stable
     */
    set attachedDisk(value: ComputeInstanceFromTemplateAttachedDisk[]);
    /**
     * @stability stable
     */
    resetAttachedDisk(): void;
    /**
     * @stability stable
     */
    get attachedDiskInput(): ComputeInstanceFromTemplateAttachedDisk[] | undefined;
    private _canIpForward?;
    /**
     * @stability stable
     */
    get canIpForward(): boolean;
    /**
     * @stability stable
     */
    set canIpForward(value: boolean);
    /**
     * @stability stable
     */
    resetCanIpForward(): void;
    /**
     * @stability stable
     */
    get canIpForwardInput(): boolean | undefined;
    /**
     * @stability stable
     */
    get cpuPlatform(): string;
    /**
     * @stability stable
     */
    get currentStatus(): string;
    private _deletionProtection?;
    /**
     * @stability stable
     */
    get deletionProtection(): boolean;
    /**
     * @stability stable
     */
    set deletionProtection(value: boolean);
    /**
     * @stability stable
     */
    resetDeletionProtection(): void;
    /**
     * @stability stable
     */
    get deletionProtectionInput(): boolean | undefined;
    private _description?;
    /**
     * @stability stable
     */
    get description(): string;
    /**
     * @stability stable
     */
    set description(value: string);
    /**
     * @stability stable
     */
    resetDescription(): void;
    /**
     * @stability stable
     */
    get descriptionInput(): string | undefined;
    private _desiredStatus?;
    /**
     * @stability stable
     */
    get desiredStatus(): string;
    /**
     * @stability stable
     */
    set desiredStatus(value: string);
    /**
     * @stability stable
     */
    resetDesiredStatus(): void;
    /**
     * @stability stable
     */
    get desiredStatusInput(): string | undefined;
    private _enableDisplay?;
    /**
     * @stability stable
     */
    get enableDisplay(): boolean;
    /**
     * @stability stable
     */
    set enableDisplay(value: boolean);
    /**
     * @stability stable
     */
    resetEnableDisplay(): void;
    /**
     * @stability stable
     */
    get enableDisplayInput(): boolean | undefined;
    private _guestAccelerator?;
    /**
     * @stability stable
     */
    get guestAccelerator(): ComputeInstanceFromTemplateGuestAccelerator[];
    /**
     * @stability stable
     */
    set guestAccelerator(value: ComputeInstanceFromTemplateGuestAccelerator[]);
    /**
     * @stability stable
     */
    resetGuestAccelerator(): void;
    /**
     * @stability stable
     */
    get guestAcceleratorInput(): ComputeInstanceFromTemplateGuestAccelerator[] | undefined;
    private _hostname?;
    /**
     * @stability stable
     */
    get hostname(): string;
    /**
     * @stability stable
     */
    set hostname(value: string);
    /**
     * @stability stable
     */
    resetHostname(): void;
    /**
     * @stability stable
     */
    get hostnameInput(): string | undefined;
    /**
     * @stability stable
     */
    get id(): string;
    /**
     * @stability stable
     */
    get instanceId(): string;
    /**
     * @stability stable
     */
    get labelFingerprint(): string;
    private _labels?;
    /**
     * @stability stable
     */
    get labels(): {
        [key: string]: string;
    };
    /**
     * @stability stable
     */
    set labels(value: {
        [key: string]: string;
    });
    /**
     * @stability stable
     */
    resetLabels(): void;
    /**
     * @stability stable
     */
    get labelsInput(): {
        [key: string]: string;
    } | undefined;
    private _machineType?;
    /**
     * @stability stable
     */
    get machineType(): string;
    /**
     * @stability stable
     */
    set machineType(value: string);
    /**
     * @stability stable
     */
    resetMachineType(): void;
    /**
     * @stability stable
     */
    get machineTypeInput(): string | undefined;
    private _metadata?;
    /**
     * @stability stable
     */
    get metadata(): {
        [key: string]: string;
    };
    /**
     * @stability stable
     */
    set metadata(value: {
        [key: string]: string;
    });
    /**
     * @stability stable
     */
    resetMetadata(): void;
    /**
     * @stability stable
     */
    get metadataInput(): {
        [key: string]: string;
    } | undefined;
    /**
     * @stability stable
     */
    get metadataFingerprint(): string;
    private _metadataStartupScript?;
    /**
     * @stability stable
     */
    get metadataStartupScript(): string;
    /**
     * @stability stable
     */
    set metadataStartupScript(value: string);
    /**
     * @stability stable
     */
    resetMetadataStartupScript(): void;
    /**
     * @stability stable
     */
    get metadataStartupScriptInput(): string | undefined;
    private _minCpuPlatform?;
    /**
     * @stability stable
     */
    get minCpuPlatform(): string;
    /**
     * @stability stable
     */
    set minCpuPlatform(value: string);
    /**
     * @stability stable
     */
    resetMinCpuPlatform(): void;
    /**
     * @stability stable
     */
    get minCpuPlatformInput(): string | undefined;
    private _name;
    /**
     * @stability stable
     */
    get name(): string;
    /**
     * @stability stable
     */
    set name(value: string);
    /**
     * @stability stable
     */
    get nameInput(): string;
    private _project?;
    /**
     * @stability stable
     */
    get project(): string;
    /**
     * @stability stable
     */
    set project(value: string);
    /**
     * @stability stable
     */
    resetProject(): void;
    /**
     * @stability stable
     */
    get projectInput(): string | undefined;
    private _resourcePolicies?;
    /**
     * @stability stable
     */
    get resourcePolicies(): string[];
    /**
     * @stability stable
     */
    set resourcePolicies(value: string[]);
    /**
     * @stability stable
     */
    resetResourcePolicies(): void;
    /**
     * @stability stable
     */
    get resourcePoliciesInput(): string[] | undefined;
    private _scratchDisk?;
    /**
     * @stability stable
     */
    get scratchDisk(): ComputeInstanceFromTemplateScratchDisk[];
    /**
     * @stability stable
     */
    set scratchDisk(value: ComputeInstanceFromTemplateScratchDisk[]);
    /**
     * @stability stable
     */
    resetScratchDisk(): void;
    /**
     * @stability stable
     */
    get scratchDiskInput(): ComputeInstanceFromTemplateScratchDisk[] | undefined;
    /**
     * @stability stable
     */
    get selfLink(): string;
    private _serviceAccount?;
    /**
     * @stability stable
     */
    get serviceAccount(): ComputeInstanceFromTemplateServiceAccount[];
    /**
     * @stability stable
     */
    set serviceAccount(value: ComputeInstanceFromTemplateServiceAccount[]);
    /**
     * @stability stable
     */
    resetServiceAccount(): void;
    /**
     * @stability stable
     */
    get serviceAccountInput(): ComputeInstanceFromTemplateServiceAccount[] | undefined;
    private _sourceInstanceTemplate;
    /**
     * @stability stable
     */
    get sourceInstanceTemplate(): string;
    /**
     * @stability stable
     */
    set sourceInstanceTemplate(value: string);
    /**
     * @stability stable
     */
    get sourceInstanceTemplateInput(): string;
    private _tags?;
    /**
     * @stability stable
     */
    get tags(): string[];
    /**
     * @stability stable
     */
    set tags(value: string[]);
    /**
     * @stability stable
     */
    resetTags(): void;
    /**
     * @stability stable
     */
    get tagsInput(): string[] | undefined;
    /**
     * @stability stable
     */
    get tagsFingerprint(): string;
    private _zone?;
    /**
     * @stability stable
     */
    get zone(): string;
    /**
     * @stability stable
     */
    set zone(value: string);
    /**
     * @stability stable
     */
    resetZone(): void;
    /**
     * @stability stable
     */
    get zoneInput(): string | undefined;
    private _bootDisk?;
    /**
     * @stability stable
     */
    get bootDisk(): ComputeInstanceFromTemplateBootDisk[];
    /**
     * @stability stable
     */
    set bootDisk(value: ComputeInstanceFromTemplateBootDisk[]);
    /**
     * @stability stable
     */
    resetBootDisk(): void;
    /**
     * @stability stable
     */
    get bootDiskInput(): ComputeInstanceFromTemplateBootDisk[] | undefined;
    private _networkInterface?;
    /**
     * @stability stable
     */
    get networkInterface(): ComputeInstanceFromTemplateNetworkInterface[];
    /**
     * @stability stable
     */
    set networkInterface(value: ComputeInstanceFromTemplateNetworkInterface[]);
    /**
     * @stability stable
     */
    resetNetworkInterface(): void;
    /**
     * @stability stable
     */
    get networkInterfaceInput(): ComputeInstanceFromTemplateNetworkInterface[] | undefined;
    private _scheduling?;
    /**
     * @stability stable
     */
    get scheduling(): ComputeInstanceFromTemplateScheduling[];
    /**
     * @stability stable
     */
    set scheduling(value: ComputeInstanceFromTemplateScheduling[]);
    /**
     * @stability stable
     */
    resetScheduling(): void;
    /**
     * @stability stable
     */
    get schedulingInput(): ComputeInstanceFromTemplateScheduling[] | undefined;
    private _shieldedInstanceConfig?;
    /**
     * @stability stable
     */
    get shieldedInstanceConfig(): ComputeInstanceFromTemplateShieldedInstanceConfig[];
    /**
     * @stability stable
     */
    set shieldedInstanceConfig(value: ComputeInstanceFromTemplateShieldedInstanceConfig[]);
    /**
     * @stability stable
     */
    resetShieldedInstanceConfig(): void;
    /**
     * @stability stable
     */
    get shieldedInstanceConfigInput(): ComputeInstanceFromTemplateShieldedInstanceConfig[] | undefined;
    private _timeouts?;
    /**
     * @stability stable
     */
    get timeouts(): ComputeInstanceFromTemplateTimeouts;
    /**
     * @stability stable
     */
    set timeouts(value: ComputeInstanceFromTemplateTimeouts);
    /**
     * @stability stable
     */
    resetTimeouts(): void;
    /**
     * @stability stable
     */
    get timeoutsInput(): ComputeInstanceFromTemplateTimeouts | undefined;
    /**
     * @stability stable
     */
    protected synthesizeAttributes(): {
        [name: string]: any;
    };
}
