import { Construct } from 'constructs';
import * as cdktf from 'cdktf';
/**
 * @stability stable
 */
export interface ComputeInstanceGroupManagerConfig extends cdktf.TerraformMetaArguments {
    /**
     * The base instance name to use for instances in this group.
     *
     * The value must be a valid RFC1035 name. Supported characters are lowercase letters, numbers, and hyphens (-). Instances are named by appending a hyphen and a random four-character string to the base instance name.
     *
     * @stability stable
     */
    readonly baseInstanceName: string;
    /**
     * An optional textual description of the instance group manager.
     *
     * @stability stable
     */
    readonly description?: string;
    /**
     * The name of the instance group manager.
     *
     * Must be 1-63 characters long and comply with RFC1035. Supported characters include lowercase letters, numbers, and hyphens.
     *
     * @stability stable
     */
    readonly name: string;
    /**
     * The ID of the project in which the resource belongs.
     *
     * If it is not provided, the provider project is used.
     *
     * @stability stable
     */
    readonly project?: string;
    /**
     * The full URL of all target pools to which new instances in the group are added.
     *
     * Updating the target pools attribute does not affect existing instances.
     *
     * @stability stable
     */
    readonly targetPools?: string[];
    /**
     * The target number of running instances for this managed instance group.
     *
     * This value should always be explicitly set unless this resource is attached to an autoscaler, in which case it should never be set. Defaults to 0.
     *
     * @stability stable
     */
    readonly targetSize?: number;
    /**
     * Whether to wait for all instances to be created/updated before returning.
     *
     * Note that if this is set to true and the operation does not succeed, Terraform will continue trying until it times out.
     *
     * @stability stable
     */
    readonly waitForInstances?: boolean;
    /**
     * The zone that instances in this group should be created in.
     *
     * @stability stable
     */
    readonly zone?: string;
    /**
     * auto_healing_policies block.
     *
     * @stability stable
     */
    readonly autoHealingPolicies?: ComputeInstanceGroupManagerAutoHealingPolicies[];
    /**
     * named_port block.
     *
     * @stability stable
     */
    readonly namedPort?: ComputeInstanceGroupManagerNamedPort[];
    /**
     * stateful_disk block.
     *
     * @stability stable
     */
    readonly statefulDisk?: ComputeInstanceGroupManagerStatefulDisk[];
    /**
     * timeouts block.
     *
     * @stability stable
     */
    readonly timeouts?: ComputeInstanceGroupManagerTimeouts;
    /**
     * update_policy block.
     *
     * @stability stable
     */
    readonly updatePolicy?: ComputeInstanceGroupManagerUpdatePolicy[];
    /**
     * version block.
     *
     * @stability stable
     */
    readonly version: ComputeInstanceGroupManagerVersion[];
}
/**
 * @stability stable
 */
export interface ComputeInstanceGroupManagerAutoHealingPolicies {
    /**
     * The health check resource that signals autohealing.
     *
     * @stability stable
     */
    readonly healthCheck: string;
    /**
     * The number of seconds that the managed instance group waits before it applies autohealing policies to new instances or recently recreated instances.
     *
     * Between 0 and 3600.
     *
     * @stability stable
     */
    readonly initialDelaySec: number;
}
/**
 * @stability stable
 */
export interface ComputeInstanceGroupManagerNamedPort {
    /**
     * The name of the port.
     *
     * @stability stable
     */
    readonly name: string;
    /**
     * The port number.
     *
     * @stability stable
     */
    readonly port: number;
}
/**
 * @stability stable
 */
export interface ComputeInstanceGroupManagerStatefulDisk {
    /**
     * A value that prescribes what should happen to the stateful disk when the VM instance is deleted.
     *
     * The available options are NEVER and ON_PERMANENT_INSTANCE_DELETION. NEVER - detach the disk when the VM is deleted, but do not delete the disk. ON_PERMANENT_INSTANCE_DELETION will delete the stateful disk when the VM is permanently deleted from the instance group. The default is NEVER.
     *
     * @stability stable
     */
    readonly deleteRule?: string;
    /**
     * The device name of the disk to be attached.
     *
     * @stability stable
     */
    readonly deviceName: string;
}
/**
 * @stability stable
 */
export interface ComputeInstanceGroupManagerTimeouts {
    /**
     * @stability stable
     */
    readonly create?: string;
    /**
     * @stability stable
     */
    readonly delete?: string;
    /**
     * @stability stable
     */
    readonly update?: string;
}
/**
 * @stability stable
 */
export interface ComputeInstanceGroupManagerUpdatePolicy {
    /**
     * The maximum number of instances that can be created above the specified targetSize during the update process.
     *
     * Conflicts with max_surge_percent. If neither is set, defaults to 1
     *
     * @stability stable
     */
    readonly maxSurgeFixed?: number;
    /**
     * The maximum number of instances(calculated as percentage) that can be created above the specified targetSize during the update process.
     *
     * Conflicts with max_surge_fixed.
     *
     * @stability stable
     */
    readonly maxSurgePercent?: number;
    /**
     * The maximum number of instances that can be unavailable during the update process.
     *
     * Conflicts with max_unavailable_percent. If neither is set, defaults to 1.
     *
     * @stability stable
     */
    readonly maxUnavailableFixed?: number;
    /**
     * The maximum number of instances(calculated as percentage) that can be unavailable during the update process.
     *
     * Conflicts with max_unavailable_fixed.
     *
     * @stability stable
     */
    readonly maxUnavailablePercent?: number;
    /**
     * Minimum number of seconds to wait for after a newly created instance becomes available.
     *
     * This value must be from range [0, 3600].
     *
     * @stability stable
     */
    readonly minReadySec?: number;
    /**
     * Minimal action to be taken on an instance.
     *
     * You can specify either RESTART to restart existing instances or REPLACE to delete and create new instances from the target template. If you specify a RESTART, the Updater will attempt to perform that action only. However, if the Updater determines that the minimal action you specify is not enough to perform the update, it might perform a more disruptive action.
     *
     * @stability stable
     */
    readonly minimalAction: string;
    /**
     * The instance replacement method for managed instance groups.
     *
     * Valid values are: "RECREATE", "SUBSTITUTE". If SUBSTITUTE (default), the group replaces VM instances with new instances that have randomly generated names. If RECREATE, instance names are preserved.  You must also set max_unavailable_fixed or max_unavailable_percent to be greater than 0.
     *
     * @stability stable
     */
    readonly replacementMethod?: string;
    /**
     * The type of update process.
     *
     * You can specify either PROACTIVE so that the instance group manager proactively executes actions in order to bring instances to their target versions or OPPORTUNISTIC so that no action is proactively executed but the update will be performed as part of other actions (for example, resizes or recreateInstances calls).
     *
     * @stability stable
     */
    readonly type: string;
}
/**
 * @stability stable
 */
export interface ComputeInstanceGroupManagerVersionTargetSize {
    /**
     * The number of instances which are managed for this version.
     *
     * Conflicts with percent.
     *
     * @stability stable
     */
    readonly fixed?: number;
    /**
     * The number of instances (calculated as percentage) which are managed for this version.
     *
     * Conflicts with fixed. Note that when using percent, rounding will be in favor of explicitly set target_size values; a managed instance group with 2 instances and 2 versions, one of which has a target_size.percent of 60 will create 2 instances of that version.
     *
     * @stability stable
     */
    readonly percent?: number;
}
/**
 * @stability stable
 */
export interface ComputeInstanceGroupManagerVersion {
    /**
     * The full URL to an instance template from which all new instances of this version will be created.
     *
     * @stability stable
     */
    readonly instanceTemplate: string;
    /**
     * Version name.
     *
     * @stability stable
     */
    readonly name?: string;
    /**
     * target_size block.
     *
     * @stability stable
     */
    readonly targetSize?: ComputeInstanceGroupManagerVersionTargetSize[];
}
/**
 * @stability stable
 */
export declare class ComputeInstanceGroupManager extends cdktf.TerraformResource {
    /**
     * @stability stable
     */
    constructor(scope: Construct, id: string, config: ComputeInstanceGroupManagerConfig);
    private _baseInstanceName;
    /**
     * @stability stable
     */
    get baseInstanceName(): string;
    /**
     * @stability stable
     */
    set baseInstanceName(value: string);
    /**
     * @stability stable
     */
    get baseInstanceNameInput(): string;
    private _description?;
    /**
     * @stability stable
     */
    get description(): string;
    /**
     * @stability stable
     */
    set description(value: string);
    /**
     * @stability stable
     */
    resetDescription(): void;
    /**
     * @stability stable
     */
    get descriptionInput(): string | undefined;
    /**
     * @stability stable
     */
    get fingerprint(): string;
    /**
     * @stability stable
     */
    get id(): string;
    /**
     * @stability stable
     */
    get instanceGroup(): string;
    private _name;
    /**
     * @stability stable
     */
    get name(): string;
    /**
     * @stability stable
     */
    set name(value: string);
    /**
     * @stability stable
     */
    get nameInput(): string;
    /**
     * @stability stable
     */
    get operation(): string;
    private _project?;
    /**
     * @stability stable
     */
    get project(): string;
    /**
     * @stability stable
     */
    set project(value: string);
    /**
     * @stability stable
     */
    resetProject(): void;
    /**
     * @stability stable
     */
    get projectInput(): string | undefined;
    /**
     * @stability stable
     */
    get selfLink(): string;
    private _targetPools?;
    /**
     * @stability stable
     */
    get targetPools(): string[];
    /**
     * @stability stable
     */
    set targetPools(value: string[]);
    /**
     * @stability stable
     */
    resetTargetPools(): void;
    /**
     * @stability stable
     */
    get targetPoolsInput(): string[] | undefined;
    private _targetSize?;
    /**
     * @stability stable
     */
    get targetSize(): number;
    /**
     * @stability stable
     */
    set targetSize(value: number);
    /**
     * @stability stable
     */
    resetTargetSize(): void;
    /**
     * @stability stable
     */
    get targetSizeInput(): number | undefined;
    private _waitForInstances?;
    /**
     * @stability stable
     */
    get waitForInstances(): boolean;
    /**
     * @stability stable
     */
    set waitForInstances(value: boolean);
    /**
     * @stability stable
     */
    resetWaitForInstances(): void;
    /**
     * @stability stable
     */
    get waitForInstancesInput(): boolean | undefined;
    private _zone?;
    /**
     * @stability stable
     */
    get zone(): string;
    /**
     * @stability stable
     */
    set zone(value: string);
    /**
     * @stability stable
     */
    resetZone(): void;
    /**
     * @stability stable
     */
    get zoneInput(): string | undefined;
    private _autoHealingPolicies?;
    /**
     * @stability stable
     */
    get autoHealingPolicies(): ComputeInstanceGroupManagerAutoHealingPolicies[];
    /**
     * @stability stable
     */
    set autoHealingPolicies(value: ComputeInstanceGroupManagerAutoHealingPolicies[]);
    /**
     * @stability stable
     */
    resetAutoHealingPolicies(): void;
    /**
     * @stability stable
     */
    get autoHealingPoliciesInput(): ComputeInstanceGroupManagerAutoHealingPolicies[] | undefined;
    private _namedPort?;
    /**
     * @stability stable
     */
    get namedPort(): ComputeInstanceGroupManagerNamedPort[];
    /**
     * @stability stable
     */
    set namedPort(value: ComputeInstanceGroupManagerNamedPort[]);
    /**
     * @stability stable
     */
    resetNamedPort(): void;
    /**
     * @stability stable
     */
    get namedPortInput(): ComputeInstanceGroupManagerNamedPort[] | undefined;
    private _statefulDisk?;
    /**
     * @stability stable
     */
    get statefulDisk(): ComputeInstanceGroupManagerStatefulDisk[];
    /**
     * @stability stable
     */
    set statefulDisk(value: ComputeInstanceGroupManagerStatefulDisk[]);
    /**
     * @stability stable
     */
    resetStatefulDisk(): void;
    /**
     * @stability stable
     */
    get statefulDiskInput(): ComputeInstanceGroupManagerStatefulDisk[] | undefined;
    private _timeouts?;
    /**
     * @stability stable
     */
    get timeouts(): ComputeInstanceGroupManagerTimeouts;
    /**
     * @stability stable
     */
    set timeouts(value: ComputeInstanceGroupManagerTimeouts);
    /**
     * @stability stable
     */
    resetTimeouts(): void;
    /**
     * @stability stable
     */
    get timeoutsInput(): ComputeInstanceGroupManagerTimeouts | undefined;
    private _updatePolicy?;
    /**
     * @stability stable
     */
    get updatePolicy(): ComputeInstanceGroupManagerUpdatePolicy[];
    /**
     * @stability stable
     */
    set updatePolicy(value: ComputeInstanceGroupManagerUpdatePolicy[]);
    /**
     * @stability stable
     */
    resetUpdatePolicy(): void;
    /**
     * @stability stable
     */
    get updatePolicyInput(): ComputeInstanceGroupManagerUpdatePolicy[] | undefined;
    private _version;
    /**
     * @stability stable
     */
    get version(): ComputeInstanceGroupManagerVersion[];
    /**
     * @stability stable
     */
    set version(value: ComputeInstanceGroupManagerVersion[]);
    /**
     * @stability stable
     */
    get versionInput(): ComputeInstanceGroupManagerVersion[];
    /**
     * @stability stable
     */
    protected synthesizeAttributes(): {
        [name: string]: any;
    };
}
