import { Construct } from 'constructs';
import * as cdktf from 'cdktf';
/**
 * @stability stable
 */
export interface ComputeManagedSslCertificateConfig extends cdktf.TerraformMetaArguments {
    /**
     * The unique identifier for the resource.
     *
     * @stability stable
     */
    readonly certificateId?: number;
    /**
     * An optional description of this resource.
     *
     * @stability stable
     */
    readonly description?: string;
    /**
     * Name of the resource.
     *
     * Provided by the client when the resource is
     * created. The name must be 1-63 characters long, and comply with
     * RFC1035. Specifically, the name must be 1-63 characters long and match
     * the regular expression '[a-z]([-a-z0-9]*[a-z0-9])?' which means the
     * first character must be a lowercase letter, and all following
     * characters must be a dash, lowercase letter, or digit, except the last
     * character, which cannot be a dash.
     *
     *
     * These are in the same namespace as the managed SSL certificates.
     *
     * @stability stable
     */
    readonly name?: string;
    /**
     * @stability stable
     */
    readonly project?: string;
    /**
     * Enum field whose value is always 'MANAGED' - used to signal to the API which type this is.
     *
     * Default value: "MANAGED" Possible values: ["MANAGED"]
     *
     * @stability stable
     */
    readonly type?: string;
    /**
     * managed block.
     *
     * @stability stable
     */
    readonly managed?: ComputeManagedSslCertificateManaged[];
    /**
     * timeouts block.
     *
     * @stability stable
     */
    readonly timeouts?: ComputeManagedSslCertificateTimeouts;
}
/**
 * @stability stable
 */
export interface ComputeManagedSslCertificateManaged {
    /**
     * Domains for which a managed SSL certificate will be valid.
     *
     * Currently,
     * there can be up to 100 domains in this list.
     *
     * @stability stable
     */
    readonly domains: string[];
}
/**
 * @stability stable
 */
export interface ComputeManagedSslCertificateTimeouts {
    /**
     * @stability stable
     */
    readonly create?: string;
    /**
     * @stability stable
     */
    readonly delete?: string;
}
/**
 * @stability stable
 */
export declare class ComputeManagedSslCertificate extends cdktf.TerraformResource {
    /**
     * @stability stable
     */
    constructor(scope: Construct, id: string, config?: ComputeManagedSslCertificateConfig);
    private _certificateId?;
    /**
     * @stability stable
     */
    get certificateId(): number;
    /**
     * @stability stable
     */
    set certificateId(value: number);
    /**
     * @stability stable
     */
    resetCertificateId(): void;
    /**
     * @stability stable
     */
    get certificateIdInput(): number | undefined;
    /**
     * @stability stable
     */
    get creationTimestamp(): string;
    private _description?;
    /**
     * @stability stable
     */
    get description(): string;
    /**
     * @stability stable
     */
    set description(value: string);
    /**
     * @stability stable
     */
    resetDescription(): void;
    /**
     * @stability stable
     */
    get descriptionInput(): string | undefined;
    /**
     * @stability stable
     */
    get expireTime(): string;
    /**
     * @stability stable
     */
    get id(): string;
    private _name?;
    /**
     * @stability stable
     */
    get name(): string;
    /**
     * @stability stable
     */
    set name(value: string);
    /**
     * @stability stable
     */
    resetName(): void;
    /**
     * @stability stable
     */
    get nameInput(): string | undefined;
    private _project?;
    /**
     * @stability stable
     */
    get project(): string;
    /**
     * @stability stable
     */
    set project(value: string);
    /**
     * @stability stable
     */
    resetProject(): void;
    /**
     * @stability stable
     */
    get projectInput(): string | undefined;
    /**
     * @stability stable
     */
    get selfLink(): string;
    /**
     * @stability stable
     */
    get subjectAlternativeNames(): string[];
    private _type?;
    /**
     * @stability stable
     */
    get type(): string;
    /**
     * @stability stable
     */
    set type(value: string);
    /**
     * @stability stable
     */
    resetType(): void;
    /**
     * @stability stable
     */
    get typeInput(): string | undefined;
    private _managed?;
    /**
     * @stability stable
     */
    get managed(): ComputeManagedSslCertificateManaged[];
    /**
     * @stability stable
     */
    set managed(value: ComputeManagedSslCertificateManaged[]);
    /**
     * @stability stable
     */
    resetManaged(): void;
    /**
     * @stability stable
     */
    get managedInput(): ComputeManagedSslCertificateManaged[] | undefined;
    private _timeouts?;
    /**
     * @stability stable
     */
    get timeouts(): ComputeManagedSslCertificateTimeouts;
    /**
     * @stability stable
     */
    set timeouts(value: ComputeManagedSslCertificateTimeouts);
    /**
     * @stability stable
     */
    resetTimeouts(): void;
    /**
     * @stability stable
     */
    get timeoutsInput(): ComputeManagedSslCertificateTimeouts | undefined;
    /**
     * @stability stable
     */
    protected synthesizeAttributes(): {
        [name: string]: any;
    };
}
