import { Construct } from 'constructs';
import * as cdktf from 'cdktf';
/**
 * @stability stable
 */
export interface ComputeNetworkEndpointConfig extends cdktf.TerraformMetaArguments {
    /**
     * The name for a specific VM instance that the IP address belongs to.
     *
     * This is required for network endpoints of type GCE_VM_IP_PORT.
     * The instance must be in the same zone of network endpoint group.
     *
     * @stability stable
     */
    readonly instance: string;
    /**
     * IPv4 address of network endpoint.
     *
     * The IP address must belong
     * to a VM in GCE (either the primary IP or as part of an aliased IP
     * range).
     *
     * @stability stable
     */
    readonly ipAddress: string;
    /**
     * The network endpoint group this endpoint is part of.
     *
     * @stability stable
     */
    readonly networkEndpointGroup: string;
    /**
     * Port number of network endpoint.
     *
     * @stability stable
     */
    readonly port: number;
    /**
     * @stability stable
     */
    readonly project?: string;
    /**
     * Zone where the containing network endpoint group is located.
     *
     * @stability stable
     */
    readonly zone?: string;
    /**
     * timeouts block.
     *
     * @stability stable
     */
    readonly timeouts?: ComputeNetworkEndpointTimeouts;
}
/**
 * @stability stable
 */
export interface ComputeNetworkEndpointTimeouts {
    /**
     * @stability stable
     */
    readonly create?: string;
    /**
     * @stability stable
     */
    readonly delete?: string;
}
/**
 * @stability stable
 */
export declare class ComputeNetworkEndpoint extends cdktf.TerraformResource {
    /**
     * @stability stable
     */
    constructor(scope: Construct, id: string, config: ComputeNetworkEndpointConfig);
    /**
     * @stability stable
     */
    get id(): string;
    private _instance;
    /**
     * @stability stable
     */
    get instance(): string;
    /**
     * @stability stable
     */
    set instance(value: string);
    /**
     * @stability stable
     */
    get instanceInput(): string;
    private _ipAddress;
    /**
     * @stability stable
     */
    get ipAddress(): string;
    /**
     * @stability stable
     */
    set ipAddress(value: string);
    /**
     * @stability stable
     */
    get ipAddressInput(): string;
    private _networkEndpointGroup;
    /**
     * @stability stable
     */
    get networkEndpointGroup(): string;
    /**
     * @stability stable
     */
    set networkEndpointGroup(value: string);
    /**
     * @stability stable
     */
    get networkEndpointGroupInput(): string;
    private _port;
    /**
     * @stability stable
     */
    get port(): number;
    /**
     * @stability stable
     */
    set port(value: number);
    /**
     * @stability stable
     */
    get portInput(): number;
    private _project?;
    /**
     * @stability stable
     */
    get project(): string;
    /**
     * @stability stable
     */
    set project(value: string);
    /**
     * @stability stable
     */
    resetProject(): void;
    /**
     * @stability stable
     */
    get projectInput(): string | undefined;
    private _zone?;
    /**
     * @stability stable
     */
    get zone(): string;
    /**
     * @stability stable
     */
    set zone(value: string);
    /**
     * @stability stable
     */
    resetZone(): void;
    /**
     * @stability stable
     */
    get zoneInput(): string | undefined;
    private _timeouts?;
    /**
     * @stability stable
     */
    get timeouts(): ComputeNetworkEndpointTimeouts;
    /**
     * @stability stable
     */
    set timeouts(value: ComputeNetworkEndpointTimeouts);
    /**
     * @stability stable
     */
    resetTimeouts(): void;
    /**
     * @stability stable
     */
    get timeoutsInput(): ComputeNetworkEndpointTimeouts | undefined;
    /**
     * @stability stable
     */
    protected synthesizeAttributes(): {
        [name: string]: any;
    };
}
