import { Construct } from 'constructs';
import * as cdktf from 'cdktf';
/**
 * @stability stable
 */
export interface ComputePerInstanceConfigConfig extends cdktf.TerraformMetaArguments {
    /**
     * The instance group manager this instance config is part of.
     *
     * @stability stable
     */
    readonly instanceGroupManager: string;
    /**
     * @stability stable
     */
    readonly minimalAction?: string;
    /**
     * @stability stable
     */
    readonly mostDisruptiveAllowedAction?: string;
    /**
     * The name for this per-instance config and its corresponding instance.
     *
     * @stability stable
     */
    readonly name: string;
    /**
     * @stability stable
     */
    readonly project?: string;
    /**
     * @stability stable
     */
    readonly removeInstanceStateOnDestroy?: boolean;
    /**
     * Zone where the containing instance group manager is located.
     *
     * @stability stable
     */
    readonly zone: string;
    /**
     * preserved_state block.
     *
     * @stability stable
     */
    readonly preservedState?: ComputePerInstanceConfigPreservedState[];
    /**
     * timeouts block.
     *
     * @stability stable
     */
    readonly timeouts?: ComputePerInstanceConfigTimeouts;
}
/**
 * @stability stable
 */
export interface ComputePerInstanceConfigPreservedStateDisk {
    /**
     * A value that prescribes what should happen to the stateful disk when the VM instance is deleted.
     *
     * The available options are 'NEVER' and 'ON_PERMANENT_INSTANCE_DELETION'.
     * 'NEVER' - detach the disk when the VM is deleted, but do not delete the disk.
     * 'ON_PERMANENT_INSTANCE_DELETION' will delete the stateful disk when the VM is permanently
     * deleted from the instance group. Default value: "NEVER" Possible values: ["NEVER", "ON_PERMANENT_INSTANCE_DELETION"]
     *
     * @stability stable
     */
    readonly deleteRule?: string;
    /**
     * A unique device name that is reflected into the /dev/ tree of a Linux operating system running within the instance.
     *
     * @stability stable
     */
    readonly deviceName: string;
    /**
     * The mode of the disk.
     *
     * Default value: "READ_WRITE" Possible values: ["READ_ONLY", "READ_WRITE"]
     *
     * @stability stable
     */
    readonly mode?: string;
    /**
     * The URI of an existing persistent disk to attach under the specified device-name in the format 'projects/project-id/zones/zone/disks/disk-name'.
     *
     * @stability stable
     */
    readonly source: string;
}
/**
 * @stability stable
 */
export interface ComputePerInstanceConfigPreservedState {
    /**
     * Preserved metadata defined for this instance.
     *
     * This is a list of key->value pairs.
     *
     * @stability stable
     */
    readonly metadata?: {
        [key: string]: string;
    };
    /**
     * disk block.
     *
     * @stability stable
     */
    readonly disk?: ComputePerInstanceConfigPreservedStateDisk[];
}
/**
 * @stability stable
 */
export interface ComputePerInstanceConfigTimeouts {
    /**
     * @stability stable
     */
    readonly create?: string;
    /**
     * @stability stable
     */
    readonly delete?: string;
    /**
     * @stability stable
     */
    readonly update?: string;
}
/**
 * @stability stable
 */
export declare class ComputePerInstanceConfig extends cdktf.TerraformResource {
    /**
     * @stability stable
     */
    constructor(scope: Construct, id: string, config: ComputePerInstanceConfigConfig);
    /**
     * @stability stable
     */
    get id(): string;
    private _instanceGroupManager;
    /**
     * @stability stable
     */
    get instanceGroupManager(): string;
    /**
     * @stability stable
     */
    set instanceGroupManager(value: string);
    /**
     * @stability stable
     */
    get instanceGroupManagerInput(): string;
    private _minimalAction?;
    /**
     * @stability stable
     */
    get minimalAction(): string;
    /**
     * @stability stable
     */
    set minimalAction(value: string);
    /**
     * @stability stable
     */
    resetMinimalAction(): void;
    /**
     * @stability stable
     */
    get minimalActionInput(): string | undefined;
    private _mostDisruptiveAllowedAction?;
    /**
     * @stability stable
     */
    get mostDisruptiveAllowedAction(): string;
    /**
     * @stability stable
     */
    set mostDisruptiveAllowedAction(value: string);
    /**
     * @stability stable
     */
    resetMostDisruptiveAllowedAction(): void;
    /**
     * @stability stable
     */
    get mostDisruptiveAllowedActionInput(): string | undefined;
    private _name;
    /**
     * @stability stable
     */
    get name(): string;
    /**
     * @stability stable
     */
    set name(value: string);
    /**
     * @stability stable
     */
    get nameInput(): string;
    private _project?;
    /**
     * @stability stable
     */
    get project(): string;
    /**
     * @stability stable
     */
    set project(value: string);
    /**
     * @stability stable
     */
    resetProject(): void;
    /**
     * @stability stable
     */
    get projectInput(): string | undefined;
    private _removeInstanceStateOnDestroy?;
    /**
     * @stability stable
     */
    get removeInstanceStateOnDestroy(): boolean;
    /**
     * @stability stable
     */
    set removeInstanceStateOnDestroy(value: boolean);
    /**
     * @stability stable
     */
    resetRemoveInstanceStateOnDestroy(): void;
    /**
     * @stability stable
     */
    get removeInstanceStateOnDestroyInput(): boolean | undefined;
    private _zone;
    /**
     * @stability stable
     */
    get zone(): string;
    /**
     * @stability stable
     */
    set zone(value: string);
    /**
     * @stability stable
     */
    get zoneInput(): string;
    private _preservedState?;
    /**
     * @stability stable
     */
    get preservedState(): ComputePerInstanceConfigPreservedState[];
    /**
     * @stability stable
     */
    set preservedState(value: ComputePerInstanceConfigPreservedState[]);
    /**
     * @stability stable
     */
    resetPreservedState(): void;
    /**
     * @stability stable
     */
    get preservedStateInput(): ComputePerInstanceConfigPreservedState[] | undefined;
    private _timeouts?;
    /**
     * @stability stable
     */
    get timeouts(): ComputePerInstanceConfigTimeouts;
    /**
     * @stability stable
     */
    set timeouts(value: ComputePerInstanceConfigTimeouts);
    /**
     * @stability stable
     */
    resetTimeouts(): void;
    /**
     * @stability stable
     */
    get timeoutsInput(): ComputePerInstanceConfigTimeouts | undefined;
    /**
     * @stability stable
     */
    protected synthesizeAttributes(): {
        [name: string]: any;
    };
}
