import { Construct } from 'constructs';
import * as cdktf from 'cdktf';
/**
 * @stability stable
 */
export interface ComputeSecurityPolicyConfig extends cdktf.TerraformMetaArguments {
    /**
     * An optional description of this security policy.
     *
     * Max size is 2048.
     *
     * @stability stable
     */
    readonly description?: string;
    /**
     * The name of the security policy.
     *
     * @stability stable
     */
    readonly name: string;
    /**
     * The project in which the resource belongs.
     *
     * If it is not provided, the provider project is used.
     *
     * @stability stable
     */
    readonly project?: string;
    /**
     * rule block.
     *
     * @stability stable
     */
    readonly rule?: ComputeSecurityPolicyRule[];
    /**
     * timeouts block.
     *
     * @stability stable
     */
    readonly timeouts?: ComputeSecurityPolicyTimeouts;
}
/**
 * @stability stable
 */
export interface ComputeSecurityPolicyRuleMatchConfig {
    /**
     * Set of IP addresses or ranges (IPV4 or IPV6) in CIDR notation to match against inbound traffic.
     *
     * There is a limit of 10 IP ranges per rule. A value of '*' matches all IPs (can be used to override the default behavior).
     *
     * @stability stable
     */
    readonly srcIpRanges: string[];
}
/**
 * @stability stable
 */
export interface ComputeSecurityPolicyRuleMatchExpr {
    /**
     * Textual representation of an expression in Common Expression Language syntax.
     *
     * The application context of the containing message determines which well-known feature set of CEL is supported.
     *
     * @stability stable
     */
    readonly expression: string;
}
/**
 * @stability stable
 */
export interface ComputeSecurityPolicyRuleMatch {
    /**
     * Predefined rule expression.
     *
     * If this field is specified, config must also be specified. Available options:   SRC_IPS_V1: Must specify the corresponding src_ip_ranges field in config.
     *
     * @stability stable
     */
    readonly versionedExpr?: string;
    /**
     * config block.
     *
     * @stability stable
     */
    readonly config?: ComputeSecurityPolicyRuleMatchConfig[];
    /**
     * expr block.
     *
     * @stability stable
     */
    readonly expr?: ComputeSecurityPolicyRuleMatchExpr[];
}
/**
 * @stability stable
 */
export interface ComputeSecurityPolicyRule {
    /**
     * Action to take when match matches the request.
     *
     * Valid values:   "allow" : allow access to target, "deny(status)" : deny access to target, returns the HTTP response code specified (valid values are 403, 404 and 502)
     *
     * @stability stable
     */
    readonly action: string;
    /**
     * An optional description of this rule.
     *
     * Max size is 64.
     *
     * @stability stable
     */
    readonly description?: string;
    /**
     * When set to true, the action specified above is not enforced.
     *
     * Stackdriver logs for requests that trigger a preview action are annotated as such.
     *
     * @stability stable
     */
    readonly preview?: boolean;
    /**
     * An unique positive integer indicating the priority of evaluation for a rule.
     *
     * Rules are evaluated from highest priority (lowest numerically) to lowest priority (highest numerically) in order.
     *
     * @stability stable
     */
    readonly priority: number;
    /**
     * match block.
     *
     * @stability stable
     */
    readonly match: ComputeSecurityPolicyRuleMatch[];
}
/**
 * @stability stable
 */
export interface ComputeSecurityPolicyTimeouts {
    /**
     * @stability stable
     */
    readonly create?: string;
    /**
     * @stability stable
     */
    readonly delete?: string;
    /**
     * @stability stable
     */
    readonly update?: string;
}
/**
 * @stability stable
 */
export declare class ComputeSecurityPolicy extends cdktf.TerraformResource {
    /**
     * @stability stable
     */
    constructor(scope: Construct, id: string, config: ComputeSecurityPolicyConfig);
    private _description?;
    /**
     * @stability stable
     */
    get description(): string;
    /**
     * @stability stable
     */
    set description(value: string);
    /**
     * @stability stable
     */
    resetDescription(): void;
    /**
     * @stability stable
     */
    get descriptionInput(): string | undefined;
    /**
     * @stability stable
     */
    get fingerprint(): string;
    /**
     * @stability stable
     */
    get id(): string;
    private _name;
    /**
     * @stability stable
     */
    get name(): string;
    /**
     * @stability stable
     */
    set name(value: string);
    /**
     * @stability stable
     */
    get nameInput(): string;
    private _project?;
    /**
     * @stability stable
     */
    get project(): string;
    /**
     * @stability stable
     */
    set project(value: string);
    /**
     * @stability stable
     */
    resetProject(): void;
    /**
     * @stability stable
     */
    get projectInput(): string | undefined;
    /**
     * @stability stable
     */
    get selfLink(): string;
    private _rule?;
    /**
     * @stability stable
     */
    get rule(): ComputeSecurityPolicyRule[];
    /**
     * @stability stable
     */
    set rule(value: ComputeSecurityPolicyRule[]);
    /**
     * @stability stable
     */
    resetRule(): void;
    /**
     * @stability stable
     */
    get ruleInput(): ComputeSecurityPolicyRule[] | undefined;
    private _timeouts?;
    /**
     * @stability stable
     */
    get timeouts(): ComputeSecurityPolicyTimeouts;
    /**
     * @stability stable
     */
    set timeouts(value: ComputeSecurityPolicyTimeouts);
    /**
     * @stability stable
     */
    resetTimeouts(): void;
    /**
     * @stability stable
     */
    get timeoutsInput(): ComputeSecurityPolicyTimeouts | undefined;
    /**
     * @stability stable
     */
    protected synthesizeAttributes(): {
        [name: string]: any;
    };
}
