import { Construct } from 'constructs';
import * as cdktf from 'cdktf';
/**
 * @stability stable
 */
export interface ComputeSslPolicyConfig extends cdktf.TerraformMetaArguments {
    /**
     * Profile specifies the set of SSL features that can be used by the load balancer when negotiating SSL with clients.
     *
     * This can be one of
     * 'COMPATIBLE', 'MODERN', 'RESTRICTED', or 'CUSTOM'. If using 'CUSTOM',
     * the set of SSL features to enable must be specified in the
     * 'customFeatures' field.
     *
     * See the [official documentation](https://cloud.google.com/compute/docs/load-balancing/ssl-policies#profilefeaturesupport)
     * for which ciphers are available to use. **Note**: this argument
     * must* be present when using the 'CUSTOM' profile. This argument
     * must not* be present when using any other profile.
     *
     * @stability stable
     */
    readonly customFeatures?: string[];
    /**
     * An optional description of this resource.
     *
     * @stability stable
     */
    readonly description?: string;
    /**
     * The minimum version of SSL protocol that can be used by the clients to establish a connection with the load balancer.
     *
     * Default value: "TLS_1_0" Possible values: ["TLS_1_0", "TLS_1_1", "TLS_1_2"]
     *
     * @stability stable
     */
    readonly minTlsVersion?: string;
    /**
     * Name of the resource.
     *
     * Provided by the client when the resource is
     * created. The name must be 1-63 characters long, and comply with
     * RFC1035. Specifically, the name must be 1-63 characters long and match
     * the regular expression '[a-z]([-a-z0-9]*[a-z0-9])?' which means the
     * first character must be a lowercase letter, and all following
     * characters must be a dash, lowercase letter, or digit, except the last
     * character, which cannot be a dash.
     *
     * @stability stable
     */
    readonly name: string;
    /**
     * Profile specifies the set of SSL features that can be used by the load balancer when negotiating SSL with clients.
     *
     * If using 'CUSTOM',
     * the set of SSL features to enable must be specified in the
     * 'customFeatures' field.
     *
     * See the [official documentation](https://cloud.google.com/compute/docs/load-balancing/ssl-policies#profilefeaturesupport)
     * for information on what cipher suites each profile provides. If
     * 'CUSTOM' is used, the 'custom_features' attribute **must be set**. Default value: "COMPATIBLE" Possible values: ["COMPATIBLE", "MODERN", "RESTRICTED", "CUSTOM"]
     *
     * @stability stable
     */
    readonly profile?: string;
    /**
     * @stability stable
     */
    readonly project?: string;
    /**
     * timeouts block.
     *
     * @stability stable
     */
    readonly timeouts?: ComputeSslPolicyTimeouts;
}
/**
 * @stability stable
 */
export interface ComputeSslPolicyTimeouts {
    /**
     * @stability stable
     */
    readonly create?: string;
    /**
     * @stability stable
     */
    readonly delete?: string;
    /**
     * @stability stable
     */
    readonly update?: string;
}
/**
 * @stability stable
 */
export declare class ComputeSslPolicy extends cdktf.TerraformResource {
    /**
     * @stability stable
     */
    constructor(scope: Construct, id: string, config: ComputeSslPolicyConfig);
    /**
     * @stability stable
     */
    get creationTimestamp(): string;
    private _customFeatures?;
    /**
     * @stability stable
     */
    get customFeatures(): string[];
    /**
     * @stability stable
     */
    set customFeatures(value: string[]);
    /**
     * @stability stable
     */
    resetCustomFeatures(): void;
    /**
     * @stability stable
     */
    get customFeaturesInput(): string[] | undefined;
    private _description?;
    /**
     * @stability stable
     */
    get description(): string;
    /**
     * @stability stable
     */
    set description(value: string);
    /**
     * @stability stable
     */
    resetDescription(): void;
    /**
     * @stability stable
     */
    get descriptionInput(): string | undefined;
    /**
     * @stability stable
     */
    get enabledFeatures(): string[];
    /**
     * @stability stable
     */
    get fingerprint(): string;
    /**
     * @stability stable
     */
    get id(): string;
    private _minTlsVersion?;
    /**
     * @stability stable
     */
    get minTlsVersion(): string;
    /**
     * @stability stable
     */
    set minTlsVersion(value: string);
    /**
     * @stability stable
     */
    resetMinTlsVersion(): void;
    /**
     * @stability stable
     */
    get minTlsVersionInput(): string | undefined;
    private _name;
    /**
     * @stability stable
     */
    get name(): string;
    /**
     * @stability stable
     */
    set name(value: string);
    /**
     * @stability stable
     */
    get nameInput(): string;
    private _profile?;
    /**
     * @stability stable
     */
    get profile(): string;
    /**
     * @stability stable
     */
    set profile(value: string);
    /**
     * @stability stable
     */
    resetProfile(): void;
    /**
     * @stability stable
     */
    get profileInput(): string | undefined;
    private _project?;
    /**
     * @stability stable
     */
    get project(): string;
    /**
     * @stability stable
     */
    set project(value: string);
    /**
     * @stability stable
     */
    resetProject(): void;
    /**
     * @stability stable
     */
    get projectInput(): string | undefined;
    /**
     * @stability stable
     */
    get selfLink(): string;
    private _timeouts?;
    /**
     * @stability stable
     */
    get timeouts(): ComputeSslPolicyTimeouts;
    /**
     * @stability stable
     */
    set timeouts(value: ComputeSslPolicyTimeouts);
    /**
     * @stability stable
     */
    resetTimeouts(): void;
    /**
     * @stability stable
     */
    get timeoutsInput(): ComputeSslPolicyTimeouts | undefined;
    /**
     * @stability stable
     */
    protected synthesizeAttributes(): {
        [name: string]: any;
    };
}
