import { Construct } from 'constructs';
import * as cdktf from 'cdktf';
/**
 * @stability stable
 */
export interface ComputeTargetPoolConfig extends cdktf.TerraformMetaArguments {
    /**
     * URL to the backup target pool.
     *
     * Must also set failover_ratio.
     *
     * @stability stable
     */
    readonly backupPool?: string;
    /**
     * Textual description field.
     *
     * @stability stable
     */
    readonly description?: string;
    /**
     * Ratio (0 to 1) of failed nodes before using the backup pool (which must also be set).
     *
     * @stability stable
     */
    readonly failoverRatio?: number;
    /**
     * List of zero or one health check name or self_link.
     *
     * Only legacy google_compute_http_health_check is supported.
     *
     * @stability stable
     */
    readonly healthChecks?: string[];
    /**
     * List of instances in the pool.
     *
     * They can be given as URLs, or in the form of "zone/name". Note that the instances need not exist at the time of target pool creation, so there is no need to use the Terraform interpolators to create a dependency on the instances from the target pool.
     *
     * @stability stable
     */
    readonly instances?: string[];
    /**
     * A unique name for the resource, required by GCE.
     *
     * Changing this forces a new resource to be created.
     *
     * @stability stable
     */
    readonly name: string;
    /**
     * The ID of the project in which the resource belongs.
     *
     * If it is not provided, the provider project is used.
     *
     * @stability stable
     */
    readonly project?: string;
    /**
     * Where the target pool resides.
     *
     * Defaults to project region.
     *
     * @stability stable
     */
    readonly region?: string;
    /**
     * How to distribute load.
     *
     * Options are "NONE" (no affinity). "CLIENT_IP" (hash of the source/dest addresses / ports), and "CLIENT_IP_PROTO" also includes the protocol (default "NONE").
     *
     * @stability stable
     */
    readonly sessionAffinity?: string;
    /**
     * timeouts block.
     *
     * @stability stable
     */
    readonly timeouts?: ComputeTargetPoolTimeouts;
}
/**
 * @stability stable
 */
export interface ComputeTargetPoolTimeouts {
    /**
     * @stability stable
     */
    readonly create?: string;
    /**
     * @stability stable
     */
    readonly delete?: string;
    /**
     * @stability stable
     */
    readonly update?: string;
}
/**
 * @stability stable
 */
export declare class ComputeTargetPool extends cdktf.TerraformResource {
    /**
     * @stability stable
     */
    constructor(scope: Construct, id: string, config: ComputeTargetPoolConfig);
    private _backupPool?;
    /**
     * @stability stable
     */
    get backupPool(): string;
    /**
     * @stability stable
     */
    set backupPool(value: string);
    /**
     * @stability stable
     */
    resetBackupPool(): void;
    /**
     * @stability stable
     */
    get backupPoolInput(): string | undefined;
    private _description?;
    /**
     * @stability stable
     */
    get description(): string;
    /**
     * @stability stable
     */
    set description(value: string);
    /**
     * @stability stable
     */
    resetDescription(): void;
    /**
     * @stability stable
     */
    get descriptionInput(): string | undefined;
    private _failoverRatio?;
    /**
     * @stability stable
     */
    get failoverRatio(): number;
    /**
     * @stability stable
     */
    set failoverRatio(value: number);
    /**
     * @stability stable
     */
    resetFailoverRatio(): void;
    /**
     * @stability stable
     */
    get failoverRatioInput(): number | undefined;
    private _healthChecks?;
    /**
     * @stability stable
     */
    get healthChecks(): string[];
    /**
     * @stability stable
     */
    set healthChecks(value: string[]);
    /**
     * @stability stable
     */
    resetHealthChecks(): void;
    /**
     * @stability stable
     */
    get healthChecksInput(): string[] | undefined;
    /**
     * @stability stable
     */
    get id(): string;
    private _instances?;
    /**
     * @stability stable
     */
    get instances(): string[];
    /**
     * @stability stable
     */
    set instances(value: string[]);
    /**
     * @stability stable
     */
    resetInstances(): void;
    /**
     * @stability stable
     */
    get instancesInput(): string[] | undefined;
    private _name;
    /**
     * @stability stable
     */
    get name(): string;
    /**
     * @stability stable
     */
    set name(value: string);
    /**
     * @stability stable
     */
    get nameInput(): string;
    private _project?;
    /**
     * @stability stable
     */
    get project(): string;
    /**
     * @stability stable
     */
    set project(value: string);
    /**
     * @stability stable
     */
    resetProject(): void;
    /**
     * @stability stable
     */
    get projectInput(): string | undefined;
    private _region?;
    /**
     * @stability stable
     */
    get region(): string;
    /**
     * @stability stable
     */
    set region(value: string);
    /**
     * @stability stable
     */
    resetRegion(): void;
    /**
     * @stability stable
     */
    get regionInput(): string | undefined;
    /**
     * @stability stable
     */
    get selfLink(): string;
    private _sessionAffinity?;
    /**
     * @stability stable
     */
    get sessionAffinity(): string;
    /**
     * @stability stable
     */
    set sessionAffinity(value: string);
    /**
     * @stability stable
     */
    resetSessionAffinity(): void;
    /**
     * @stability stable
     */
    get sessionAffinityInput(): string | undefined;
    private _timeouts?;
    /**
     * @stability stable
     */
    get timeouts(): ComputeTargetPoolTimeouts;
    /**
     * @stability stable
     */
    set timeouts(value: ComputeTargetPoolTimeouts);
    /**
     * @stability stable
     */
    resetTimeouts(): void;
    /**
     * @stability stable
     */
    get timeoutsInput(): ComputeTargetPoolTimeouts | undefined;
    /**
     * @stability stable
     */
    protected synthesizeAttributes(): {
        [name: string]: any;
    };
}
