import { Construct } from 'constructs';
import * as cdktf from 'cdktf';
/**
 * @stability stable
 */
export interface ContainerClusterConfig extends cdktf.TerraformMetaArguments {
    /**
     * The IP address range of the Kubernetes pods in this cluster in CIDR notation (e.g. 10.96.0.0/14). Leave blank to have one automatically chosen or specify a /14 block in 10.0.0.0/8. This field will only work for routes-based clusters, where ip_allocation_policy is not defined.
     *
     * @stability stable
     */
    readonly clusterIpv4Cidr?: string;
    /**
     * The default maximum number of pods per node in this cluster.
     *
     * This doesn't work on "routes-based" clusters, clusters that don't have IP Aliasing enabled.
     *
     * @stability stable
     */
    readonly defaultMaxPodsPerNode?: number;
    /**
     * Description of the cluster.
     *
     * @stability stable
     */
    readonly description?: string;
    /**
     * Enable Binary Authorization for this cluster.
     *
     * If enabled, all container images will be validated by Google Binary Authorization.
     *
     * @stability stable
     */
    readonly enableBinaryAuthorization?: boolean;
    /**
     * Whether Intra-node visibility is enabled for this cluster.
     *
     * This makes same node pod to pod traffic visible for VPC network.
     *
     * @stability stable
     */
    readonly enableIntranodeVisibility?: boolean;
    /**
     * Whether to enable Kubernetes Alpha features for this cluster.
     *
     * Note that when this option is enabled, the cluster cannot be upgraded and will be automatically deleted after 30 days.
     *
     * @stability stable
     */
    readonly enableKubernetesAlpha?: boolean;
    /**
     * Whether the ABAC authorizer is enabled for this cluster.
     *
     * When enabled, identities in the system, including service accounts, nodes, and controllers, will have statically granted permissions beyond those provided by the RBAC configuration or IAM. Defaults to false.
     *
     * @stability stable
     */
    readonly enableLegacyAbac?: boolean;
    /**
     * Enable Shielded Nodes features on all nodes in this cluster.
     *
     * Defaults to false.
     *
     * @stability stable
     */
    readonly enableShieldedNodes?: boolean;
    /**
     * Whether to enable Cloud TPU resources in this cluster.
     *
     * @stability stable
     */
    readonly enableTpu?: boolean;
    /**
     * The number of nodes to create in this cluster's default node pool.
     *
     * In regional or multi-zonal clusters, this is the number of nodes per zone. Must be set if node_pool is not set. If you're using google_container_node_pool objects with no default node pool, you'll need to set this to a value of at least 1, alongside setting remove_default_node_pool to true.
     *
     * @stability stable
     */
    readonly initialNodeCount?: number;
    /**
     * The location (region or zone) in which the cluster master will be created, as well as the default node location.
     *
     * If you specify a zone (such as us-central1-a), the cluster will be a zonal cluster with a single cluster master. If you specify a region (such as us-west1), the cluster will be a regional cluster with multiple masters spread across zones in the region, and with default node locations in those zones as well.
     *
     * @stability stable
     */
    readonly location?: string;
    /**
     * The logging service that the cluster should write logs to.
     *
     * Available options include logging.googleapis.com(Legacy Stackdriver), logging.googleapis.com/kubernetes(Stackdriver Kubernetes Engine Logging), and none. Defaults to logging.googleapis.com/kubernetes.
     *
     * @stability stable
     */
    readonly loggingService?: string;
    /**
     * The minimum version of the master.
     *
     * GKE will auto-update the master to new versions, so this does not guarantee the current master version--use the read-only master_version field to obtain that. If unset, the cluster's version will be set by GKE to the version of the most recent official release (which is not necessarily the latest version).
     *
     * @stability stable
     */
    readonly minMasterVersion?: string;
    /**
     * The monitoring service that the cluster should write metrics to.
     *
     * Automatically send metrics from pods in the cluster to the Google Cloud Monitoring API. VM metrics will be collected by Google Compute Engine regardless of this setting Available options include monitoring.googleapis.com(Legacy Stackdriver), monitoring.googleapis.com/kubernetes(Stackdriver Kubernetes Engine Monitoring), and none. Defaults to monitoring.googleapis.com/kubernetes.
     *
     * @stability stable
     */
    readonly monitoringService?: string;
    /**
     * The name of the cluster, unique within the project and location.
     *
     * @stability stable
     */
    readonly name: string;
    /**
     * The name or self_link of the Google Compute Engine network to which the cluster is connected.
     *
     * For Shared VPC, set this to the self link of the shared network.
     *
     * @stability stable
     */
    readonly network?: string;
    /**
     * The list of zones in which the cluster's nodes are located.
     *
     * Nodes must be in the region of their regional cluster or in the same region as their cluster's zone for zonal clusters. If this is specified for a zonal cluster, omit the cluster's zone.
     *
     * @stability stable
     */
    readonly nodeLocations?: string[];
    /**
     * The Kubernetes version on the nodes.
     *
     * Must either be unset or set to the same value as min_master_version on create. Defaults to the default version set by GKE which is not necessarily the latest version. This only affects nodes in the default node pool. While a fuzzy version can be specified, it's recommended that you specify explicit versions as Terraform will see spurious diffs when fuzzy versions are used. See the google_container_engine_versions data source's version_prefix field to approximate fuzzy versions in a Terraform-compatible way. To update nodes in other node pools, use the version attribute on the node pool.
     *
     * @stability stable
     */
    readonly nodeVersion?: string;
    /**
     * The ID of the project in which the resource belongs.
     *
     * If it is not provided, the provider project is used.
     *
     * @stability stable
     */
    readonly project?: string;
    /**
     * If true, deletes the default node pool upon cluster creation.
     *
     * If you're using google_container_node_pool resources with no default node pool, this should be set to true, alongside setting initial_node_count to at least 1.
     *
     * @stability stable
     */
    readonly removeDefaultNodePool?: boolean;
    /**
     * The GCE resource labels (a map of key/value pairs) to be applied to the cluster.
     *
     * @stability stable
     */
    readonly resourceLabels?: {
        [key: string]: string;
    };
    /**
     * The name or self_link of the Google Compute Engine subnetwork in which the cluster's instances are launched.
     *
     * @stability stable
     */
    readonly subnetwork?: string;
    /**
     * addons_config block.
     *
     * @stability stable
     */
    readonly addonsConfig?: ContainerClusterAddonsConfig[];
    /**
     * authenticator_groups_config block.
     *
     * @stability stable
     */
    readonly authenticatorGroupsConfig?: ContainerClusterAuthenticatorGroupsConfig[];
    /**
     * cluster_autoscaling block.
     *
     * @stability stable
     */
    readonly clusterAutoscaling?: ContainerClusterClusterAutoscaling[];
    /**
     * database_encryption block.
     *
     * @stability stable
     */
    readonly databaseEncryption?: ContainerClusterDatabaseEncryption[];
    /**
     * ip_allocation_policy block.
     *
     * @stability stable
     */
    readonly ipAllocationPolicy?: ContainerClusterIpAllocationPolicy[];
    /**
     * maintenance_policy block.
     *
     * @stability stable
     */
    readonly maintenancePolicy?: ContainerClusterMaintenancePolicy[];
    /**
     * master_auth block.
     *
     * @stability stable
     */
    readonly masterAuth?: ContainerClusterMasterAuth[];
    /**
     * master_authorized_networks_config block.
     *
     * @stability stable
     */
    readonly masterAuthorizedNetworksConfig?: ContainerClusterMasterAuthorizedNetworksConfig[];
    /**
     * network_policy block.
     *
     * @stability stable
     */
    readonly networkPolicy?: ContainerClusterNetworkPolicy[];
    /**
     * node_config block.
     *
     * @stability stable
     */
    readonly nodeConfig?: ContainerClusterNodeConfig[];
    /**
     * node_pool block.
     *
     * @stability stable
     */
    readonly nodePool?: ContainerClusterNodePool[];
    /**
     * pod_security_policy_config block.
     *
     * @stability stable
     */
    readonly podSecurityPolicyConfig?: ContainerClusterPodSecurityPolicyConfig[];
    /**
     * private_cluster_config block.
     *
     * @stability stable
     */
    readonly privateClusterConfig?: ContainerClusterPrivateClusterConfig[];
    /**
     * release_channel block.
     *
     * @stability stable
     */
    readonly releaseChannel?: ContainerClusterReleaseChannel[];
    /**
     * resource_usage_export_config block.
     *
     * @stability stable
     */
    readonly resourceUsageExportConfig?: ContainerClusterResourceUsageExportConfig[];
    /**
     * timeouts block.
     *
     * @stability stable
     */
    readonly timeouts?: ContainerClusterTimeouts;
    /**
     * vertical_pod_autoscaling block.
     *
     * @stability stable
     */
    readonly verticalPodAutoscaling?: ContainerClusterVerticalPodAutoscaling[];
    /**
     * workload_identity_config block.
     *
     * @stability stable
     */
    readonly workloadIdentityConfig?: ContainerClusterWorkloadIdentityConfig[];
}
/**
 * @stability stable
 */
export interface ContainerClusterAddonsConfigCloudrunConfig {
    /**
     * @stability stable
     */
    readonly disabled: boolean;
    /**
     * @stability stable
     */
    readonly loadBalancerType?: string;
}
/**
 * @stability stable
 */
export interface ContainerClusterAddonsConfigHorizontalPodAutoscaling {
    /**
     * @stability stable
     */
    readonly disabled: boolean;
}
/**
 * @stability stable
 */
export interface ContainerClusterAddonsConfigHttpLoadBalancing {
    /**
     * @stability stable
     */
    readonly disabled: boolean;
}
/**
 * @stability stable
 */
export interface ContainerClusterAddonsConfigNetworkPolicyConfig {
    /**
     * @stability stable
     */
    readonly disabled: boolean;
}
/**
 * @stability stable
 */
export interface ContainerClusterAddonsConfig {
    /**
     * cloudrun_config block.
     *
     * @stability stable
     */
    readonly cloudrunConfig?: ContainerClusterAddonsConfigCloudrunConfig[];
    /**
     * horizontal_pod_autoscaling block.
     *
     * @stability stable
     */
    readonly horizontalPodAutoscaling?: ContainerClusterAddonsConfigHorizontalPodAutoscaling[];
    /**
     * http_load_balancing block.
     *
     * @stability stable
     */
    readonly httpLoadBalancing?: ContainerClusterAddonsConfigHttpLoadBalancing[];
    /**
     * network_policy_config block.
     *
     * @stability stable
     */
    readonly networkPolicyConfig?: ContainerClusterAddonsConfigNetworkPolicyConfig[];
}
/**
 * @stability stable
 */
export interface ContainerClusterAuthenticatorGroupsConfig {
    /**
     * The name of the RBAC security group for use with Google security groups in Kubernetes RBAC.
     *
     * Group name must be in format gke-security-groups@yourdomain.com.
     *
     * @stability stable
     */
    readonly securityGroup: string;
}
/**
 * @stability stable
 */
export interface ContainerClusterClusterAutoscalingAutoProvisioningDefaults {
    /**
     * Scopes that are used by NAP when creating node pools.
     *
     * @stability stable
     */
    readonly oauthScopes?: string[];
    /**
     * The Google Cloud Platform Service Account to be used by the node VMs.
     *
     * @stability stable
     */
    readonly serviceAccount?: string;
}
/**
 * @stability stable
 */
export interface ContainerClusterClusterAutoscalingResourceLimits {
    /**
     * Maximum amount of the resource in the cluster.
     *
     * @stability stable
     */
    readonly maximum?: number;
    /**
     * Minimum amount of the resource in the cluster.
     *
     * @stability stable
     */
    readonly minimum?: number;
    /**
     * The type of the resource.
     *
     * For example, cpu and memory. See the guide to using Node Auto-Provisioning for a list of types.
     *
     * @stability stable
     */
    readonly resourceType: string;
}
/**
 * @stability stable
 */
export interface ContainerClusterClusterAutoscaling {
    /**
     * Whether node auto-provisioning is enabled.
     *
     * Resource limits for cpu and memory must be defined to enable node auto-provisioning.
     *
     * @stability stable
     */
    readonly enabled: boolean;
    /**
     * auto_provisioning_defaults block.
     *
     * @stability stable
     */
    readonly autoProvisioningDefaults?: ContainerClusterClusterAutoscalingAutoProvisioningDefaults[];
    /**
     * resource_limits block.
     *
     * @stability stable
     */
    readonly resourceLimits?: ContainerClusterClusterAutoscalingResourceLimits[];
}
/**
 * @stability stable
 */
export interface ContainerClusterDatabaseEncryption {
    /**
     * The key to use to encrypt/decrypt secrets.
     *
     * @stability stable
     */
    readonly keyName?: string;
    /**
     * ENCRYPTED or DECRYPTED.
     *
     * @stability stable
     */
    readonly state: string;
}
/**
 * @stability stable
 */
export interface ContainerClusterIpAllocationPolicy {
    /**
     * The IP address range for the cluster pod IPs.
     *
     * Set to blank to have a range chosen with the default size. Set to /netmask (e.g. /14) to have a range chosen with a specific netmask. Set to a CIDR notation (e.g. 10.96.0.0/14) from the RFC-1918 private networks (e.g. 10.0.0.0/8, 172.16.0.0/12, 192.168.0.0/16) to pick a specific range to use.
     *
     * @stability stable
     */
    readonly clusterIpv4CidrBlock?: string;
    /**
     * The name of the existing secondary range in the cluster's subnetwork to use for pod IP addresses.
     *
     * Alternatively, cluster_ipv4_cidr_block can be used to automatically create a GKE-managed one.
     *
     * @stability stable
     */
    readonly clusterSecondaryRangeName?: string;
    /**
     * The IP address range of the services IPs in this cluster.
     *
     * Set to blank to have a range chosen with the default size. Set to /netmask (e.g. /14) to have a range chosen with a specific netmask. Set to a CIDR notation (e.g. 10.96.0.0/14) from the RFC-1918 private networks (e.g. 10.0.0.0/8, 172.16.0.0/12, 192.168.0.0/16) to pick a specific range to use.
     *
     * @stability stable
     */
    readonly servicesIpv4CidrBlock?: string;
    /**
     * The name of the existing secondary range in the cluster's subnetwork to use for service ClusterIPs.
     *
     * Alternatively, services_ipv4_cidr_block can be used to automatically create a GKE-managed one.
     *
     * @stability stable
     */
    readonly servicesSecondaryRangeName?: string;
}
/**
 * @stability stable
 */
export interface ContainerClusterMaintenancePolicyDailyMaintenanceWindow {
    /**
     * @stability stable
     */
    readonly startTime: string;
}
/**
 * @stability stable
 */
export interface ContainerClusterMaintenancePolicyMaintenanceExclusion {
    /**
     * @stability stable
     */
    readonly endTime: string;
    /**
     * @stability stable
     */
    readonly exclusionName: string;
    /**
     * @stability stable
     */
    readonly startTime: string;
}
/**
 * @stability stable
 */
export interface ContainerClusterMaintenancePolicyRecurringWindow {
    /**
     * @stability stable
     */
    readonly endTime: string;
    /**
     * @stability stable
     */
    readonly recurrence: string;
    /**
     * @stability stable
     */
    readonly startTime: string;
}
/**
 * @stability stable
 */
export interface ContainerClusterMaintenancePolicy {
    /**
     * daily_maintenance_window block.
     *
     * @stability stable
     */
    readonly dailyMaintenanceWindow?: ContainerClusterMaintenancePolicyDailyMaintenanceWindow[];
    /**
     * maintenance_exclusion block.
     *
     * @stability stable
     */
    readonly maintenanceExclusion?: ContainerClusterMaintenancePolicyMaintenanceExclusion[];
    /**
     * recurring_window block.
     *
     * @stability stable
     */
    readonly recurringWindow?: ContainerClusterMaintenancePolicyRecurringWindow[];
}
/**
 * @stability stable
 */
export interface ContainerClusterMasterAuthClientCertificateConfig {
    /**
     * Whether client certificate authorization is enabled for this cluster.
     *
     * @stability stable
     */
    readonly issueClientCertificate: boolean;
}
/**
 * @stability stable
 */
export interface ContainerClusterMasterAuth {
    /**
     * The password to use for HTTP basic authentication when accessing the Kubernetes master endpoint.
     *
     * @stability stable
     */
    readonly password?: string;
    /**
     * The username to use for HTTP basic authentication when accessing the Kubernetes master endpoint.
     *
     * If not present basic auth will be disabled.
     *
     * @stability stable
     */
    readonly username?: string;
    /**
     * client_certificate_config block.
     *
     * @stability stable
     */
    readonly clientCertificateConfig?: ContainerClusterMasterAuthClientCertificateConfig[];
}
/**
 * @stability stable
 */
export interface ContainerClusterMasterAuthorizedNetworksConfigCidrBlocks {
    /**
     * External network that can access Kubernetes master through HTTPS.
     *
     * Must be specified in CIDR notation.
     *
     * @stability stable
     */
    readonly cidrBlock: string;
    /**
     * Field for users to identify CIDR blocks.
     *
     * @stability stable
     */
    readonly displayName?: string;
}
/**
 * @stability stable
 */
export interface ContainerClusterMasterAuthorizedNetworksConfig {
    /**
     * cidr_blocks block.
     *
     * @stability stable
     */
    readonly cidrBlocks?: ContainerClusterMasterAuthorizedNetworksConfigCidrBlocks[];
}
/**
 * @stability stable
 */
export interface ContainerClusterNetworkPolicy {
    /**
     * Whether network policy is enabled on the cluster.
     *
     * @stability stable
     */
    readonly enabled: boolean;
    /**
     * The selected network policy provider.
     *
     * Defaults to PROVIDER_UNSPECIFIED.
     *
     * @stability stable
     */
    readonly provider?: string;
}
/**
 * @stability stable
 */
export interface ContainerClusterNodeConfigGuestAccelerator {
    /**
     * @stability stable
     */
    readonly count?: number;
    /**
     * @stability stable
     */
    readonly type?: string;
}
/**
 * @stability stable
 */
export interface ContainerClusterNodeConfigTaint {
    /**
     * @stability stable
     */
    readonly effect?: string;
    /**
     * @stability stable
     */
    readonly key?: string;
    /**
     * @stability stable
     */
    readonly value?: string;
}
/**
 * @stability stable
 */
export interface ContainerClusterNodeConfigShieldedInstanceConfig {
    /**
     * @stability stable
     */
    readonly enableIntegrityMonitoring?: boolean;
    /**
     * @stability stable
     */
    readonly enableSecureBoot?: boolean;
}
/**
 * @stability stable
 */
export interface ContainerClusterNodeConfigWorkloadMetadataConfig {
    /**
     * @stability stable
     */
    readonly nodeMetadata: string;
}
/**
 * @stability stable
 */
export interface ContainerClusterNodeConfig {
    /**
     * @stability stable
     */
    readonly diskSizeGb?: number;
    /**
     * @stability stable
     */
    readonly diskType?: string;
    /**
     * @stability stable
     */
    readonly guestAccelerator?: ContainerClusterNodeConfigGuestAccelerator[];
    /**
     * @stability stable
     */
    readonly imageType?: string;
    /**
     * @stability stable
     */
    readonly labels?: {
        [key: string]: string;
    };
    /**
     * @stability stable
     */
    readonly localSsdCount?: number;
    /**
     * @stability stable
     */
    readonly machineType?: string;
    /**
     * @stability stable
     */
    readonly metadata?: {
        [key: string]: string;
    };
    /**
     * @stability stable
     */
    readonly minCpuPlatform?: string;
    /**
     * @stability stable
     */
    readonly oauthScopes?: string[];
    /**
     * @stability stable
     */
    readonly preemptible?: boolean;
    /**
     * @stability stable
     */
    readonly serviceAccount?: string;
    /**
     * @stability stable
     */
    readonly tags?: string[];
    /**
     * @stability stable
     */
    readonly taint?: ContainerClusterNodeConfigTaint[];
    /**
     * shielded_instance_config block.
     *
     * @stability stable
     */
    readonly shieldedInstanceConfig?: ContainerClusterNodeConfigShieldedInstanceConfig[];
    /**
     * workload_metadata_config block.
     *
     * @stability stable
     */
    readonly workloadMetadataConfig?: ContainerClusterNodeConfigWorkloadMetadataConfig[];
}
/**
 * @stability stable
 */
export interface ContainerClusterNodePoolAutoscaling {
    /**
     * Maximum number of nodes in the NodePool.
     *
     * Must be >= min_node_count.
     *
     * @stability stable
     */
    readonly maxNodeCount: number;
    /**
     * Minimum number of nodes in the NodePool.
     *
     * Must be >=0 and <= max_node_count.
     *
     * @stability stable
     */
    readonly minNodeCount: number;
}
/**
 * @stability stable
 */
export interface ContainerClusterNodePoolManagement {
    /**
     * Whether the nodes will be automatically repaired.
     *
     * @stability stable
     */
    readonly autoRepair?: boolean;
    /**
     * Whether the nodes will be automatically upgraded.
     *
     * @stability stable
     */
    readonly autoUpgrade?: boolean;
}
/**
 * @stability stable
 */
export interface ContainerClusterNodePoolNodeConfigGuestAccelerator {
    /**
     * @stability stable
     */
    readonly count?: number;
    /**
     * @stability stable
     */
    readonly type?: string;
}
/**
 * @stability stable
 */
export interface ContainerClusterNodePoolNodeConfigTaint {
    /**
     * @stability stable
     */
    readonly effect?: string;
    /**
     * @stability stable
     */
    readonly key?: string;
    /**
     * @stability stable
     */
    readonly value?: string;
}
/**
 * @stability stable
 */
export interface ContainerClusterNodePoolNodeConfigShieldedInstanceConfig {
    /**
     * @stability stable
     */
    readonly enableIntegrityMonitoring?: boolean;
    /**
     * @stability stable
     */
    readonly enableSecureBoot?: boolean;
}
/**
 * @stability stable
 */
export interface ContainerClusterNodePoolNodeConfigWorkloadMetadataConfig {
    /**
     * @stability stable
     */
    readonly nodeMetadata: string;
}
/**
 * @stability stable
 */
export interface ContainerClusterNodePoolNodeConfig {
    /**
     * @stability stable
     */
    readonly diskSizeGb?: number;
    /**
     * @stability stable
     */
    readonly diskType?: string;
    /**
     * @stability stable
     */
    readonly guestAccelerator?: ContainerClusterNodePoolNodeConfigGuestAccelerator[];
    /**
     * @stability stable
     */
    readonly imageType?: string;
    /**
     * @stability stable
     */
    readonly labels?: {
        [key: string]: string;
    };
    /**
     * @stability stable
     */
    readonly localSsdCount?: number;
    /**
     * @stability stable
     */
    readonly machineType?: string;
    /**
     * @stability stable
     */
    readonly metadata?: {
        [key: string]: string;
    };
    /**
     * @stability stable
     */
    readonly minCpuPlatform?: string;
    /**
     * @stability stable
     */
    readonly oauthScopes?: string[];
    /**
     * @stability stable
     */
    readonly preemptible?: boolean;
    /**
     * @stability stable
     */
    readonly serviceAccount?: string;
    /**
     * @stability stable
     */
    readonly tags?: string[];
    /**
     * @stability stable
     */
    readonly taint?: ContainerClusterNodePoolNodeConfigTaint[];
    /**
     * shielded_instance_config block.
     *
     * @stability stable
     */
    readonly shieldedInstanceConfig?: ContainerClusterNodePoolNodeConfigShieldedInstanceConfig[];
    /**
     * workload_metadata_config block.
     *
     * @stability stable
     */
    readonly workloadMetadataConfig?: ContainerClusterNodePoolNodeConfigWorkloadMetadataConfig[];
}
/**
 * @stability stable
 */
export interface ContainerClusterNodePoolUpgradeSettings {
    /**
     * The number of additional nodes that can be added to the node pool during an upgrade.
     *
     * Increasing max_surge raises the number of nodes that can be upgraded simultaneously. Can be set to 0 or greater.
     *
     * @stability stable
     */
    readonly maxSurge: number;
    /**
     * The number of nodes that can be simultaneously unavailable during an upgrade.
     *
     * Increasing max_unavailable raises the number of nodes that can be upgraded in parallel. Can be set to 0 or greater.
     *
     * @stability stable
     */
    readonly maxUnavailable: number;
}
/**
 * @stability stable
 */
export interface ContainerClusterNodePool {
    /**
     * The initial number of nodes for the pool.
     *
     * In regional or multi-zonal clusters, this is the number of nodes per zone. Changing this will force recreation of the resource.
     *
     * @stability stable
     */
    readonly initialNodeCount?: number;
    /**
     * The maximum number of pods per node in this node pool.
     *
     * Note that this does not work on node pools which are "route-based" - that is, node pools belonging to clusters that do not have IP Aliasing enabled.
     *
     * @stability stable
     */
    readonly maxPodsPerNode?: number;
    /**
     * The name of the node pool.
     *
     * If left blank, Terraform will auto-generate a unique name.
     *
     * @stability stable
     */
    readonly name?: string;
    /**
     * Creates a unique name for the node pool beginning with the specified prefix.
     *
     * Conflicts with name.
     *
     * @stability stable
     */
    readonly namePrefix?: string;
    /**
     * The number of nodes per instance group.
     *
     * This field can be used to update the number of nodes per instance group but should not be used alongside autoscaling.
     *
     * @stability stable
     */
    readonly nodeCount?: number;
    /**
     * The list of zones in which the node pool's nodes should be located.
     *
     * Nodes must be in the region of their regional cluster or in the same region as their cluster's zone for zonal clusters. If unspecified, the cluster-level node_locations will be used.
     *
     * @stability stable
     */
    readonly nodeLocations?: string[];
    /**
     * The Kubernetes version for the nodes in this pool.
     *
     * Note that if this field and auto_upgrade are both specified, they will fight each other for what the node version should be, so setting both is highly discouraged. While a fuzzy version can be specified, it's recommended that you specify explicit versions as Terraform will see spurious diffs when fuzzy versions are used. See the google_container_engine_versions data source's version_prefix field to approximate fuzzy versions in a Terraform-compatible way.
     *
     * @stability stable
     */
    readonly version?: string;
    /**
     * autoscaling block.
     *
     * @stability stable
     */
    readonly autoscaling?: ContainerClusterNodePoolAutoscaling[];
    /**
     * management block.
     *
     * @stability stable
     */
    readonly management?: ContainerClusterNodePoolManagement[];
    /**
     * node_config block.
     *
     * @stability stable
     */
    readonly nodeConfig?: ContainerClusterNodePoolNodeConfig[];
    /**
     * upgrade_settings block.
     *
     * @stability stable
     */
    readonly upgradeSettings?: ContainerClusterNodePoolUpgradeSettings[];
}
/**
 * @stability stable
 */
export interface ContainerClusterPodSecurityPolicyConfig {
    /**
     * Enable the PodSecurityPolicy controller for this cluster.
     *
     * If enabled, pods must be valid under a PodSecurityPolicy to be created.
     *
     * @stability stable
     */
    readonly enabled: boolean;
}
/**
 * @stability stable
 */
export interface ContainerClusterPrivateClusterConfig {
    /**
     * Enables the private cluster feature, creating a private endpoint on the cluster.
     *
     * In a private cluster, nodes only have RFC 1918 private addresses and communicate with the master's private endpoint via private networking.
     *
     * @stability stable
     */
    readonly enablePrivateEndpoint: boolean;
    /**
     * When true, the cluster's private endpoint is used as the cluster endpoint and access through the public endpoint is disabled.
     *
     * When false, either endpoint can be used. This field only applies to private clusters, when enable_private_nodes is true.
     *
     * @stability stable
     */
    readonly enablePrivateNodes?: boolean;
    /**
     * The IP range in CIDR notation to use for the hosted master network.
     *
     * This range will be used for assigning private IP addresses to the cluster master(s) and the ILB VIP. This range must not overlap with any other ranges in use within the cluster's network, and it must be a /28 subnet. See Private Cluster Limitations for more details. This field only applies to private clusters, when enable_private_nodes is true.
     *
     * @stability stable
     */
    readonly masterIpv4CidrBlock?: string;
}
/**
 * @stability stable
 */
export interface ContainerClusterReleaseChannel {
    /**
     * The selected release channel.
     *
     * Accepted values are:
     * UNSPECIFIED: Not set.
     * RAPID: Weekly upgrade cadence; Early testers and developers who requires new features.
     * REGULAR: Multiple per month upgrade cadence; Production users who need features not yet offered in the Stable channel.
     * STABLE: Every few months upgrade cadence; Production users who need stability above all else, and for whom frequent upgrades are too risky.
     *
     * @stability stable
     */
    readonly channel: string;
}
/**
 * @stability stable
 */
export interface ContainerClusterResourceUsageExportConfigBigqueryDestination {
    /**
     * The ID of a BigQuery Dataset.
     *
     * @stability stable
     */
    readonly datasetId: string;
}
/**
 * @stability stable
 */
export interface ContainerClusterResourceUsageExportConfig {
    /**
     * Whether to enable network egress metering for this cluster.
     *
     * If enabled, a daemonset will be created in the cluster to meter network egress traffic.
     *
     * @stability stable
     */
    readonly enableNetworkEgressMetering?: boolean;
    /**
     * Whether to enable resource consumption metering on this cluster.
     *
     * When enabled, a table will be created in the resource export BigQuery dataset to store resource consumption data. The resulting table can be joined with the resource usage table or with BigQuery billing export. Defaults to true.
     *
     * @stability stable
     */
    readonly enableResourceConsumptionMetering?: boolean;
    /**
     * bigquery_destination block.
     *
     * @stability stable
     */
    readonly bigqueryDestination: ContainerClusterResourceUsageExportConfigBigqueryDestination[];
}
/**
 * @stability stable
 */
export interface ContainerClusterTimeouts {
    /**
     * @stability stable
     */
    readonly create?: string;
    /**
     * @stability stable
     */
    readonly delete?: string;
    /**
     * @stability stable
     */
    readonly read?: string;
    /**
     * @stability stable
     */
    readonly update?: string;
}
/**
 * @stability stable
 */
export interface ContainerClusterVerticalPodAutoscaling {
    /**
     * Enables vertical pod autoscaling.
     *
     * @stability stable
     */
    readonly enabled: boolean;
}
/**
 * @stability stable
 */
export interface ContainerClusterWorkloadIdentityConfig {
    /**
     * @stability stable
     */
    readonly identityNamespace: string;
}
/**
 * @stability stable
 */
export declare class ContainerCluster extends cdktf.TerraformResource {
    /**
     * @stability stable
     */
    constructor(scope: Construct, id: string, config: ContainerClusterConfig);
    private _clusterIpv4Cidr?;
    /**
     * @stability stable
     */
    get clusterIpv4Cidr(): string;
    /**
     * @stability stable
     */
    set clusterIpv4Cidr(value: string);
    /**
     * @stability stable
     */
    resetClusterIpv4Cidr(): void;
    /**
     * @stability stable
     */
    get clusterIpv4CidrInput(): string | undefined;
    private _defaultMaxPodsPerNode?;
    /**
     * @stability stable
     */
    get defaultMaxPodsPerNode(): number;
    /**
     * @stability stable
     */
    set defaultMaxPodsPerNode(value: number);
    /**
     * @stability stable
     */
    resetDefaultMaxPodsPerNode(): void;
    /**
     * @stability stable
     */
    get defaultMaxPodsPerNodeInput(): number | undefined;
    private _description?;
    /**
     * @stability stable
     */
    get description(): string;
    /**
     * @stability stable
     */
    set description(value: string);
    /**
     * @stability stable
     */
    resetDescription(): void;
    /**
     * @stability stable
     */
    get descriptionInput(): string | undefined;
    private _enableBinaryAuthorization?;
    /**
     * @stability stable
     */
    get enableBinaryAuthorization(): boolean;
    /**
     * @stability stable
     */
    set enableBinaryAuthorization(value: boolean);
    /**
     * @stability stable
     */
    resetEnableBinaryAuthorization(): void;
    /**
     * @stability stable
     */
    get enableBinaryAuthorizationInput(): boolean | undefined;
    private _enableIntranodeVisibility?;
    /**
     * @stability stable
     */
    get enableIntranodeVisibility(): boolean;
    /**
     * @stability stable
     */
    set enableIntranodeVisibility(value: boolean);
    /**
     * @stability stable
     */
    resetEnableIntranodeVisibility(): void;
    /**
     * @stability stable
     */
    get enableIntranodeVisibilityInput(): boolean | undefined;
    private _enableKubernetesAlpha?;
    /**
     * @stability stable
     */
    get enableKubernetesAlpha(): boolean;
    /**
     * @stability stable
     */
    set enableKubernetesAlpha(value: boolean);
    /**
     * @stability stable
     */
    resetEnableKubernetesAlpha(): void;
    /**
     * @stability stable
     */
    get enableKubernetesAlphaInput(): boolean | undefined;
    private _enableLegacyAbac?;
    /**
     * @stability stable
     */
    get enableLegacyAbac(): boolean;
    /**
     * @stability stable
     */
    set enableLegacyAbac(value: boolean);
    /**
     * @stability stable
     */
    resetEnableLegacyAbac(): void;
    /**
     * @stability stable
     */
    get enableLegacyAbacInput(): boolean | undefined;
    private _enableShieldedNodes?;
    /**
     * @stability stable
     */
    get enableShieldedNodes(): boolean;
    /**
     * @stability stable
     */
    set enableShieldedNodes(value: boolean);
    /**
     * @stability stable
     */
    resetEnableShieldedNodes(): void;
    /**
     * @stability stable
     */
    get enableShieldedNodesInput(): boolean | undefined;
    private _enableTpu?;
    /**
     * @stability stable
     */
    get enableTpu(): boolean;
    /**
     * @stability stable
     */
    set enableTpu(value: boolean);
    /**
     * @stability stable
     */
    resetEnableTpu(): void;
    /**
     * @stability stable
     */
    get enableTpuInput(): boolean | undefined;
    /**
     * @stability stable
     */
    get endpoint(): string;
    /**
     * @stability stable
     */
    get id(): string;
    private _initialNodeCount?;
    /**
     * @stability stable
     */
    get initialNodeCount(): number;
    /**
     * @stability stable
     */
    set initialNodeCount(value: number);
    /**
     * @stability stable
     */
    resetInitialNodeCount(): void;
    /**
     * @stability stable
     */
    get initialNodeCountInput(): number | undefined;
    /**
     * @stability stable
     */
    get instanceGroupUrls(): string[];
    /**
     * @stability stable
     */
    get labelFingerprint(): string;
    private _location?;
    /**
     * @stability stable
     */
    get location(): string;
    /**
     * @stability stable
     */
    set location(value: string);
    /**
     * @stability stable
     */
    resetLocation(): void;
    /**
     * @stability stable
     */
    get locationInput(): string | undefined;
    private _loggingService?;
    /**
     * @stability stable
     */
    get loggingService(): string;
    /**
     * @stability stable
     */
    set loggingService(value: string);
    /**
     * @stability stable
     */
    resetLoggingService(): void;
    /**
     * @stability stable
     */
    get loggingServiceInput(): string | undefined;
    /**
     * @stability stable
     */
    get masterVersion(): string;
    private _minMasterVersion?;
    /**
     * @stability stable
     */
    get minMasterVersion(): string;
    /**
     * @stability stable
     */
    set minMasterVersion(value: string);
    /**
     * @stability stable
     */
    resetMinMasterVersion(): void;
    /**
     * @stability stable
     */
    get minMasterVersionInput(): string | undefined;
    private _monitoringService?;
    /**
     * @stability stable
     */
    get monitoringService(): string;
    /**
     * @stability stable
     */
    set monitoringService(value: string);
    /**
     * @stability stable
     */
    resetMonitoringService(): void;
    /**
     * @stability stable
     */
    get monitoringServiceInput(): string | undefined;
    private _name;
    /**
     * @stability stable
     */
    get name(): string;
    /**
     * @stability stable
     */
    set name(value: string);
    /**
     * @stability stable
     */
    get nameInput(): string;
    private _network?;
    /**
     * @stability stable
     */
    get network(): string;
    /**
     * @stability stable
     */
    set network(value: string);
    /**
     * @stability stable
     */
    resetNetwork(): void;
    /**
     * @stability stable
     */
    get networkInput(): string | undefined;
    private _nodeLocations?;
    /**
     * @stability stable
     */
    get nodeLocations(): string[];
    /**
     * @stability stable
     */
    set nodeLocations(value: string[]);
    /**
     * @stability stable
     */
    resetNodeLocations(): void;
    /**
     * @stability stable
     */
    get nodeLocationsInput(): string[] | undefined;
    private _nodeVersion?;
    /**
     * @stability stable
     */
    get nodeVersion(): string;
    /**
     * @stability stable
     */
    set nodeVersion(value: string);
    /**
     * @stability stable
     */
    resetNodeVersion(): void;
    /**
     * @stability stable
     */
    get nodeVersionInput(): string | undefined;
    /**
     * @stability stable
     */
    get operation(): string;
    private _project?;
    /**
     * @stability stable
     */
    get project(): string;
    /**
     * @stability stable
     */
    set project(value: string);
    /**
     * @stability stable
     */
    resetProject(): void;
    /**
     * @stability stable
     */
    get projectInput(): string | undefined;
    private _removeDefaultNodePool?;
    /**
     * @stability stable
     */
    get removeDefaultNodePool(): boolean;
    /**
     * @stability stable
     */
    set removeDefaultNodePool(value: boolean);
    /**
     * @stability stable
     */
    resetRemoveDefaultNodePool(): void;
    /**
     * @stability stable
     */
    get removeDefaultNodePoolInput(): boolean | undefined;
    private _resourceLabels?;
    /**
     * @stability stable
     */
    get resourceLabels(): {
        [key: string]: string;
    };
    /**
     * @stability stable
     */
    set resourceLabels(value: {
        [key: string]: string;
    });
    /**
     * @stability stable
     */
    resetResourceLabels(): void;
    /**
     * @stability stable
     */
    get resourceLabelsInput(): {
        [key: string]: string;
    } | undefined;
    /**
     * @stability stable
     */
    get selfLink(): string;
    /**
     * @stability stable
     */
    get servicesIpv4Cidr(): string;
    private _subnetwork?;
    /**
     * @stability stable
     */
    get subnetwork(): string;
    /**
     * @stability stable
     */
    set subnetwork(value: string);
    /**
     * @stability stable
     */
    resetSubnetwork(): void;
    /**
     * @stability stable
     */
    get subnetworkInput(): string | undefined;
    private _addonsConfig?;
    /**
     * @stability stable
     */
    get addonsConfig(): ContainerClusterAddonsConfig[];
    /**
     * @stability stable
     */
    set addonsConfig(value: ContainerClusterAddonsConfig[]);
    /**
     * @stability stable
     */
    resetAddonsConfig(): void;
    /**
     * @stability stable
     */
    get addonsConfigInput(): ContainerClusterAddonsConfig[] | undefined;
    private _authenticatorGroupsConfig?;
    /**
     * @stability stable
     */
    get authenticatorGroupsConfig(): ContainerClusterAuthenticatorGroupsConfig[];
    /**
     * @stability stable
     */
    set authenticatorGroupsConfig(value: ContainerClusterAuthenticatorGroupsConfig[]);
    /**
     * @stability stable
     */
    resetAuthenticatorGroupsConfig(): void;
    /**
     * @stability stable
     */
    get authenticatorGroupsConfigInput(): ContainerClusterAuthenticatorGroupsConfig[] | undefined;
    private _clusterAutoscaling?;
    /**
     * @stability stable
     */
    get clusterAutoscaling(): ContainerClusterClusterAutoscaling[];
    /**
     * @stability stable
     */
    set clusterAutoscaling(value: ContainerClusterClusterAutoscaling[]);
    /**
     * @stability stable
     */
    resetClusterAutoscaling(): void;
    /**
     * @stability stable
     */
    get clusterAutoscalingInput(): ContainerClusterClusterAutoscaling[] | undefined;
    private _databaseEncryption?;
    /**
     * @stability stable
     */
    get databaseEncryption(): ContainerClusterDatabaseEncryption[];
    /**
     * @stability stable
     */
    set databaseEncryption(value: ContainerClusterDatabaseEncryption[]);
    /**
     * @stability stable
     */
    resetDatabaseEncryption(): void;
    /**
     * @stability stable
     */
    get databaseEncryptionInput(): ContainerClusterDatabaseEncryption[] | undefined;
    private _ipAllocationPolicy?;
    /**
     * @stability stable
     */
    get ipAllocationPolicy(): ContainerClusterIpAllocationPolicy[];
    /**
     * @stability stable
     */
    set ipAllocationPolicy(value: ContainerClusterIpAllocationPolicy[]);
    /**
     * @stability stable
     */
    resetIpAllocationPolicy(): void;
    /**
     * @stability stable
     */
    get ipAllocationPolicyInput(): ContainerClusterIpAllocationPolicy[] | undefined;
    private _maintenancePolicy?;
    /**
     * @stability stable
     */
    get maintenancePolicy(): ContainerClusterMaintenancePolicy[];
    /**
     * @stability stable
     */
    set maintenancePolicy(value: ContainerClusterMaintenancePolicy[]);
    /**
     * @stability stable
     */
    resetMaintenancePolicy(): void;
    /**
     * @stability stable
     */
    get maintenancePolicyInput(): ContainerClusterMaintenancePolicy[] | undefined;
    private _masterAuth?;
    /**
     * @stability stable
     */
    get masterAuth(): ContainerClusterMasterAuth[];
    /**
     * @stability stable
     */
    set masterAuth(value: ContainerClusterMasterAuth[]);
    /**
     * @stability stable
     */
    resetMasterAuth(): void;
    /**
     * @stability stable
     */
    get masterAuthInput(): ContainerClusterMasterAuth[] | undefined;
    private _masterAuthorizedNetworksConfig?;
    /**
     * @stability stable
     */
    get masterAuthorizedNetworksConfig(): ContainerClusterMasterAuthorizedNetworksConfig[];
    /**
     * @stability stable
     */
    set masterAuthorizedNetworksConfig(value: ContainerClusterMasterAuthorizedNetworksConfig[]);
    /**
     * @stability stable
     */
    resetMasterAuthorizedNetworksConfig(): void;
    /**
     * @stability stable
     */
    get masterAuthorizedNetworksConfigInput(): ContainerClusterMasterAuthorizedNetworksConfig[] | undefined;
    private _networkPolicy?;
    /**
     * @stability stable
     */
    get networkPolicy(): ContainerClusterNetworkPolicy[];
    /**
     * @stability stable
     */
    set networkPolicy(value: ContainerClusterNetworkPolicy[]);
    /**
     * @stability stable
     */
    resetNetworkPolicy(): void;
    /**
     * @stability stable
     */
    get networkPolicyInput(): ContainerClusterNetworkPolicy[] | undefined;
    private _nodeConfig?;
    /**
     * @stability stable
     */
    get nodeConfig(): ContainerClusterNodeConfig[];
    /**
     * @stability stable
     */
    set nodeConfig(value: ContainerClusterNodeConfig[]);
    /**
     * @stability stable
     */
    resetNodeConfig(): void;
    /**
     * @stability stable
     */
    get nodeConfigInput(): ContainerClusterNodeConfig[] | undefined;
    private _nodePool?;
    /**
     * @stability stable
     */
    get nodePool(): ContainerClusterNodePool[];
    /**
     * @stability stable
     */
    set nodePool(value: ContainerClusterNodePool[]);
    /**
     * @stability stable
     */
    resetNodePool(): void;
    /**
     * @stability stable
     */
    get nodePoolInput(): ContainerClusterNodePool[] | undefined;
    private _podSecurityPolicyConfig?;
    /**
     * @stability stable
     */
    get podSecurityPolicyConfig(): ContainerClusterPodSecurityPolicyConfig[];
    /**
     * @stability stable
     */
    set podSecurityPolicyConfig(value: ContainerClusterPodSecurityPolicyConfig[]);
    /**
     * @stability stable
     */
    resetPodSecurityPolicyConfig(): void;
    /**
     * @stability stable
     */
    get podSecurityPolicyConfigInput(): ContainerClusterPodSecurityPolicyConfig[] | undefined;
    private _privateClusterConfig?;
    /**
     * @stability stable
     */
    get privateClusterConfig(): ContainerClusterPrivateClusterConfig[];
    /**
     * @stability stable
     */
    set privateClusterConfig(value: ContainerClusterPrivateClusterConfig[]);
    /**
     * @stability stable
     */
    resetPrivateClusterConfig(): void;
    /**
     * @stability stable
     */
    get privateClusterConfigInput(): ContainerClusterPrivateClusterConfig[] | undefined;
    private _releaseChannel?;
    /**
     * @stability stable
     */
    get releaseChannel(): ContainerClusterReleaseChannel[];
    /**
     * @stability stable
     */
    set releaseChannel(value: ContainerClusterReleaseChannel[]);
    /**
     * @stability stable
     */
    resetReleaseChannel(): void;
    /**
     * @stability stable
     */
    get releaseChannelInput(): ContainerClusterReleaseChannel[] | undefined;
    private _resourceUsageExportConfig?;
    /**
     * @stability stable
     */
    get resourceUsageExportConfig(): ContainerClusterResourceUsageExportConfig[];
    /**
     * @stability stable
     */
    set resourceUsageExportConfig(value: ContainerClusterResourceUsageExportConfig[]);
    /**
     * @stability stable
     */
    resetResourceUsageExportConfig(): void;
    /**
     * @stability stable
     */
    get resourceUsageExportConfigInput(): ContainerClusterResourceUsageExportConfig[] | undefined;
    private _timeouts?;
    /**
     * @stability stable
     */
    get timeouts(): ContainerClusterTimeouts;
    /**
     * @stability stable
     */
    set timeouts(value: ContainerClusterTimeouts);
    /**
     * @stability stable
     */
    resetTimeouts(): void;
    /**
     * @stability stable
     */
    get timeoutsInput(): ContainerClusterTimeouts | undefined;
    private _verticalPodAutoscaling?;
    /**
     * @stability stable
     */
    get verticalPodAutoscaling(): ContainerClusterVerticalPodAutoscaling[];
    /**
     * @stability stable
     */
    set verticalPodAutoscaling(value: ContainerClusterVerticalPodAutoscaling[]);
    /**
     * @stability stable
     */
    resetVerticalPodAutoscaling(): void;
    /**
     * @stability stable
     */
    get verticalPodAutoscalingInput(): ContainerClusterVerticalPodAutoscaling[] | undefined;
    private _workloadIdentityConfig?;
    /**
     * @stability stable
     */
    get workloadIdentityConfig(): ContainerClusterWorkloadIdentityConfig[];
    /**
     * @stability stable
     */
    set workloadIdentityConfig(value: ContainerClusterWorkloadIdentityConfig[]);
    /**
     * @stability stable
     */
    resetWorkloadIdentityConfig(): void;
    /**
     * @stability stable
     */
    get workloadIdentityConfigInput(): ContainerClusterWorkloadIdentityConfig[] | undefined;
    /**
     * @stability stable
     */
    protected synthesizeAttributes(): {
        [name: string]: any;
    };
}
