import { Construct } from 'constructs';
import * as cdktf from 'cdktf';
/**
 * @stability stable
 */
export interface ContainerNodePoolConfig extends cdktf.TerraformMetaArguments {
    /**
     * The cluster to create the node pool for.
     *
     * Cluster must be present in location provided for zonal clusters.
     *
     * @stability stable
     */
    readonly cluster: string;
    /**
     * The initial number of nodes for the pool.
     *
     * In regional or multi-zonal clusters, this is the number of nodes per zone. Changing this will force recreation of the resource.
     *
     * @stability stable
     */
    readonly initialNodeCount?: number;
    /**
     * The location (region or zone) of the cluster.
     *
     * @stability stable
     */
    readonly location?: string;
    /**
     * The maximum number of pods per node in this node pool.
     *
     * Note that this does not work on node pools which are "route-based" - that is, node pools belonging to clusters that do not have IP Aliasing enabled.
     *
     * @stability stable
     */
    readonly maxPodsPerNode?: number;
    /**
     * The name of the node pool.
     *
     * If left blank, Terraform will auto-generate a unique name.
     *
     * @stability stable
     */
    readonly name?: string;
    /**
     * Creates a unique name for the node pool beginning with the specified prefix.
     *
     * Conflicts with name.
     *
     * @stability stable
     */
    readonly namePrefix?: string;
    /**
     * The number of nodes per instance group.
     *
     * This field can be used to update the number of nodes per instance group but should not be used alongside autoscaling.
     *
     * @stability stable
     */
    readonly nodeCount?: number;
    /**
     * The list of zones in which the node pool's nodes should be located.
     *
     * Nodes must be in the region of their regional cluster or in the same region as their cluster's zone for zonal clusters. If unspecified, the cluster-level node_locations will be used.
     *
     * @stability stable
     */
    readonly nodeLocations?: string[];
    /**
     * The ID of the project in which to create the node pool.
     *
     * If blank, the provider-configured project will be used.
     *
     * @stability stable
     */
    readonly project?: string;
    /**
     * The Kubernetes version for the nodes in this pool.
     *
     * Note that if this field and auto_upgrade are both specified, they will fight each other for what the node version should be, so setting both is highly discouraged. While a fuzzy version can be specified, it's recommended that you specify explicit versions as Terraform will see spurious diffs when fuzzy versions are used. See the google_container_engine_versions data source's version_prefix field to approximate fuzzy versions in a Terraform-compatible way.
     *
     * @stability stable
     */
    readonly version?: string;
    /**
     * autoscaling block.
     *
     * @stability stable
     */
    readonly autoscaling?: ContainerNodePoolAutoscaling[];
    /**
     * management block.
     *
     * @stability stable
     */
    readonly management?: ContainerNodePoolManagement[];
    /**
     * node_config block.
     *
     * @stability stable
     */
    readonly nodeConfig?: ContainerNodePoolNodeConfig[];
    /**
     * timeouts block.
     *
     * @stability stable
     */
    readonly timeouts?: ContainerNodePoolTimeouts;
    /**
     * upgrade_settings block.
     *
     * @stability stable
     */
    readonly upgradeSettings?: ContainerNodePoolUpgradeSettings[];
}
/**
 * @stability stable
 */
export interface ContainerNodePoolAutoscaling {
    /**
     * Maximum number of nodes in the NodePool.
     *
     * Must be >= min_node_count.
     *
     * @stability stable
     */
    readonly maxNodeCount: number;
    /**
     * Minimum number of nodes in the NodePool.
     *
     * Must be >=0 and <= max_node_count.
     *
     * @stability stable
     */
    readonly minNodeCount: number;
}
/**
 * @stability stable
 */
export interface ContainerNodePoolManagement {
    /**
     * Whether the nodes will be automatically repaired.
     *
     * @stability stable
     */
    readonly autoRepair?: boolean;
    /**
     * Whether the nodes will be automatically upgraded.
     *
     * @stability stable
     */
    readonly autoUpgrade?: boolean;
}
/**
 * @stability stable
 */
export interface ContainerNodePoolNodeConfigGuestAccelerator {
    /**
     * @stability stable
     */
    readonly count?: number;
    /**
     * @stability stable
     */
    readonly type?: string;
}
/**
 * @stability stable
 */
export interface ContainerNodePoolNodeConfigTaint {
    /**
     * @stability stable
     */
    readonly effect?: string;
    /**
     * @stability stable
     */
    readonly key?: string;
    /**
     * @stability stable
     */
    readonly value?: string;
}
/**
 * @stability stable
 */
export interface ContainerNodePoolNodeConfigShieldedInstanceConfig {
    /**
     * @stability stable
     */
    readonly enableIntegrityMonitoring?: boolean;
    /**
     * @stability stable
     */
    readonly enableSecureBoot?: boolean;
}
/**
 * @stability stable
 */
export interface ContainerNodePoolNodeConfigWorkloadMetadataConfig {
    /**
     * @stability stable
     */
    readonly nodeMetadata: string;
}
/**
 * @stability stable
 */
export interface ContainerNodePoolNodeConfig {
    /**
     * @stability stable
     */
    readonly diskSizeGb?: number;
    /**
     * @stability stable
     */
    readonly diskType?: string;
    /**
     * @stability stable
     */
    readonly guestAccelerator?: ContainerNodePoolNodeConfigGuestAccelerator[];
    /**
     * @stability stable
     */
    readonly imageType?: string;
    /**
     * @stability stable
     */
    readonly labels?: {
        [key: string]: string;
    };
    /**
     * @stability stable
     */
    readonly localSsdCount?: number;
    /**
     * @stability stable
     */
    readonly machineType?: string;
    /**
     * @stability stable
     */
    readonly metadata?: {
        [key: string]: string;
    };
    /**
     * @stability stable
     */
    readonly minCpuPlatform?: string;
    /**
     * @stability stable
     */
    readonly oauthScopes?: string[];
    /**
     * @stability stable
     */
    readonly preemptible?: boolean;
    /**
     * @stability stable
     */
    readonly serviceAccount?: string;
    /**
     * @stability stable
     */
    readonly tags?: string[];
    /**
     * @stability stable
     */
    readonly taint?: ContainerNodePoolNodeConfigTaint[];
    /**
     * shielded_instance_config block.
     *
     * @stability stable
     */
    readonly shieldedInstanceConfig?: ContainerNodePoolNodeConfigShieldedInstanceConfig[];
    /**
     * workload_metadata_config block.
     *
     * @stability stable
     */
    readonly workloadMetadataConfig?: ContainerNodePoolNodeConfigWorkloadMetadataConfig[];
}
/**
 * @stability stable
 */
export interface ContainerNodePoolTimeouts {
    /**
     * @stability stable
     */
    readonly create?: string;
    /**
     * @stability stable
     */
    readonly delete?: string;
    /**
     * @stability stable
     */
    readonly update?: string;
}
/**
 * @stability stable
 */
export interface ContainerNodePoolUpgradeSettings {
    /**
     * The number of additional nodes that can be added to the node pool during an upgrade.
     *
     * Increasing max_surge raises the number of nodes that can be upgraded simultaneously. Can be set to 0 or greater.
     *
     * @stability stable
     */
    readonly maxSurge: number;
    /**
     * The number of nodes that can be simultaneously unavailable during an upgrade.
     *
     * Increasing max_unavailable raises the number of nodes that can be upgraded in parallel. Can be set to 0 or greater.
     *
     * @stability stable
     */
    readonly maxUnavailable: number;
}
/**
 * @stability stable
 */
export declare class ContainerNodePool extends cdktf.TerraformResource {
    /**
     * @stability stable
     */
    constructor(scope: Construct, id: string, config: ContainerNodePoolConfig);
    private _cluster;
    /**
     * @stability stable
     */
    get cluster(): string;
    /**
     * @stability stable
     */
    set cluster(value: string);
    /**
     * @stability stable
     */
    get clusterInput(): string;
    /**
     * @stability stable
     */
    get id(): string;
    private _initialNodeCount?;
    /**
     * @stability stable
     */
    get initialNodeCount(): number;
    /**
     * @stability stable
     */
    set initialNodeCount(value: number);
    /**
     * @stability stable
     */
    resetInitialNodeCount(): void;
    /**
     * @stability stable
     */
    get initialNodeCountInput(): number | undefined;
    /**
     * @stability stable
     */
    get instanceGroupUrls(): string[];
    private _location?;
    /**
     * @stability stable
     */
    get location(): string;
    /**
     * @stability stable
     */
    set location(value: string);
    /**
     * @stability stable
     */
    resetLocation(): void;
    /**
     * @stability stable
     */
    get locationInput(): string | undefined;
    private _maxPodsPerNode?;
    /**
     * @stability stable
     */
    get maxPodsPerNode(): number;
    /**
     * @stability stable
     */
    set maxPodsPerNode(value: number);
    /**
     * @stability stable
     */
    resetMaxPodsPerNode(): void;
    /**
     * @stability stable
     */
    get maxPodsPerNodeInput(): number | undefined;
    private _name?;
    /**
     * @stability stable
     */
    get name(): string;
    /**
     * @stability stable
     */
    set name(value: string);
    /**
     * @stability stable
     */
    resetName(): void;
    /**
     * @stability stable
     */
    get nameInput(): string | undefined;
    private _namePrefix?;
    /**
     * @stability stable
     */
    get namePrefix(): string;
    /**
     * @stability stable
     */
    set namePrefix(value: string);
    /**
     * @stability stable
     */
    resetNamePrefix(): void;
    /**
     * @stability stable
     */
    get namePrefixInput(): string | undefined;
    private _nodeCount?;
    /**
     * @stability stable
     */
    get nodeCount(): number;
    /**
     * @stability stable
     */
    set nodeCount(value: number);
    /**
     * @stability stable
     */
    resetNodeCount(): void;
    /**
     * @stability stable
     */
    get nodeCountInput(): number | undefined;
    private _nodeLocations?;
    /**
     * @stability stable
     */
    get nodeLocations(): string[];
    /**
     * @stability stable
     */
    set nodeLocations(value: string[]);
    /**
     * @stability stable
     */
    resetNodeLocations(): void;
    /**
     * @stability stable
     */
    get nodeLocationsInput(): string[] | undefined;
    private _project?;
    /**
     * @stability stable
     */
    get project(): string;
    /**
     * @stability stable
     */
    set project(value: string);
    /**
     * @stability stable
     */
    resetProject(): void;
    /**
     * @stability stable
     */
    get projectInput(): string | undefined;
    private _version?;
    /**
     * @stability stable
     */
    get version(): string;
    /**
     * @stability stable
     */
    set version(value: string);
    /**
     * @stability stable
     */
    resetVersion(): void;
    /**
     * @stability stable
     */
    get versionInput(): string | undefined;
    private _autoscaling?;
    /**
     * @stability stable
     */
    get autoscaling(): ContainerNodePoolAutoscaling[];
    /**
     * @stability stable
     */
    set autoscaling(value: ContainerNodePoolAutoscaling[]);
    /**
     * @stability stable
     */
    resetAutoscaling(): void;
    /**
     * @stability stable
     */
    get autoscalingInput(): ContainerNodePoolAutoscaling[] | undefined;
    private _management?;
    /**
     * @stability stable
     */
    get management(): ContainerNodePoolManagement[];
    /**
     * @stability stable
     */
    set management(value: ContainerNodePoolManagement[]);
    /**
     * @stability stable
     */
    resetManagement(): void;
    /**
     * @stability stable
     */
    get managementInput(): ContainerNodePoolManagement[] | undefined;
    private _nodeConfig?;
    /**
     * @stability stable
     */
    get nodeConfig(): ContainerNodePoolNodeConfig[];
    /**
     * @stability stable
     */
    set nodeConfig(value: ContainerNodePoolNodeConfig[]);
    /**
     * @stability stable
     */
    resetNodeConfig(): void;
    /**
     * @stability stable
     */
    get nodeConfigInput(): ContainerNodePoolNodeConfig[] | undefined;
    private _timeouts?;
    /**
     * @stability stable
     */
    get timeouts(): ContainerNodePoolTimeouts;
    /**
     * @stability stable
     */
    set timeouts(value: ContainerNodePoolTimeouts);
    /**
     * @stability stable
     */
    resetTimeouts(): void;
    /**
     * @stability stable
     */
    get timeoutsInput(): ContainerNodePoolTimeouts | undefined;
    private _upgradeSettings?;
    /**
     * @stability stable
     */
    get upgradeSettings(): ContainerNodePoolUpgradeSettings[];
    /**
     * @stability stable
     */
    set upgradeSettings(value: ContainerNodePoolUpgradeSettings[]);
    /**
     * @stability stable
     */
    resetUpgradeSettings(): void;
    /**
     * @stability stable
     */
    get upgradeSettingsInput(): ContainerNodePoolUpgradeSettings[] | undefined;
    /**
     * @stability stable
     */
    protected synthesizeAttributes(): {
        [name: string]: any;
    };
}
