import { Construct } from 'constructs';
import * as cdktf from 'cdktf';
/**
 * @stability stable
 */
export interface DataCatalogEntryGroupConfig extends cdktf.TerraformMetaArguments {
    /**
     * Entry group description, which can consist of several sentences or paragraphs that describe entry group contents.
     *
     * @stability stable
     */
    readonly description?: string;
    /**
     * A short name to identify the entry group, for example, "analytics data - jan 2011".
     *
     * @stability stable
     */
    readonly displayName?: string;
    /**
     * The id of the entry group to create.
     *
     * The id must begin with a letter or underscore,
     * contain only English letters, numbers and underscores, and be at most 64 characters.
     *
     * @stability stable
     */
    readonly entryGroupId: string;
    /**
     * @stability stable
     */
    readonly project?: string;
    /**
     * EntryGroup location region.
     *
     * @stability stable
     */
    readonly region?: string;
    /**
     * timeouts block.
     *
     * @stability stable
     */
    readonly timeouts?: DataCatalogEntryGroupTimeouts;
}
/**
 * @stability stable
 */
export interface DataCatalogEntryGroupTimeouts {
    /**
     * @stability stable
     */
    readonly create?: string;
    /**
     * @stability stable
     */
    readonly delete?: string;
    /**
     * @stability stable
     */
    readonly update?: string;
}
/**
 * @stability stable
 */
export declare class DataCatalogEntryGroup extends cdktf.TerraformResource {
    /**
     * @stability stable
     */
    constructor(scope: Construct, id: string, config: DataCatalogEntryGroupConfig);
    private _description?;
    /**
     * @stability stable
     */
    get description(): string;
    /**
     * @stability stable
     */
    set description(value: string);
    /**
     * @stability stable
     */
    resetDescription(): void;
    /**
     * @stability stable
     */
    get descriptionInput(): string | undefined;
    private _displayName?;
    /**
     * @stability stable
     */
    get displayName(): string;
    /**
     * @stability stable
     */
    set displayName(value: string);
    /**
     * @stability stable
     */
    resetDisplayName(): void;
    /**
     * @stability stable
     */
    get displayNameInput(): string | undefined;
    private _entryGroupId;
    /**
     * @stability stable
     */
    get entryGroupId(): string;
    /**
     * @stability stable
     */
    set entryGroupId(value: string);
    /**
     * @stability stable
     */
    get entryGroupIdInput(): string;
    /**
     * @stability stable
     */
    get id(): string;
    /**
     * @stability stable
     */
    get name(): string;
    private _project?;
    /**
     * @stability stable
     */
    get project(): string;
    /**
     * @stability stable
     */
    set project(value: string);
    /**
     * @stability stable
     */
    resetProject(): void;
    /**
     * @stability stable
     */
    get projectInput(): string | undefined;
    private _region?;
    /**
     * @stability stable
     */
    get region(): string;
    /**
     * @stability stable
     */
    set region(value: string);
    /**
     * @stability stable
     */
    resetRegion(): void;
    /**
     * @stability stable
     */
    get regionInput(): string | undefined;
    private _timeouts?;
    /**
     * @stability stable
     */
    get timeouts(): DataCatalogEntryGroupTimeouts;
    /**
     * @stability stable
     */
    set timeouts(value: DataCatalogEntryGroupTimeouts);
    /**
     * @stability stable
     */
    resetTimeouts(): void;
    /**
     * @stability stable
     */
    get timeoutsInput(): DataCatalogEntryGroupTimeouts | undefined;
    /**
     * @stability stable
     */
    protected synthesizeAttributes(): {
        [name: string]: any;
    };
}
