import { Construct } from 'constructs';
import * as cdktf from 'cdktf';
/**
 * @stability stable
 */
export interface DataGoogleMonitoringClusterIstioServiceConfig extends cdktf.TerraformMetaArguments {
    /**
     * The name of the Kubernetes cluster in which this Istio service is defined.
     *
     * Corresponds to the clusterName resource label in k8s_cluster resources.
     *
     * @stability stable
     */
    readonly clusterName: string;
    /**
     * The location of the Kubernetes cluster in which this Istio service is defined.
     *
     * Corresponds to the location resource label in k8s_cluster resources.
     *
     * @stability stable
     */
    readonly location: string;
    /**
     * @stability stable
     */
    readonly project?: string;
    /**
     * The name of the Istio service underlying this service.
     *
     * Corresponds to the destination_service_name metric label in Istio metrics.
     *
     * @stability stable
     */
    readonly serviceName: string;
    /**
     * The namespace of the Istio service underlying this service.
     *
     * Corresponds to the destination_service_namespace metric label in Istio metrics.
     *
     * @stability stable
     */
    readonly serviceNamespace: string;
}
/**
 * @stability stable
 */
export declare class DataGoogleMonitoringClusterIstioServiceTelemetry extends cdktf.ComplexComputedList {
    /**
     * @stability stable
     */
    get resourceName(): string;
}
/**
 * @stability stable
 */
export declare class DataGoogleMonitoringClusterIstioService extends cdktf.TerraformDataSource {
    /**
     * @stability stable
     */
    constructor(scope: Construct, id: string, config: DataGoogleMonitoringClusterIstioServiceConfig);
    private _clusterName;
    /**
     * @stability stable
     */
    get clusterName(): string;
    /**
     * @stability stable
     */
    set clusterName(value: string);
    /**
     * @stability stable
     */
    get clusterNameInput(): string;
    /**
     * @stability stable
     */
    get displayName(): string;
    /**
     * @stability stable
     */
    get id(): string;
    private _location;
    /**
     * @stability stable
     */
    get location(): string;
    /**
     * @stability stable
     */
    set location(value: string);
    /**
     * @stability stable
     */
    get locationInput(): string;
    /**
     * @stability stable
     */
    get name(): string;
    private _project?;
    /**
     * @stability stable
     */
    get project(): string;
    /**
     * @stability stable
     */
    set project(value: string);
    /**
     * @stability stable
     */
    resetProject(): void;
    /**
     * @stability stable
     */
    get projectInput(): string | undefined;
    /**
     * @stability stable
     */
    get serviceId(): string;
    private _serviceName;
    /**
     * @stability stable
     */
    get serviceName(): string;
    /**
     * @stability stable
     */
    set serviceName(value: string);
    /**
     * @stability stable
     */
    get serviceNameInput(): string;
    private _serviceNamespace;
    /**
     * @stability stable
     */
    get serviceNamespace(): string;
    /**
     * @stability stable
     */
    set serviceNamespace(value: string);
    /**
     * @stability stable
     */
    get serviceNamespaceInput(): string;
    /**
     * @stability stable
     */
    telemetry(index: string): DataGoogleMonitoringClusterIstioServiceTelemetry;
    /**
     * @stability stable
     */
    protected synthesizeAttributes(): {
        [name: string]: any;
    };
}
