import { Construct } from 'constructs';
import * as cdktf from 'cdktf';
/**
 * @stability stable
 */
export interface DataLossPreventionJobTriggerConfig extends cdktf.TerraformMetaArguments {
    /**
     * A description of the job trigger.
     *
     * @stability stable
     */
    readonly description?: string;
    /**
     * User set display name of the job trigger.
     *
     * @stability stable
     */
    readonly displayName?: string;
    /**
     * The parent of the trigger, either in the format 'projects/{{project}}' or 'projects/{{project}}/locations/{{location}}'.
     *
     * @stability stable
     */
    readonly parent: string;
    /**
     * Whether the trigger is currently active.
     *
     * Default value: "HEALTHY" Possible values: ["PAUSED", "HEALTHY", "CANCELLED"]
     *
     * @stability stable
     */
    readonly status?: string;
    /**
     * inspect_job block.
     *
     * @stability stable
     */
    readonly inspectJob?: DataLossPreventionJobTriggerInspectJob[];
    /**
     * timeouts block.
     *
     * @stability stable
     */
    readonly timeouts?: DataLossPreventionJobTriggerTimeouts;
    /**
     * triggers block.
     *
     * @stability stable
     */
    readonly triggers: DataLossPreventionJobTriggerTriggers[];
}
/**
 * @stability stable
 */
export interface DataLossPreventionJobTriggerInspectJobActionsSaveFindingsOutputConfigTable {
    /**
     * Dataset ID of the table.
     *
     * @stability stable
     */
    readonly datasetId: string;
    /**
     * The Google Cloud Platform project ID of the project containing the table.
     *
     * @stability stable
     */
    readonly projectId: string;
    /**
     * Name of the table.
     *
     * If is not set a new one will be generated for you with the following format:
     * 'dlp_googleapis_yyyy_mm_dd_[dlp_job_id]'. Pacific timezone will be used for generating the date details.
     *
     * @stability stable
     */
    readonly tableId?: string;
}
/**
 * @stability stable
 */
export interface DataLossPreventionJobTriggerInspectJobActionsSaveFindingsOutputConfig {
    /**
     * Schema used for writing the findings for Inspect jobs.
     *
     * This field is only used for
     * Inspect and must be unspecified for Risk jobs. Columns are derived from the Finding
     * object. If appending to an existing table, any columns from the predefined schema
     * that are missing will be added. No columns in the existing table will be deleted.
     *
     * If unspecified, then all available columns will be used for a new table or an (existing)
     * table with no schema, and no changes will be made to an existing table that has a schema.
     * Only for use with external storage. Possible values: ["BASIC_COLUMNS", "GCS_COLUMNS", "DATASTORE_COLUMNS", "BIG_QUERY_COLUMNS", "ALL_COLUMNS"]
     *
     * @stability stable
     */
    readonly outputSchema?: string;
    /**
     * table block.
     *
     * @stability stable
     */
    readonly table: DataLossPreventionJobTriggerInspectJobActionsSaveFindingsOutputConfigTable[];
}
/**
 * @stability stable
 */
export interface DataLossPreventionJobTriggerInspectJobActionsSaveFindings {
    /**
     * output_config block.
     *
     * @stability stable
     */
    readonly outputConfig: DataLossPreventionJobTriggerInspectJobActionsSaveFindingsOutputConfig[];
}
/**
 * @stability stable
 */
export interface DataLossPreventionJobTriggerInspectJobActions {
    /**
     * save_findings block.
     *
     * @stability stable
     */
    readonly saveFindings: DataLossPreventionJobTriggerInspectJobActionsSaveFindings[];
}
/**
 * @stability stable
 */
export interface DataLossPreventionJobTriggerInspectJobStorageConfigBigQueryOptionsTableReference {
    /**
     * The dataset ID of the table.
     *
     * @stability stable
     */
    readonly datasetId: string;
    /**
     * The Google Cloud Platform project ID of the project containing the table.
     *
     * @stability stable
     */
    readonly projectId: string;
    /**
     * The name of the table.
     *
     * @stability stable
     */
    readonly tableId: string;
}
/**
 * @stability stable
 */
export interface DataLossPreventionJobTriggerInspectJobStorageConfigBigQueryOptions {
    /**
     * table_reference block.
     *
     * @stability stable
     */
    readonly tableReference: DataLossPreventionJobTriggerInspectJobStorageConfigBigQueryOptionsTableReference[];
}
/**
 * @stability stable
 */
export interface DataLossPreventionJobTriggerInspectJobStorageConfigCloudStorageOptionsFileSetRegexFileSet {
    /**
     * The name of a Cloud Storage bucket.
     *
     * @stability stable
     */
    readonly bucketName: string;
    /**
     * A list of regular expressions matching file paths to exclude.
     *
     * All files in the bucket that match at
     * least one of these regular expressions will be excluded from the scan.
     *
     * @stability stable
     */
    readonly excludeRegex?: string[];
    /**
     * A list of regular expressions matching file paths to include.
     *
     * All files in the bucket
     * that match at least one of these regular expressions will be included in the set of files,
     * except for those that also match an item in excludeRegex. Leaving this field empty will
     * match all files by default (this is equivalent to including .* in the list)
     *
     * @stability stable
     */
    readonly includeRegex?: string[];
}
/**
 * @stability stable
 */
export interface DataLossPreventionJobTriggerInspectJobStorageConfigCloudStorageOptionsFileSet {
    /**
     * The Cloud Storage url of the file(s) to scan, in the format 'gs://<bucket>/<path>'. Trailing wildcard in the path is allowed.
     *
     * If the url ends in a trailing slash, the bucket or directory represented by the url will be scanned
     * non-recursively (content in sub-directories will not be scanned). This means that 'gs://mybucket/' is
     * equivalent to 'gs://mybucket/*', and 'gs://mybucket/directory/' is equivalent to 'gs://mybucket/directory/*'.
     *
     * @stability stable
     */
    readonly url?: string;
    /**
     * regex_file_set block.
     *
     * @stability stable
     */
    readonly regexFileSet?: DataLossPreventionJobTriggerInspectJobStorageConfigCloudStorageOptionsFileSetRegexFileSet[];
}
/**
 * @stability stable
 */
export interface DataLossPreventionJobTriggerInspectJobStorageConfigCloudStorageOptions {
    /**
     * Max number of bytes to scan from a file.
     *
     * If a scanned file's size is bigger than this value
     * then the rest of the bytes are omitted.
     *
     * @stability stable
     */
    readonly bytesLimitPerFile?: number;
    /**
     * Max percentage of bytes to scan from a file.
     *
     * The rest are omitted. The number of bytes scanned is rounded down.
     * Must be between 0 and 100, inclusively. Both 0 and 100 means no limit.
     *
     * @stability stable
     */
    readonly bytesLimitPerFilePercent?: number;
    /**
     * List of file type groups to include in the scan.
     *
     * If empty, all files are scanned and available data
     * format processors are applied. In addition, the binary content of the selected files is always scanned as well.
     * Images are scanned only as binary if the specified region does not support image inspection and no fileTypes were specified. Possible values: ["BINARY_FILE", "TEXT_FILE", "IMAGE", "WORD", "PDF", "AVRO", "CSV", "TSV"]
     *
     * @stability stable
     */
    readonly fileTypes?: string[];
    /**
     * Limits the number of files to scan to this percentage of the input FileSet.
     *
     * Number of files scanned is rounded down.
     * Must be between 0 and 100, inclusively. Both 0 and 100 means no limit.
     *
     * @stability stable
     */
    readonly filesLimitPercent?: number;
    /**
     * How to sample bytes if not all bytes are scanned.
     *
     * Meaningful only when used in conjunction with bytesLimitPerFile.
     * If not specified, scanning would start from the top. Possible values: ["TOP", "RANDOM_START"]
     *
     * @stability stable
     */
    readonly sampleMethod?: string;
    /**
     * file_set block.
     *
     * @stability stable
     */
    readonly fileSet: DataLossPreventionJobTriggerInspectJobStorageConfigCloudStorageOptionsFileSet[];
}
/**
 * @stability stable
 */
export interface DataLossPreventionJobTriggerInspectJobStorageConfigDatastoreOptionsKind {
    /**
     * The name of the Datastore kind.
     *
     * @stability stable
     */
    readonly name: string;
}
/**
 * @stability stable
 */
export interface DataLossPreventionJobTriggerInspectJobStorageConfigDatastoreOptionsPartitionId {
    /**
     * If not empty, the ID of the namespace to which the entities belong.
     *
     * @stability stable
     */
    readonly namespaceId?: string;
    /**
     * The ID of the project to which the entities belong.
     *
     * @stability stable
     */
    readonly projectId: string;
}
/**
 * @stability stable
 */
export interface DataLossPreventionJobTriggerInspectJobStorageConfigDatastoreOptions {
    /**
     * kind block.
     *
     * @stability stable
     */
    readonly kind: DataLossPreventionJobTriggerInspectJobStorageConfigDatastoreOptionsKind[];
    /**
     * partition_id block.
     *
     * @stability stable
     */
    readonly partitionId: DataLossPreventionJobTriggerInspectJobStorageConfigDatastoreOptionsPartitionId[];
}
/**
 * @stability stable
 */
export interface DataLossPreventionJobTriggerInspectJobStorageConfigTimespanConfigTimestampField {
    /**
     * Specification of the field containing the timestamp of scanned items. Used for data sources like Datastore and BigQuery.
     *
     * For BigQuery: Required to filter out rows based on the given start and end times. If not specified and the table was
     * modified between the given start and end times, the entire table will be scanned. The valid data types of the timestamp
     * field are: INTEGER, DATE, TIMESTAMP, or DATETIME BigQuery column.
     *
     * For Datastore. Valid data types of the timestamp field are: TIMESTAMP. Datastore entity will be scanned if the
     * timestamp property does not exist or its value is empty or invalid.
     *
     * @stability stable
     */
    readonly name: string;
}
/**
 * @stability stable
 */
export interface DataLossPreventionJobTriggerInspectJobStorageConfigTimespanConfig {
    /**
     * When the job is started by a JobTrigger we will automatically figure out a valid startTime to avoid scanning files that have not been modified since the last time the JobTrigger executed.
     *
     * This will
     * be based on the time of the execution of the last run of the JobTrigger.
     *
     * @stability stable
     */
    readonly enableAutoPopulationOfTimespanConfig?: boolean;
    /**
     * Exclude files or rows newer than this value.
     *
     * If set to zero, no upper time limit is applied.
     *
     * @stability stable
     */
    readonly endTime?: string;
    /**
     * Exclude files or rows older than this value.
     *
     * @stability stable
     */
    readonly startTime?: string;
    /**
     * timestamp_field block.
     *
     * @stability stable
     */
    readonly timestampField: DataLossPreventionJobTriggerInspectJobStorageConfigTimespanConfigTimestampField[];
}
/**
 * @stability stable
 */
export interface DataLossPreventionJobTriggerInspectJobStorageConfig {
    /**
     * big_query_options block.
     *
     * @stability stable
     */
    readonly bigQueryOptions?: DataLossPreventionJobTriggerInspectJobStorageConfigBigQueryOptions[];
    /**
     * cloud_storage_options block.
     *
     * @stability stable
     */
    readonly cloudStorageOptions?: DataLossPreventionJobTriggerInspectJobStorageConfigCloudStorageOptions[];
    /**
     * datastore_options block.
     *
     * @stability stable
     */
    readonly datastoreOptions?: DataLossPreventionJobTriggerInspectJobStorageConfigDatastoreOptions[];
    /**
     * timespan_config block.
     *
     * @stability stable
     */
    readonly timespanConfig?: DataLossPreventionJobTriggerInspectJobStorageConfigTimespanConfig[];
}
/**
 * @stability stable
 */
export interface DataLossPreventionJobTriggerInspectJob {
    /**
     * The name of the template to run when this job is triggered.
     *
     * @stability stable
     */
    readonly inspectTemplateName: string;
    /**
     * actions block.
     *
     * @stability stable
     */
    readonly actions: DataLossPreventionJobTriggerInspectJobActions[];
    /**
     * storage_config block.
     *
     * @stability stable
     */
    readonly storageConfig: DataLossPreventionJobTriggerInspectJobStorageConfig[];
}
/**
 * @stability stable
 */
export interface DataLossPreventionJobTriggerTimeouts {
    /**
     * @stability stable
     */
    readonly create?: string;
    /**
     * @stability stable
     */
    readonly delete?: string;
    /**
     * @stability stable
     */
    readonly update?: string;
}
/**
 * @stability stable
 */
export interface DataLossPreventionJobTriggerTriggersSchedule {
    /**
     * With this option a job is started a regular periodic basis. For example: every day (86400 seconds).
     *
     * A scheduled start time will be skipped if the previous execution has not ended when its scheduled time occurs.
     *
     * This value must be set to a time duration greater than or equal to 1 day and can be no longer than 60 days.
     *
     * A duration in seconds with up to nine fractional digits, terminated by 's'. Example: "3.5s".
     *
     * @stability stable
     */
    readonly recurrencePeriodDuration?: string;
}
/**
 * @stability stable
 */
export interface DataLossPreventionJobTriggerTriggers {
    /**
     * schedule block.
     *
     * @stability stable
     */
    readonly schedule?: DataLossPreventionJobTriggerTriggersSchedule[];
}
/**
 * @stability stable
 */
export declare class DataLossPreventionJobTrigger extends cdktf.TerraformResource {
    /**
     * @stability stable
     */
    constructor(scope: Construct, id: string, config: DataLossPreventionJobTriggerConfig);
    private _description?;
    /**
     * @stability stable
     */
    get description(): string;
    /**
     * @stability stable
     */
    set description(value: string);
    /**
     * @stability stable
     */
    resetDescription(): void;
    /**
     * @stability stable
     */
    get descriptionInput(): string | undefined;
    private _displayName?;
    /**
     * @stability stable
     */
    get displayName(): string;
    /**
     * @stability stable
     */
    set displayName(value: string);
    /**
     * @stability stable
     */
    resetDisplayName(): void;
    /**
     * @stability stable
     */
    get displayNameInput(): string | undefined;
    /**
     * @stability stable
     */
    get id(): string;
    /**
     * @stability stable
     */
    get lastRunTime(): string;
    /**
     * @stability stable
     */
    get name(): string;
    private _parent;
    /**
     * @stability stable
     */
    get parent(): string;
    /**
     * @stability stable
     */
    set parent(value: string);
    /**
     * @stability stable
     */
    get parentInput(): string;
    private _status?;
    /**
     * @stability stable
     */
    get status(): string;
    /**
     * @stability stable
     */
    set status(value: string);
    /**
     * @stability stable
     */
    resetStatus(): void;
    /**
     * @stability stable
     */
    get statusInput(): string | undefined;
    private _inspectJob?;
    /**
     * @stability stable
     */
    get inspectJob(): DataLossPreventionJobTriggerInspectJob[];
    /**
     * @stability stable
     */
    set inspectJob(value: DataLossPreventionJobTriggerInspectJob[]);
    /**
     * @stability stable
     */
    resetInspectJob(): void;
    /**
     * @stability stable
     */
    get inspectJobInput(): DataLossPreventionJobTriggerInspectJob[] | undefined;
    private _timeouts?;
    /**
     * @stability stable
     */
    get timeouts(): DataLossPreventionJobTriggerTimeouts;
    /**
     * @stability stable
     */
    set timeouts(value: DataLossPreventionJobTriggerTimeouts);
    /**
     * @stability stable
     */
    resetTimeouts(): void;
    /**
     * @stability stable
     */
    get timeoutsInput(): DataLossPreventionJobTriggerTimeouts | undefined;
    private _triggers;
    /**
     * @stability stable
     */
    get triggers(): DataLossPreventionJobTriggerTriggers[];
    /**
     * @stability stable
     */
    set triggers(value: DataLossPreventionJobTriggerTriggers[]);
    /**
     * @stability stable
     */
    get triggersInput(): DataLossPreventionJobTriggerTriggers[];
    /**
     * @stability stable
     */
    protected synthesizeAttributes(): {
        [name: string]: any;
    };
}
