import { Construct } from 'constructs';
import * as cdktf from 'cdktf';
/**
 * @stability stable
 */
export interface DataLossPreventionStoredInfoTypeConfig extends cdktf.TerraformMetaArguments {
    /**
     * A description of the info type.
     *
     * @stability stable
     */
    readonly description?: string;
    /**
     * User set display name of the info type.
     *
     * @stability stable
     */
    readonly displayName?: string;
    /**
     * The parent of the info type in any of the following formats:.
     *
     * 'projects/{{project}}'
     * 'projects/{{project}}/locations/{{location}}'
     * 'organizations/{{organization_id}}'
     * 'organizations/{{organization_id}}/locations/{{location}}'
     *
     * @stability stable
     */
    readonly parent: string;
    /**
     * dictionary block.
     *
     * @stability stable
     */
    readonly dictionary?: DataLossPreventionStoredInfoTypeDictionary[];
    /**
     * large_custom_dictionary block.
     *
     * @stability stable
     */
    readonly largeCustomDictionary?: DataLossPreventionStoredInfoTypeLargeCustomDictionary[];
    /**
     * regex block.
     *
     * @stability stable
     */
    readonly regex?: DataLossPreventionStoredInfoTypeRegex[];
    /**
     * timeouts block.
     *
     * @stability stable
     */
    readonly timeouts?: DataLossPreventionStoredInfoTypeTimeouts;
}
/**
 * @stability stable
 */
export interface DataLossPreventionStoredInfoTypeDictionaryCloudStoragePath {
    /**
     * A url representing a file or path (no wildcards) in Cloud Storage.
     *
     * Example: 'gs://[BUCKET_NAME]/dictionary.txt'
     *
     * @stability stable
     */
    readonly path: string;
}
/**
 * @stability stable
 */
export interface DataLossPreventionStoredInfoTypeDictionaryWordList {
    /**
     * Words or phrases defining the dictionary.
     *
     * The dictionary must contain at least one
     * phrase and every phrase must contain at least 2 characters that are letters or digits.
     *
     * @stability stable
     */
    readonly words: string[];
}
/**
 * @stability stable
 */
export interface DataLossPreventionStoredInfoTypeDictionary {
    /**
     * cloud_storage_path block.
     *
     * @stability stable
     */
    readonly cloudStoragePath?: DataLossPreventionStoredInfoTypeDictionaryCloudStoragePath[];
    /**
     * word_list block.
     *
     * @stability stable
     */
    readonly wordList?: DataLossPreventionStoredInfoTypeDictionaryWordList[];
}
/**
 * @stability stable
 */
export interface DataLossPreventionStoredInfoTypeLargeCustomDictionaryBigQueryFieldField {
    /**
     * Name describing the field.
     *
     * @stability stable
     */
    readonly name: string;
}
/**
 * @stability stable
 */
export interface DataLossPreventionStoredInfoTypeLargeCustomDictionaryBigQueryFieldTable {
    /**
     * The dataset ID of the table.
     *
     * @stability stable
     */
    readonly datasetId: string;
    /**
     * The Google Cloud Platform project ID of the project containing the table.
     *
     * @stability stable
     */
    readonly projectId: string;
    /**
     * The name of the table.
     *
     * @stability stable
     */
    readonly tableId: string;
}
/**
 * @stability stable
 */
export interface DataLossPreventionStoredInfoTypeLargeCustomDictionaryBigQueryField {
    /**
     * field block.
     *
     * @stability stable
     */
    readonly field: DataLossPreventionStoredInfoTypeLargeCustomDictionaryBigQueryFieldField[];
    /**
     * table block.
     *
     * @stability stable
     */
    readonly table: DataLossPreventionStoredInfoTypeLargeCustomDictionaryBigQueryFieldTable[];
}
/**
 * @stability stable
 */
export interface DataLossPreventionStoredInfoTypeLargeCustomDictionaryCloudStorageFileSet {
    /**
     * The url, in the format 'gs://<bucket>/<path>'.
     *
     * Trailing wildcard in the path is allowed.
     *
     * @stability stable
     */
    readonly url: string;
}
/**
 * @stability stable
 */
export interface DataLossPreventionStoredInfoTypeLargeCustomDictionaryOutputPath {
    /**
     * A url representing a file or path (no wildcards) in Cloud Storage.
     *
     * Example: 'gs://[BUCKET_NAME]/dictionary.txt'
     *
     * @stability stable
     */
    readonly path: string;
}
/**
 * @stability stable
 */
export interface DataLossPreventionStoredInfoTypeLargeCustomDictionary {
    /**
     * big_query_field block.
     *
     * @stability stable
     */
    readonly bigQueryField?: DataLossPreventionStoredInfoTypeLargeCustomDictionaryBigQueryField[];
    /**
     * cloud_storage_file_set block.
     *
     * @stability stable
     */
    readonly cloudStorageFileSet?: DataLossPreventionStoredInfoTypeLargeCustomDictionaryCloudStorageFileSet[];
    /**
     * output_path block.
     *
     * @stability stable
     */
    readonly outputPath: DataLossPreventionStoredInfoTypeLargeCustomDictionaryOutputPath[];
}
/**
 * @stability stable
 */
export interface DataLossPreventionStoredInfoTypeRegex {
    /**
     * The index of the submatch to extract as findings.
     *
     * When not specified, the entire match is returned. No more than 3 may be included.
     *
     * @stability stable
     */
    readonly groupIndexes?: number[];
    /**
     * Pattern defining the regular expression.
     *
     * Its syntax (https://github.com/google/re2/wiki/Syntax) can be found under the google/re2 repository on GitHub.
     *
     * @stability stable
     */
    readonly pattern: string;
}
/**
 * @stability stable
 */
export interface DataLossPreventionStoredInfoTypeTimeouts {
    /**
     * @stability stable
     */
    readonly create?: string;
    /**
     * @stability stable
     */
    readonly delete?: string;
    /**
     * @stability stable
     */
    readonly update?: string;
}
/**
 * @stability stable
 */
export declare class DataLossPreventionStoredInfoType extends cdktf.TerraformResource {
    /**
     * @stability stable
     */
    constructor(scope: Construct, id: string, config: DataLossPreventionStoredInfoTypeConfig);
    private _description?;
    /**
     * @stability stable
     */
    get description(): string;
    /**
     * @stability stable
     */
    set description(value: string);
    /**
     * @stability stable
     */
    resetDescription(): void;
    /**
     * @stability stable
     */
    get descriptionInput(): string | undefined;
    private _displayName?;
    /**
     * @stability stable
     */
    get displayName(): string;
    /**
     * @stability stable
     */
    set displayName(value: string);
    /**
     * @stability stable
     */
    resetDisplayName(): void;
    /**
     * @stability stable
     */
    get displayNameInput(): string | undefined;
    /**
     * @stability stable
     */
    get id(): string;
    /**
     * @stability stable
     */
    get name(): string;
    private _parent;
    /**
     * @stability stable
     */
    get parent(): string;
    /**
     * @stability stable
     */
    set parent(value: string);
    /**
     * @stability stable
     */
    get parentInput(): string;
    private _dictionary?;
    /**
     * @stability stable
     */
    get dictionary(): DataLossPreventionStoredInfoTypeDictionary[];
    /**
     * @stability stable
     */
    set dictionary(value: DataLossPreventionStoredInfoTypeDictionary[]);
    /**
     * @stability stable
     */
    resetDictionary(): void;
    /**
     * @stability stable
     */
    get dictionaryInput(): DataLossPreventionStoredInfoTypeDictionary[] | undefined;
    private _largeCustomDictionary?;
    /**
     * @stability stable
     */
    get largeCustomDictionary(): DataLossPreventionStoredInfoTypeLargeCustomDictionary[];
    /**
     * @stability stable
     */
    set largeCustomDictionary(value: DataLossPreventionStoredInfoTypeLargeCustomDictionary[]);
    /**
     * @stability stable
     */
    resetLargeCustomDictionary(): void;
    /**
     * @stability stable
     */
    get largeCustomDictionaryInput(): DataLossPreventionStoredInfoTypeLargeCustomDictionary[] | undefined;
    private _regex?;
    /**
     * @stability stable
     */
    get regex(): DataLossPreventionStoredInfoTypeRegex[];
    /**
     * @stability stable
     */
    set regex(value: DataLossPreventionStoredInfoTypeRegex[]);
    /**
     * @stability stable
     */
    resetRegex(): void;
    /**
     * @stability stable
     */
    get regexInput(): DataLossPreventionStoredInfoTypeRegex[] | undefined;
    private _timeouts?;
    /**
     * @stability stable
     */
    get timeouts(): DataLossPreventionStoredInfoTypeTimeouts;
    /**
     * @stability stable
     */
    set timeouts(value: DataLossPreventionStoredInfoTypeTimeouts);
    /**
     * @stability stable
     */
    resetTimeouts(): void;
    /**
     * @stability stable
     */
    get timeoutsInput(): DataLossPreventionStoredInfoTypeTimeouts | undefined;
    /**
     * @stability stable
     */
    protected synthesizeAttributes(): {
        [name: string]: any;
    };
}
