import { Construct } from 'constructs';
import * as cdktf from 'cdktf';
/**
 * @stability stable
 */
export interface DataprocClusterConfig extends cdktf.TerraformMetaArguments {
    /**
     * The timeout duration which allows graceful decomissioning when you change the number of worker nodes directly through a terraform apply.
     *
     * @stability stable
     */
    readonly gracefulDecommissionTimeout?: string;
    /**
     * The list of labels (key/value pairs) to be applied to instances in the cluster.
     *
     * GCP generates some itself including goog-dataproc-cluster-name which is the name of the cluster.
     *
     * @stability stable
     */
    readonly labels?: {
        [key: string]: string;
    };
    /**
     * The name of the cluster, unique within the project and zone.
     *
     * @stability stable
     */
    readonly name: string;
    /**
     * The ID of the project in which the cluster will exist.
     *
     * If it is not provided, the provider project is used.
     *
     * @stability stable
     */
    readonly project?: string;
    /**
     * The region in which the cluster and associated nodes will be created in.
     *
     * Defaults to global.
     *
     * @stability stable
     */
    readonly region?: string;
    /**
     * cluster_config block.
     *
     * @stability stable
     */
    readonly clusterConfig?: DataprocClusterClusterConfig[];
    /**
     * timeouts block.
     *
     * @stability stable
     */
    readonly timeouts?: DataprocClusterTimeouts;
}
/**
 * @stability stable
 */
export interface DataprocClusterClusterConfigAutoscalingConfig {
    /**
     * The autoscaling policy used by the cluster.
     *
     * @stability stable
     */
    readonly policyUri: string;
}
/**
 * @stability stable
 */
export interface DataprocClusterClusterConfigEncryptionConfig {
    /**
     * The Cloud KMS key name to use for PD disk encryption for all instances in the cluster.
     *
     * @stability stable
     */
    readonly kmsKeyName: string;
}
/**
 * @stability stable
 */
export interface DataprocClusterClusterConfigGceClusterConfig {
    /**
     * By default, clusters are not restricted to internal IP addresses, and will have ephemeral external IP addresses assigned to each instance.
     *
     * If set to true, all instances in the cluster will only have internal IP addresses. Note: Private Google Access (also known as privateIpGoogleAccess) must be enabled on the subnetwork that the cluster will be launched in.
     *
     * @stability stable
     */
    readonly internalIpOnly?: boolean;
    /**
     * A map of the Compute Engine metadata entries to add to all instances.
     *
     * @stability stable
     */
    readonly metadata?: {
        [key: string]: string;
    };
    /**
     * The name or self_link of the Google Compute Engine network to the cluster will be part of.
     *
     * Conflicts with subnetwork. If neither is specified, this defaults to the "default" network.
     *
     * @stability stable
     */
    readonly network?: string;
    /**
     * The service account to be used by the Node VMs.
     *
     * If not specified, the "default" service account is used.
     *
     * @stability stable
     */
    readonly serviceAccount?: string;
    /**
     * The set of Google API scopes to be made available on all of the node VMs under the service_account specified.
     *
     * These can be either FQDNs, or scope aliases.
     *
     * @stability stable
     */
    readonly serviceAccountScopes?: string[];
    /**
     * The name or self_link of the Google Compute Engine subnetwork the cluster will be part of.
     *
     * Conflicts with network.
     *
     * @stability stable
     */
    readonly subnetwork?: string;
    /**
     * The list of instance tags applied to instances in the cluster.
     *
     * Tags are used to identify valid sources or targets for network firewalls.
     *
     * @stability stable
     */
    readonly tags?: string[];
    /**
     * The GCP zone where your data is stored and used (i.e. where the master and the worker nodes will be created in). If region is set to 'global' (default) then zone is mandatory, otherwise GCP is able to make use of Auto Zone Placement to determine this automatically for you. Note: This setting additionally determines and restricts which computing resources are available for use with other configs such as cluster_config.master_config.machine_type and cluster_config.worker_config.machine_type.
     *
     * @stability stable
     */
    readonly zone?: string;
}
/**
 * @stability stable
 */
export interface DataprocClusterClusterConfigInitializationAction {
    /**
     * The script to be executed during initialization of the cluster.
     *
     * The script must be a GCS file with a gs:// prefix.
     *
     * @stability stable
     */
    readonly script: string;
    /**
     * The maximum duration (in seconds) which script is allowed to take to execute its action.
     *
     * GCP will default to a predetermined computed value if not set (currently 300).
     *
     * @stability stable
     */
    readonly timeoutSec?: number;
}
/**
 * @stability stable
 */
export interface DataprocClusterClusterConfigMasterConfigAccelerators {
    /**
     * The number of the accelerator cards of this type exposed to this instance.
     *
     * Often restricted to one of 1, 2, 4, or 8.
     *
     * @stability stable
     */
    readonly acceleratorCount: number;
    /**
     * The short name of the accelerator type to expose to this instance.
     *
     * For example, nvidia-tesla-k80.
     *
     * @stability stable
     */
    readonly acceleratorType: string;
}
/**
 * @stability stable
 */
export interface DataprocClusterClusterConfigMasterConfigDiskConfig {
    /**
     * Size of the primary disk attached to each node, specified in GB.
     *
     * The primary disk contains the boot volume and system libraries, and the smallest allowed disk size is 10GB. GCP will default to a predetermined computed value if not set (currently 500GB). Note: If SSDs are not attached, it also contains the HDFS data blocks and Hadoop working directories.
     *
     * @stability stable
     */
    readonly bootDiskSizeGb?: number;
    /**
     * The disk type of the primary disk attached to each node.
     *
     * One of "pd-ssd" or "pd-standard". Defaults to "pd-standard".
     *
     * @stability stable
     */
    readonly bootDiskType?: string;
    /**
     * The amount of local SSD disks that will be attached to each master cluster node.
     *
     * Defaults to 0.
     *
     * @stability stable
     */
    readonly numLocalSsds?: number;
}
/**
 * @stability stable
 */
export interface DataprocClusterClusterConfigMasterConfig {
    /**
     * The URI for the image to use for this master/worker.
     *
     * @stability stable
     */
    readonly imageUri?: string;
    /**
     * The name of a Google Compute Engine machine type to create for the master/worker.
     *
     * @stability stable
     */
    readonly machineType?: string;
    /**
     * The name of a minimum generation of CPU family for the master/worker.
     *
     * If not specified, GCP will default to a predetermined computed value for each zone.
     *
     * @stability stable
     */
    readonly minCpuPlatform?: string;
    /**
     * Specifies the number of master/worker nodes to create.
     *
     * If not specified, GCP will default to a predetermined computed value.
     *
     * @stability stable
     */
    readonly numInstances?: number;
    /**
     * accelerators block.
     *
     * @stability stable
     */
    readonly accelerators?: DataprocClusterClusterConfigMasterConfigAccelerators[];
    /**
     * disk_config block.
     *
     * @stability stable
     */
    readonly diskConfig?: DataprocClusterClusterConfigMasterConfigDiskConfig[];
}
/**
 * @stability stable
 */
export interface DataprocClusterClusterConfigPreemptibleWorkerConfigDiskConfig {
    /**
     * Size of the primary disk attached to each preemptible worker node, specified in GB.
     *
     * The smallest allowed disk size is 10GB. GCP will default to a predetermined computed value if not set (currently 500GB). Note: If SSDs are not attached, it also contains the HDFS data blocks and Hadoop working directories.
     *
     * @stability stable
     */
    readonly bootDiskSizeGb?: number;
    /**
     * The disk type of the primary disk attached to each preemptible worker node.
     *
     * One of "pd-ssd" or "pd-standard". Defaults to "pd-standard".
     *
     * @stability stable
     */
    readonly bootDiskType?: string;
    /**
     * The amount of local SSD disks that will be attached to each preemptible worker node.
     *
     * Defaults to 0.
     *
     * @stability stable
     */
    readonly numLocalSsds?: number;
}
/**
 * @stability stable
 */
export interface DataprocClusterClusterConfigPreemptibleWorkerConfig {
    /**
     * Specifies the number of preemptible nodes to create.
     *
     * Defaults to 0.
     *
     * @stability stable
     */
    readonly numInstances?: number;
    /**
     * disk_config block.
     *
     * @stability stable
     */
    readonly diskConfig?: DataprocClusterClusterConfigPreemptibleWorkerConfigDiskConfig[];
}
/**
 * @stability stable
 */
export interface DataprocClusterClusterConfigSecurityConfigKerberosConfig {
    /**
     * The admin server (IP or hostname) for the remote trusted realm in a cross realm trust relationship.
     *
     * @stability stable
     */
    readonly crossRealmTrustAdminServer?: string;
    /**
     * The KDC (IP or hostname) for the remote trusted realm in a cross realm trust relationship.
     *
     * @stability stable
     */
    readonly crossRealmTrustKdc?: string;
    /**
     * The remote realm the Dataproc on-cluster KDC will trust, should the user enable cross realm trust.
     *
     * @stability stable
     */
    readonly crossRealmTrustRealm?: string;
    /**
     * The Cloud Storage URI of a KMS encrypted file containing the shared password between the on-cluster Kerberos realm and the remote trusted realm, in a cross realm trust relationship.
     *
     * @stability stable
     */
    readonly crossRealmTrustSharedPasswordUri?: string;
    /**
     * Flag to indicate whether to Kerberize the cluster.
     *
     * @stability stable
     */
    readonly enableKerberos?: boolean;
    /**
     * The Cloud Storage URI of a KMS encrypted file containing the master key of the KDC database.
     *
     * @stability stable
     */
    readonly kdcDbKeyUri?: string;
    /**
     * The Cloud Storage URI of a KMS encrypted file containing the password to the user provided key.
     *
     * For the self-signed certificate, this password is generated by Dataproc.
     *
     * @stability stable
     */
    readonly keyPasswordUri?: string;
    /**
     * The Cloud Storage URI of a KMS encrypted file containing the password to the user provided keystore.
     *
     * For the self-signed certificate, this password is generated
     * by Dataproc
     *
     * @stability stable
     */
    readonly keystorePasswordUri?: string;
    /**
     * The Cloud Storage URI of the keystore file used for SSL encryption.
     *
     * If not provided, Dataproc will provide a self-signed certificate.
     *
     * @stability stable
     */
    readonly keystoreUri?: string;
    /**
     * The uri of the KMS key used to encrypt various sensitive files.
     *
     * @stability stable
     */
    readonly kmsKeyUri: string;
    /**
     * The name of the on-cluster Kerberos realm.
     *
     * If not specified, the uppercased domain of hostnames will be the realm.
     *
     * @stability stable
     */
    readonly realm?: string;
    /**
     * The cloud Storage URI of a KMS encrypted file containing the root principal password.
     *
     * @stability stable
     */
    readonly rootPrincipalPasswordUri: string;
    /**
     * The lifetime of the ticket granting ticket, in hours.
     *
     * @stability stable
     */
    readonly tgtLifetimeHours?: number;
    /**
     * The Cloud Storage URI of a KMS encrypted file containing the password to the user provided truststore.
     *
     * For the self-signed certificate, this password is generated by Dataproc.
     *
     * @stability stable
     */
    readonly truststorePasswordUri?: string;
    /**
     * The Cloud Storage URI of the truststore file used for SSL encryption.
     *
     * If not provided, Dataproc will provide a self-signed certificate.
     *
     * @stability stable
     */
    readonly truststoreUri?: string;
}
/**
 * @stability stable
 */
export interface DataprocClusterClusterConfigSecurityConfig {
    /**
     * kerberos_config block.
     *
     * @stability stable
     */
    readonly kerberosConfig: DataprocClusterClusterConfigSecurityConfigKerberosConfig[];
}
/**
 * @stability stable
 */
export interface DataprocClusterClusterConfigSoftwareConfig {
    /**
     * The Cloud Dataproc image version to use for the cluster - this controls the sets of software versions installed onto the nodes when you create clusters.
     *
     * If not specified, defaults to the latest version.
     *
     * @stability stable
     */
    readonly imageVersion?: string;
    /**
     * The set of optional components to activate on the cluster.
     *
     * @stability stable
     */
    readonly optionalComponents?: string[];
    /**
     * A list of override and additional properties (key/value pairs) used to modify various aspects of the common configuration files used when creating a cluster.
     *
     * @stability stable
     */
    readonly overrideProperties?: {
        [key: string]: string;
    };
}
/**
 * @stability stable
 */
export interface DataprocClusterClusterConfigWorkerConfigAccelerators {
    /**
     * The number of the accelerator cards of this type exposed to this instance.
     *
     * Often restricted to one of 1, 2, 4, or 8.
     *
     * @stability stable
     */
    readonly acceleratorCount: number;
    /**
     * The short name of the accelerator type to expose to this instance.
     *
     * For example, nvidia-tesla-k80.
     *
     * @stability stable
     */
    readonly acceleratorType: string;
}
/**
 * @stability stable
 */
export interface DataprocClusterClusterConfigWorkerConfigDiskConfig {
    /**
     * Size of the primary disk attached to each node, specified in GB.
     *
     * The primary disk contains the boot volume and system libraries, and the smallest allowed disk size is 10GB. GCP will default to a predetermined computed value if not set (currently 500GB). Note: If SSDs are not attached, it also contains the HDFS data blocks and Hadoop working directories.
     *
     * @stability stable
     */
    readonly bootDiskSizeGb?: number;
    /**
     * The disk type of the primary disk attached to each node.
     *
     * One of "pd-ssd" or "pd-standard". Defaults to "pd-standard".
     *
     * @stability stable
     */
    readonly bootDiskType?: string;
    /**
     * The amount of local SSD disks that will be attached to each master cluster node.
     *
     * Defaults to 0.
     *
     * @stability stable
     */
    readonly numLocalSsds?: number;
}
/**
 * @stability stable
 */
export interface DataprocClusterClusterConfigWorkerConfig {
    /**
     * The URI for the image to use for this master/worker.
     *
     * @stability stable
     */
    readonly imageUri?: string;
    /**
     * The name of a Google Compute Engine machine type to create for the master/worker.
     *
     * @stability stable
     */
    readonly machineType?: string;
    /**
     * The name of a minimum generation of CPU family for the master/worker.
     *
     * If not specified, GCP will default to a predetermined computed value for each zone.
     *
     * @stability stable
     */
    readonly minCpuPlatform?: string;
    /**
     * Specifies the number of master/worker nodes to create.
     *
     * If not specified, GCP will default to a predetermined computed value.
     *
     * @stability stable
     */
    readonly numInstances?: number;
    /**
     * accelerators block.
     *
     * @stability stable
     */
    readonly accelerators?: DataprocClusterClusterConfigWorkerConfigAccelerators[];
    /**
     * disk_config block.
     *
     * @stability stable
     */
    readonly diskConfig?: DataprocClusterClusterConfigWorkerConfigDiskConfig[];
}
/**
 * @stability stable
 */
export interface DataprocClusterClusterConfig {
    /**
     * The Cloud Storage staging bucket used to stage files, such as Hadoop jars, between client machines and the cluster.
     *
     * Note: If you don't explicitly specify a staging_bucket then GCP will auto create / assign one for you. However, you are not guaranteed an auto generated bucket which is solely dedicated to your cluster; it may be shared with other clusters in the same region/zone also choosing to use the auto generation option.
     *
     * @stability stable
     */
    readonly stagingBucket?: string;
    /**
     * autoscaling_config block.
     *
     * @stability stable
     */
    readonly autoscalingConfig?: DataprocClusterClusterConfigAutoscalingConfig[];
    /**
     * encryption_config block.
     *
     * @stability stable
     */
    readonly encryptionConfig?: DataprocClusterClusterConfigEncryptionConfig[];
    /**
     * gce_cluster_config block.
     *
     * @stability stable
     */
    readonly gceClusterConfig?: DataprocClusterClusterConfigGceClusterConfig[];
    /**
     * initialization_action block.
     *
     * @stability stable
     */
    readonly initializationAction?: DataprocClusterClusterConfigInitializationAction[];
    /**
     * master_config block.
     *
     * @stability stable
     */
    readonly masterConfig?: DataprocClusterClusterConfigMasterConfig[];
    /**
     * preemptible_worker_config block.
     *
     * @stability stable
     */
    readonly preemptibleWorkerConfig?: DataprocClusterClusterConfigPreemptibleWorkerConfig[];
    /**
     * security_config block.
     *
     * @stability stable
     */
    readonly securityConfig?: DataprocClusterClusterConfigSecurityConfig[];
    /**
     * software_config block.
     *
     * @stability stable
     */
    readonly softwareConfig?: DataprocClusterClusterConfigSoftwareConfig[];
    /**
     * worker_config block.
     *
     * @stability stable
     */
    readonly workerConfig?: DataprocClusterClusterConfigWorkerConfig[];
}
/**
 * @stability stable
 */
export interface DataprocClusterTimeouts {
    /**
     * @stability stable
     */
    readonly create?: string;
    /**
     * @stability stable
     */
    readonly delete?: string;
    /**
     * @stability stable
     */
    readonly update?: string;
}
/**
 * @stability stable
 */
export declare class DataprocCluster extends cdktf.TerraformResource {
    /**
     * @stability stable
     */
    constructor(scope: Construct, id: string, config: DataprocClusterConfig);
    private _gracefulDecommissionTimeout?;
    /**
     * @stability stable
     */
    get gracefulDecommissionTimeout(): string;
    /**
     * @stability stable
     */
    set gracefulDecommissionTimeout(value: string);
    /**
     * @stability stable
     */
    resetGracefulDecommissionTimeout(): void;
    /**
     * @stability stable
     */
    get gracefulDecommissionTimeoutInput(): string | undefined;
    /**
     * @stability stable
     */
    get id(): string;
    private _labels?;
    /**
     * @stability stable
     */
    get labels(): {
        [key: string]: string;
    };
    /**
     * @stability stable
     */
    set labels(value: {
        [key: string]: string;
    });
    /**
     * @stability stable
     */
    resetLabels(): void;
    /**
     * @stability stable
     */
    get labelsInput(): {
        [key: string]: string;
    } | undefined;
    private _name;
    /**
     * @stability stable
     */
    get name(): string;
    /**
     * @stability stable
     */
    set name(value: string);
    /**
     * @stability stable
     */
    get nameInput(): string;
    private _project?;
    /**
     * @stability stable
     */
    get project(): string;
    /**
     * @stability stable
     */
    set project(value: string);
    /**
     * @stability stable
     */
    resetProject(): void;
    /**
     * @stability stable
     */
    get projectInput(): string | undefined;
    private _region?;
    /**
     * @stability stable
     */
    get region(): string;
    /**
     * @stability stable
     */
    set region(value: string);
    /**
     * @stability stable
     */
    resetRegion(): void;
    /**
     * @stability stable
     */
    get regionInput(): string | undefined;
    private _clusterConfig?;
    /**
     * @stability stable
     */
    get clusterConfig(): DataprocClusterClusterConfig[];
    /**
     * @stability stable
     */
    set clusterConfig(value: DataprocClusterClusterConfig[]);
    /**
     * @stability stable
     */
    resetClusterConfig(): void;
    /**
     * @stability stable
     */
    get clusterConfigInput(): DataprocClusterClusterConfig[] | undefined;
    private _timeouts?;
    /**
     * @stability stable
     */
    get timeouts(): DataprocClusterTimeouts;
    /**
     * @stability stable
     */
    set timeouts(value: DataprocClusterTimeouts);
    /**
     * @stability stable
     */
    resetTimeouts(): void;
    /**
     * @stability stable
     */
    get timeoutsInput(): DataprocClusterTimeouts | undefined;
    /**
     * @stability stable
     */
    protected synthesizeAttributes(): {
        [name: string]: any;
    };
}
