import { Construct } from 'constructs';
import * as cdktf from 'cdktf';
/**
 * @stability stable
 */
export interface DatastoreIndexConfig extends cdktf.TerraformMetaArguments {
    /**
     * Policy for including ancestors in the index.
     *
     * Default value: "NONE" Possible values: ["NONE", "ALL_ANCESTORS"]
     *
     * @stability stable
     */
    readonly ancestor?: string;
    /**
     * The entity kind which the index applies to.
     *
     * @stability stable
     */
    readonly kind: string;
    /**
     * @stability stable
     */
    readonly project?: string;
    /**
     * properties block.
     *
     * @stability stable
     */
    readonly properties?: DatastoreIndexProperties[];
    /**
     * timeouts block.
     *
     * @stability stable
     */
    readonly timeouts?: DatastoreIndexTimeouts;
}
/**
 * @stability stable
 */
export interface DatastoreIndexProperties {
    /**
     * The direction the index should optimize for sorting.
     *
     * Possible values: ["ASCENDING", "DESCENDING"]
     *
     * @stability stable
     */
    readonly direction: string;
    /**
     * The property name to index.
     *
     * @stability stable
     */
    readonly name: string;
}
/**
 * @stability stable
 */
export interface DatastoreIndexTimeouts {
    /**
     * @stability stable
     */
    readonly create?: string;
    /**
     * @stability stable
     */
    readonly delete?: string;
}
/**
 * @stability stable
 */
export declare class DatastoreIndex extends cdktf.TerraformResource {
    /**
     * @stability stable
     */
    constructor(scope: Construct, id: string, config: DatastoreIndexConfig);
    private _ancestor?;
    /**
     * @stability stable
     */
    get ancestor(): string;
    /**
     * @stability stable
     */
    set ancestor(value: string);
    /**
     * @stability stable
     */
    resetAncestor(): void;
    /**
     * @stability stable
     */
    get ancestorInput(): string | undefined;
    /**
     * @stability stable
     */
    get id(): string;
    /**
     * @stability stable
     */
    get indexId(): string;
    private _kind;
    /**
     * @stability stable
     */
    get kind(): string;
    /**
     * @stability stable
     */
    set kind(value: string);
    /**
     * @stability stable
     */
    get kindInput(): string;
    private _project?;
    /**
     * @stability stable
     */
    get project(): string;
    /**
     * @stability stable
     */
    set project(value: string);
    /**
     * @stability stable
     */
    resetProject(): void;
    /**
     * @stability stable
     */
    get projectInput(): string | undefined;
    private _properties?;
    /**
     * @stability stable
     */
    get properties(): DatastoreIndexProperties[];
    /**
     * @stability stable
     */
    set properties(value: DatastoreIndexProperties[]);
    /**
     * @stability stable
     */
    resetProperties(): void;
    /**
     * @stability stable
     */
    get propertiesInput(): DatastoreIndexProperties[] | undefined;
    private _timeouts?;
    /**
     * @stability stable
     */
    get timeouts(): DatastoreIndexTimeouts;
    /**
     * @stability stable
     */
    set timeouts(value: DatastoreIndexTimeouts);
    /**
     * @stability stable
     */
    resetTimeouts(): void;
    /**
     * @stability stable
     */
    get timeoutsInput(): DatastoreIndexTimeouts | undefined;
    /**
     * @stability stable
     */
    protected synthesizeAttributes(): {
        [name: string]: any;
    };
}
