import { Construct } from 'constructs';
import * as cdktf from 'cdktf';
/**
 * @stability stable
 */
export interface FirestoreDocumentConfig extends cdktf.TerraformMetaArguments {
    /**
     * The collection ID, relative to database.
     *
     * For example: chatrooms or chatrooms/my-document/private-messages.
     *
     * @stability stable
     */
    readonly collection: string;
    /**
     * The Firestore database id.
     *
     * Defaults to '"(default)"'.
     *
     * @stability stable
     */
    readonly database?: string;
    /**
     * The client-assigned document ID to use for this document during creation.
     *
     * @stability stable
     */
    readonly documentId: string;
    /**
     * The document's [fields](https://cloud.google.com/firestore/docs/reference/rest/v1/projects.databases.documents) formated as a json string.
     *
     * @stability stable
     */
    readonly fields: string;
    /**
     * @stability stable
     */
    readonly project?: string;
    /**
     * timeouts block.
     *
     * @stability stable
     */
    readonly timeouts?: FirestoreDocumentTimeouts;
}
/**
 * @stability stable
 */
export interface FirestoreDocumentTimeouts {
    /**
     * @stability stable
     */
    readonly create?: string;
    /**
     * @stability stable
     */
    readonly delete?: string;
    /**
     * @stability stable
     */
    readonly update?: string;
}
/**
 * @stability stable
 */
export declare class FirestoreDocument extends cdktf.TerraformResource {
    /**
     * @stability stable
     */
    constructor(scope: Construct, id: string, config: FirestoreDocumentConfig);
    private _collection;
    /**
     * @stability stable
     */
    get collection(): string;
    /**
     * @stability stable
     */
    set collection(value: string);
    /**
     * @stability stable
     */
    get collectionInput(): string;
    /**
     * @stability stable
     */
    get createTime(): string;
    private _database?;
    /**
     * @stability stable
     */
    get database(): string;
    /**
     * @stability stable
     */
    set database(value: string);
    /**
     * @stability stable
     */
    resetDatabase(): void;
    /**
     * @stability stable
     */
    get databaseInput(): string | undefined;
    private _documentId;
    /**
     * @stability stable
     */
    get documentId(): string;
    /**
     * @stability stable
     */
    set documentId(value: string);
    /**
     * @stability stable
     */
    get documentIdInput(): string;
    private _fields;
    /**
     * @stability stable
     */
    get fields(): string;
    /**
     * @stability stable
     */
    set fields(value: string);
    /**
     * @stability stable
     */
    get fieldsInput(): string;
    /**
     * @stability stable
     */
    get id(): string;
    /**
     * @stability stable
     */
    get name(): string;
    /**
     * @stability stable
     */
    get path(): string;
    private _project?;
    /**
     * @stability stable
     */
    get project(): string;
    /**
     * @stability stable
     */
    set project(value: string);
    /**
     * @stability stable
     */
    resetProject(): void;
    /**
     * @stability stable
     */
    get projectInput(): string | undefined;
    /**
     * @stability stable
     */
    get updateTime(): string;
    private _timeouts?;
    /**
     * @stability stable
     */
    get timeouts(): FirestoreDocumentTimeouts;
    /**
     * @stability stable
     */
    set timeouts(value: FirestoreDocumentTimeouts);
    /**
     * @stability stable
     */
    resetTimeouts(): void;
    /**
     * @stability stable
     */
    get timeoutsInput(): FirestoreDocumentTimeouts | undefined;
    /**
     * @stability stable
     */
    protected synthesizeAttributes(): {
        [name: string]: any;
    };
}
