import { Construct } from 'constructs';
import * as cdktf from 'cdktf';
/**
 * @stability stable
 */
export interface FirestoreIndexConfig extends cdktf.TerraformMetaArguments {
    /**
     * The collection being indexed.
     *
     * @stability stable
     */
    readonly collection: string;
    /**
     * The Firestore database id.
     *
     * Defaults to '"(default)"'.
     *
     * @stability stable
     */
    readonly database?: string;
    /**
     * @stability stable
     */
    readonly project?: string;
    /**
     * The scope at which a query is run.
     *
     * Default value: "COLLECTION" Possible values: ["COLLECTION", "COLLECTION_GROUP"]
     *
     * @stability stable
     */
    readonly queryScope?: string;
    /**
     * fields block.
     *
     * @stability stable
     */
    readonly fields: FirestoreIndexFields[];
    /**
     * timeouts block.
     *
     * @stability stable
     */
    readonly timeouts?: FirestoreIndexTimeouts;
}
/**
 * @stability stable
 */
export interface FirestoreIndexFields {
    /**
     * Indicates that this field supports operations on arrayValues.
     *
     * Only one of 'order' and 'arrayConfig' can
     * be specified. Possible values: ["CONTAINS"]
     *
     * @stability stable
     */
    readonly arrayConfig?: string;
    /**
     * Name of the field.
     *
     * @stability stable
     */
    readonly fieldPath?: string;
    /**
     * Indicates that this field supports ordering by the specified order or comparing using =, <, <=, >, >=.
     *
     * Only one of 'order' and 'arrayConfig' can be specified. Possible values: ["ASCENDING", "DESCENDING"]
     *
     * @stability stable
     */
    readonly order?: string;
}
/**
 * @stability stable
 */
export interface FirestoreIndexTimeouts {
    /**
     * @stability stable
     */
    readonly create?: string;
    /**
     * @stability stable
     */
    readonly delete?: string;
}
/**
 * @stability stable
 */
export declare class FirestoreIndex extends cdktf.TerraformResource {
    /**
     * @stability stable
     */
    constructor(scope: Construct, id: string, config: FirestoreIndexConfig);
    private _collection;
    /**
     * @stability stable
     */
    get collection(): string;
    /**
     * @stability stable
     */
    set collection(value: string);
    /**
     * @stability stable
     */
    get collectionInput(): string;
    private _database?;
    /**
     * @stability stable
     */
    get database(): string;
    /**
     * @stability stable
     */
    set database(value: string);
    /**
     * @stability stable
     */
    resetDatabase(): void;
    /**
     * @stability stable
     */
    get databaseInput(): string | undefined;
    /**
     * @stability stable
     */
    get id(): string;
    /**
     * @stability stable
     */
    get name(): string;
    private _project?;
    /**
     * @stability stable
     */
    get project(): string;
    /**
     * @stability stable
     */
    set project(value: string);
    /**
     * @stability stable
     */
    resetProject(): void;
    /**
     * @stability stable
     */
    get projectInput(): string | undefined;
    private _queryScope?;
    /**
     * @stability stable
     */
    get queryScope(): string;
    /**
     * @stability stable
     */
    set queryScope(value: string);
    /**
     * @stability stable
     */
    resetQueryScope(): void;
    /**
     * @stability stable
     */
    get queryScopeInput(): string | undefined;
    private _fields;
    /**
     * @stability stable
     */
    get fields(): FirestoreIndexFields[];
    /**
     * @stability stable
     */
    set fields(value: FirestoreIndexFields[]);
    /**
     * @stability stable
     */
    get fieldsInput(): FirestoreIndexFields[];
    private _timeouts?;
    /**
     * @stability stable
     */
    get timeouts(): FirestoreIndexTimeouts;
    /**
     * @stability stable
     */
    set timeouts(value: FirestoreIndexTimeouts);
    /**
     * @stability stable
     */
    resetTimeouts(): void;
    /**
     * @stability stable
     */
    get timeoutsInput(): FirestoreIndexTimeouts | undefined;
    /**
     * @stability stable
     */
    protected synthesizeAttributes(): {
        [name: string]: any;
    };
}
