import { Construct } from 'constructs';
import * as cdktf from 'cdktf';
/**
 * @stability stable
 */
export interface FolderAccessApprovalSettingsConfig extends cdktf.TerraformMetaArguments {
    /**
     * ID of the folder of the access approval settings.
     *
     * @stability stable
     */
    readonly folderId: string;
    /**
     * A list of email addresses to which notifications relating to approval requests should be sent.
     *
     * Notifications relating to a resource will be sent to all emails in the settings of ancestor
     * resources of that resource. A maximum of 50 email addresses are allowed.
     *
     * @stability stable
     */
    readonly notificationEmails?: string[];
    /**
     * enrolled_services block.
     *
     * @stability stable
     */
    readonly enrolledServices: FolderAccessApprovalSettingsEnrolledServices[];
    /**
     * timeouts block.
     *
     * @stability stable
     */
    readonly timeouts?: FolderAccessApprovalSettingsTimeouts;
}
/**
 * @stability stable
 */
export interface FolderAccessApprovalSettingsEnrolledServices {
    /**
     * The product for which Access Approval will be enrolled.
     *
     * Allowed values are listed (case-sensitive):
     * all
     * App Engine
     * BigQuery
     * Cloud Bigtable
     * Cloud Key Management Service
     * Compute Engine
     * Cloud Dataflow
     * Cloud Identity and Access Management
     * Cloud Pub/Sub
     * Cloud Storage
     * Persistent Disk
     *
     * Note: These values are supported as input, but considered a legacy format:
     * all
     * appengine.googleapis.com
     * bigquery.googleapis.com
     * bigtable.googleapis.com
     * cloudkms.googleapis.com
     * compute.googleapis.com
     * dataflow.googleapis.com
     * iam.googleapis.com
     * pubsub.googleapis.com
     * storage.googleapis.com
     *
     * @stability stable
     */
    readonly cloudProduct: string;
    /**
     * The enrollment level of the service.
     *
     * Default value: "BLOCK_ALL" Possible values: ["BLOCK_ALL"]
     *
     * @stability stable
     */
    readonly enrollmentLevel?: string;
}
/**
 * @stability stable
 */
export interface FolderAccessApprovalSettingsTimeouts {
    /**
     * @stability stable
     */
    readonly create?: string;
    /**
     * @stability stable
     */
    readonly delete?: string;
    /**
     * @stability stable
     */
    readonly update?: string;
}
/**
 * @stability stable
 */
export declare class FolderAccessApprovalSettings extends cdktf.TerraformResource {
    /**
     * @stability stable
     */
    constructor(scope: Construct, id: string, config: FolderAccessApprovalSettingsConfig);
    /**
     * @stability stable
     */
    get enrolledAncestor(): boolean;
    private _folderId;
    /**
     * @stability stable
     */
    get folderId(): string;
    /**
     * @stability stable
     */
    set folderId(value: string);
    /**
     * @stability stable
     */
    get folderIdInput(): string;
    /**
     * @stability stable
     */
    get id(): string;
    /**
     * @stability stable
     */
    get name(): string;
    private _notificationEmails?;
    /**
     * @stability stable
     */
    get notificationEmails(): string[];
    /**
     * @stability stable
     */
    set notificationEmails(value: string[]);
    /**
     * @stability stable
     */
    resetNotificationEmails(): void;
    /**
     * @stability stable
     */
    get notificationEmailsInput(): string[] | undefined;
    private _enrolledServices;
    /**
     * @stability stable
     */
    get enrolledServices(): FolderAccessApprovalSettingsEnrolledServices[];
    /**
     * @stability stable
     */
    set enrolledServices(value: FolderAccessApprovalSettingsEnrolledServices[]);
    /**
     * @stability stable
     */
    get enrolledServicesInput(): FolderAccessApprovalSettingsEnrolledServices[];
    private _timeouts?;
    /**
     * @stability stable
     */
    get timeouts(): FolderAccessApprovalSettingsTimeouts;
    /**
     * @stability stable
     */
    set timeouts(value: FolderAccessApprovalSettingsTimeouts);
    /**
     * @stability stable
     */
    resetTimeouts(): void;
    /**
     * @stability stable
     */
    get timeoutsInput(): FolderAccessApprovalSettingsTimeouts | undefined;
    /**
     * @stability stable
     */
    protected synthesizeAttributes(): {
        [name: string]: any;
    };
}
