import { Construct } from 'constructs';
import * as cdktf from 'cdktf';
/**
 * @stability stable
 */
export interface FolderOrganizationPolicyConfig extends cdktf.TerraformMetaArguments {
    /**
     * The name of the Constraint the Policy is configuring, for example, serviceuser.services.
     *
     * @stability stable
     */
    readonly constraint: string;
    /**
     * The resource name of the folder to set the policy for.
     *
     * Its format is folders/{folder_id}.
     *
     * @stability stable
     */
    readonly folder: string;
    /**
     * Version of the Policy.
     *
     * Default version is 0.
     *
     * @stability stable
     */
    readonly version?: number;
    /**
     * boolean_policy block.
     *
     * @stability stable
     */
    readonly booleanPolicy?: FolderOrganizationPolicyBooleanPolicy[];
    /**
     * list_policy block.
     *
     * @stability stable
     */
    readonly listPolicy?: FolderOrganizationPolicyListPolicy[];
    /**
     * restore_policy block.
     *
     * @stability stable
     */
    readonly restorePolicy?: FolderOrganizationPolicyRestorePolicy[];
    /**
     * timeouts block.
     *
     * @stability stable
     */
    readonly timeouts?: FolderOrganizationPolicyTimeouts;
}
/**
 * @stability stable
 */
export interface FolderOrganizationPolicyBooleanPolicy {
    /**
     * If true, then the Policy is enforced.
     *
     * If false, then any configuration is acceptable.
     *
     * @stability stable
     */
    readonly enforced: boolean;
}
/**
 * @stability stable
 */
export interface FolderOrganizationPolicyListPolicyAllow {
    /**
     * The policy allows or denies all values.
     *
     * @stability stable
     */
    readonly all?: boolean;
    /**
     * The policy can define specific values that are allowed or denied.
     *
     * @stability stable
     */
    readonly values?: string[];
}
/**
 * @stability stable
 */
export interface FolderOrganizationPolicyListPolicyDeny {
    /**
     * The policy allows or denies all values.
     *
     * @stability stable
     */
    readonly all?: boolean;
    /**
     * The policy can define specific values that are allowed or denied.
     *
     * @stability stable
     */
    readonly values?: string[];
}
/**
 * @stability stable
 */
export interface FolderOrganizationPolicyListPolicy {
    /**
     * If set to true, the values from the effective Policy of the parent resource are inherited, meaning the values set in this Policy are added to the values inherited up the hierarchy.
     *
     * @stability stable
     */
    readonly inheritFromParent?: boolean;
    /**
     * The Google Cloud Console will try to default to a configuration that matches the value specified in this field.
     *
     * @stability stable
     */
    readonly suggestedValue?: string;
    /**
     * allow block.
     *
     * @stability stable
     */
    readonly allow?: FolderOrganizationPolicyListPolicyAllow[];
    /**
     * deny block.
     *
     * @stability stable
     */
    readonly deny?: FolderOrganizationPolicyListPolicyDeny[];
}
/**
 * @stability stable
 */
export interface FolderOrganizationPolicyRestorePolicy {
    /**
     * May only be set to true.
     *
     * If set, then the default Policy is restored.
     *
     * @stability stable
     */
    readonly default: boolean;
}
/**
 * @stability stable
 */
export interface FolderOrganizationPolicyTimeouts {
    /**
     * @stability stable
     */
    readonly create?: string;
    /**
     * @stability stable
     */
    readonly delete?: string;
    /**
     * @stability stable
     */
    readonly read?: string;
    /**
     * @stability stable
     */
    readonly update?: string;
}
/**
 * @stability stable
 */
export declare class FolderOrganizationPolicy extends cdktf.TerraformResource {
    /**
     * @stability stable
     */
    constructor(scope: Construct, id: string, config: FolderOrganizationPolicyConfig);
    private _constraint;
    /**
     * @stability stable
     */
    get constraint(): string;
    /**
     * @stability stable
     */
    set constraint(value: string);
    /**
     * @stability stable
     */
    get constraintInput(): string;
    /**
     * @stability stable
     */
    get etag(): string;
    private _folder;
    /**
     * @stability stable
     */
    get folder(): string;
    /**
     * @stability stable
     */
    set folder(value: string);
    /**
     * @stability stable
     */
    get folderInput(): string;
    /**
     * @stability stable
     */
    get id(): string;
    /**
     * @stability stable
     */
    get updateTime(): string;
    private _version?;
    /**
     * @stability stable
     */
    get version(): number;
    /**
     * @stability stable
     */
    set version(value: number);
    /**
     * @stability stable
     */
    resetVersion(): void;
    /**
     * @stability stable
     */
    get versionInput(): number | undefined;
    private _booleanPolicy?;
    /**
     * @stability stable
     */
    get booleanPolicy(): FolderOrganizationPolicyBooleanPolicy[];
    /**
     * @stability stable
     */
    set booleanPolicy(value: FolderOrganizationPolicyBooleanPolicy[]);
    /**
     * @stability stable
     */
    resetBooleanPolicy(): void;
    /**
     * @stability stable
     */
    get booleanPolicyInput(): FolderOrganizationPolicyBooleanPolicy[] | undefined;
    private _listPolicy?;
    /**
     * @stability stable
     */
    get listPolicy(): FolderOrganizationPolicyListPolicy[];
    /**
     * @stability stable
     */
    set listPolicy(value: FolderOrganizationPolicyListPolicy[]);
    /**
     * @stability stable
     */
    resetListPolicy(): void;
    /**
     * @stability stable
     */
    get listPolicyInput(): FolderOrganizationPolicyListPolicy[] | undefined;
    private _restorePolicy?;
    /**
     * @stability stable
     */
    get restorePolicy(): FolderOrganizationPolicyRestorePolicy[];
    /**
     * @stability stable
     */
    set restorePolicy(value: FolderOrganizationPolicyRestorePolicy[]);
    /**
     * @stability stable
     */
    resetRestorePolicy(): void;
    /**
     * @stability stable
     */
    get restorePolicyInput(): FolderOrganizationPolicyRestorePolicy[] | undefined;
    private _timeouts?;
    /**
     * @stability stable
     */
    get timeouts(): FolderOrganizationPolicyTimeouts;
    /**
     * @stability stable
     */
    set timeouts(value: FolderOrganizationPolicyTimeouts);
    /**
     * @stability stable
     */
    resetTimeouts(): void;
    /**
     * @stability stable
     */
    get timeoutsInput(): FolderOrganizationPolicyTimeouts | undefined;
    /**
     * @stability stable
     */
    protected synthesizeAttributes(): {
        [name: string]: any;
    };
}
