import { Construct } from 'constructs';
import * as cdktf from 'cdktf';
/**
 * @stability stable
 */
export interface FolderConfig extends cdktf.TerraformMetaArguments {
    /**
     * The folder's display name.
     *
     * A folder's display name must be unique amongst its siblings, e.g. no two folders with the same parent can share the same display name. The display name must start and end with a letter or digit, may contain letters, digits, spaces, hyphens and underscores and can be no longer than 30 characters.
     *
     * @stability stable
     */
    readonly displayName: string;
    /**
     * The resource name of the parent Folder or Organization.
     *
     * Must be of the form folders/{folder_id} or organizations/{org_id}.
     *
     * @stability stable
     */
    readonly parent: string;
    /**
     * timeouts block.
     *
     * @stability stable
     */
    readonly timeouts?: FolderTimeouts;
}
/**
 * @stability stable
 */
export interface FolderTimeouts {
    /**
     * @stability stable
     */
    readonly create?: string;
    /**
     * @stability stable
     */
    readonly delete?: string;
    /**
     * @stability stable
     */
    readonly read?: string;
    /**
     * @stability stable
     */
    readonly update?: string;
}
/**
 * @stability stable
 */
export declare class Folder extends cdktf.TerraformResource {
    /**
     * @stability stable
     */
    constructor(scope: Construct, id: string, config: FolderConfig);
    /**
     * @stability stable
     */
    get createTime(): string;
    private _displayName;
    /**
     * @stability stable
     */
    get displayName(): string;
    /**
     * @stability stable
     */
    set displayName(value: string);
    /**
     * @stability stable
     */
    get displayNameInput(): string;
    /**
     * @stability stable
     */
    get folderId(): string;
    /**
     * @stability stable
     */
    get id(): string;
    /**
     * @stability stable
     */
    get lifecycleState(): string;
    /**
     * @stability stable
     */
    get name(): string;
    private _parent;
    /**
     * @stability stable
     */
    get parent(): string;
    /**
     * @stability stable
     */
    set parent(value: string);
    /**
     * @stability stable
     */
    get parentInput(): string;
    private _timeouts?;
    /**
     * @stability stable
     */
    get timeouts(): FolderTimeouts;
    /**
     * @stability stable
     */
    set timeouts(value: FolderTimeouts);
    /**
     * @stability stable
     */
    resetTimeouts(): void;
    /**
     * @stability stable
     */
    get timeoutsInput(): FolderTimeouts | undefined;
    /**
     * @stability stable
     */
    protected synthesizeAttributes(): {
        [name: string]: any;
    };
}
