import { Construct } from 'constructs';
import * as cdktf from 'cdktf';
/**
 * @stability stable
 */
export interface GameServicesGameServerClusterConfig extends cdktf.TerraformMetaArguments {
    /**
     * Required.
     *
     * The resource name of the game server cluster
     *
     * @stability stable
     */
    readonly clusterId: string;
    /**
     * Human readable description of the cluster.
     *
     * @stability stable
     */
    readonly description?: string;
    /**
     * The labels associated with this game server cluster.
     *
     * Each label is a
     * key-value pair.
     *
     * @stability stable
     */
    readonly labels?: {
        [key: string]: string;
    };
    /**
     * Location of the Cluster.
     *
     * @stability stable
     */
    readonly location?: string;
    /**
     * @stability stable
     */
    readonly project?: string;
    /**
     * The realm id of the game server realm.
     *
     * @stability stable
     */
    readonly realmId: string;
    /**
     * connection_info block.
     *
     * @stability stable
     */
    readonly connectionInfo: GameServicesGameServerClusterConnectionInfo[];
    /**
     * timeouts block.
     *
     * @stability stable
     */
    readonly timeouts?: GameServicesGameServerClusterTimeouts;
}
/**
 * @stability stable
 */
export interface GameServicesGameServerClusterConnectionInfoGkeClusterReference {
    /**
     * The full or partial name of a GKE cluster, using one of the following forms:.
     *
     * 'projects/{project_id}/locations/{location}/clusters/{cluster_id}'
     * 'locations/{location}/clusters/{cluster_id}'
     * '{cluster_id}'
     *
     * If project and location are not specified, the project and location of the
     * GameServerCluster resource are used to generate the full name of the
     * GKE cluster.
     *
     * @stability stable
     */
    readonly cluster: string;
}
/**
 * @stability stable
 */
export interface GameServicesGameServerClusterConnectionInfo {
    /**
     * Namespace designated on the game server cluster where the game server instances will be created.
     *
     * The namespace existence will be validated
     * during creation.
     *
     * @stability stable
     */
    readonly namespace: string;
    /**
     * gke_cluster_reference block.
     *
     * @stability stable
     */
    readonly gkeClusterReference: GameServicesGameServerClusterConnectionInfoGkeClusterReference[];
}
/**
 * @stability stable
 */
export interface GameServicesGameServerClusterTimeouts {
    /**
     * @stability stable
     */
    readonly create?: string;
    /**
     * @stability stable
     */
    readonly delete?: string;
    /**
     * @stability stable
     */
    readonly update?: string;
}
/**
 * @stability stable
 */
export declare class GameServicesGameServerCluster extends cdktf.TerraformResource {
    /**
     * @stability stable
     */
    constructor(scope: Construct, id: string, config: GameServicesGameServerClusterConfig);
    private _clusterId;
    /**
     * @stability stable
     */
    get clusterId(): string;
    /**
     * @stability stable
     */
    set clusterId(value: string);
    /**
     * @stability stable
     */
    get clusterIdInput(): string;
    private _description?;
    /**
     * @stability stable
     */
    get description(): string;
    /**
     * @stability stable
     */
    set description(value: string);
    /**
     * @stability stable
     */
    resetDescription(): void;
    /**
     * @stability stable
     */
    get descriptionInput(): string | undefined;
    /**
     * @stability stable
     */
    get id(): string;
    private _labels?;
    /**
     * @stability stable
     */
    get labels(): {
        [key: string]: string;
    };
    /**
     * @stability stable
     */
    set labels(value: {
        [key: string]: string;
    });
    /**
     * @stability stable
     */
    resetLabels(): void;
    /**
     * @stability stable
     */
    get labelsInput(): {
        [key: string]: string;
    } | undefined;
    private _location?;
    /**
     * @stability stable
     */
    get location(): string;
    /**
     * @stability stable
     */
    set location(value: string);
    /**
     * @stability stable
     */
    resetLocation(): void;
    /**
     * @stability stable
     */
    get locationInput(): string | undefined;
    /**
     * @stability stable
     */
    get name(): string;
    private _project?;
    /**
     * @stability stable
     */
    get project(): string;
    /**
     * @stability stable
     */
    set project(value: string);
    /**
     * @stability stable
     */
    resetProject(): void;
    /**
     * @stability stable
     */
    get projectInput(): string | undefined;
    private _realmId;
    /**
     * @stability stable
     */
    get realmId(): string;
    /**
     * @stability stable
     */
    set realmId(value: string);
    /**
     * @stability stable
     */
    get realmIdInput(): string;
    private _connectionInfo;
    /**
     * @stability stable
     */
    get connectionInfo(): GameServicesGameServerClusterConnectionInfo[];
    /**
     * @stability stable
     */
    set connectionInfo(value: GameServicesGameServerClusterConnectionInfo[]);
    /**
     * @stability stable
     */
    get connectionInfoInput(): GameServicesGameServerClusterConnectionInfo[];
    private _timeouts?;
    /**
     * @stability stable
     */
    get timeouts(): GameServicesGameServerClusterTimeouts;
    /**
     * @stability stable
     */
    set timeouts(value: GameServicesGameServerClusterTimeouts);
    /**
     * @stability stable
     */
    resetTimeouts(): void;
    /**
     * @stability stable
     */
    get timeoutsInput(): GameServicesGameServerClusterTimeouts | undefined;
    /**
     * @stability stable
     */
    protected synthesizeAttributes(): {
        [name: string]: any;
    };
}
