import { Construct } from 'constructs';
import * as cdktf from 'cdktf';
/**
 * @stability stable
 */
export interface GameServicesRealmConfig extends cdktf.TerraformMetaArguments {
    /**
     * Human readable description of the realm.
     *
     * @stability stable
     */
    readonly description?: string;
    /**
     * The labels associated with this realm.
     *
     * Each label is a key-value pair.
     *
     * @stability stable
     */
    readonly labels?: {
        [key: string]: string;
    };
    /**
     * Location of the Realm.
     *
     * @stability stable
     */
    readonly location?: string;
    /**
     * @stability stable
     */
    readonly project?: string;
    /**
     * GCP region of the Realm.
     *
     * @stability stable
     */
    readonly realmId: string;
    /**
     * Required.
     *
     * Time zone where all realm-specific policies are evaluated. The value of
     * this field must be from the IANA time zone database:
     * https://www.iana.org/time-zones.
     *
     * @stability stable
     */
    readonly timeZone: string;
    /**
     * timeouts block.
     *
     * @stability stable
     */
    readonly timeouts?: GameServicesRealmTimeouts;
}
/**
 * @stability stable
 */
export interface GameServicesRealmTimeouts {
    /**
     * @stability stable
     */
    readonly create?: string;
    /**
     * @stability stable
     */
    readonly delete?: string;
    /**
     * @stability stable
     */
    readonly update?: string;
}
/**
 * @stability stable
 */
export declare class GameServicesRealm extends cdktf.TerraformResource {
    /**
     * @stability stable
     */
    constructor(scope: Construct, id: string, config: GameServicesRealmConfig);
    private _description?;
    /**
     * @stability stable
     */
    get description(): string;
    /**
     * @stability stable
     */
    set description(value: string);
    /**
     * @stability stable
     */
    resetDescription(): void;
    /**
     * @stability stable
     */
    get descriptionInput(): string | undefined;
    /**
     * @stability stable
     */
    get etag(): string;
    /**
     * @stability stable
     */
    get id(): string;
    private _labels?;
    /**
     * @stability stable
     */
    get labels(): {
        [key: string]: string;
    };
    /**
     * @stability stable
     */
    set labels(value: {
        [key: string]: string;
    });
    /**
     * @stability stable
     */
    resetLabels(): void;
    /**
     * @stability stable
     */
    get labelsInput(): {
        [key: string]: string;
    } | undefined;
    private _location?;
    /**
     * @stability stable
     */
    get location(): string;
    /**
     * @stability stable
     */
    set location(value: string);
    /**
     * @stability stable
     */
    resetLocation(): void;
    /**
     * @stability stable
     */
    get locationInput(): string | undefined;
    /**
     * @stability stable
     */
    get name(): string;
    private _project?;
    /**
     * @stability stable
     */
    get project(): string;
    /**
     * @stability stable
     */
    set project(value: string);
    /**
     * @stability stable
     */
    resetProject(): void;
    /**
     * @stability stable
     */
    get projectInput(): string | undefined;
    private _realmId;
    /**
     * @stability stable
     */
    get realmId(): string;
    /**
     * @stability stable
     */
    set realmId(value: string);
    /**
     * @stability stable
     */
    get realmIdInput(): string;
    private _timeZone;
    /**
     * @stability stable
     */
    get timeZone(): string;
    /**
     * @stability stable
     */
    set timeZone(value: string);
    /**
     * @stability stable
     */
    get timeZoneInput(): string;
    private _timeouts?;
    /**
     * @stability stable
     */
    get timeouts(): GameServicesRealmTimeouts;
    /**
     * @stability stable
     */
    set timeouts(value: GameServicesRealmTimeouts);
    /**
     * @stability stable
     */
    resetTimeouts(): void;
    /**
     * @stability stable
     */
    get timeoutsInput(): GameServicesRealmTimeouts | undefined;
    /**
     * @stability stable
     */
    protected synthesizeAttributes(): {
        [name: string]: any;
    };
}
