import { Construct } from 'constructs';
import * as cdktf from 'cdktf';
/**
 * @stability stable
 */
export interface IdentityPlatformTenantOauthIdpConfigConfig extends cdktf.TerraformMetaArguments {
    /**
     * The client id of an OAuth client.
     *
     * @stability stable
     */
    readonly clientId: string;
    /**
     * The client secret of the OAuth client, to enable OIDC code flow.
     *
     * @stability stable
     */
    readonly clientSecret?: string;
    /**
     * Human friendly display name.
     *
     * @stability stable
     */
    readonly displayName: string;
    /**
     * If this config allows users to sign in with the provider.
     *
     * @stability stable
     */
    readonly enabled?: boolean;
    /**
     * For OIDC Idps, the issuer identifier.
     *
     * @stability stable
     */
    readonly issuer: string;
    /**
     * The name of the OauthIdpConfig.
     *
     * Must start with 'oidc.'.
     *
     * @stability stable
     */
    readonly name: string;
    /**
     * @stability stable
     */
    readonly project?: string;
    /**
     * The name of the tenant where this OIDC IDP configuration resource exists.
     *
     * @stability stable
     */
    readonly tenant: string;
    /**
     * timeouts block.
     *
     * @stability stable
     */
    readonly timeouts?: IdentityPlatformTenantOauthIdpConfigTimeouts;
}
/**
 * @stability stable
 */
export interface IdentityPlatformTenantOauthIdpConfigTimeouts {
    /**
     * @stability stable
     */
    readonly create?: string;
    /**
     * @stability stable
     */
    readonly delete?: string;
    /**
     * @stability stable
     */
    readonly update?: string;
}
/**
 * @stability stable
 */
export declare class IdentityPlatformTenantOauthIdpConfig extends cdktf.TerraformResource {
    /**
     * @stability stable
     */
    constructor(scope: Construct, id: string, config: IdentityPlatformTenantOauthIdpConfigConfig);
    private _clientId;
    /**
     * @stability stable
     */
    get clientId(): string;
    /**
     * @stability stable
     */
    set clientId(value: string);
    /**
     * @stability stable
     */
    get clientIdInput(): string;
    private _clientSecret?;
    /**
     * @stability stable
     */
    get clientSecret(): string;
    /**
     * @stability stable
     */
    set clientSecret(value: string);
    /**
     * @stability stable
     */
    resetClientSecret(): void;
    /**
     * @stability stable
     */
    get clientSecretInput(): string | undefined;
    private _displayName;
    /**
     * @stability stable
     */
    get displayName(): string;
    /**
     * @stability stable
     */
    set displayName(value: string);
    /**
     * @stability stable
     */
    get displayNameInput(): string;
    private _enabled?;
    /**
     * @stability stable
     */
    get enabled(): boolean;
    /**
     * @stability stable
     */
    set enabled(value: boolean);
    /**
     * @stability stable
     */
    resetEnabled(): void;
    /**
     * @stability stable
     */
    get enabledInput(): boolean | undefined;
    /**
     * @stability stable
     */
    get id(): string;
    private _issuer;
    /**
     * @stability stable
     */
    get issuer(): string;
    /**
     * @stability stable
     */
    set issuer(value: string);
    /**
     * @stability stable
     */
    get issuerInput(): string;
    private _name;
    /**
     * @stability stable
     */
    get name(): string;
    /**
     * @stability stable
     */
    set name(value: string);
    /**
     * @stability stable
     */
    get nameInput(): string;
    private _project?;
    /**
     * @stability stable
     */
    get project(): string;
    /**
     * @stability stable
     */
    set project(value: string);
    /**
     * @stability stable
     */
    resetProject(): void;
    /**
     * @stability stable
     */
    get projectInput(): string | undefined;
    private _tenant;
    /**
     * @stability stable
     */
    get tenant(): string;
    /**
     * @stability stable
     */
    set tenant(value: string);
    /**
     * @stability stable
     */
    get tenantInput(): string;
    private _timeouts?;
    /**
     * @stability stable
     */
    get timeouts(): IdentityPlatformTenantOauthIdpConfigTimeouts;
    /**
     * @stability stable
     */
    set timeouts(value: IdentityPlatformTenantOauthIdpConfigTimeouts);
    /**
     * @stability stable
     */
    resetTimeouts(): void;
    /**
     * @stability stable
     */
    get timeoutsInput(): IdentityPlatformTenantOauthIdpConfigTimeouts | undefined;
    /**
     * @stability stable
     */
    protected synthesizeAttributes(): {
        [name: string]: any;
    };
}
