import { Construct } from 'constructs';
import * as cdktf from 'cdktf';
/**
 * @stability stable
 */
export interface KmsSecretCiphertextConfig extends cdktf.TerraformMetaArguments {
    /**
     * The additional authenticated data used for integrity checks during encryption and decryption.
     *
     * @stability stable
     */
    readonly additionalAuthenticatedData?: string;
    /**
     * The full name of the CryptoKey that will be used to encrypt the provided plaintext.
     *
     * Format: ''projects/{{project}}/locations/{{location}}/keyRings/{{keyRing}}/cryptoKeys/{{cryptoKey}}''
     *
     * @stability stable
     */
    readonly cryptoKey: string;
    /**
     * The plaintext to be encrypted.
     *
     * @stability stable
     */
    readonly plaintext: string;
    /**
     * timeouts block.
     *
     * @stability stable
     */
    readonly timeouts?: KmsSecretCiphertextTimeouts;
}
/**
 * @stability stable
 */
export interface KmsSecretCiphertextTimeouts {
    /**
     * @stability stable
     */
    readonly create?: string;
    /**
     * @stability stable
     */
    readonly delete?: string;
}
/**
 * @stability stable
 */
export declare class KmsSecretCiphertext extends cdktf.TerraformResource {
    /**
     * @stability stable
     */
    constructor(scope: Construct, id: string, config: KmsSecretCiphertextConfig);
    private _additionalAuthenticatedData?;
    /**
     * @stability stable
     */
    get additionalAuthenticatedData(): string;
    /**
     * @stability stable
     */
    set additionalAuthenticatedData(value: string);
    /**
     * @stability stable
     */
    resetAdditionalAuthenticatedData(): void;
    /**
     * @stability stable
     */
    get additionalAuthenticatedDataInput(): string | undefined;
    /**
     * @stability stable
     */
    get ciphertext(): string;
    private _cryptoKey;
    /**
     * @stability stable
     */
    get cryptoKey(): string;
    /**
     * @stability stable
     */
    set cryptoKey(value: string);
    /**
     * @stability stable
     */
    get cryptoKeyInput(): string;
    /**
     * @stability stable
     */
    get id(): string;
    private _plaintext;
    /**
     * @stability stable
     */
    get plaintext(): string;
    /**
     * @stability stable
     */
    set plaintext(value: string);
    /**
     * @stability stable
     */
    get plaintextInput(): string;
    private _timeouts?;
    /**
     * @stability stable
     */
    get timeouts(): KmsSecretCiphertextTimeouts;
    /**
     * @stability stable
     */
    set timeouts(value: KmsSecretCiphertextTimeouts);
    /**
     * @stability stable
     */
    resetTimeouts(): void;
    /**
     * @stability stable
     */
    get timeoutsInput(): KmsSecretCiphertextTimeouts | undefined;
    /**
     * @stability stable
     */
    protected synthesizeAttributes(): {
        [name: string]: any;
    };
}
