import { Construct } from 'constructs';
import * as cdktf from 'cdktf';
/**
 * @stability stable
 */
export interface MonitoringNotificationChannelConfig extends cdktf.TerraformMetaArguments {
    /**
     * An optional human-readable description of this notification channel.
     *
     * This description may provide additional details, beyond the display name, for the channel. This may not exceed 1024 Unicode characters.
     *
     * @stability stable
     */
    readonly description?: string;
    /**
     * An optional human-readable name for this notification channel.
     *
     * It is recommended that you specify a non-empty and unique name in order to make it easier to identify the channels in your project, though this is not enforced. The display name is limited to 512 Unicode characters.
     *
     * @stability stable
     */
    readonly displayName?: string;
    /**
     * Whether notifications are forwarded to the described channel.
     *
     * This makes it possible to disable delivery of notifications to a particular channel without removing the channel from all alerting policies that reference the channel. This is a more convenient approach when the change is temporary and you want to receive notifications from the same set of alerting policies on the channel at some point in the future.
     *
     * @stability stable
     */
    readonly enabled?: boolean;
    /**
     * Configuration fields that define the channel and its behavior.
     *
     * The
     * permissible and required labels are specified in the
     * NotificationChannelDescriptor corresponding to the type field.
     *
     * Labels with sensitive data are obfuscated by the API and therefore Terraform cannot
     * determine if there are upstream changes to these fields. They can also be configured via
     * the sensitive_labels block, but cannot be configured in both places.
     *
     * @stability stable
     */
    readonly labels?: {
        [key: string]: string;
    };
    /**
     * @stability stable
     */
    readonly project?: string;
    /**
     * The type of the notification channel.
     *
     * This field matches the value of the NotificationChannelDescriptor.type field. See https://cloud.google.com/monitoring/api/ref_v3/rest/v3/projects.notificationChannelDescriptors/list to get the list of valid values such as "email", "slack", etc...
     *
     * @stability stable
     */
    readonly type: string;
    /**
     * User-supplied key/value data that does not need to conform to the corresponding NotificationChannelDescriptor's schema, unlike the labels field.
     *
     * This field is intended to be used for organizing and identifying the NotificationChannel objects.The field can contain up to 64 entries. Each key and value is limited to 63 Unicode characters or 128 bytes, whichever is smaller. Labels and values can contain only lowercase letters, numerals, underscores, and dashes. Keys must begin with a letter.
     *
     * @stability stable
     */
    readonly userLabels?: {
        [key: string]: string;
    };
    /**
     * sensitive_labels block.
     *
     * @stability stable
     */
    readonly sensitiveLabels?: MonitoringNotificationChannelSensitiveLabels[];
    /**
     * timeouts block.
     *
     * @stability stable
     */
    readonly timeouts?: MonitoringNotificationChannelTimeouts;
}
/**
 * @stability stable
 */
export interface MonitoringNotificationChannelSensitiveLabels {
    /**
     * An authorization token for a notification channel.
     *
     * Channel types that support this field include: slack
     *
     * @stability stable
     */
    readonly authToken?: string;
    /**
     * An password for a notification channel.
     *
     * Channel types that support this field include: webhook_basicauth
     *
     * @stability stable
     */
    readonly password?: string;
    /**
     * An servicekey token for a notification channel.
     *
     * Channel types that support this field include: pagerduty
     *
     * @stability stable
     */
    readonly serviceKey?: string;
}
/**
 * @stability stable
 */
export interface MonitoringNotificationChannelTimeouts {
    /**
     * @stability stable
     */
    readonly create?: string;
    /**
     * @stability stable
     */
    readonly delete?: string;
    /**
     * @stability stable
     */
    readonly update?: string;
}
/**
 * @stability stable
 */
export declare class MonitoringNotificationChannel extends cdktf.TerraformResource {
    /**
     * @stability stable
     */
    constructor(scope: Construct, id: string, config: MonitoringNotificationChannelConfig);
    private _description?;
    /**
     * @stability stable
     */
    get description(): string;
    /**
     * @stability stable
     */
    set description(value: string);
    /**
     * @stability stable
     */
    resetDescription(): void;
    /**
     * @stability stable
     */
    get descriptionInput(): string | undefined;
    private _displayName?;
    /**
     * @stability stable
     */
    get displayName(): string;
    /**
     * @stability stable
     */
    set displayName(value: string);
    /**
     * @stability stable
     */
    resetDisplayName(): void;
    /**
     * @stability stable
     */
    get displayNameInput(): string | undefined;
    private _enabled?;
    /**
     * @stability stable
     */
    get enabled(): boolean;
    /**
     * @stability stable
     */
    set enabled(value: boolean);
    /**
     * @stability stable
     */
    resetEnabled(): void;
    /**
     * @stability stable
     */
    get enabledInput(): boolean | undefined;
    /**
     * @stability stable
     */
    get id(): string;
    private _labels?;
    /**
     * @stability stable
     */
    get labels(): {
        [key: string]: string;
    };
    /**
     * @stability stable
     */
    set labels(value: {
        [key: string]: string;
    });
    /**
     * @stability stable
     */
    resetLabels(): void;
    /**
     * @stability stable
     */
    get labelsInput(): {
        [key: string]: string;
    } | undefined;
    /**
     * @stability stable
     */
    get name(): string;
    private _project?;
    /**
     * @stability stable
     */
    get project(): string;
    /**
     * @stability stable
     */
    set project(value: string);
    /**
     * @stability stable
     */
    resetProject(): void;
    /**
     * @stability stable
     */
    get projectInput(): string | undefined;
    private _type;
    /**
     * @stability stable
     */
    get type(): string;
    /**
     * @stability stable
     */
    set type(value: string);
    /**
     * @stability stable
     */
    get typeInput(): string;
    private _userLabels?;
    /**
     * @stability stable
     */
    get userLabels(): {
        [key: string]: string;
    };
    /**
     * @stability stable
     */
    set userLabels(value: {
        [key: string]: string;
    });
    /**
     * @stability stable
     */
    resetUserLabels(): void;
    /**
     * @stability stable
     */
    get userLabelsInput(): {
        [key: string]: string;
    } | undefined;
    /**
     * @stability stable
     */
    get verificationStatus(): string;
    private _sensitiveLabels?;
    /**
     * @stability stable
     */
    get sensitiveLabels(): MonitoringNotificationChannelSensitiveLabels[];
    /**
     * @stability stable
     */
    set sensitiveLabels(value: MonitoringNotificationChannelSensitiveLabels[]);
    /**
     * @stability stable
     */
    resetSensitiveLabels(): void;
    /**
     * @stability stable
     */
    get sensitiveLabelsInput(): MonitoringNotificationChannelSensitiveLabels[] | undefined;
    private _timeouts?;
    /**
     * @stability stable
     */
    get timeouts(): MonitoringNotificationChannelTimeouts;
    /**
     * @stability stable
     */
    set timeouts(value: MonitoringNotificationChannelTimeouts);
    /**
     * @stability stable
     */
    resetTimeouts(): void;
    /**
     * @stability stable
     */
    get timeoutsInput(): MonitoringNotificationChannelTimeouts | undefined;
    /**
     * @stability stable
     */
    protected synthesizeAttributes(): {
        [name: string]: any;
    };
}
