import { Construct } from 'constructs';
import * as cdktf from 'cdktf';
/**
 * @stability stable
 */
export interface NotebooksInstanceConfig extends cdktf.TerraformMetaArguments {
    /**
     * The size of the boot disk in GB attached to this instance, up to a maximum of 64000 GB (64 TB).
     *
     * The minimum recommended value is 100 GB.
     * If not specified, this defaults to 100.
     *
     * @stability stable
     */
    readonly bootDiskSizeGb?: number;
    /**
     * Possible disk types for notebook instances.
     *
     * Possible values: ["DISK_TYPE_UNSPECIFIED", "PD_STANDARD", "PD_SSD", "PD_BALANCED"]
     *
     * @stability stable
     */
    readonly bootDiskType?: string;
    /**
     * Instance creation time.
     *
     * @stability stable
     */
    readonly createTime?: string;
    /**
     * Specify a custom Cloud Storage path where the GPU driver is stored.
     *
     * If not specified, we'll automatically choose from official GPU drivers.
     *
     * @stability stable
     */
    readonly customGpuDriverPath?: string;
    /**
     * The size of the data disk in GB attached to this instance, up to a maximum of 64000 GB (64 TB).
     *
     * You can choose the size of the data disk based on how big your notebooks and data are.
     * If not specified, this defaults to 100.
     *
     * @stability stable
     */
    readonly dataDiskSizeGb?: number;
    /**
     * Possible disk types for notebook instances.
     *
     * Possible values: ["DISK_TYPE_UNSPECIFIED", "PD_STANDARD", "PD_SSD", "PD_BALANCED"]
     *
     * @stability stable
     */
    readonly dataDiskType?: string;
    /**
     * Disk encryption method used on the boot and data disks, defaults to GMEK.
     *
     * Possible values: ["DISK_ENCRYPTION_UNSPECIFIED", "GMEK", "CMEK"]
     *
     * @stability stable
     */
    readonly diskEncryption?: string;
    /**
     * Whether the end user authorizes Google Cloud to install GPU driver on this instance.
     *
     * If this field is empty or set to false, the GPU driver
     * won't be installed. Only applicable to instances with GPUs.
     *
     * @stability stable
     */
    readonly installGpuDriver?: boolean;
    /**
     * The list of owners of this instance after creation.
     *
     * Format: alias@example.com.
     * Currently supports one owner only.
     * If not specified, all of the service account users of
     * your VM instance's service account can use the instance.
     *
     * @stability stable
     */
    readonly instanceOwners?: string[];
    /**
     * The KMS key used to encrypt the disks, only applicable if diskEncryption is CMEK.
     *
     * Format: projects/{project_id}/locations/{location}/keyRings/{key_ring_id}/cryptoKeys/{key_id}
     *
     * @stability stable
     */
    readonly kmsKey?: string;
    /**
     * Labels to apply to this instance.
     *
     * These can be later modified by the setLabels method.
     * An object containing a list of "key": value pairs. Example: { "name": "wrench", "mass": "1.3kg", "count": "3" }.
     *
     * @stability stable
     */
    readonly labels?: {
        [key: string]: string;
    };
    /**
     * A reference to the zone where the machine resides.
     *
     * @stability stable
     */
    readonly location: string;
    /**
     * A reference to a machine type which defines VM kind.
     *
     * @stability stable
     */
    readonly machineType: string;
    /**
     * Custom metadata to apply to this instance.
     *
     * An object containing a list of "key": value pairs. Example: { "name": "wrench", "mass": "1.3kg", "count": "3" }.
     *
     * @stability stable
     */
    readonly metadata?: {
        [key: string]: string;
    };
    /**
     * The name specified for the Notebook instance.
     *
     * @stability stable
     */
    readonly name: string;
    /**
     * The name of the VPC that this instance is in.
     *
     * Format: projects/{project_id}/global/networks/{network_id}
     *
     * @stability stable
     */
    readonly network?: string;
    /**
     * the notebook instance will not register with the proxy..
     *
     * @stability stable
     */
    readonly noProxyAccess?: boolean;
    /**
     * no public IP will be assigned to this instance.
     *
     * @stability stable
     */
    readonly noPublicIp?: boolean;
    /**
     * If true, the data disk will not be auto deleted when deleting the instance.
     *
     * @stability stable
     */
    readonly noRemoveDataDisk?: boolean;
    /**
     * Path to a Bash script that automatically runs after a notebook instance fully boots up.
     *
     * The path must be a URL
     * or Cloud Storage path (gs://path-to-file/file-name).
     *
     * @stability stable
     */
    readonly postStartupScript?: string;
    /**
     * @stability stable
     */
    readonly project?: string;
    /**
     * The service account on this instance, giving access to other Google Cloud services.
     *
     * You can use any service account within
     * the same project, but you must have the service account user
     * permission to use the instance. If not specified,
     * the Compute Engine default service account is used.
     *
     * @stability stable
     */
    readonly serviceAccount?: string;
    /**
     * The name of the subnet that this instance is in.
     *
     * Format: projects/{project_id}/regions/{region}/subnetworks/{subnetwork_id}
     *
     * @stability stable
     */
    readonly subnet?: string;
    /**
     * Instance update time.
     *
     * @stability stable
     */
    readonly updateTime?: string;
    /**
     * accelerator_config block.
     *
     * @stability stable
     */
    readonly acceleratorConfig?: NotebooksInstanceAcceleratorConfig[];
    /**
     * container_image block.
     *
     * @stability stable
     */
    readonly containerImage?: NotebooksInstanceContainerImage[];
    /**
     * timeouts block.
     *
     * @stability stable
     */
    readonly timeouts?: NotebooksInstanceTimeouts;
    /**
     * vm_image block.
     *
     * @stability stable
     */
    readonly vmImage?: NotebooksInstanceVmImage[];
}
/**
 * @stability stable
 */
export interface NotebooksInstanceAcceleratorConfig {
    /**
     * Count of cores of this accelerator.
     *
     * @stability stable
     */
    readonly coreCount: number;
    /**
     * Type of this accelerator.
     *
     * Possible values: ["ACCELERATOR_TYPE_UNSPECIFIED", "NVIDIA_TESLA_K80", "NVIDIA_TESLA_P100", "NVIDIA_TESLA_V100", "NVIDIA_TESLA_P4", "NVIDIA_TESLA_T4", "NVIDIA_TESLA_T4_VWS", "NVIDIA_TESLA_P100_VWS", "NVIDIA_TESLA_P4_VWS", "TPU_V2", "TPU_V3"]
     *
     * @stability stable
     */
    readonly type: string;
}
/**
 * @stability stable
 */
export interface NotebooksInstanceContainerImage {
    /**
     * The path to the container image repository.
     *
     * For example: gcr.io/{project_id}/{imageName}
     *
     * @stability stable
     */
    readonly repository: string;
    /**
     * The tag of the container image.
     *
     * If not specified, this defaults to the latest tag.
     *
     * @stability stable
     */
    readonly tag?: string;
}
/**
 * @stability stable
 */
export interface NotebooksInstanceTimeouts {
    /**
     * @stability stable
     */
    readonly create?: string;
    /**
     * @stability stable
     */
    readonly delete?: string;
    /**
     * @stability stable
     */
    readonly update?: string;
}
/**
 * @stability stable
 */
export interface NotebooksInstanceVmImage {
    /**
     * Use this VM image family to find the image;
     *
     * the newest image in this family will be used.
     *
     * @stability stable
     */
    readonly imageFamily?: string;
    /**
     * Use VM image name to find the image.
     *
     * @stability stable
     */
    readonly imageName?: string;
    /**
     * The name of the Google Cloud project that this VM image belongs to.
     *
     * Format: projects/{project_id}
     *
     * @stability stable
     */
    readonly project: string;
}
/**
 * @stability stable
 */
export declare class NotebooksInstance extends cdktf.TerraformResource {
    /**
     * @stability stable
     */
    constructor(scope: Construct, id: string, config: NotebooksInstanceConfig);
    private _bootDiskSizeGb?;
    /**
     * @stability stable
     */
    get bootDiskSizeGb(): number;
    /**
     * @stability stable
     */
    set bootDiskSizeGb(value: number);
    /**
     * @stability stable
     */
    resetBootDiskSizeGb(): void;
    /**
     * @stability stable
     */
    get bootDiskSizeGbInput(): number | undefined;
    private _bootDiskType?;
    /**
     * @stability stable
     */
    get bootDiskType(): string;
    /**
     * @stability stable
     */
    set bootDiskType(value: string);
    /**
     * @stability stable
     */
    resetBootDiskType(): void;
    /**
     * @stability stable
     */
    get bootDiskTypeInput(): string | undefined;
    private _createTime?;
    /**
     * @stability stable
     */
    get createTime(): string;
    /**
     * @stability stable
     */
    set createTime(value: string);
    /**
     * @stability stable
     */
    resetCreateTime(): void;
    /**
     * @stability stable
     */
    get createTimeInput(): string | undefined;
    private _customGpuDriverPath?;
    /**
     * @stability stable
     */
    get customGpuDriverPath(): string;
    /**
     * @stability stable
     */
    set customGpuDriverPath(value: string);
    /**
     * @stability stable
     */
    resetCustomGpuDriverPath(): void;
    /**
     * @stability stable
     */
    get customGpuDriverPathInput(): string | undefined;
    private _dataDiskSizeGb?;
    /**
     * @stability stable
     */
    get dataDiskSizeGb(): number;
    /**
     * @stability stable
     */
    set dataDiskSizeGb(value: number);
    /**
     * @stability stable
     */
    resetDataDiskSizeGb(): void;
    /**
     * @stability stable
     */
    get dataDiskSizeGbInput(): number | undefined;
    private _dataDiskType?;
    /**
     * @stability stable
     */
    get dataDiskType(): string;
    /**
     * @stability stable
     */
    set dataDiskType(value: string);
    /**
     * @stability stable
     */
    resetDataDiskType(): void;
    /**
     * @stability stable
     */
    get dataDiskTypeInput(): string | undefined;
    private _diskEncryption?;
    /**
     * @stability stable
     */
    get diskEncryption(): string;
    /**
     * @stability stable
     */
    set diskEncryption(value: string);
    /**
     * @stability stable
     */
    resetDiskEncryption(): void;
    /**
     * @stability stable
     */
    get diskEncryptionInput(): string | undefined;
    /**
     * @stability stable
     */
    get id(): string;
    private _installGpuDriver?;
    /**
     * @stability stable
     */
    get installGpuDriver(): boolean;
    /**
     * @stability stable
     */
    set installGpuDriver(value: boolean);
    /**
     * @stability stable
     */
    resetInstallGpuDriver(): void;
    /**
     * @stability stable
     */
    get installGpuDriverInput(): boolean | undefined;
    private _instanceOwners?;
    /**
     * @stability stable
     */
    get instanceOwners(): string[];
    /**
     * @stability stable
     */
    set instanceOwners(value: string[]);
    /**
     * @stability stable
     */
    resetInstanceOwners(): void;
    /**
     * @stability stable
     */
    get instanceOwnersInput(): string[] | undefined;
    private _kmsKey?;
    /**
     * @stability stable
     */
    get kmsKey(): string;
    /**
     * @stability stable
     */
    set kmsKey(value: string);
    /**
     * @stability stable
     */
    resetKmsKey(): void;
    /**
     * @stability stable
     */
    get kmsKeyInput(): string | undefined;
    private _labels?;
    /**
     * @stability stable
     */
    get labels(): {
        [key: string]: string;
    };
    /**
     * @stability stable
     */
    set labels(value: {
        [key: string]: string;
    });
    /**
     * @stability stable
     */
    resetLabels(): void;
    /**
     * @stability stable
     */
    get labelsInput(): {
        [key: string]: string;
    } | undefined;
    private _location;
    /**
     * @stability stable
     */
    get location(): string;
    /**
     * @stability stable
     */
    set location(value: string);
    /**
     * @stability stable
     */
    get locationInput(): string;
    private _machineType;
    /**
     * @stability stable
     */
    get machineType(): string;
    /**
     * @stability stable
     */
    set machineType(value: string);
    /**
     * @stability stable
     */
    get machineTypeInput(): string;
    private _metadata?;
    /**
     * @stability stable
     */
    get metadata(): {
        [key: string]: string;
    };
    /**
     * @stability stable
     */
    set metadata(value: {
        [key: string]: string;
    });
    /**
     * @stability stable
     */
    resetMetadata(): void;
    /**
     * @stability stable
     */
    get metadataInput(): {
        [key: string]: string;
    } | undefined;
    private _name;
    /**
     * @stability stable
     */
    get name(): string;
    /**
     * @stability stable
     */
    set name(value: string);
    /**
     * @stability stable
     */
    get nameInput(): string;
    private _network?;
    /**
     * @stability stable
     */
    get network(): string;
    /**
     * @stability stable
     */
    set network(value: string);
    /**
     * @stability stable
     */
    resetNetwork(): void;
    /**
     * @stability stable
     */
    get networkInput(): string | undefined;
    private _noProxyAccess?;
    /**
     * @stability stable
     */
    get noProxyAccess(): boolean;
    /**
     * @stability stable
     */
    set noProxyAccess(value: boolean);
    /**
     * @stability stable
     */
    resetNoProxyAccess(): void;
    /**
     * @stability stable
     */
    get noProxyAccessInput(): boolean | undefined;
    private _noPublicIp?;
    /**
     * @stability stable
     */
    get noPublicIp(): boolean;
    /**
     * @stability stable
     */
    set noPublicIp(value: boolean);
    /**
     * @stability stable
     */
    resetNoPublicIp(): void;
    /**
     * @stability stable
     */
    get noPublicIpInput(): boolean | undefined;
    private _noRemoveDataDisk?;
    /**
     * @stability stable
     */
    get noRemoveDataDisk(): boolean;
    /**
     * @stability stable
     */
    set noRemoveDataDisk(value: boolean);
    /**
     * @stability stable
     */
    resetNoRemoveDataDisk(): void;
    /**
     * @stability stable
     */
    get noRemoveDataDiskInput(): boolean | undefined;
    private _postStartupScript?;
    /**
     * @stability stable
     */
    get postStartupScript(): string;
    /**
     * @stability stable
     */
    set postStartupScript(value: string);
    /**
     * @stability stable
     */
    resetPostStartupScript(): void;
    /**
     * @stability stable
     */
    get postStartupScriptInput(): string | undefined;
    private _project?;
    /**
     * @stability stable
     */
    get project(): string;
    /**
     * @stability stable
     */
    set project(value: string);
    /**
     * @stability stable
     */
    resetProject(): void;
    /**
     * @stability stable
     */
    get projectInput(): string | undefined;
    /**
     * @stability stable
     */
    get proxyUri(): string;
    private _serviceAccount?;
    /**
     * @stability stable
     */
    get serviceAccount(): string;
    /**
     * @stability stable
     */
    set serviceAccount(value: string);
    /**
     * @stability stable
     */
    resetServiceAccount(): void;
    /**
     * @stability stable
     */
    get serviceAccountInput(): string | undefined;
    /**
     * @stability stable
     */
    get state(): string;
    private _subnet?;
    /**
     * @stability stable
     */
    get subnet(): string;
    /**
     * @stability stable
     */
    set subnet(value: string);
    /**
     * @stability stable
     */
    resetSubnet(): void;
    /**
     * @stability stable
     */
    get subnetInput(): string | undefined;
    private _updateTime?;
    /**
     * @stability stable
     */
    get updateTime(): string;
    /**
     * @stability stable
     */
    set updateTime(value: string);
    /**
     * @stability stable
     */
    resetUpdateTime(): void;
    /**
     * @stability stable
     */
    get updateTimeInput(): string | undefined;
    private _acceleratorConfig?;
    /**
     * @stability stable
     */
    get acceleratorConfig(): NotebooksInstanceAcceleratorConfig[];
    /**
     * @stability stable
     */
    set acceleratorConfig(value: NotebooksInstanceAcceleratorConfig[]);
    /**
     * @stability stable
     */
    resetAcceleratorConfig(): void;
    /**
     * @stability stable
     */
    get acceleratorConfigInput(): NotebooksInstanceAcceleratorConfig[] | undefined;
    private _containerImage?;
    /**
     * @stability stable
     */
    get containerImage(): NotebooksInstanceContainerImage[];
    /**
     * @stability stable
     */
    set containerImage(value: NotebooksInstanceContainerImage[]);
    /**
     * @stability stable
     */
    resetContainerImage(): void;
    /**
     * @stability stable
     */
    get containerImageInput(): NotebooksInstanceContainerImage[] | undefined;
    private _timeouts?;
    /**
     * @stability stable
     */
    get timeouts(): NotebooksInstanceTimeouts;
    /**
     * @stability stable
     */
    set timeouts(value: NotebooksInstanceTimeouts);
    /**
     * @stability stable
     */
    resetTimeouts(): void;
    /**
     * @stability stable
     */
    get timeoutsInput(): NotebooksInstanceTimeouts | undefined;
    private _vmImage?;
    /**
     * @stability stable
     */
    get vmImage(): NotebooksInstanceVmImage[];
    /**
     * @stability stable
     */
    set vmImage(value: NotebooksInstanceVmImage[]);
    /**
     * @stability stable
     */
    resetVmImage(): void;
    /**
     * @stability stable
     */
    get vmImageInput(): NotebooksInstanceVmImage[] | undefined;
    /**
     * @stability stable
     */
    protected synthesizeAttributes(): {
        [name: string]: any;
    };
}
