import { Construct } from 'constructs';
import * as cdktf from 'cdktf';
/**
 * @stability stable
 */
export interface OrganizationAccessApprovalSettingsConfig extends cdktf.TerraformMetaArguments {
    /**
     * A list of email addresses to which notifications relating to approval requests should be sent.
     *
     * Notifications relating to a resource will be sent to all emails in the settings of ancestor
     * resources of that resource. A maximum of 50 email addresses are allowed.
     *
     * @stability stable
     */
    readonly notificationEmails?: string[];
    /**
     * ID of the organization of the access approval settings.
     *
     * @stability stable
     */
    readonly organizationId: string;
    /**
     * enrolled_services block.
     *
     * @stability stable
     */
    readonly enrolledServices: OrganizationAccessApprovalSettingsEnrolledServices[];
    /**
     * timeouts block.
     *
     * @stability stable
     */
    readonly timeouts?: OrganizationAccessApprovalSettingsTimeouts;
}
/**
 * @stability stable
 */
export interface OrganizationAccessApprovalSettingsEnrolledServices {
    /**
     * The product for which Access Approval will be enrolled.
     *
     * Allowed values are listed (case-sensitive):
     * all
     * appengine.googleapis.com
     * bigquery.googleapis.com
     * bigtable.googleapis.com
     * cloudkms.googleapis.com
     * compute.googleapis.com
     * dataflow.googleapis.com
     * iam.googleapis.com
     * pubsub.googleapis.com
     * storage.googleapis.com
     *
     * @stability stable
     */
    readonly cloudProduct: string;
    /**
     * The enrollment level of the service.
     *
     * Default value: "BLOCK_ALL" Possible values: ["BLOCK_ALL"]
     *
     * @stability stable
     */
    readonly enrollmentLevel?: string;
}
/**
 * @stability stable
 */
export interface OrganizationAccessApprovalSettingsTimeouts {
    /**
     * @stability stable
     */
    readonly create?: string;
    /**
     * @stability stable
     */
    readonly delete?: string;
    /**
     * @stability stable
     */
    readonly update?: string;
}
/**
 * @stability stable
 */
export declare class OrganizationAccessApprovalSettings extends cdktf.TerraformResource {
    /**
     * @stability stable
     */
    constructor(scope: Construct, id: string, config: OrganizationAccessApprovalSettingsConfig);
    /**
     * @stability stable
     */
    get enrolledAncestor(): boolean;
    /**
     * @stability stable
     */
    get id(): string;
    /**
     * @stability stable
     */
    get name(): string;
    private _notificationEmails?;
    /**
     * @stability stable
     */
    get notificationEmails(): string[];
    /**
     * @stability stable
     */
    set notificationEmails(value: string[]);
    /**
     * @stability stable
     */
    resetNotificationEmails(): void;
    /**
     * @stability stable
     */
    get notificationEmailsInput(): string[] | undefined;
    private _organizationId;
    /**
     * @stability stable
     */
    get organizationId(): string;
    /**
     * @stability stable
     */
    set organizationId(value: string);
    /**
     * @stability stable
     */
    get organizationIdInput(): string;
    private _enrolledServices;
    /**
     * @stability stable
     */
    get enrolledServices(): OrganizationAccessApprovalSettingsEnrolledServices[];
    /**
     * @stability stable
     */
    set enrolledServices(value: OrganizationAccessApprovalSettingsEnrolledServices[]);
    /**
     * @stability stable
     */
    get enrolledServicesInput(): OrganizationAccessApprovalSettingsEnrolledServices[];
    private _timeouts?;
    /**
     * @stability stable
     */
    get timeouts(): OrganizationAccessApprovalSettingsTimeouts;
    /**
     * @stability stable
     */
    set timeouts(value: OrganizationAccessApprovalSettingsTimeouts);
    /**
     * @stability stable
     */
    resetTimeouts(): void;
    /**
     * @stability stable
     */
    get timeoutsInput(): OrganizationAccessApprovalSettingsTimeouts | undefined;
    /**
     * @stability stable
     */
    protected synthesizeAttributes(): {
        [name: string]: any;
    };
}
