import { Construct } from 'constructs';
import * as cdktf from 'cdktf';
/**
 * @stability stable
 */
export interface OrganizationIamAuditConfigConfig extends cdktf.TerraformMetaArguments {
    /**
     * The numeric ID of the organization in which you want to manage the audit logging config.
     *
     * @stability stable
     */
    readonly orgId: string;
    /**
     * Service which will be enabled for audit logging.
     *
     * The special value allServices covers all services.
     *
     * @stability stable
     */
    readonly service: string;
    /**
     * audit_log_config block.
     *
     * @stability stable
     */
    readonly auditLogConfig: OrganizationIamAuditConfigAuditLogConfig[];
}
/**
 * @stability stable
 */
export interface OrganizationIamAuditConfigAuditLogConfig {
    /**
     * Identities that do not cause logging for this type of permission.
     *
     * Each entry can have one of the following values:user:{emailid}: An email address that represents a specific Google account. For example, alice@gmail.com or joe@example.com. serviceAccount:{emailid}: An email address that represents a service account. For example, my-other-app@appspot.gserviceaccount.com. group:{emailid}: An email address that represents a Google group. For example, admins@example.com. domain:{domain}: A G Suite domain (primary, instead of alias) name that represents all the users of that domain. For example, google.com or example.com.
     *
     * @stability stable
     */
    readonly exemptedMembers?: string[];
    /**
     * Permission type for which logging is to be configured.
     *
     * Must be one of DATA_READ, DATA_WRITE, or ADMIN_READ.
     *
     * @stability stable
     */
    readonly logType: string;
}
/**
 * @stability stable
 */
export declare class OrganizationIamAuditConfig extends cdktf.TerraformResource {
    /**
     * @stability stable
     */
    constructor(scope: Construct, id: string, config: OrganizationIamAuditConfigConfig);
    /**
     * @stability stable
     */
    get etag(): string;
    /**
     * @stability stable
     */
    get id(): string;
    private _orgId;
    /**
     * @stability stable
     */
    get orgId(): string;
    /**
     * @stability stable
     */
    set orgId(value: string);
    /**
     * @stability stable
     */
    get orgIdInput(): string;
    private _service;
    /**
     * @stability stable
     */
    get service(): string;
    /**
     * @stability stable
     */
    set service(value: string);
    /**
     * @stability stable
     */
    get serviceInput(): string;
    private _auditLogConfig;
    /**
     * @stability stable
     */
    get auditLogConfig(): OrganizationIamAuditConfigAuditLogConfig[];
    /**
     * @stability stable
     */
    set auditLogConfig(value: OrganizationIamAuditConfigAuditLogConfig[]);
    /**
     * @stability stable
     */
    get auditLogConfigInput(): OrganizationIamAuditConfigAuditLogConfig[];
    /**
     * @stability stable
     */
    protected synthesizeAttributes(): {
        [name: string]: any;
    };
}
