import { Construct } from 'constructs';
import * as cdktf from 'cdktf';
/**
 * @stability stable
 */
export interface ProjectDefaultServiceAccountsConfig extends cdktf.TerraformMetaArguments {
    /**
     * The action to be performed in the default service accounts.
     *
     * Valid values are: DEPRIVILEGE, DELETE, DISABLE.
     * Note that DEPRIVILEGE action will ignore the REVERT configuration in the restore_policy.
     *
     * @stability stable
     */
    readonly action: string;
    /**
     * The project ID where service accounts are created.
     *
     * @stability stable
     */
    readonly project: string;
    /**
     * The action to be performed in the default service accounts on the resource destroy.
     *
     * Valid values are NONE, REVERT and REVERT_AND_IGNORE_FAILURE. It is applied for any action but in the DEPRIVILEGE.
     *
     * @stability stable
     */
    readonly restorePolicy?: string;
    /**
     * timeouts block.
     *
     * @stability stable
     */
    readonly timeouts?: ProjectDefaultServiceAccountsTimeouts;
}
/**
 * @stability stable
 */
export interface ProjectDefaultServiceAccountsTimeouts {
    /**
     * @stability stable
     */
    readonly create?: string;
    /**
     * @stability stable
     */
    readonly delete?: string;
    /**
     * @stability stable
     */
    readonly read?: string;
}
/**
 * @stability stable
 */
export declare class ProjectDefaultServiceAccounts extends cdktf.TerraformResource {
    /**
     * @stability stable
     */
    constructor(scope: Construct, id: string, config: ProjectDefaultServiceAccountsConfig);
    private _action;
    /**
     * @stability stable
     */
    get action(): string;
    /**
     * @stability stable
     */
    set action(value: string);
    /**
     * @stability stable
     */
    get actionInput(): string;
    /**
     * @stability stable
     */
    get id(): string;
    private _project;
    /**
     * @stability stable
     */
    get project(): string;
    /**
     * @stability stable
     */
    set project(value: string);
    /**
     * @stability stable
     */
    get projectInput(): string;
    private _restorePolicy?;
    /**
     * @stability stable
     */
    get restorePolicy(): string;
    /**
     * @stability stable
     */
    set restorePolicy(value: string);
    /**
     * @stability stable
     */
    resetRestorePolicy(): void;
    /**
     * @stability stable
     */
    get restorePolicyInput(): string | undefined;
    /**
     * @stability stable
     */
    serviceAccounts(key: string): string;
    private _timeouts?;
    /**
     * @stability stable
     */
    get timeouts(): ProjectDefaultServiceAccountsTimeouts;
    /**
     * @stability stable
     */
    set timeouts(value: ProjectDefaultServiceAccountsTimeouts);
    /**
     * @stability stable
     */
    resetTimeouts(): void;
    /**
     * @stability stable
     */
    get timeoutsInput(): ProjectDefaultServiceAccountsTimeouts | undefined;
    /**
     * @stability stable
     */
    protected synthesizeAttributes(): {
        [name: string]: any;
    };
}
