import { Construct } from 'constructs';
import * as cdktf from 'cdktf';
/**
 * @stability stable
 */
export interface ProjectConfig extends cdktf.TerraformMetaArguments {
    /**
     * Create the 'default' network automatically.
     *
     * Default true. If set to false, the default network will be deleted.  Note that, for quota purposes, you will still need to have 1 network slot available to create the project successfully, even if you set auto_create_network to false, since the network will exist momentarily.
     *
     * @stability stable
     */
    readonly autoCreateNetwork?: boolean;
    /**
     * The alphanumeric ID of the billing account this project belongs to.
     *
     * The user or service account performing this operation with Terraform must have Billing Account Administrator privileges (roles/billing.admin) in the organization. See Google Cloud Billing API Access Control for more details.
     *
     * @stability stable
     */
    readonly billingAccount?: string;
    /**
     * The numeric ID of the folder this project should be created under.
     *
     * Only one of org_id or folder_id may be specified. If the folder_id is specified, then the project is created under the specified folder. Changing this forces the project to be migrated to the newly specified folder.
     *
     * @stability stable
     */
    readonly folderId?: string;
    /**
     * A set of key/value label pairs to assign to the project.
     *
     * @stability stable
     */
    readonly labels?: {
        [key: string]: string;
    };
    /**
     * The display name of the project.
     *
     * @stability stable
     */
    readonly name: string;
    /**
     * The numeric ID of the organization this project belongs to.
     *
     * Changing this forces a new project to be created.  Only one of org_id or folder_id may be specified. If the org_id is specified then the project is created at the top level. Changing this forces the project to be migrated to the newly specified organization.
     *
     * @stability stable
     */
    readonly orgId?: string;
    /**
     * The project ID.
     *
     * Changing this forces a new project to be created.
     *
     * @stability stable
     */
    readonly projectId: string;
    /**
     * If true, the Terraform resource can be deleted without deleting the Project via the Google API.
     *
     * @stability stable
     */
    readonly skipDelete?: boolean;
    /**
     * timeouts block.
     *
     * @stability stable
     */
    readonly timeouts?: ProjectTimeouts;
}
/**
 * @stability stable
 */
export interface ProjectTimeouts {
    /**
     * @stability stable
     */
    readonly create?: string;
    /**
     * @stability stable
     */
    readonly delete?: string;
    /**
     * @stability stable
     */
    readonly read?: string;
    /**
     * @stability stable
     */
    readonly update?: string;
}
/**
 * @stability stable
 */
export declare class Project extends cdktf.TerraformResource {
    /**
     * @stability stable
     */
    constructor(scope: Construct, id: string, config: ProjectConfig);
    private _autoCreateNetwork?;
    /**
     * @stability stable
     */
    get autoCreateNetwork(): boolean;
    /**
     * @stability stable
     */
    set autoCreateNetwork(value: boolean);
    /**
     * @stability stable
     */
    resetAutoCreateNetwork(): void;
    /**
     * @stability stable
     */
    get autoCreateNetworkInput(): boolean | undefined;
    private _billingAccount?;
    /**
     * @stability stable
     */
    get billingAccount(): string;
    /**
     * @stability stable
     */
    set billingAccount(value: string);
    /**
     * @stability stable
     */
    resetBillingAccount(): void;
    /**
     * @stability stable
     */
    get billingAccountInput(): string | undefined;
    private _folderId?;
    /**
     * @stability stable
     */
    get folderId(): string;
    /**
     * @stability stable
     */
    set folderId(value: string);
    /**
     * @stability stable
     */
    resetFolderId(): void;
    /**
     * @stability stable
     */
    get folderIdInput(): string | undefined;
    /**
     * @stability stable
     */
    get id(): string;
    private _labels?;
    /**
     * @stability stable
     */
    get labels(): {
        [key: string]: string;
    };
    /**
     * @stability stable
     */
    set labels(value: {
        [key: string]: string;
    });
    /**
     * @stability stable
     */
    resetLabels(): void;
    /**
     * @stability stable
     */
    get labelsInput(): {
        [key: string]: string;
    } | undefined;
    private _name;
    /**
     * @stability stable
     */
    get name(): string;
    /**
     * @stability stable
     */
    set name(value: string);
    /**
     * @stability stable
     */
    get nameInput(): string;
    /**
     * @stability stable
     */
    get number(): string;
    private _orgId?;
    /**
     * @stability stable
     */
    get orgId(): string;
    /**
     * @stability stable
     */
    set orgId(value: string);
    /**
     * @stability stable
     */
    resetOrgId(): void;
    /**
     * @stability stable
     */
    get orgIdInput(): string | undefined;
    private _projectId;
    /**
     * @stability stable
     */
    get projectId(): string;
    /**
     * @stability stable
     */
    set projectId(value: string);
    /**
     * @stability stable
     */
    get projectIdInput(): string;
    private _skipDelete?;
    /**
     * @stability stable
     */
    get skipDelete(): boolean;
    /**
     * @stability stable
     */
    set skipDelete(value: boolean);
    /**
     * @stability stable
     */
    resetSkipDelete(): void;
    /**
     * @stability stable
     */
    get skipDeleteInput(): boolean | undefined;
    private _timeouts?;
    /**
     * @stability stable
     */
    get timeouts(): ProjectTimeouts;
    /**
     * @stability stable
     */
    set timeouts(value: ProjectTimeouts);
    /**
     * @stability stable
     */
    resetTimeouts(): void;
    /**
     * @stability stable
     */
    get timeoutsInput(): ProjectTimeouts | undefined;
    /**
     * @stability stable
     */
    protected synthesizeAttributes(): {
        [name: string]: any;
    };
}
