import { Construct } from 'constructs';
import * as cdktf from 'cdktf';
/**
 * @stability stable
 */
export interface PubsubSubscriptionConfig extends cdktf.TerraformMetaArguments {
    /**
     * This value is the maximum time after a subscriber receives a message before the subscriber should acknowledge the message.
     *
     * After message
     * delivery but before the ack deadline expires and before the message is
     * acknowledged, it is an outstanding message and will not be delivered
     * again during that time (on a best-effort basis).
     *
     * For pull subscriptions, this value is used as the initial value for
     * the ack deadline. To override this value for a given message, call
     * subscriptions.modifyAckDeadline with the corresponding ackId if using
     * pull. The minimum custom deadline you can specify is 10 seconds. The
     * maximum custom deadline you can specify is 600 seconds (10 minutes).
     * If this parameter is 0, a default value of 10 seconds is used.
     *
     * For push delivery, this value is also used to set the request timeout
     * for the call to the push endpoint.
     *
     * If the subscriber never acknowledges the message, the Pub/Sub system
     * will eventually redeliver the message.
     *
     * @stability stable
     */
    readonly ackDeadlineSeconds?: number;
    /**
     * If 'true', messages published with the same orderingKey in PubsubMessage will be delivered to the subscribers in the order in which they are received by the Pub/Sub system.
     *
     * Otherwise, they
     * may be delivered in any order.
     *
     * @stability stable
     */
    readonly enableMessageOrdering?: boolean;
    /**
     * The subscription only delivers the messages that match the filter.
     *
     * Pub/Sub automatically acknowledges the messages that don't match the filter. You can filter messages
     * by their attributes. The maximum length of a filter is 256 bytes. After creating the subscription,
     * you can't modify the filter.
     *
     * @stability stable
     */
    readonly filter?: string;
    /**
     * A set of key/value label pairs to assign to this Subscription.
     *
     * @stability stable
     */
    readonly labels?: {
        [key: string]: string;
    };
    /**
     * How long to retain unacknowledged messages in the subscription's backlog, from the moment a message is published.
     *
     * If
     * retainAckedMessages is true, then this also configures the retention
     * of acknowledged messages, and thus configures how far back in time a
     * subscriptions.seek can be done. Defaults to 7 days. Cannot be more
     * than 7 days ('"604800s"') or less than 10 minutes ('"600s"').
     *
     * A duration in seconds with up to nine fractional digits, terminated
     * by 's'. Example: '"600.5s"'.
     *
     * @stability stable
     */
    readonly messageRetentionDuration?: string;
    /**
     * Name of the subscription.
     *
     * @stability stable
     */
    readonly name: string;
    /**
     * @stability stable
     */
    readonly project?: string;
    /**
     * Indicates whether to retain acknowledged messages.
     *
     * If 'true', then
     * messages are not expunged from the subscription's backlog, even if
     * they are acknowledged, until they fall out of the
     * messageRetentionDuration window.
     *
     * @stability stable
     */
    readonly retainAckedMessages?: boolean;
    /**
     * A reference to a Topic resource.
     *
     * @stability stable
     */
    readonly topic: string;
    /**
     * dead_letter_policy block.
     *
     * @stability stable
     */
    readonly deadLetterPolicy?: PubsubSubscriptionDeadLetterPolicy[];
    /**
     * expiration_policy block.
     *
     * @stability stable
     */
    readonly expirationPolicy?: PubsubSubscriptionExpirationPolicy[];
    /**
     * push_config block.
     *
     * @stability stable
     */
    readonly pushConfig?: PubsubSubscriptionPushConfig[];
    /**
     * retry_policy block.
     *
     * @stability stable
     */
    readonly retryPolicy?: PubsubSubscriptionRetryPolicy[];
    /**
     * timeouts block.
     *
     * @stability stable
     */
    readonly timeouts?: PubsubSubscriptionTimeouts;
}
/**
 * @stability stable
 */
export interface PubsubSubscriptionDeadLetterPolicy {
    /**
     * The name of the topic to which dead letter messages should be published. Format is 'projects/{project}/topics/{topic}'.
     *
     * The Cloud Pub/Sub service account associated with the enclosing subscription's
     * parent project (i.e.,
     * service-{project_number}@gcp-sa-pubsub.iam.gserviceaccount.com) must have
     * permission to Publish() to this topic.
     *
     * The operation will fail if the topic does not exist.
     * Users should ensure that there is a subscription attached to this topic
     * since messages published to a topic with no subscriptions are lost.
     *
     * @stability stable
     */
    readonly deadLetterTopic?: string;
    /**
     * The maximum number of delivery attempts for any message. The value must be between 5 and 100.
     *
     * The number of delivery attempts is defined as 1 + (the sum of number of
     * NACKs and number of times the acknowledgement deadline has been exceeded for the message).
     *
     * A NACK is any call to ModifyAckDeadline with a 0 deadline. Note that
     * client libraries may automatically extend ack_deadlines.
     *
     * This field will be honored on a best effort basis.
     *
     * If this parameter is 0, a default value of 5 is used.
     *
     * @stability stable
     */
    readonly maxDeliveryAttempts?: number;
}
/**
 * @stability stable
 */
export interface PubsubSubscriptionExpirationPolicy {
    /**
     * Specifies the "time-to-live" duration for an associated resource.
     *
     * The
     * resource expires if it is not active for a period of ttl.
     * If ttl is not set, the associated resource never expires.
     * A duration in seconds with up to nine fractional digits, terminated by 's'.
     * Example - "3.5s".
     *
     * @stability stable
     */
    readonly ttl: string;
}
/**
 * @stability stable
 */
export interface PubsubSubscriptionPushConfigOidcToken {
    /**
     * Audience to be used when generating OIDC token.
     *
     * The audience claim
     * identifies the recipients that the JWT is intended for. The audience
     * value is a single case-sensitive string. Having multiple values (array)
     * for the audience field is not supported. More info about the OIDC JWT
     * token audience here: https://tools.ietf.org/html/rfc7519#section-4.1.3
     * Note: if not specified, the Push endpoint URL will be used.
     *
     * @stability stable
     */
    readonly audience?: string;
    /**
     * Service account email to be used for generating the OIDC token.
     *
     * The caller (for subscriptions.create, subscriptions.patch, and
     * subscriptions.modifyPushConfig RPCs) must have the
     * iam.serviceAccounts.actAs permission for the service account.
     *
     * @stability stable
     */
    readonly serviceAccountEmail: string;
}
/**
 * @stability stable
 */
export interface PubsubSubscriptionPushConfig {
    /**
     * Endpoint configuration attributes.
     *
     * Every endpoint has a set of API supported attributes that can
     * be used to control different aspects of the message delivery.
     *
     * The currently supported attribute is x-goog-version, which you
     * can use to change the format of the pushed message. This
     * attribute indicates the version of the data expected by
     * the endpoint. This controls the shape of the pushed message
     * (i.e., its fields and metadata). The endpoint version is
     * based on the version of the Pub/Sub API.
     *
     * If not present during the subscriptions.create call,
     * it will default to the version of the API used to make
     * such call. If not present during a subscriptions.modifyPushConfig
     * call, its value will not be changed. subscriptions.get
     * calls will always return a valid version, even if the
     * subscription was created without this attribute.
     *
     * The possible values for this attribute are:
     *
     * - v1beta1: uses the push format defined in the v1beta1 Pub/Sub API.
     * - v1 or v1beta2: uses the push format defined in the v1 Pub/Sub API.
     *
     * @stability stable
     */
    readonly attributes?: {
        [key: string]: string;
    };
    /**
     * A URL locating the endpoint to which messages should be pushed.
     *
     * For example, a Webhook endpoint might use
     * "https://example.com/push".
     *
     * @stability stable
     */
    readonly pushEndpoint: string;
    /**
     * oidc_token block.
     *
     * @stability stable
     */
    readonly oidcToken?: PubsubSubscriptionPushConfigOidcToken[];
}
/**
 * @stability stable
 */
export interface PubsubSubscriptionRetryPolicy {
    /**
     * The maximum delay between consecutive deliveries of a given message.
     *
     * Value should be between 0 and 600 seconds. Defaults to 600 seconds.
     * A duration in seconds with up to nine fractional digits, terminated by 's'. Example: "3.5s".
     *
     * @stability stable
     */
    readonly maximumBackoff?: string;
    /**
     * The minimum delay between consecutive deliveries of a given message.
     *
     * Value should be between 0 and 600 seconds. Defaults to 10 seconds.
     * A duration in seconds with up to nine fractional digits, terminated by 's'. Example: "3.5s".
     *
     * @stability stable
     */
    readonly minimumBackoff?: string;
}
/**
 * @stability stable
 */
export interface PubsubSubscriptionTimeouts {
    /**
     * @stability stable
     */
    readonly create?: string;
    /**
     * @stability stable
     */
    readonly delete?: string;
    /**
     * @stability stable
     */
    readonly update?: string;
}
/**
 * @stability stable
 */
export declare class PubsubSubscription extends cdktf.TerraformResource {
    /**
     * @stability stable
     */
    constructor(scope: Construct, id: string, config: PubsubSubscriptionConfig);
    private _ackDeadlineSeconds?;
    /**
     * @stability stable
     */
    get ackDeadlineSeconds(): number;
    /**
     * @stability stable
     */
    set ackDeadlineSeconds(value: number);
    /**
     * @stability stable
     */
    resetAckDeadlineSeconds(): void;
    /**
     * @stability stable
     */
    get ackDeadlineSecondsInput(): number | undefined;
    private _enableMessageOrdering?;
    /**
     * @stability stable
     */
    get enableMessageOrdering(): boolean;
    /**
     * @stability stable
     */
    set enableMessageOrdering(value: boolean);
    /**
     * @stability stable
     */
    resetEnableMessageOrdering(): void;
    /**
     * @stability stable
     */
    get enableMessageOrderingInput(): boolean | undefined;
    private _filter?;
    /**
     * @stability stable
     */
    get filter(): string;
    /**
     * @stability stable
     */
    set filter(value: string);
    /**
     * @stability stable
     */
    resetFilter(): void;
    /**
     * @stability stable
     */
    get filterInput(): string | undefined;
    /**
     * @stability stable
     */
    get id(): string;
    private _labels?;
    /**
     * @stability stable
     */
    get labels(): {
        [key: string]: string;
    };
    /**
     * @stability stable
     */
    set labels(value: {
        [key: string]: string;
    });
    /**
     * @stability stable
     */
    resetLabels(): void;
    /**
     * @stability stable
     */
    get labelsInput(): {
        [key: string]: string;
    } | undefined;
    private _messageRetentionDuration?;
    /**
     * @stability stable
     */
    get messageRetentionDuration(): string;
    /**
     * @stability stable
     */
    set messageRetentionDuration(value: string);
    /**
     * @stability stable
     */
    resetMessageRetentionDuration(): void;
    /**
     * @stability stable
     */
    get messageRetentionDurationInput(): string | undefined;
    private _name;
    /**
     * @stability stable
     */
    get name(): string;
    /**
     * @stability stable
     */
    set name(value: string);
    /**
     * @stability stable
     */
    get nameInput(): string;
    /**
     * @stability stable
     */
    get path(): string;
    private _project?;
    /**
     * @stability stable
     */
    get project(): string;
    /**
     * @stability stable
     */
    set project(value: string);
    /**
     * @stability stable
     */
    resetProject(): void;
    /**
     * @stability stable
     */
    get projectInput(): string | undefined;
    private _retainAckedMessages?;
    /**
     * @stability stable
     */
    get retainAckedMessages(): boolean;
    /**
     * @stability stable
     */
    set retainAckedMessages(value: boolean);
    /**
     * @stability stable
     */
    resetRetainAckedMessages(): void;
    /**
     * @stability stable
     */
    get retainAckedMessagesInput(): boolean | undefined;
    private _topic;
    /**
     * @stability stable
     */
    get topic(): string;
    /**
     * @stability stable
     */
    set topic(value: string);
    /**
     * @stability stable
     */
    get topicInput(): string;
    private _deadLetterPolicy?;
    /**
     * @stability stable
     */
    get deadLetterPolicy(): PubsubSubscriptionDeadLetterPolicy[];
    /**
     * @stability stable
     */
    set deadLetterPolicy(value: PubsubSubscriptionDeadLetterPolicy[]);
    /**
     * @stability stable
     */
    resetDeadLetterPolicy(): void;
    /**
     * @stability stable
     */
    get deadLetterPolicyInput(): PubsubSubscriptionDeadLetterPolicy[] | undefined;
    private _expirationPolicy?;
    /**
     * @stability stable
     */
    get expirationPolicy(): PubsubSubscriptionExpirationPolicy[];
    /**
     * @stability stable
     */
    set expirationPolicy(value: PubsubSubscriptionExpirationPolicy[]);
    /**
     * @stability stable
     */
    resetExpirationPolicy(): void;
    /**
     * @stability stable
     */
    get expirationPolicyInput(): PubsubSubscriptionExpirationPolicy[] | undefined;
    private _pushConfig?;
    /**
     * @stability stable
     */
    get pushConfig(): PubsubSubscriptionPushConfig[];
    /**
     * @stability stable
     */
    set pushConfig(value: PubsubSubscriptionPushConfig[]);
    /**
     * @stability stable
     */
    resetPushConfig(): void;
    /**
     * @stability stable
     */
    get pushConfigInput(): PubsubSubscriptionPushConfig[] | undefined;
    private _retryPolicy?;
    /**
     * @stability stable
     */
    get retryPolicy(): PubsubSubscriptionRetryPolicy[];
    /**
     * @stability stable
     */
    set retryPolicy(value: PubsubSubscriptionRetryPolicy[]);
    /**
     * @stability stable
     */
    resetRetryPolicy(): void;
    /**
     * @stability stable
     */
    get retryPolicyInput(): PubsubSubscriptionRetryPolicy[] | undefined;
    private _timeouts?;
    /**
     * @stability stable
     */
    get timeouts(): PubsubSubscriptionTimeouts;
    /**
     * @stability stable
     */
    set timeouts(value: PubsubSubscriptionTimeouts);
    /**
     * @stability stable
     */
    resetTimeouts(): void;
    /**
     * @stability stable
     */
    get timeoutsInput(): PubsubSubscriptionTimeouts | undefined;
    /**
     * @stability stable
     */
    protected synthesizeAttributes(): {
        [name: string]: any;
    };
}
