import { Construct } from 'constructs';
import * as cdktf from 'cdktf';
/**
 * @stability stable
 */
export interface PubsubTopicConfig extends cdktf.TerraformMetaArguments {
    /**
     * The resource name of the Cloud KMS CryptoKey to be used to protect access to messages published on this topic.
     *
     * Your project's PubSub service account
     * ('service-{{PROJECT_NUMBER}}@gcp-sa-pubsub.iam.gserviceaccount.com') must have
     * 'roles/cloudkms.cryptoKeyEncrypterDecrypter' to use this feature.
     * The expected format is 'projects/*\/locations/*\/keyRings/*\/cryptoKeys/*'
     *
     * @stability stable
     */
    readonly kmsKeyName?: string;
    /**
     * A set of key/value label pairs to assign to this Topic.
     *
     * @stability stable
     */
    readonly labels?: {
        [key: string]: string;
    };
    /**
     * Name of the topic.
     *
     * @stability stable
     */
    readonly name: string;
    /**
     * @stability stable
     */
    readonly project?: string;
    /**
     * message_storage_policy block.
     *
     * @stability stable
     */
    readonly messageStoragePolicy?: PubsubTopicMessageStoragePolicy[];
    /**
     * timeouts block.
     *
     * @stability stable
     */
    readonly timeouts?: PubsubTopicTimeouts;
}
/**
 * @stability stable
 */
export interface PubsubTopicMessageStoragePolicy {
    /**
     * A list of IDs of GCP regions where messages that are published to the topic may be persisted in storage.
     *
     * Messages published by
     * publishers running in non-allowed GCP regions (or running outside
     * of GCP altogether) will be routed for storage in one of the
     * allowed regions. An empty list means that no regions are allowed,
     * and is not a valid configuration.
     *
     * @stability stable
     */
    readonly allowedPersistenceRegions: string[];
}
/**
 * @stability stable
 */
export interface PubsubTopicTimeouts {
    /**
     * @stability stable
     */
    readonly create?: string;
    /**
     * @stability stable
     */
    readonly delete?: string;
    /**
     * @stability stable
     */
    readonly update?: string;
}
/**
 * @stability stable
 */
export declare class PubsubTopic extends cdktf.TerraformResource {
    /**
     * @stability stable
     */
    constructor(scope: Construct, id: string, config: PubsubTopicConfig);
    /**
     * @stability stable
     */
    get id(): string;
    private _kmsKeyName?;
    /**
     * @stability stable
     */
    get kmsKeyName(): string;
    /**
     * @stability stable
     */
    set kmsKeyName(value: string);
    /**
     * @stability stable
     */
    resetKmsKeyName(): void;
    /**
     * @stability stable
     */
    get kmsKeyNameInput(): string | undefined;
    private _labels?;
    /**
     * @stability stable
     */
    get labels(): {
        [key: string]: string;
    };
    /**
     * @stability stable
     */
    set labels(value: {
        [key: string]: string;
    });
    /**
     * @stability stable
     */
    resetLabels(): void;
    /**
     * @stability stable
     */
    get labelsInput(): {
        [key: string]: string;
    } | undefined;
    private _name;
    /**
     * @stability stable
     */
    get name(): string;
    /**
     * @stability stable
     */
    set name(value: string);
    /**
     * @stability stable
     */
    get nameInput(): string;
    private _project?;
    /**
     * @stability stable
     */
    get project(): string;
    /**
     * @stability stable
     */
    set project(value: string);
    /**
     * @stability stable
     */
    resetProject(): void;
    /**
     * @stability stable
     */
    get projectInput(): string | undefined;
    private _messageStoragePolicy?;
    /**
     * @stability stable
     */
    get messageStoragePolicy(): PubsubTopicMessageStoragePolicy[];
    /**
     * @stability stable
     */
    set messageStoragePolicy(value: PubsubTopicMessageStoragePolicy[]);
    /**
     * @stability stable
     */
    resetMessageStoragePolicy(): void;
    /**
     * @stability stable
     */
    get messageStoragePolicyInput(): PubsubTopicMessageStoragePolicy[] | undefined;
    private _timeouts?;
    /**
     * @stability stable
     */
    get timeouts(): PubsubTopicTimeouts;
    /**
     * @stability stable
     */
    set timeouts(value: PubsubTopicTimeouts);
    /**
     * @stability stable
     */
    resetTimeouts(): void;
    /**
     * @stability stable
     */
    get timeoutsInput(): PubsubTopicTimeouts | undefined;
    /**
     * @stability stable
     */
    protected synthesizeAttributes(): {
        [name: string]: any;
    };
}
