import { Construct } from 'constructs';
import * as cdktf from 'cdktf';
/**
 * @stability stable
 */
export interface ServiceAccountKeyConfig extends cdktf.TerraformMetaArguments {
    /**
     * The algorithm used to generate the key, used only on create.
     *
     * KEY_ALG_RSA_2048 is the default algorithm. Valid values are: "KEY_ALG_RSA_1024", "KEY_ALG_RSA_2048".
     *
     * @stability stable
     */
    readonly keyAlgorithm?: string;
    /**
     * @stability stable
     */
    readonly privateKeyType?: string;
    /**
     * A field that allows clients to upload their own public key.
     *
     * If set, use this public key data to create a service account key for given service account. Please note, the expected format for this field is a base64 encoded X509_PEM.
     *
     * @stability stable
     */
    readonly publicKeyData?: string;
    /**
     * @stability stable
     */
    readonly publicKeyType?: string;
    /**
     * The ID of the parent service account of the key.
     *
     * This can be a string in the format {ACCOUNT} or projects/{PROJECT_ID}/serviceAccounts/{ACCOUNT}, where {ACCOUNT} is the email address or unique id of the service account. If the {ACCOUNT} syntax is used, the project will be inferred from the account.
     *
     * @stability stable
     */
    readonly serviceAccountId: string;
}
/**
 * @stability stable
 */
export declare class ServiceAccountKey extends cdktf.TerraformResource {
    /**
     * @stability stable
     */
    constructor(scope: Construct, id: string, config: ServiceAccountKeyConfig);
    /**
     * @stability stable
     */
    get id(): string;
    private _keyAlgorithm?;
    /**
     * @stability stable
     */
    get keyAlgorithm(): string;
    /**
     * @stability stable
     */
    set keyAlgorithm(value: string);
    /**
     * @stability stable
     */
    resetKeyAlgorithm(): void;
    /**
     * @stability stable
     */
    get keyAlgorithmInput(): string | undefined;
    /**
     * @stability stable
     */
    get name(): string;
    /**
     * @stability stable
     */
    get privateKey(): string;
    private _privateKeyType?;
    /**
     * @stability stable
     */
    get privateKeyType(): string;
    /**
     * @stability stable
     */
    set privateKeyType(value: string);
    /**
     * @stability stable
     */
    resetPrivateKeyType(): void;
    /**
     * @stability stable
     */
    get privateKeyTypeInput(): string | undefined;
    /**
     * @stability stable
     */
    get publicKey(): string;
    private _publicKeyData?;
    /**
     * @stability stable
     */
    get publicKeyData(): string;
    /**
     * @stability stable
     */
    set publicKeyData(value: string);
    /**
     * @stability stable
     */
    resetPublicKeyData(): void;
    /**
     * @stability stable
     */
    get publicKeyDataInput(): string | undefined;
    private _publicKeyType?;
    /**
     * @stability stable
     */
    get publicKeyType(): string;
    /**
     * @stability stable
     */
    set publicKeyType(value: string);
    /**
     * @stability stable
     */
    resetPublicKeyType(): void;
    /**
     * @stability stable
     */
    get publicKeyTypeInput(): string | undefined;
    private _serviceAccountId;
    /**
     * @stability stable
     */
    get serviceAccountId(): string;
    /**
     * @stability stable
     */
    set serviceAccountId(value: string);
    /**
     * @stability stable
     */
    get serviceAccountIdInput(): string;
    /**
     * @stability stable
     */
    get validAfter(): string;
    /**
     * @stability stable
     */
    get validBefore(): string;
    /**
     * @stability stable
     */
    protected synthesizeAttributes(): {
        [name: string]: any;
    };
}
