import { Construct } from 'constructs';
import * as cdktf from 'cdktf';
/**
 * @stability stable
 */
export interface ServiceNetworkingConnectionConfig extends cdktf.TerraformMetaArguments {
    /**
     * Name of VPC network connected with service producers using VPC peering.
     *
     * @stability stable
     */
    readonly network: string;
    /**
     * Named IP address range(s) of PEERING type reserved for this service provider.
     *
     * Note that invoking this method with a different range when connection is already established will not reallocate already provisioned service producer subnetworks.
     *
     * @stability stable
     */
    readonly reservedPeeringRanges: string[];
    /**
     * Provider peering service that is managing peering connectivity for a service provider organization.
     *
     * For Google services that support this functionality it is 'servicenetworking.googleapis.com'.
     *
     * @stability stable
     */
    readonly service: string;
    /**
     * timeouts block.
     *
     * @stability stable
     */
    readonly timeouts?: ServiceNetworkingConnectionTimeouts;
}
/**
 * @stability stable
 */
export interface ServiceNetworkingConnectionTimeouts {
    /**
     * @stability stable
     */
    readonly create?: string;
    /**
     * @stability stable
     */
    readonly delete?: string;
    /**
     * @stability stable
     */
    readonly update?: string;
}
/**
 * @stability stable
 */
export declare class ServiceNetworkingConnection extends cdktf.TerraformResource {
    /**
     * @stability stable
     */
    constructor(scope: Construct, id: string, config: ServiceNetworkingConnectionConfig);
    /**
     * @stability stable
     */
    get id(): string;
    private _network;
    /**
     * @stability stable
     */
    get network(): string;
    /**
     * @stability stable
     */
    set network(value: string);
    /**
     * @stability stable
     */
    get networkInput(): string;
    /**
     * @stability stable
     */
    get peering(): string;
    private _reservedPeeringRanges;
    /**
     * @stability stable
     */
    get reservedPeeringRanges(): string[];
    /**
     * @stability stable
     */
    set reservedPeeringRanges(value: string[]);
    /**
     * @stability stable
     */
    get reservedPeeringRangesInput(): string[];
    private _service;
    /**
     * @stability stable
     */
    get service(): string;
    /**
     * @stability stable
     */
    set service(value: string);
    /**
     * @stability stable
     */
    get serviceInput(): string;
    private _timeouts?;
    /**
     * @stability stable
     */
    get timeouts(): ServiceNetworkingConnectionTimeouts;
    /**
     * @stability stable
     */
    set timeouts(value: ServiceNetworkingConnectionTimeouts);
    /**
     * @stability stable
     */
    resetTimeouts(): void;
    /**
     * @stability stable
     */
    get timeoutsInput(): ServiceNetworkingConnectionTimeouts | undefined;
    /**
     * @stability stable
     */
    protected synthesizeAttributes(): {
        [name: string]: any;
    };
}
