import { Construct } from 'constructs';
import * as cdktf from 'cdktf';
/**
 * @stability stable
 */
export interface SqlDatabaseInstanceConfig extends cdktf.TerraformMetaArguments {
    /**
     * The MySQL, PostgreSQL or SQL Server (beta) version to use.
     *
     * Supported values include MYSQL_5_6, MYSQL_5_7, POSTGRES_9_6,POSTGRES_11, SQLSERVER_2017_STANDARD, SQLSERVER_2017_ENTERPRISE, SQLSERVER_2017_EXPRESS, SQLSERVER_2017_WEB. Database Version Policies includes an up-to-date reference of supported versions.
     *
     * @stability stable
     */
    readonly databaseVersion?: string;
    /**
     * Used to block Terraform from deleting a SQL Instance.
     *
     * @stability stable
     */
    readonly deletionProtection?: boolean;
    /**
     * The name of the instance that will act as the master in the replication setup.
     *
     * Note, this requires the master to have binary_log_enabled set, as well as existing backups.
     *
     * @stability stable
     */
    readonly masterInstanceName?: string;
    /**
     * The name of the instance.
     *
     * If the name is left blank, Terraform will randomly generate one when the instance is first created. This is done because after a name is used, it cannot be reused for up to one week.
     *
     * @stability stable
     */
    readonly name?: string;
    /**
     * The ID of the project in which the resource belongs.
     *
     * If it is not provided, the provider project is used.
     *
     * @stability stable
     */
    readonly project?: string;
    /**
     * The region the instance will sit in.
     *
     * Note, Cloud SQL is not available in all regions - choose from one of the options listed here. A valid region must be provided to use this resource. If a region is not provided in the resource definition, the provider region will be used instead, but this will be an apply-time error for instances if the provider region is not supported with Cloud SQL. If you choose not to provide the region argument for this resource, make sure you understand this.
     *
     * @stability stable
     */
    readonly region?: string;
    /**
     * Initial root password.
     *
     * Required for MS SQL Server, ignored by MySQL and PostgreSQL.
     *
     * @stability stable
     */
    readonly rootPassword?: string;
    /**
     * replica_configuration block.
     *
     * @stability stable
     */
    readonly replicaConfiguration?: SqlDatabaseInstanceReplicaConfiguration[];
    /**
     * settings block.
     *
     * @stability stable
     */
    readonly settings: SqlDatabaseInstanceSettings[];
    /**
     * timeouts block.
     *
     * @stability stable
     */
    readonly timeouts?: SqlDatabaseInstanceTimeouts;
}
/**
 * @stability stable
 */
export declare class SqlDatabaseInstanceIpAddress extends cdktf.ComplexComputedList {
    /**
     * @stability stable
     */
    get ipAddress(): string;
    /**
     * @stability stable
     */
    get timeToRetire(): string;
    /**
     * @stability stable
     */
    get type(): string;
}
/**
 * @stability stable
 */
export declare class SqlDatabaseInstanceServerCaCert extends cdktf.ComplexComputedList {
    /**
     * @stability stable
     */
    get cert(): string;
    /**
     * @stability stable
     */
    get commonName(): string;
    /**
     * @stability stable
     */
    get createTime(): string;
    /**
     * @stability stable
     */
    get expirationTime(): string;
    /**
     * @stability stable
     */
    get sha1Fingerprint(): string;
}
/**
 * @stability stable
 */
export interface SqlDatabaseInstanceReplicaConfiguration {
    /**
     * PEM representation of the trusted CA's x509 certificate.
     *
     * @stability stable
     */
    readonly caCertificate?: string;
    /**
     * PEM representation of the slave's x509 certificate.
     *
     * @stability stable
     */
    readonly clientCertificate?: string;
    /**
     * PEM representation of the slave's private key.
     *
     * The corresponding public key in encoded in the client_certificate.
     *
     * @stability stable
     */
    readonly clientKey?: string;
    /**
     * The number of seconds between connect retries.
     *
     * @stability stable
     */
    readonly connectRetryInterval?: number;
    /**
     * Path to a SQL file in Google Cloud Storage from which slave instances are created.
     *
     * Format is gs://bucket/filename.
     *
     * @stability stable
     */
    readonly dumpFilePath?: string;
    /**
     * Specifies if the replica is the failover target.
     *
     * If the field is set to true the replica will be designated as a failover replica. If the master instance fails, the replica instance will be promoted as the new master instance.
     *
     * @stability stable
     */
    readonly failoverTarget?: boolean;
    /**
     * Time in ms between replication heartbeats.
     *
     * @stability stable
     */
    readonly masterHeartbeatPeriod?: number;
    /**
     * Password for the replication connection.
     *
     * @stability stable
     */
    readonly password?: string;
    /**
     * Permissible ciphers for use in SSL encryption.
     *
     * @stability stable
     */
    readonly sslCipher?: string;
    /**
     * Username for replication connection.
     *
     * @stability stable
     */
    readonly username?: string;
    /**
     * True if the master's common name value is checked during the SSL handshake.
     *
     * @stability stable
     */
    readonly verifyServerCertificate?: boolean;
}
/**
 * @stability stable
 */
export interface SqlDatabaseInstanceSettingsBackupConfiguration {
    /**
     * True if binary logging is enabled.
     *
     * If settings.backup_configuration.enabled is false, this must be as well. Cannot be used with Postgres.
     *
     * @stability stable
     */
    readonly binaryLogEnabled?: boolean;
    /**
     * True if backup configuration is enabled.
     *
     * @stability stable
     */
    readonly enabled?: boolean;
    /**
     * Location of the backup configuration.
     *
     * @stability stable
     */
    readonly location?: string;
    /**
     * True if Point-in-time recovery is enabled.
     *
     * @stability stable
     */
    readonly pointInTimeRecoveryEnabled?: boolean;
    /**
     * HH:MM format time indicating when backup configuration starts.
     *
     * @stability stable
     */
    readonly startTime?: string;
}
/**
 * @stability stable
 */
export interface SqlDatabaseInstanceSettingsDatabaseFlags {
    /**
     * Name of the flag.
     *
     * @stability stable
     */
    readonly name: string;
    /**
     * Value of the flag.
     *
     * @stability stable
     */
    readonly value: string;
}
/**
 * @stability stable
 */
export interface SqlDatabaseInstanceSettingsIpConfigurationAuthorizedNetworks {
    /**
     * @stability stable
     */
    readonly expirationTime?: string;
    /**
     * @stability stable
     */
    readonly name?: string;
    /**
     * @stability stable
     */
    readonly value: string;
}
/**
 * @stability stable
 */
export interface SqlDatabaseInstanceSettingsIpConfiguration {
    /**
     * Whether this Cloud SQL instance should be assigned a public IPV4 address.
     *
     * Either ipv4_enabled must be enabled or a private_network must be configured.
     *
     * @stability stable
     */
    readonly ipv4Enabled?: boolean;
    /**
     * The VPC network from which the Cloud SQL instance is accessible for private IP.
     *
     * For example, projects/myProject/global/networks/default. Specifying a network enables private IP. Either ipv4_enabled must be enabled or a private_network must be configured. This setting can be updated, but it cannot be removed after it is set.
     *
     * @stability stable
     */
    readonly privateNetwork?: string;
    /**
     * @stability stable
     */
    readonly requireSsl?: boolean;
    /**
     * authorized_networks block.
     *
     * @stability stable
     */
    readonly authorizedNetworks?: SqlDatabaseInstanceSettingsIpConfigurationAuthorizedNetworks[];
}
/**
 * @stability stable
 */
export interface SqlDatabaseInstanceSettingsLocationPreference {
    /**
     * A Google App Engine application whose zone to remain in.
     *
     * Must be in the same region as this instance.
     *
     * @stability stable
     */
    readonly followGaeApplication?: string;
    /**
     * The preferred compute engine zone.
     *
     * @stability stable
     */
    readonly zone?: string;
}
/**
 * @stability stable
 */
export interface SqlDatabaseInstanceSettingsMaintenanceWindow {
    /**
     * Day of week (1-7), starting on Monday.
     *
     * @stability stable
     */
    readonly day?: number;
    /**
     * Hour of day (0-23), ignored if day not set.
     *
     * @stability stable
     */
    readonly hour?: number;
    /**
     * Receive updates earlier (canary) or later (stable).
     *
     * @stability stable
     */
    readonly updateTrack?: string;
}
/**
 * @stability stable
 */
export interface SqlDatabaseInstanceSettings {
    /**
     * This specifies when the instance should be active.
     *
     * Can be either ALWAYS, NEVER or ON_DEMAND.
     *
     * @stability stable
     */
    readonly activationPolicy?: string;
    /**
     * This property is only applicable to First Generation instances.
     *
     * First Generation instances are now deprecated, see https://cloud.google.com/sql/docs/mysql/deprecation-notice for information on how to upgrade to Second Generation instances. A list of Google App Engine project names that are allowed to access this instance.
     *
     * @stability stable
     */
    readonly authorizedGaeApplications?: string[];
    /**
     * The availability type of the Cloud SQL instance, high availability (REGIONAL) or single zone (ZONAL).
     *
     * For MySQL instances, ensure that
     * settings.backup_configuration.enabled and
     * settings.backup_configuration.binary_log_enabled are both set to true.
     *
     * @stability stable
     */
    readonly availabilityType?: string;
    /**
     * This property is only applicable to First Generation instances.
     *
     * First Generation instances are now deprecated, see here for information on how to upgrade to Second Generation instances. Specific to read instances, indicates when crash-safe replication flags are enabled.
     *
     * @stability stable
     */
    readonly crashSafeReplication?: boolean;
    /**
     * Configuration to increase storage size automatically.
     *
     * Note that future terraform apply calls will attempt to resize the disk to the value specified in disk_size - if this is set, do not set disk_size.
     *
     * @stability stable
     */
    readonly diskAutoresize?: boolean;
    /**
     * The size of data disk, in GB.
     *
     * Size of a running instance cannot be reduced but can be increased.
     *
     * @stability stable
     */
    readonly diskSize?: number;
    /**
     * The type of data disk: PD_SSD or PD_HDD.
     *
     * @stability stable
     */
    readonly diskType?: string;
    /**
     * Pricing plan for this instance, can only be PER_USE.
     *
     * @stability stable
     */
    readonly pricingPlan?: string;
    /**
     * This property is only applicable to First Generation instances.
     *
     * First Generation instances are now deprecated, see here for information on how to upgrade to Second Generation instances. Replication type for this instance, can be one of ASYNCHRONOUS or SYNCHRONOUS.
     *
     * @stability stable
     */
    readonly replicationType?: string;
    /**
     * The machine type to use.
     *
     * See tiers for more details and supported versions. Postgres supports only shared-core machine types such as db-f1-micro, and custom machine types such as db-custom-2-13312. See the Custom Machine Type Documentation to learn about specifying custom machine types.
     *
     * @stability stable
     */
    readonly tier: string;
    /**
     * A set of key/value user label pairs to assign to the instance.
     *
     * @stability stable
     */
    readonly userLabels?: {
        [key: string]: string;
    };
    /**
     * backup_configuration block.
     *
     * @stability stable
     */
    readonly backupConfiguration?: SqlDatabaseInstanceSettingsBackupConfiguration[];
    /**
     * database_flags block.
     *
     * @stability stable
     */
    readonly databaseFlags?: SqlDatabaseInstanceSettingsDatabaseFlags[];
    /**
     * ip_configuration block.
     *
     * @stability stable
     */
    readonly ipConfiguration?: SqlDatabaseInstanceSettingsIpConfiguration[];
    /**
     * location_preference block.
     *
     * @stability stable
     */
    readonly locationPreference?: SqlDatabaseInstanceSettingsLocationPreference[];
    /**
     * maintenance_window block.
     *
     * @stability stable
     */
    readonly maintenanceWindow?: SqlDatabaseInstanceSettingsMaintenanceWindow[];
}
/**
 * @stability stable
 */
export interface SqlDatabaseInstanceTimeouts {
    /**
     * @stability stable
     */
    readonly create?: string;
    /**
     * @stability stable
     */
    readonly delete?: string;
    /**
     * @stability stable
     */
    readonly update?: string;
}
/**
 * @stability stable
 */
export declare class SqlDatabaseInstance extends cdktf.TerraformResource {
    /**
     * @stability stable
     */
    constructor(scope: Construct, id: string, config: SqlDatabaseInstanceConfig);
    /**
     * @stability stable
     */
    get connectionName(): string;
    private _databaseVersion?;
    /**
     * @stability stable
     */
    get databaseVersion(): string;
    /**
     * @stability stable
     */
    set databaseVersion(value: string);
    /**
     * @stability stable
     */
    resetDatabaseVersion(): void;
    /**
     * @stability stable
     */
    get databaseVersionInput(): string | undefined;
    private _deletionProtection?;
    /**
     * @stability stable
     */
    get deletionProtection(): boolean;
    /**
     * @stability stable
     */
    set deletionProtection(value: boolean);
    /**
     * @stability stable
     */
    resetDeletionProtection(): void;
    /**
     * @stability stable
     */
    get deletionProtectionInput(): boolean | undefined;
    /**
     * @stability stable
     */
    get firstIpAddress(): string;
    /**
     * @stability stable
     */
    get id(): string;
    /**
     * @stability stable
     */
    ipAddress(index: string): SqlDatabaseInstanceIpAddress;
    private _masterInstanceName?;
    /**
     * @stability stable
     */
    get masterInstanceName(): string;
    /**
     * @stability stable
     */
    set masterInstanceName(value: string);
    /**
     * @stability stable
     */
    resetMasterInstanceName(): void;
    /**
     * @stability stable
     */
    get masterInstanceNameInput(): string | undefined;
    private _name?;
    /**
     * @stability stable
     */
    get name(): string;
    /**
     * @stability stable
     */
    set name(value: string);
    /**
     * @stability stable
     */
    resetName(): void;
    /**
     * @stability stable
     */
    get nameInput(): string | undefined;
    /**
     * @stability stable
     */
    get privateIpAddress(): string;
    private _project?;
    /**
     * @stability stable
     */
    get project(): string;
    /**
     * @stability stable
     */
    set project(value: string);
    /**
     * @stability stable
     */
    resetProject(): void;
    /**
     * @stability stable
     */
    get projectInput(): string | undefined;
    /**
     * @stability stable
     */
    get publicIpAddress(): string;
    private _region?;
    /**
     * @stability stable
     */
    get region(): string;
    /**
     * @stability stable
     */
    set region(value: string);
    /**
     * @stability stable
     */
    resetRegion(): void;
    /**
     * @stability stable
     */
    get regionInput(): string | undefined;
    private _rootPassword?;
    /**
     * @stability stable
     */
    get rootPassword(): string;
    /**
     * @stability stable
     */
    set rootPassword(value: string);
    /**
     * @stability stable
     */
    resetRootPassword(): void;
    /**
     * @stability stable
     */
    get rootPasswordInput(): string | undefined;
    /**
     * @stability stable
     */
    get selfLink(): string;
    /**
     * @stability stable
     */
    serverCaCert(index: string): SqlDatabaseInstanceServerCaCert;
    /**
     * @stability stable
     */
    get serviceAccountEmailAddress(): string;
    private _replicaConfiguration?;
    /**
     * @stability stable
     */
    get replicaConfiguration(): SqlDatabaseInstanceReplicaConfiguration[];
    /**
     * @stability stable
     */
    set replicaConfiguration(value: SqlDatabaseInstanceReplicaConfiguration[]);
    /**
     * @stability stable
     */
    resetReplicaConfiguration(): void;
    /**
     * @stability stable
     */
    get replicaConfigurationInput(): SqlDatabaseInstanceReplicaConfiguration[] | undefined;
    private _settings;
    /**
     * @stability stable
     */
    get settings(): SqlDatabaseInstanceSettings[];
    /**
     * @stability stable
     */
    set settings(value: SqlDatabaseInstanceSettings[]);
    /**
     * @stability stable
     */
    get settingsInput(): SqlDatabaseInstanceSettings[];
    private _timeouts?;
    /**
     * @stability stable
     */
    get timeouts(): SqlDatabaseInstanceTimeouts;
    /**
     * @stability stable
     */
    set timeouts(value: SqlDatabaseInstanceTimeouts);
    /**
     * @stability stable
     */
    resetTimeouts(): void;
    /**
     * @stability stable
     */
    get timeoutsInput(): SqlDatabaseInstanceTimeouts | undefined;
    /**
     * @stability stable
     */
    protected synthesizeAttributes(): {
        [name: string]: any;
    };
}
