import { Construct } from 'constructs';
import * as cdktf from 'cdktf';
/**
 * @stability stable
 */
export interface SqlDatabaseConfig extends cdktf.TerraformMetaArguments {
    /**
     * The charset value.
     *
     * See MySQL's
     * [Supported Character Sets and Collations](https://dev.mysql.com/doc/refman/5.7/en/charset-charsets.html)
     * and Postgres' [Character Set Support](https://www.postgresql.org/docs/9.6/static/multibyte.html)
     * for more details and supported values. Postgres databases only support
     * a value of 'UTF8' at creation time.
     *
     * @stability stable
     */
    readonly charset?: string;
    /**
     * The collation value.
     *
     * See MySQL's
     * [Supported Character Sets and Collations](https://dev.mysql.com/doc/refman/5.7/en/charset-charsets.html)
     * and Postgres' [Collation Support](https://www.postgresql.org/docs/9.6/static/collation.html)
     * for more details and supported values. Postgres databases only support
     * a value of 'en_US.UTF8' at creation time.
     *
     * @stability stable
     */
    readonly collation?: string;
    /**
     * The name of the Cloud SQL instance.
     *
     * This does not include the project
     * ID.
     *
     * @stability stable
     */
    readonly instance: string;
    /**
     * The name of the database in the Cloud SQL instance.
     *
     * This does not include the project ID or instance name.
     *
     * @stability stable
     */
    readonly name: string;
    /**
     * @stability stable
     */
    readonly project?: string;
    /**
     * timeouts block.
     *
     * @stability stable
     */
    readonly timeouts?: SqlDatabaseTimeouts;
}
/**
 * @stability stable
 */
export interface SqlDatabaseTimeouts {
    /**
     * @stability stable
     */
    readonly create?: string;
    /**
     * @stability stable
     */
    readonly delete?: string;
    /**
     * @stability stable
     */
    readonly update?: string;
}
/**
 * @stability stable
 */
export declare class SqlDatabase extends cdktf.TerraformResource {
    /**
     * @stability stable
     */
    constructor(scope: Construct, id: string, config: SqlDatabaseConfig);
    private _charset?;
    /**
     * @stability stable
     */
    get charset(): string;
    /**
     * @stability stable
     */
    set charset(value: string);
    /**
     * @stability stable
     */
    resetCharset(): void;
    /**
     * @stability stable
     */
    get charsetInput(): string | undefined;
    private _collation?;
    /**
     * @stability stable
     */
    get collation(): string;
    /**
     * @stability stable
     */
    set collation(value: string);
    /**
     * @stability stable
     */
    resetCollation(): void;
    /**
     * @stability stable
     */
    get collationInput(): string | undefined;
    /**
     * @stability stable
     */
    get id(): string;
    private _instance;
    /**
     * @stability stable
     */
    get instance(): string;
    /**
     * @stability stable
     */
    set instance(value: string);
    /**
     * @stability stable
     */
    get instanceInput(): string;
    private _name;
    /**
     * @stability stable
     */
    get name(): string;
    /**
     * @stability stable
     */
    set name(value: string);
    /**
     * @stability stable
     */
    get nameInput(): string;
    private _project?;
    /**
     * @stability stable
     */
    get project(): string;
    /**
     * @stability stable
     */
    set project(value: string);
    /**
     * @stability stable
     */
    resetProject(): void;
    /**
     * @stability stable
     */
    get projectInput(): string | undefined;
    /**
     * @stability stable
     */
    get selfLink(): string;
    private _timeouts?;
    /**
     * @stability stable
     */
    get timeouts(): SqlDatabaseTimeouts;
    /**
     * @stability stable
     */
    set timeouts(value: SqlDatabaseTimeouts);
    /**
     * @stability stable
     */
    resetTimeouts(): void;
    /**
     * @stability stable
     */
    get timeoutsInput(): SqlDatabaseTimeouts | undefined;
    /**
     * @stability stable
     */
    protected synthesizeAttributes(): {
        [name: string]: any;
    };
}
