import { Construct } from 'constructs';
import * as cdktf from 'cdktf';
/**
 * @stability stable
 */
export interface StorageBucketAccessControlConfig extends cdktf.TerraformMetaArguments {
    /**
     * The name of the bucket.
     *
     * @stability stable
     */
    readonly bucket: string;
    /**
     * The entity holding the permission, in one of the following forms: user-userId user-email group-groupId group-email domain-domain project-team-projectId allUsers allAuthenticatedUsers Examples: The user liz@example.com would be user-liz@example.com. The group example@googlegroups.com would be group-example@googlegroups.com. To refer to all members of the Google Apps for Business domain example.com, the entity would be domain-example.com.
     *
     * @stability stable
     */
    readonly entity: string;
    /**
     * The access permission for the entity.
     *
     * Possible values: ["OWNER", "READER", "WRITER"]
     *
     * @stability stable
     */
    readonly role?: string;
    /**
     * timeouts block.
     *
     * @stability stable
     */
    readonly timeouts?: StorageBucketAccessControlTimeouts;
}
/**
 * @stability stable
 */
export interface StorageBucketAccessControlTimeouts {
    /**
     * @stability stable
     */
    readonly create?: string;
    /**
     * @stability stable
     */
    readonly delete?: string;
    /**
     * @stability stable
     */
    readonly update?: string;
}
/**
 * @stability stable
 */
export declare class StorageBucketAccessControl extends cdktf.TerraformResource {
    /**
     * @stability stable
     */
    constructor(scope: Construct, id: string, config: StorageBucketAccessControlConfig);
    private _bucket;
    /**
     * @stability stable
     */
    get bucket(): string;
    /**
     * @stability stable
     */
    set bucket(value: string);
    /**
     * @stability stable
     */
    get bucketInput(): string;
    /**
     * @stability stable
     */
    get domain(): string;
    /**
     * @stability stable
     */
    get email(): string;
    private _entity;
    /**
     * @stability stable
     */
    get entity(): string;
    /**
     * @stability stable
     */
    set entity(value: string);
    /**
     * @stability stable
     */
    get entityInput(): string;
    /**
     * @stability stable
     */
    get id(): string;
    private _role?;
    /**
     * @stability stable
     */
    get role(): string;
    /**
     * @stability stable
     */
    set role(value: string);
    /**
     * @stability stable
     */
    resetRole(): void;
    /**
     * @stability stable
     */
    get roleInput(): string | undefined;
    private _timeouts?;
    /**
     * @stability stable
     */
    get timeouts(): StorageBucketAccessControlTimeouts;
    /**
     * @stability stable
     */
    set timeouts(value: StorageBucketAccessControlTimeouts);
    /**
     * @stability stable
     */
    resetTimeouts(): void;
    /**
     * @stability stable
     */
    get timeoutsInput(): StorageBucketAccessControlTimeouts | undefined;
    /**
     * @stability stable
     */
    protected synthesizeAttributes(): {
        [name: string]: any;
    };
}
