import { Construct } from 'constructs';
import * as cdktf from 'cdktf';
/**
 * @stability stable
 */
export interface StorageBucketConfig extends cdktf.TerraformMetaArguments {
    /**
     * Enables Bucket Policy Only access to a bucket.
     *
     * @stability stable
     */
    readonly bucketPolicyOnly?: boolean;
    /**
     * @stability stable
     */
    readonly defaultEventBasedHold?: boolean;
    /**
     * When deleting a bucket, this boolean option will delete all contained objects.
     *
     * If you try to delete a bucket that contains objects, Terraform will fail that run.
     *
     * @stability stable
     */
    readonly forceDestroy?: boolean;
    /**
     * A set of key/value label pairs to assign to the bucket.
     *
     * @stability stable
     */
    readonly labels?: {
        [key: string]: string;
    };
    /**
     * The Google Cloud Storage location.
     *
     * @stability stable
     */
    readonly location?: string;
    /**
     * The name of the bucket.
     *
     * @stability stable
     */
    readonly name: string;
    /**
     * The ID of the project in which the resource belongs.
     *
     * If it is not provided, the provider project is used.
     *
     * @stability stable
     */
    readonly project?: string;
    /**
     * Enables Requester Pays on a storage bucket.
     *
     * @stability stable
     */
    readonly requesterPays?: boolean;
    /**
     * The Storage Class of the new bucket.
     *
     * Supported values include: STANDARD, MULTI_REGIONAL, REGIONAL, NEARLINE, COLDLINE, ARCHIVE.
     *
     * @stability stable
     */
    readonly storageClass?: string;
    /**
     * Enables uniform bucket-level access on a bucket.
     *
     * @stability stable
     */
    readonly uniformBucketLevelAccess?: boolean;
    /**
     * cors block.
     *
     * @stability stable
     */
    readonly cors?: StorageBucketCors[];
    /**
     * encryption block.
     *
     * @stability stable
     */
    readonly encryption?: StorageBucketEncryption[];
    /**
     * lifecycle_rule block.
     *
     * @stability stable
     */
    readonly lifecycleRule?: StorageBucketLifecycleRule[];
    /**
     * logging block.
     *
     * @stability stable
     */
    readonly logging?: StorageBucketLogging[];
    /**
     * retention_policy block.
     *
     * @stability stable
     */
    readonly retentionPolicy?: StorageBucketRetentionPolicy[];
    /**
     * versioning block.
     *
     * @stability stable
     */
    readonly versioning?: StorageBucketVersioning[];
    /**
     * website block.
     *
     * @stability stable
     */
    readonly website?: StorageBucketWebsite[];
}
/**
 * @stability stable
 */
export interface StorageBucketCors {
    /**
     * The value, in seconds, to return in the Access-Control-Max-Age header used in preflight responses.
     *
     * @stability stable
     */
    readonly maxAgeSeconds?: number;
    /**
     * The list of HTTP methods on which to include CORS response headers, (GET, OPTIONS, POST, etc) Note: "*" is permitted in the list of methods, and means "any method".
     *
     * @stability stable
     */
    readonly method?: string[];
    /**
     * The list of Origins eligible to receive CORS response headers.
     *
     * Note: "*" is permitted in the list of origins, and means "any Origin".
     *
     * @stability stable
     */
    readonly origin?: string[];
    /**
     * The list of HTTP headers other than the simple response headers to give permission for the user-agent to share across domains.
     *
     * @stability stable
     */
    readonly responseHeader?: string[];
}
/**
 * @stability stable
 */
export interface StorageBucketEncryption {
    /**
     * A Cloud KMS key that will be used to encrypt objects inserted into this bucket, if no encryption method is specified.
     *
     * You must pay attention to whether the crypto key is available in the location that this bucket is created in. See the docs for more details.
     *
     * @stability stable
     */
    readonly defaultKmsKeyName: string;
}
/**
 * @stability stable
 */
export interface StorageBucketLifecycleRuleAction {
    /**
     * The target Storage Class of objects affected by this Lifecycle Rule.
     *
     * Supported values include: MULTI_REGIONAL, REGIONAL, NEARLINE, COLDLINE, ARCHIVE.
     *
     * @stability stable
     */
    readonly storageClass?: string;
    /**
     * The type of the action of this Lifecycle Rule.
     *
     * Supported values include: Delete and SetStorageClass.
     *
     * @stability stable
     */
    readonly type: string;
}
/**
 * @stability stable
 */
export interface StorageBucketLifecycleRuleCondition {
    /**
     * Minimum age of an object in days to satisfy this condition.
     *
     * @stability stable
     */
    readonly age?: number;
    /**
     * Creation date of an object in RFC 3339 (e.g. 2017-06-13) to satisfy this condition.
     *
     * @stability stable
     */
    readonly createdBefore?: string;
    /**
     * Creation date of an object in RFC 3339 (e.g. 2017-06-13) to satisfy this condition.
     *
     * @stability stable
     */
    readonly customTimeBefore?: string;
    /**
     * Number of days elapsed since the user-specified timestamp set on an object.
     *
     * @stability stable
     */
    readonly daysSinceCustomTime?: number;
    /**
     * Number of days elapsed since the noncurrent timestamp of an object.
     *
     * This
     * 				condition is relevant only for versioned objects.
     *
     * @stability stable
     */
    readonly daysSinceNoncurrentTime?: number;
    /**
     * Storage Class of objects to satisfy this condition.
     *
     * Supported values include: MULTI_REGIONAL, REGIONAL, NEARLINE, COLDLINE, ARCHIVE, STANDARD, DURABLE_REDUCED_AVAILABILITY.
     *
     * @stability stable
     */
    readonly matchesStorageClass?: string[];
    /**
     * Creation date of an object in RFC 3339 (e.g. 2017-06-13) to satisfy this condition.
     *
     * @stability stable
     */
    readonly noncurrentTimeBefore?: string;
    /**
     * Relevant only for versioned objects.
     *
     * The number of newer versions of an object to satisfy this condition.
     *
     * @stability stable
     */
    readonly numNewerVersions?: number;
    /**
     * Match to live and/or archived objects.
     *
     * Unversioned buckets have only live objects. Supported values include: "LIVE", "ARCHIVED", "ANY".
     *
     * @stability stable
     */
    readonly withState?: string;
}
/**
 * @stability stable
 */
export interface StorageBucketLifecycleRule {
    /**
     * action block.
     *
     * @stability stable
     */
    readonly action: StorageBucketLifecycleRuleAction[];
    /**
     * condition block.
     *
     * @stability stable
     */
    readonly condition: StorageBucketLifecycleRuleCondition[];
}
/**
 * @stability stable
 */
export interface StorageBucketLogging {
    /**
     * The bucket that will receive log objects.
     *
     * @stability stable
     */
    readonly logBucket: string;
    /**
     * The object prefix for log objects.
     *
     * If it's not provided, by default Google Cloud Storage sets this to this bucket's name.
     *
     * @stability stable
     */
    readonly logObjectPrefix?: string;
}
/**
 * @stability stable
 */
export interface StorageBucketRetentionPolicy {
    /**
     * If set to true, the bucket will be locked and permanently restrict edits to the bucket's retention policy.
     *
     * Caution: Locking a bucket is an irreversible action.
     *
     * @stability stable
     */
    readonly isLocked?: boolean;
    /**
     * The period of time, in seconds, that objects in the bucket must be retained and cannot be deleted, overwritten, or archived.
     *
     * The value must be less than 3,155,760,000 seconds.
     *
     * @stability stable
     */
    readonly retentionPeriod: number;
}
/**
 * @stability stable
 */
export interface StorageBucketVersioning {
    /**
     * While set to true, versioning is fully enabled for this bucket.
     *
     * @stability stable
     */
    readonly enabled: boolean;
}
/**
 * @stability stable
 */
export interface StorageBucketWebsite {
    /**
     * Behaves as the bucket's directory index where missing objects are treated as potential directories.
     *
     * @stability stable
     */
    readonly mainPageSuffix?: string;
    /**
     * The custom object to return when a requested resource is not found.
     *
     * @stability stable
     */
    readonly notFoundPage?: string;
}
/**
 * @stability stable
 */
export declare class StorageBucket extends cdktf.TerraformResource {
    /**
     * @stability stable
     */
    constructor(scope: Construct, id: string, config: StorageBucketConfig);
    private _bucketPolicyOnly?;
    /**
     * @stability stable
     */
    get bucketPolicyOnly(): boolean;
    /**
     * @stability stable
     */
    set bucketPolicyOnly(value: boolean);
    /**
     * @stability stable
     */
    resetBucketPolicyOnly(): void;
    /**
     * @stability stable
     */
    get bucketPolicyOnlyInput(): boolean | undefined;
    private _defaultEventBasedHold?;
    /**
     * @stability stable
     */
    get defaultEventBasedHold(): boolean;
    /**
     * @stability stable
     */
    set defaultEventBasedHold(value: boolean);
    /**
     * @stability stable
     */
    resetDefaultEventBasedHold(): void;
    /**
     * @stability stable
     */
    get defaultEventBasedHoldInput(): boolean | undefined;
    private _forceDestroy?;
    /**
     * @stability stable
     */
    get forceDestroy(): boolean;
    /**
     * @stability stable
     */
    set forceDestroy(value: boolean);
    /**
     * @stability stable
     */
    resetForceDestroy(): void;
    /**
     * @stability stable
     */
    get forceDestroyInput(): boolean | undefined;
    /**
     * @stability stable
     */
    get id(): string;
    private _labels?;
    /**
     * @stability stable
     */
    get labels(): {
        [key: string]: string;
    };
    /**
     * @stability stable
     */
    set labels(value: {
        [key: string]: string;
    });
    /**
     * @stability stable
     */
    resetLabels(): void;
    /**
     * @stability stable
     */
    get labelsInput(): {
        [key: string]: string;
    } | undefined;
    private _location?;
    /**
     * @stability stable
     */
    get location(): string;
    /**
     * @stability stable
     */
    set location(value: string);
    /**
     * @stability stable
     */
    resetLocation(): void;
    /**
     * @stability stable
     */
    get locationInput(): string | undefined;
    private _name;
    /**
     * @stability stable
     */
    get name(): string;
    /**
     * @stability stable
     */
    set name(value: string);
    /**
     * @stability stable
     */
    get nameInput(): string;
    private _project?;
    /**
     * @stability stable
     */
    get project(): string;
    /**
     * @stability stable
     */
    set project(value: string);
    /**
     * @stability stable
     */
    resetProject(): void;
    /**
     * @stability stable
     */
    get projectInput(): string | undefined;
    private _requesterPays?;
    /**
     * @stability stable
     */
    get requesterPays(): boolean;
    /**
     * @stability stable
     */
    set requesterPays(value: boolean);
    /**
     * @stability stable
     */
    resetRequesterPays(): void;
    /**
     * @stability stable
     */
    get requesterPaysInput(): boolean | undefined;
    /**
     * @stability stable
     */
    get selfLink(): string;
    private _storageClass?;
    /**
     * @stability stable
     */
    get storageClass(): string;
    /**
     * @stability stable
     */
    set storageClass(value: string);
    /**
     * @stability stable
     */
    resetStorageClass(): void;
    /**
     * @stability stable
     */
    get storageClassInput(): string | undefined;
    private _uniformBucketLevelAccess?;
    /**
     * @stability stable
     */
    get uniformBucketLevelAccess(): boolean;
    /**
     * @stability stable
     */
    set uniformBucketLevelAccess(value: boolean);
    /**
     * @stability stable
     */
    resetUniformBucketLevelAccess(): void;
    /**
     * @stability stable
     */
    get uniformBucketLevelAccessInput(): boolean | undefined;
    /**
     * @stability stable
     */
    get url(): string;
    private _cors?;
    /**
     * @stability stable
     */
    get cors(): StorageBucketCors[];
    /**
     * @stability stable
     */
    set cors(value: StorageBucketCors[]);
    /**
     * @stability stable
     */
    resetCors(): void;
    /**
     * @stability stable
     */
    get corsInput(): StorageBucketCors[] | undefined;
    private _encryption?;
    /**
     * @stability stable
     */
    get encryption(): StorageBucketEncryption[];
    /**
     * @stability stable
     */
    set encryption(value: StorageBucketEncryption[]);
    /**
     * @stability stable
     */
    resetEncryption(): void;
    /**
     * @stability stable
     */
    get encryptionInput(): StorageBucketEncryption[] | undefined;
    private _lifecycleRule?;
    /**
     * @stability stable
     */
    get lifecycleRule(): StorageBucketLifecycleRule[];
    /**
     * @stability stable
     */
    set lifecycleRule(value: StorageBucketLifecycleRule[]);
    /**
     * @stability stable
     */
    resetLifecycleRule(): void;
    /**
     * @stability stable
     */
    get lifecycleRuleInput(): StorageBucketLifecycleRule[] | undefined;
    private _logging?;
    /**
     * @stability stable
     */
    get logging(): StorageBucketLogging[];
    /**
     * @stability stable
     */
    set logging(value: StorageBucketLogging[]);
    /**
     * @stability stable
     */
    resetLogging(): void;
    /**
     * @stability stable
     */
    get loggingInput(): StorageBucketLogging[] | undefined;
    private _retentionPolicy?;
    /**
     * @stability stable
     */
    get retentionPolicy(): StorageBucketRetentionPolicy[];
    /**
     * @stability stable
     */
    set retentionPolicy(value: StorageBucketRetentionPolicy[]);
    /**
     * @stability stable
     */
    resetRetentionPolicy(): void;
    /**
     * @stability stable
     */
    get retentionPolicyInput(): StorageBucketRetentionPolicy[] | undefined;
    private _versioning?;
    /**
     * @stability stable
     */
    get versioning(): StorageBucketVersioning[];
    /**
     * @stability stable
     */
    set versioning(value: StorageBucketVersioning[]);
    /**
     * @stability stable
     */
    resetVersioning(): void;
    /**
     * @stability stable
     */
    get versioningInput(): StorageBucketVersioning[] | undefined;
    private _website?;
    /**
     * @stability stable
     */
    get website(): StorageBucketWebsite[];
    /**
     * @stability stable
     */
    set website(value: StorageBucketWebsite[]);
    /**
     * @stability stable
     */
    resetWebsite(): void;
    /**
     * @stability stable
     */
    get websiteInput(): StorageBucketWebsite[] | undefined;
    /**
     * @stability stable
     */
    protected synthesizeAttributes(): {
        [name: string]: any;
    };
}
