import { Construct } from 'constructs';
import * as cdktf from 'cdktf';
/**
 * @stability stable
 */
export interface StorageNotificationConfig extends cdktf.TerraformMetaArguments {
    /**
     * The name of the bucket.
     *
     * @stability stable
     */
    readonly bucket: string;
    /**
     * A set of key/value attribute pairs to attach to each Cloud Pub/Sub message published for this notification subscription.
     *
     * @stability stable
     */
    readonly customAttributes?: {
        [key: string]: string;
    };
    /**
     * List of event type filters for this notification config.
     *
     * If not specified, Cloud Storage will send notifications for all event types. The valid types are: "OBJECT_FINALIZE", "OBJECT_METADATA_UPDATE", "OBJECT_DELETE", "OBJECT_ARCHIVE"
     *
     * @stability stable
     */
    readonly eventTypes?: string[];
    /**
     * Specifies a prefix path filter for this notification config.
     *
     * Cloud Storage will only send notifications for objects in this bucket whose names begin with the specified prefix.
     *
     * @stability stable
     */
    readonly objectNamePrefix?: string;
    /**
     * The desired content of the Payload.
     *
     * One of "JSON_API_V1" or "NONE".
     *
     * @stability stable
     */
    readonly payloadFormat: string;
    /**
     * The Cloud Pub/Sub topic to which this subscription publishes.
     *
     * Expects either the  topic name, assumed to belong to the default GCP provider project, or the project-level name,  i.e. projects/my-gcp-project/topics/my-topic or my-topic. If the project is not set in the provider, you will need to use the project-level name.
     *
     * @stability stable
     */
    readonly topic: string;
}
/**
 * @stability stable
 */
export declare class StorageNotification extends cdktf.TerraformResource {
    /**
     * @stability stable
     */
    constructor(scope: Construct, id: string, config: StorageNotificationConfig);
    private _bucket;
    /**
     * @stability stable
     */
    get bucket(): string;
    /**
     * @stability stable
     */
    set bucket(value: string);
    /**
     * @stability stable
     */
    get bucketInput(): string;
    private _customAttributes?;
    /**
     * @stability stable
     */
    get customAttributes(): {
        [key: string]: string;
    };
    /**
     * @stability stable
     */
    set customAttributes(value: {
        [key: string]: string;
    });
    /**
     * @stability stable
     */
    resetCustomAttributes(): void;
    /**
     * @stability stable
     */
    get customAttributesInput(): {
        [key: string]: string;
    } | undefined;
    private _eventTypes?;
    /**
     * @stability stable
     */
    get eventTypes(): string[];
    /**
     * @stability stable
     */
    set eventTypes(value: string[]);
    /**
     * @stability stable
     */
    resetEventTypes(): void;
    /**
     * @stability stable
     */
    get eventTypesInput(): string[] | undefined;
    /**
     * @stability stable
     */
    get id(): string;
    /**
     * @stability stable
     */
    get notificationId(): string;
    private _objectNamePrefix?;
    /**
     * @stability stable
     */
    get objectNamePrefix(): string;
    /**
     * @stability stable
     */
    set objectNamePrefix(value: string);
    /**
     * @stability stable
     */
    resetObjectNamePrefix(): void;
    /**
     * @stability stable
     */
    get objectNamePrefixInput(): string | undefined;
    private _payloadFormat;
    /**
     * @stability stable
     */
    get payloadFormat(): string;
    /**
     * @stability stable
     */
    set payloadFormat(value: string);
    /**
     * @stability stable
     */
    get payloadFormatInput(): string;
    /**
     * @stability stable
     */
    get selfLink(): string;
    private _topic;
    /**
     * @stability stable
     */
    get topic(): string;
    /**
     * @stability stable
     */
    set topic(value: string);
    /**
     * @stability stable
     */
    get topicInput(): string;
    /**
     * @stability stable
     */
    protected synthesizeAttributes(): {
        [name: string]: any;
    };
}
