import { Construct } from 'constructs';
import * as cdktf from 'cdktf';
/**
 * @stability stable
 */
export interface StorageTransferJobConfig extends cdktf.TerraformMetaArguments {
    /**
     * Unique description to identify the Transfer Job.
     *
     * @stability stable
     */
    readonly description: string;
    /**
     * The project in which the resource belongs.
     *
     * If it is not provided, the provider project is used.
     *
     * @stability stable
     */
    readonly project?: string;
    /**
     * Status of the job.
     *
     * Default: ENABLED. NOTE: The effect of the new job status takes place during a subsequent job run. For example, if you change the job status from ENABLED to DISABLED, and an operation spawned by the transfer is running, the status change would not affect the current operation.
     *
     * @stability stable
     */
    readonly status?: string;
    /**
     * schedule block.
     *
     * @stability stable
     */
    readonly schedule: StorageTransferJobSchedule[];
    /**
     * transfer_spec block.
     *
     * @stability stable
     */
    readonly transferSpec: StorageTransferJobTransferSpec[];
}
/**
 * @stability stable
 */
export interface StorageTransferJobScheduleScheduleEndDate {
    /**
     * Day of month.
     *
     * Must be from 1 to 31 and valid for the year and month.
     *
     * @stability stable
     */
    readonly day: number;
    /**
     * Month of year.
     *
     * Must be from 1 to 12.
     *
     * @stability stable
     */
    readonly month: number;
    /**
     * Year of date.
     *
     * Must be from 1 to 9999.
     *
     * @stability stable
     */
    readonly year: number;
}
/**
 * @stability stable
 */
export interface StorageTransferJobScheduleScheduleStartDate {
    /**
     * Day of month.
     *
     * Must be from 1 to 31 and valid for the year and month.
     *
     * @stability stable
     */
    readonly day: number;
    /**
     * Month of year.
     *
     * Must be from 1 to 12.
     *
     * @stability stable
     */
    readonly month: number;
    /**
     * Year of date.
     *
     * Must be from 1 to 9999.
     *
     * @stability stable
     */
    readonly year: number;
}
/**
 * @stability stable
 */
export interface StorageTransferJobScheduleStartTimeOfDay {
    /**
     * Hours of day in 24 hour format.
     *
     * Should be from 0 to 23.
     *
     * @stability stable
     */
    readonly hours: number;
    /**
     * Minutes of hour of day.
     *
     * Must be from 0 to 59.
     *
     * @stability stable
     */
    readonly minutes: number;
    /**
     * Fractions of seconds in nanoseconds.
     *
     * Must be from 0 to 999,999,999.
     *
     * @stability stable
     */
    readonly nanos: number;
    /**
     * Seconds of minutes of the time.
     *
     * Must normally be from 0 to 59.
     *
     * @stability stable
     */
    readonly seconds: number;
}
/**
 * @stability stable
 */
export interface StorageTransferJobSchedule {
    /**
     * schedule_end_date block.
     *
     * @stability stable
     */
    readonly scheduleEndDate?: StorageTransferJobScheduleScheduleEndDate[];
    /**
     * schedule_start_date block.
     *
     * @stability stable
     */
    readonly scheduleStartDate: StorageTransferJobScheduleScheduleStartDate[];
    /**
     * start_time_of_day block.
     *
     * @stability stable
     */
    readonly startTimeOfDay?: StorageTransferJobScheduleStartTimeOfDay[];
}
/**
 * @stability stable
 */
export interface StorageTransferJobTransferSpecAwsS3DataSourceAwsAccessKey {
    /**
     * AWS Key ID.
     *
     * @stability stable
     */
    readonly accessKeyId: string;
    /**
     * AWS Secret Access Key.
     *
     * @stability stable
     */
    readonly secretAccessKey: string;
}
/**
 * @stability stable
 */
export interface StorageTransferJobTransferSpecAwsS3DataSource {
    /**
     * S3 Bucket name.
     *
     * @stability stable
     */
    readonly bucketName: string;
    /**
     * aws_access_key block.
     *
     * @stability stable
     */
    readonly awsAccessKey: StorageTransferJobTransferSpecAwsS3DataSourceAwsAccessKey[];
}
/**
 * @stability stable
 */
export interface StorageTransferJobTransferSpecGcsDataSink {
    /**
     * Google Cloud Storage bucket name.
     *
     * @stability stable
     */
    readonly bucketName: string;
}
/**
 * @stability stable
 */
export interface StorageTransferJobTransferSpecGcsDataSource {
    /**
     * Google Cloud Storage bucket name.
     *
     * @stability stable
     */
    readonly bucketName: string;
}
/**
 * @stability stable
 */
export interface StorageTransferJobTransferSpecHttpDataSource {
    /**
     * The URL that points to the file that stores the object list entries.
     *
     * This file must allow public access. Currently, only URLs with HTTP and HTTPS schemes are supported.
     *
     * @stability stable
     */
    readonly listUrl: string;
}
/**
 * @stability stable
 */
export interface StorageTransferJobTransferSpecObjectConditions {
    /**
     * exclude_prefixes must follow the requirements described for include_prefixes.
     *
     * @stability stable
     */
    readonly excludePrefixes?: string[];
    /**
     * If include_refixes is specified, objects that satisfy the object conditions must have names that start with one of the include_prefixes and that do not start with any of the exclude_prefixes.
     *
     * If include_prefixes is not specified, all objects except those that have names starting with one of the exclude_prefixes must satisfy the object conditions.
     *
     * @stability stable
     */
    readonly includePrefixes?: string[];
    /**
     * A duration in seconds with up to nine fractional digits, terminated by 's'.
     *
     * Example: "3.5s".
     *
     * @stability stable
     */
    readonly maxTimeElapsedSinceLastModification?: string;
    /**
     * A duration in seconds with up to nine fractional digits, terminated by 's'.
     *
     * Example: "3.5s".
     *
     * @stability stable
     */
    readonly minTimeElapsedSinceLastModification?: string;
}
/**
 * @stability stable
 */
export interface StorageTransferJobTransferSpecTransferOptions {
    /**
     * Whether objects should be deleted from the source after they are transferred to the sink.
     *
     * Note that this option and delete_objects_unique_in_sink are mutually exclusive.
     *
     * @stability stable
     */
    readonly deleteObjectsFromSourceAfterTransfer?: boolean;
    /**
     * Whether objects that exist only in the sink should be deleted.
     *
     * Note that this option and delete_objects_from_source_after_transfer are mutually exclusive.
     *
     * @stability stable
     */
    readonly deleteObjectsUniqueInSink?: boolean;
    /**
     * Whether overwriting objects that already exist in the sink is allowed.
     *
     * @stability stable
     */
    readonly overwriteObjectsAlreadyExistingInSink?: boolean;
}
/**
 * @stability stable
 */
export interface StorageTransferJobTransferSpec {
    /**
     * aws_s3_data_source block.
     *
     * @stability stable
     */
    readonly awsS3DataSource?: StorageTransferJobTransferSpecAwsS3DataSource[];
    /**
     * gcs_data_sink block.
     *
     * @stability stable
     */
    readonly gcsDataSink?: StorageTransferJobTransferSpecGcsDataSink[];
    /**
     * gcs_data_source block.
     *
     * @stability stable
     */
    readonly gcsDataSource?: StorageTransferJobTransferSpecGcsDataSource[];
    /**
     * http_data_source block.
     *
     * @stability stable
     */
    readonly httpDataSource?: StorageTransferJobTransferSpecHttpDataSource[];
    /**
     * object_conditions block.
     *
     * @stability stable
     */
    readonly objectConditions?: StorageTransferJobTransferSpecObjectConditions[];
    /**
     * transfer_options block.
     *
     * @stability stable
     */
    readonly transferOptions?: StorageTransferJobTransferSpecTransferOptions[];
}
/**
 * @stability stable
 */
export declare class StorageTransferJob extends cdktf.TerraformResource {
    /**
     * @stability stable
     */
    constructor(scope: Construct, id: string, config: StorageTransferJobConfig);
    /**
     * @stability stable
     */
    get creationTime(): string;
    /**
     * @stability stable
     */
    get deletionTime(): string;
    private _description;
    /**
     * @stability stable
     */
    get description(): string;
    /**
     * @stability stable
     */
    set description(value: string);
    /**
     * @stability stable
     */
    get descriptionInput(): string;
    /**
     * @stability stable
     */
    get id(): string;
    /**
     * @stability stable
     */
    get lastModificationTime(): string;
    /**
     * @stability stable
     */
    get name(): string;
    private _project?;
    /**
     * @stability stable
     */
    get project(): string;
    /**
     * @stability stable
     */
    set project(value: string);
    /**
     * @stability stable
     */
    resetProject(): void;
    /**
     * @stability stable
     */
    get projectInput(): string | undefined;
    private _status?;
    /**
     * @stability stable
     */
    get status(): string;
    /**
     * @stability stable
     */
    set status(value: string);
    /**
     * @stability stable
     */
    resetStatus(): void;
    /**
     * @stability stable
     */
    get statusInput(): string | undefined;
    private _schedule;
    /**
     * @stability stable
     */
    get schedule(): StorageTransferJobSchedule[];
    /**
     * @stability stable
     */
    set schedule(value: StorageTransferJobSchedule[]);
    /**
     * @stability stable
     */
    get scheduleInput(): StorageTransferJobSchedule[];
    private _transferSpec;
    /**
     * @stability stable
     */
    get transferSpec(): StorageTransferJobTransferSpec[];
    /**
     * @stability stable
     */
    set transferSpec(value: StorageTransferJobTransferSpec[]);
    /**
     * @stability stable
     */
    get transferSpecInput(): StorageTransferJobTransferSpec[];
    /**
     * @stability stable
     */
    protected synthesizeAttributes(): {
        [name: string]: any;
    };
}
