import { Construct } from 'constructs';
import * as cdktf from 'cdktf';
/**
 * @stability stable
 */
export interface TpuNodeConfig extends cdktf.TerraformMetaArguments {
    /**
     * The type of hardware accelerators associated with this node.
     *
     * @stability stable
     */
    readonly acceleratorType: string;
    /**
     * The CIDR block that the TPU node will use when selecting an IP address.
     *
     * This CIDR block must be a /29 block; the Compute Engine
     * networks API forbids a smaller block, and using a larger block would
     * be wasteful (a node can only consume one IP address).
     *
     * Errors will occur if the CIDR block has already been used for a
     * currently existing TPU node, the CIDR block conflicts with any
     * subnetworks in the user's provided network, or the provided network
     * is peered with another network that is using that CIDR block.
     *
     * @stability stable
     */
    readonly cidrBlock?: string;
    /**
     * The user-supplied description of the TPU.
     *
     * Maximum of 512 characters.
     *
     * @stability stable
     */
    readonly description?: string;
    /**
     * Resource labels to represent user provided metadata.
     *
     * @stability stable
     */
    readonly labels?: {
        [key: string]: string;
    };
    /**
     * The immutable name of the TPU.
     *
     * @stability stable
     */
    readonly name: string;
    /**
     * The name of a network to peer the TPU node to.
     *
     * It must be a
     * preexisting Compute Engine network inside of the project on which
     * this API has been activated. If none is provided, "default" will be
     * used.
     *
     * @stability stable
     */
    readonly network?: string;
    /**
     * @stability stable
     */
    readonly project?: string;
    /**
     * The version of Tensorflow running in the Node.
     *
     * @stability stable
     */
    readonly tensorflowVersion: string;
    /**
     * Whether the VPC peering for the node is set up through Service Networking API.
     *
     * The VPC Peering should be set up before provisioning the node. If this field is set,
     * cidr_block field should not be specified. If the network that you want to peer the
     * TPU Node to is a Shared VPC network, the node must be created with this this field enabled.
     *
     * @stability stable
     */
    readonly useServiceNetworking?: boolean;
    /**
     * The GCP location for the TPU.
     *
     * @stability stable
     */
    readonly zone: string;
    /**
     * scheduling_config block.
     *
     * @stability stable
     */
    readonly schedulingConfig?: TpuNodeSchedulingConfig[];
    /**
     * timeouts block.
     *
     * @stability stable
     */
    readonly timeouts?: TpuNodeTimeouts;
}
/**
 * @stability stable
 */
export declare class TpuNodeNetworkEndpoints extends cdktf.ComplexComputedList {
    /**
     * @stability stable
     */
    get ipAddress(): string;
    /**
     * @stability stable
     */
    get port(): number;
}
/**
 * @stability stable
 */
export interface TpuNodeSchedulingConfig {
    /**
     * Defines whether the TPU instance is preemptible.
     *
     * @stability stable
     */
    readonly preemptible: boolean;
}
/**
 * @stability stable
 */
export interface TpuNodeTimeouts {
    /**
     * @stability stable
     */
    readonly create?: string;
    /**
     * @stability stable
     */
    readonly delete?: string;
    /**
     * @stability stable
     */
    readonly update?: string;
}
/**
 * @stability stable
 */
export declare class TpuNode extends cdktf.TerraformResource {
    /**
     * @stability stable
     */
    constructor(scope: Construct, id: string, config: TpuNodeConfig);
    private _acceleratorType;
    /**
     * @stability stable
     */
    get acceleratorType(): string;
    /**
     * @stability stable
     */
    set acceleratorType(value: string);
    /**
     * @stability stable
     */
    get acceleratorTypeInput(): string;
    private _cidrBlock?;
    /**
     * @stability stable
     */
    get cidrBlock(): string;
    /**
     * @stability stable
     */
    set cidrBlock(value: string);
    /**
     * @stability stable
     */
    resetCidrBlock(): void;
    /**
     * @stability stable
     */
    get cidrBlockInput(): string | undefined;
    private _description?;
    /**
     * @stability stable
     */
    get description(): string;
    /**
     * @stability stable
     */
    set description(value: string);
    /**
     * @stability stable
     */
    resetDescription(): void;
    /**
     * @stability stable
     */
    get descriptionInput(): string | undefined;
    /**
     * @stability stable
     */
    get id(): string;
    private _labels?;
    /**
     * @stability stable
     */
    get labels(): {
        [key: string]: string;
    };
    /**
     * @stability stable
     */
    set labels(value: {
        [key: string]: string;
    });
    /**
     * @stability stable
     */
    resetLabels(): void;
    /**
     * @stability stable
     */
    get labelsInput(): {
        [key: string]: string;
    } | undefined;
    private _name;
    /**
     * @stability stable
     */
    get name(): string;
    /**
     * @stability stable
     */
    set name(value: string);
    /**
     * @stability stable
     */
    get nameInput(): string;
    private _network?;
    /**
     * @stability stable
     */
    get network(): string;
    /**
     * @stability stable
     */
    set network(value: string);
    /**
     * @stability stable
     */
    resetNetwork(): void;
    /**
     * @stability stable
     */
    get networkInput(): string | undefined;
    /**
     * @stability stable
     */
    networkEndpoints(index: string): TpuNodeNetworkEndpoints;
    private _project?;
    /**
     * @stability stable
     */
    get project(): string;
    /**
     * @stability stable
     */
    set project(value: string);
    /**
     * @stability stable
     */
    resetProject(): void;
    /**
     * @stability stable
     */
    get projectInput(): string | undefined;
    /**
     * @stability stable
     */
    get serviceAccount(): string;
    private _tensorflowVersion;
    /**
     * @stability stable
     */
    get tensorflowVersion(): string;
    /**
     * @stability stable
     */
    set tensorflowVersion(value: string);
    /**
     * @stability stable
     */
    get tensorflowVersionInput(): string;
    private _useServiceNetworking?;
    /**
     * @stability stable
     */
    get useServiceNetworking(): boolean;
    /**
     * @stability stable
     */
    set useServiceNetworking(value: boolean);
    /**
     * @stability stable
     */
    resetUseServiceNetworking(): void;
    /**
     * @stability stable
     */
    get useServiceNetworkingInput(): boolean | undefined;
    private _zone;
    /**
     * @stability stable
     */
    get zone(): string;
    /**
     * @stability stable
     */
    set zone(value: string);
    /**
     * @stability stable
     */
    get zoneInput(): string;
    private _schedulingConfig?;
    /**
     * @stability stable
     */
    get schedulingConfig(): TpuNodeSchedulingConfig[];
    /**
     * @stability stable
     */
    set schedulingConfig(value: TpuNodeSchedulingConfig[]);
    /**
     * @stability stable
     */
    resetSchedulingConfig(): void;
    /**
     * @stability stable
     */
    get schedulingConfigInput(): TpuNodeSchedulingConfig[] | undefined;
    private _timeouts?;
    /**
     * @stability stable
     */
    get timeouts(): TpuNodeTimeouts;
    /**
     * @stability stable
     */
    set timeouts(value: TpuNodeTimeouts);
    /**
     * @stability stable
     */
    resetTimeouts(): void;
    /**
     * @stability stable
     */
    get timeoutsInput(): TpuNodeTimeouts | undefined;
    /**
     * @stability stable
     */
    protected synthesizeAttributes(): {
        [name: string]: any;
    };
}
